<?php

   /**
    *
    * base functions
    *
    */

    # get path to wordpress core
    function ueldo_custom_sidebars_ajax_core_path() {

        # explode the content path
        $exploded = explode( 'wp-content', $_SERVER['SCRIPT_FILENAME'] );

        # path up to themes directory
        return( $exploded[0] );
    }

    # check if connection is legal
    function ueldo_check_custom_sidebars_ajax_call_correctness() {

        # is the http referer correct?
        if( strpos( $_SERVER['HTTP_REFERER'], 'widgets.php' ) === false ) return( false );

        # is the call made from current domain?
        if( strpos( $_SERVER['HTTP_REFERER'], $_SERVER['HTTP_HOST'] ) === false ) return( false );

        # return result
        return( is_user_logged_in() && current_user_can( 'manage_options' ) );
    }

    # remove inactive / removed sidebars from sidebars_widgets option
    function ueldo_clear_sidebars_widget_option_from_removed_custom_sidebars( $custom_sidebars ) {

        # array of active custom sidebars
        $active_custom_sidebars = array();

        # update array of active custom sidebars
        foreach( $custom_sidebars['sidebars'] as $custom_sidebar_id => $custom_sidebar_title ) {

            # add active custom sidebar to array
            $active_custom_sidebars[] = 'ueldo-custom-sidebar-'. esc_attr( $custom_sidebar_id );
        }

        # get sidebars widgets option data
        $sidebars_widgets = get_option( 'sidebars_widgets' );

        # walk for each sidebar
        foreach( $sidebars_widgets as $sidebar_id => $sidebar_widgets ) {

            # only custom sidebars
            if( strpos( $sidebar_id, 'ueldo-custom-sidebar-' ) !== 0 ) continue;

            # not found in array of active custom sidebars?
            if( !in_array( $sidebar_id, $active_custom_sidebars, true ) ) {

                # remove from sidebars widgets array
                unset( $sidebars_widgets[esc_attr( $sidebar_id )] );
            }
        }

        # update sidebars widgets option
        update_option( 'sidebars_widgets', $sidebars_widgets );

        # remove temporary variables
        unset( $active_custom_sidebars, $custom_sidebars, $custom_sidebar_id, $custom_sidebar_title, $sidebars_widgets, $sidebar_id, $sidebar_widgets );
    }

   /**
    *
    * configurations
    *
    */

    # include wordpress core
    define( 'WP_USE_THEMES', false );
    require( ueldo_custom_sidebars_ajax_core_path() .'wp-load.php' );

    # check if user is logged-in
    if( ueldo_check_custom_sidebars_ajax_call_correctness() == false ) exit( esc_html( __( 'Permission denied.', 'ueldo' ) ) );

    # if there is no data
    if( !isset( $_POST ) || !isset( $_POST['sidebars'] ) || !is_array( $_POST['sidebars'] ) ) exit;

    # update option
    update_option( 'ueldo_custom_sidebars', $_POST['sidebars'] );

    # remove inactive / removed sidebars from sidebars_widgets option
    ueldo_clear_sidebars_widget_option_from_removed_custom_sidebars( $_POST['sidebars'] );

   /**
    *
    * end of file
    *
    */

?>