<?php

   /**
    *
    * register custom sidebars
    *
    */

    add_action( 'widgets_init', 'ueldo_sidebars_register_custom_sidebars' );
    function ueldo_sidebars_register_custom_sidebars() {

        # get custom sidebars option
        $sidebars = get_option( 'ueldo_custom_sidebars' );

        # if custom sidebars exists
        if( !empty( $sidebars ) && $sidebars != false && isset( $sidebars['sidebars'] ) ) {

            # each custom sidebar loop
            foreach( $sidebars['sidebars'] as $sidebarID => $sidebar_name ) {

                # register each custom sidebar
                register_sidebar( array(
                    'name' => esc_html( stripslashes( $sidebar_name ) ),
                    'id' => 'ueldo-custom-sidebar-'. $sidebarID,
                    'description' => esc_html( __( 'Custom sidebar: ', 'ueldo' ) ) . esc_html( stripslashes( $sidebar_name ) ),
                    'before_title' => '<h4>',
                    'after_title' => '</h4>',
                    'before_widget' => '<div class="widget">',
                    'after_widget' => '</div>'
                ));
            }
        }

        # remove temporary variables
        unset( $sidebars );
    }

   /**
    *
    * add custom sidebars manager to
    * widgets admin page
    *
    */

    add_action( 'widgets_admin_page', 'ueldo_sidebars_custom_sidebars_manager' );
    function ueldo_sidebars_custom_sidebars_manager() {

        # enqueue script
        wp_enqueue_script( 'ueldo-sidebars-javascript', ueldo_plugin_get_url() .'_parts/_custom-sidebars/custom-sidebars.js', array( 'jquery' ), null, true );

        # plugin javascript functions translation
        wp_localize_script( 'ueldo-sidebars-javascript', 'ueldo_sidebars_l10n', array(
            'custom_sidebars_manager' => esc_html( __( 'Custom Sidebars Manager', 'ueldo' ) ),
            'custom_sidebar_name' => esc_html( __( 'Custom sidebar name...', 'ueldo' ) ),
            'remove' => esc_html( __( 'Remove', 'ueldo' ) ),
            'not_found_any_custom_sidebars' => esc_html( __( 'Not found any custom sidebars', 'ueldo' ) ),
            'plugin_dir_url' => esc_url( ueldo_plugin_get_url() .'_parts/_custom-sidebars/' )
        ));

        # enqueue widget stylesheet
	       wp_enqueue_style( 'ueldo-sidebars-stylesheet', ueldo_plugin_get_url() .'_parts/_custom-sidebars/custom-sidebars.css', false, null );

        ?>
        <div id="ueldo-custom-sidebars-manager-popup">

            <div class="ueldo-custom-sidebars-manager-popup-background">
            </div>

            <div class="ueldo-custom-sidebars-manager-popup-content">

                <?php

                    # get option
                    $sidebars = get_option( 'ueldo_custom_sidebars' );

                    # do we have custom sidebars?
                    if( $sidebars == false || !is_array( $sidebars ) ) {

                        # default values
                        $sidebars = array(
                            'next-custom-sidebar-id' => '1',
                            'sidebars' => array()
                        );
                    }

                ?>

                <div class="ueldo-custom-sidebars-manager-popup-close"><i class="fa fa-times"></i></div>

                <h2><?php echo esc_html( __( 'Ueldo: Custom Sidebars Manager', 'ueldo' ) ); ?></h2>
                <table class="ueldo-custom-sidebars-manager-popup-content-table" data-next-custom-sidebar-id="<?php echo esc_attr( $sidebars['next-custom-sidebar-id'] ); ?>">

                    <tr class="ueldo-custom-sidebars-manager-popup-content-table-head">

                        <td><?php echo esc_html( __( 'Title', 'ueldo' ) ); ?></td>
                        <td class="ueldo-custom-sidebars-manager-popup-content-table-actions"><?php echo esc_html( __( 'Actions', 'ueldo' ) ); ?></td>

                    </tr>

                    <?php

                        # do we have custom sidebars?
                        if( isset( $sidebars['sidebars'] ) && count( $sidebars['sidebars'] ) > 0 ) {

                            # show each sidebar
                            foreach( $sidebars['sidebars'] as $sidebarID => $sidebar_name ) {

                                ?>
                                <tr data-custom-sidebar-id="<?php echo esc_attr( $sidebarID ); ?>">

                                    <td><input type="text" placeholder="<?php echo esc_html( __( 'Custom sidebar name...', 'ueldo' ) ); ?>" value="<?php echo esc_attr( stripslashes( $sidebar_name ) ); ?>" /></td>
                                    <td class="ueldo-custom-sidebars-manager-popup-content-table-actions"><a href="#" class="ueldo-remove-custom-sidebar"><?php echo esc_html( __( 'Remove', 'ueldo' ) ); ?></a></td>

                                </tr>
                                <?php
                            }
                        }

                        # default empty message
                        else {

                            ?>
                            <tr data-custom-sidebar-id="empty">

                                <td colspan="2"><?php echo esc_html( __( 'Not found any custom sidebars', 'ueldo' ) ); ?></td>

                            </tr>
                            <?php
                        }

                    ?>

                </table>

                <div class="ueldo-custom-sidebars-manager-popup-content-buttons">

                    <input type="button" class="button button-primary ueldo-save-custom-sidebars" value="<?php echo esc_html( __( 'Save changes', 'ueldo' ) ); ?>" />
                    <input type="button" class="button ueldo-add-custom-sidebar-button" value="<?php echo esc_html( __( 'Add new custom sidebar', 'ueldo' ) ); ?>" />

                </div>

            </div>

        </div>
        <?php
    }

   /**
    *
    * end of code.
    *
    */

?>