<?php

   /**
    *
    * base functions
    *
    */

    # get path to wordpress core
    function ueldo_dashboard_ajax_core_path() {

        # explode the content path
        $exploded = explode( 'wp-content', $_SERVER['SCRIPT_FILENAME'] );

        # path up to themes directory
        return( $exploded[0] );
    }

    # check if connection is legal
    function ueldo_check_dashboard_ajax_call_correctness() {

        # is the http referer correct?
        if( strpos( $_SERVER['HTTP_REFERER'], '?page=ueldo_dashboard' ) === false ) return( false );

        # is the call made from current domain?
        if( strpos( $_SERVER['HTTP_REFERER'], $_SERVER['HTTP_HOST'] ) === false ) return( false );

        # return result
        return( is_user_logged_in() && current_user_can( 'manage_options' ) );
    }

   /**
    *
    * configurations
    *
    */

    # include wordpress core
    define( 'WP_USE_THEMES', false );
    require( ueldo_dashboard_ajax_core_path() .'wp-load.php' );

    # check if user is logged-in
    if( ueldo_check_dashboard_ajax_call_correctness() == false ) exit( esc_html( __( 'Permission denied.', 'ueldo' ) ) );

    # there's no action set?
    if( !isset( $_POST ) || !isset( $_POST['action'] ) ) exit( esc_html( __( 'Incorrect input data.', 'ueldo' ) ) );

   /**
    *
    * switch by action
    *
    */

    switch( $_POST['action'] ) {

        # check theme version
        case 'check_version':

            # do we have current version set?
            if( !isset( $_POST['current_version'] ) ) exit( esc_html( __( 'Incorrect input data.', 'ueldo' ) ) );

            # check the latest theme version
            $latest_version = ueldo_check_latest_theme_version();

            # is correct response?
            if( !is_array( $latest_version ) || !isset( $latest_version['version'] ) || !isset( $latest_version['checked'] ) ) exit( $latest_version );

            # compare
            exit( $_POST['current_version'] == $latest_version['version'] ? 'OK' : 'UPDATE_AVAILABLE/'. esc_attr( $latest_version['version'] ) );

        break;
    }

   /**
    *
    * end of file.
    *
    */

?>