<?php

   /**
    *
    * register icons uploader page
    *
    */

    add_action( 'admin_menu', 'ueldo_plugin_add_dashboard_page' );
    function ueldo_plugin_add_dashboard_page() {

        # add menu page
        $ueldo_dashboard_page = add_menu_page(
            esc_html( __( 'Ueldo', 'ueldo' ) ),
            esc_html( __( 'Ueldo', 'ueldo' ) ),
            'manage_options',
            'ueldo_dashboard',
            'ueldo_show_dashboard_page'
        );

        # add submenu page for dashboard
        add_submenu_page(
            'ueldo_dashboard',
            esc_html( __( 'Dashboard', 'ueldo' ) ),
            esc_html( __( 'Dashboard', 'ueldo' ) ),
            'manage_options',
            'ueldo_dashboard'
        );

        # add submenu page for theme options
        $ueldo_theme_options_page = add_submenu_page(
            'ueldo_dashboard',
            esc_html( __( 'Theme Options', 'ueldo' ) ),
            esc_html( __( 'Theme Options', 'ueldo' ) ),
            'manage_options',
            'ueldo_admin',
            'ueldo_show_admin_page'
        );

        # load scripts and styles for dashboard page
        add_action( 'load-'. $ueldo_dashboard_page, 'ueldo_load_scripts_for_dashboard_page' );

        # load scripts and styles for theme options page
        add_action( 'load-'. $ueldo_theme_options_page, 'ueldo_load_scripts_for_theme_options_page' );
    }

   /**
    *
    * add action - enqueue scripts and styles for icons uploader page
    *
    */

    function ueldo_load_scripts_for_dashboard_page() {

        # add action for "admin_enqueue_scripts" hook
        add_action( 'admin_enqueue_scripts', 'ueldo_scripts_and_styles_for_dashboard_page' );
    }

   /**
    *
    * all scripts and styles needed by icons uploader page
    *
    */

    function ueldo_scripts_and_styles_for_dashboard_page() {

        # enqueue dashboard script
        wp_enqueue_script( 'ueldo-plugin-dashboard-javascript-functions', ueldo_plugin_get_url() .'_parts/_dashboard/dashboard.js', array( 'jquery' ), null, true );

        # localize strings for scripts
        wp_localize_script( 'ueldo-plugin-dashboard-javascript-functions', 'ueldo_plugin_dashboard_javascript_functions_l10n', array(
            'checking' => esc_html( __( 'Checking...', 'ueldo' ) ),
            'check_now' => esc_html( __( 'Check now!', 'ueldo' ) ),
            'ajax_path' => ueldo_plugin_get_url() .'_parts/_dashboard/dashboard-ajax.php',
            'last_checked_1_min_ago' => esc_html( __( 'Last checked: 1 min ago', 'ueldo' ) ),
            'theme_is_up_to_date' => esc_html( __( 'Theme is up to date!', 'ueldo' ) ),
            'there_is_new_theme_version_available_please_update' => esc_html( __( 'There is new theme version available, please update!', 'ueldo' ) )
        ));

        # enqueue theme dashboard stylesheet
        wp_enqueue_style( 'ueldo-plugin-dashboard-stylesheet', ueldo_plugin_get_url() .'_parts/_dashboard/dashboard.css', false, null );
    }

   /**
    *
    * check the latest theme version
    *
    */

    function ueldo_check_latest_theme_version() {

        # connect with service
        $response = wp_remote_post( 'https://ueldo.com/wp-content/uploads/version.php', array( 'body' => array( 'theme' => 'Ueldo' ) ) );

        # is there any error found?
        if( is_wp_error( $response ) ) {

            # return error
            return( $response -> get_error_message() );
        }

        # get the version
        $version = json_decode( wp_remote_retrieve_body( $response ), true );

        # do we have correct version?
        if( $version == null || $version == false || !is_array( $version ) || !isset( $version['version'] ) ) {

            # return error
            return( esc_html( __( 'Incorrect server response.', 'ueldo' ) ) );
        }

        # prepare results array
        $result = array( 'version' => esc_attr( $version['version'] ), 'checked' => date( 'U' ) );

        # add new transient, expired in one day
        set_transient( 'ueldo-latest-theme-version', $result, 86400 );

        # all goes fine
        return( $result );
    }

   /**
    *
    * get the latest theme version
    *
    */

    function ueldo_get_latest_theme_version() {

        # get the transient
        $transient = get_transient( 'ueldo-latest-theme-version' );

        # return result
        return( $transient == false ? ueldo_check_latest_theme_version() : $transient );
    }

   /**
    *
    * display theme updates history
    *
    */

    function ueldo_display_theme_updates_history() {

        # path to release-log file
        $path = get_template_directory() .'/_assets/release-log.txt';

        # file exists?
        if( file_exists( $path ) ) return( file_get_contents( $path ) );

        # file not found
        return( esc_html( __( 'Couldn\'t find release log file.', 'ueldo' ) ) );
    }

   /**
    *
    * this function displays icons uploader page
    *
    */

    function ueldo_show_dashboard_page() {

        ?>
        <div class="wrap">

            <div class="ueldo-dashboard-wrapper">

                <div class="ueldo-dashboard-column ueldo-dashboard-column-left">

                    <div class="ueldo-dashboard-box">

                         <?php

                             # get theme data
                             $theme_data = wp_get_theme();

                             # get theme version
                             $theme_version = $theme_data -> get( 'Version' );

                             # get latest theme version
                             $latest_theme_version = ueldo_get_latest_theme_version();

                             # is theme updated?
                             $is_theme_updated = isset( $latest_theme_version['version'] ) ? $theme_version == $latest_theme_version['version'] : false;

                         ?>

                         <div class="ueldo-dashboard-box-heading">

                             <h3><?php echo esc_html( __( 'Theme updates', 'ueldo' ) ); ?></h3>

                             <p>

                                 <button type="button" class="button button-secondary ueldo-dashboard-check-latest-theme-version" data-current-version="<?php echo esc_attr( $theme_version ); ?>"><?php echo esc_html( __( 'Check now!', 'ueldo' ) ); ?></button>
                                 <span class="ueldo-dashboard-box-content-button-notice">

                                     <?php

                                         # do we have latest theme version response?
                                         if( is_array( $latest_theme_version ) && isset( $latest_theme_version['checked'] ) ) {

                                             # display title
                                             echo esc_html( __( 'Last checked:', 'ueldo' ) );

                                             # get the latest check date
                                             echo ' '. ueldo_show_when( $latest_theme_version['checked'], false );
                                         }

                                     ?>

                                 </span>

                             </p>

                         </div>

                         <div class="ueldo-dashboard-box-content">

                             <div class="ueldo-dashboard-box-<?php echo esc_attr( isset( $latest_theme_version['version'] ) ? ( $is_theme_updated ? 'updated' : 'info' ) : 'error' ); ?>-notice">

                                 <p><?php echo isset( $latest_theme_version['version'] ) ? ( $is_theme_updated ? esc_html( __( 'Theme is up to date!', 'ueldo' ) ) : esc_html( __( 'There is new theme version available, please update!', 'ueldo' ) ) ) : esc_html( __( 'Couldn\'t connect with Ueldo server, please try again later.', 'ueldo' ) ); ?></p>

                             </div>

                             <div class="ueldo-dashboard-box-content-double-row">

                                 <div class="ueldo-dashboard-box-content-double-col">

                                     <h4><?php echo esc_html( __( 'Installed version:', 'ueldo' ) ); ?></h4>
                                     <p><?php echo esc_html( $theme_version ); ?></p>

                                 </div>

                                 <div class="ueldo-dashboard-box-content-double-col">

                                     <?php

                                         # do we have latest theme version response?
                                         if( is_array( $latest_theme_version ) && isset( $latest_theme_version['checked'] ) ) {

                                             ?>
                                             <h4><?php echo esc_html( __( 'Latest available version:', 'ueldo' ) ); ?></h4>
                                             <p class="ueldo-dashboard-box-latest-theme-version-value"><?php echo esc_html( $latest_theme_version['version'] ); ?></p>
                                             <?php

                                         # end of info.
                                         }

                                     ?>

                                 </div>

                             </div>

                         </div>

                    </div>

                    <div class="ueldo-dashboard-box">

                        <div class="ueldo-dashboard-box-heading">

                            <h3><?php echo esc_html( __( 'System requirements', 'ueldo' ) ); ?></h3>
                            <p><?php echo esc_html( __( 'Check here if your server meets all theme requirements - this is important to have all features working correctly.', 'ueldo' ) ); ?></p>

                        </div>

                        <div class="ueldo-dashboard-box-content">

                            <div class="ueldo-dashboard-box-content-system-requirements-element">

                                <?php

                                    # get uploads dir
                                    $uploads_dir = wp_upload_dir();
                                    $uploads_dir = $uploads_dir['basedir'];

                                    # get system requirement data
                                    $system_data = array(
                                        'value' => is_writable( $uploads_dir ),
                                        'status' => 'success',
                                        'notice' => ''
                                    );

                                    # non-writable?
                                    if( $system_data['value'] == false ) {

                                        # update status variable
                                        $system_data['status'] = 'error';

                                        # update notice
                                        $system_data['notice'] = esc_html( __( 'Uploads folder is non-writable; some features like "Add Custom Icons" would not work correctly.', 'ueldo' ) );
                                    }

                                    # update value
                                    $system_data['value'] = $system_data['value'] == true ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) );

                                ?>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-status ueldo-dashboard-box-content-system-requirements-element-status-<?php echo esc_attr( $system_data['status'] ); ?>"><?php echo esc_html( $system_data['value'] ); ?></div>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-content">

                                     <h4><?php echo esc_html( __( 'Uploads folder writable', 'ueldo' ) ); ?></h4>
                                     <?php echo !empty( $system_data['notice'] ) ? wpautop( $system_data['notice'] ) : ''; ?>

                                </div>

                                <?php

                                    # clear temporary variables
                                    unset( $system_data, $uploads_dir );

                                ?>

                            </div>

                            <div class="ueldo-dashboard-box-content-system-requirements-element">

                                <?php

                                    # get system requirement data
                                    $system_data = array(
                                        'value' => ini_get( 'max_input_vars' ),
                                        'status' => 'success',
                                        'notice' => ''
                                    );

                                    # less than 1000?
                                    if( $system_data['value'] < 1000 ) {

                                        # update status variable
                                        $system_data['status'] = 'error';

                                        # update notice
                                        $system_data['notice'] = esc_html( __( 'The "max_input_vars" php.ini variable should not be less than 1000; recommended value for non-multilingual websites is 2048, and for multilingual websites is 8192.', 'ueldo' ) );
                                    }

                                    # more than 1000, check other possibilities
                                    else {

                                        # is multilingual?
                                        if( ueldo_is_multilingual() && ueldo_get_languages_list() !== false ) {

                                            # less than 8192?
                                            if( $system_data['value'] < 8192 ) {

                                                # update status variable
                                                $system_data['status'] = 'notice';

                                                # update notice
                                                $system_data['notice'] = esc_html( __( 'The "max_input_vars" php.ini variable recommended value for multilingual websites is 8192.', 'ueldo' ) );
                                            }
                                        }

                                        # non-multilingual website
                                        else {

                                            # less than 8192?
                                            if( $system_data['value'] < 2048 ) {

                                                # update status variable
                                                $system_data['status'] = 'notice';

                                                # update notice
                                                $system_data['notice'] = esc_html( __( 'The "max_input_vars" php.ini variable recommended value for non-multilingual websites is 2048.', 'ueldo' ) );
                                            }
                                        }
                                    }

                                ?>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-status ueldo-dashboard-box-content-system-requirements-element-status-<?php echo esc_attr( $system_data['status'] ); ?>"><?php echo esc_html( $system_data['value'] ); ?></div>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-content">

                                     <h4><?php echo esc_html( __( 'Max input vars', 'ueldo' ) ); ?></h4>
                                     <?php echo !empty( $system_data['notice'] ) ? wpautop( $system_data['notice'] ) : ''; ?>

                                </div>

                                <?php

                                    # clear temporary variables
                                    unset( $system_data );

                                ?>

                            </div>

                            <div class="ueldo-dashboard-box-content-system-requirements-element">

                                <?php

                                    # get system requirement data
                                    $system_data = array(
                                        'value' => ini_get( 'max_execution_time' ),
                                        'status' => 'success',
                                        'notice' => ''
                                    );

                                    # is not available?
                                    if( $system_data['value'] < 1000 ) {

                                        # update status variable
                                        $system_data['status'] = 'notice';

                                        # update notice
                                        $system_data['notice'] = esc_html( __( 'The "max_execution_time" php.ini variable recommended value is 300.', 'ueldo' ) );
                                    }

                                ?>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-status ueldo-dashboard-box-content-system-requirements-element-status-<?php echo esc_attr( $system_data['status'] ); ?>"><?php echo esc_html( $system_data['value'] ); ?></div>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-content">

                                     <h4><?php echo esc_html( __( 'Max execution time', 'ueldo' ) ); ?></h4>
                                     <?php echo !empty( $system_data['notice'] ) ? wpautop( $system_data['notice'] ) : ''; ?>

                                </div>

                                <?php

                                    # clear temporary variables
                                    unset( $system_data );

                                ?>

                            </div>

                            <div class="ueldo-dashboard-box-content-system-requirements-element">

                                <?php

                                    # get system requirement data
                                    $system_data = array(
                                        'value' => ini_get( 'memory_limit' ),
                                        'status' => 'success',
                                        'notice' => ''
                                    );

                                    # less than 256M?
                                    if( wp_convert_hr_to_bytes( $system_data['value'] ) < 268435456 ) {

                                        # update status variable
                                        $system_data['status'] = 'error';

                                        # update notice
                                        $system_data['notice'] = esc_html( __( 'Memory limit shouldn\'t be less than 256M.', 'ueldo' ) );
                                    }

                                ?>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-status ueldo-dashboard-box-content-system-requirements-element-status-<?php echo esc_attr( $system_data['status'] ); ?>"><?php echo esc_html( $system_data['value'] ); ?></div>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-content">

                                     <h4><?php echo esc_html( __( 'Memory limit', 'ueldo' ) ); ?></h4>
                                     <?php echo !empty( $system_data['notice'] ) ? wpautop( $system_data['notice'] ) : ''; ?>

                                </div>

                                <?php

                                    # clear temporary variables
                                    unset( $system_data );

                                ?>

                            </div>

                            <div class="ueldo-dashboard-box-content-system-requirements-element">

                                <?php

                                    # get system requirement data
                                    $system_data = array(
                                        'value' => ini_get( 'upload_max_filesize' ),
                                        'status' => 'success',
                                        'notice' => ''
                                    );

                                    # less than 32M?
                                    if( wp_convert_hr_to_bytes( $system_data['value'] ) < 33554432 ) {

                                        # update status variable
                                        $system_data['status'] = 'error';

                                        # update notice
                                        $system_data['notice'] = esc_html( __( 'Server upload max. file size shouldn\'t be less than 32M.', 'ueldo' ) );
                                    }

                                ?>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-status ueldo-dashboard-box-content-system-requirements-element-status-<?php echo esc_attr( $system_data['status'] ); ?>"><?php echo esc_html( $system_data['value'] ); ?></div>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-content">

                                     <h4><?php echo esc_html( __( 'Server upload max. file size', 'ueldo' ) ); ?></h4>
                                     <?php echo !empty( $system_data['notice'] ) ? wpautop( $system_data['notice'] ) : ''; ?>

                                </div>

                                <?php

                                    # clear temporary variables
                                    unset( $system_data );

                                ?>

                            </div>

                            <div class="ueldo-dashboard-box-content-system-requirements-element">

                                <?php

                                    # get system requirement data
                                    $system_data = array(
                                        'value' => wp_max_upload_size(),
                                        'status' => 'success',
                                        'notice' => ''
                                    );

                                    # less than 32M?
                                    if( $system_data['value'] < 33554432 ) {

                                        # update status variable
                                        $system_data['status'] = 'error';

                                        # update notice
                                        $system_data['notice'] = esc_html( __( 'WP upload max. file size shouldn\'t be less than 32M.', 'ueldo' ) );
                                    }

                                    # format the result
                                    $system_data['value'] = str_replace( ' MB', 'M', size_format( $system_data['value'] ) );

                                ?>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-status ueldo-dashboard-box-content-system-requirements-element-status-<?php echo esc_attr( $system_data['status'] ); ?>"><?php echo esc_html( $system_data['value'] ); ?></div>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-content">

                                     <h4><?php echo esc_html( __( 'WP upload max. file size', 'ueldo' ) ); ?></h4>
                                     <?php echo !empty( $system_data['notice'] ) ? wpautop( $system_data['notice'] ) : ''; ?>

                                </div>

                                <?php

                                    # clear temporary variables
                                    unset( $system_data );

                                ?>

                            </div>

                            <div class="ueldo-dashboard-box-content-system-requirements-element">

                                <?php

                                    # get system requirement data
                                    $system_data = array(
                                        'value' => ueldo_plugin_is_openssl_available(),
                                        'status' => 'success',
                                        'notice' => ''
                                    );

                                    # is not available?
                                    if( $system_data['value'] == false ) {

                                        # update status variable
                                        $system_data['status'] = 'error';

                                        # update notice
                                        $system_data['notice'] = esc_html( __( 'Without OpenSSL library, Import / Export Options feature wouldn\'t work correctly.', 'ueldo' ) );
                                    }

                                    # update value
                                    $system_data['value'] = $system_data['value'] == true ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) );

                                ?>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-status ueldo-dashboard-box-content-system-requirements-element-status-<?php echo esc_attr( $system_data['status'] ); ?>"><?php echo esc_html( $system_data['value'] ); ?></div>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-content">

                                     <h4><?php echo esc_html( __( 'OpenSSL available', 'ueldo' ) ); ?></h4>
                                     <?php echo !empty( $system_data['notice'] ) ? wpautop( $system_data['notice'] ) : ''; ?>

                                </div>

                                <?php

                                    # clear temporary variables
                                    unset( $system_data );

                                ?>

                            </div>

                            <div class="ueldo-dashboard-box-content-system-requirements-element">

                                <?php

                                    # mime type found flag
                                    $mime_type_found = false;

                                    # walk for allowed mime types
                                    foreach( get_allowed_mime_types() as $mime_type ) {

                                        # found?
                                        if( $mime_type == 'application/zip' ) {

                                            # update flag
                                            $mime_type_found = true;

                                            # break the loop
                                            break;
                                        }
                                    }

                                    # get system requirement data
                                    $system_data = array(
                                        'value' => $mime_type_found,
                                        'status' => 'success',
                                        'notice' => ''
                                    );

                                    # is not available?
                                    if( $system_data['value'] == false ) {

                                        # update status variable
                                        $system_data['status'] = 'error';

                                        # update notice
                                        $system_data['notice'] = esc_html( __( 'Without ZIP files upload allowed, you can\'t install custom icons and Revolution Slider sliders.', 'ueldo' ) );
                                    }

                                    # update value
                                    $system_data['value'] = $system_data['value'] == true ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) );

                                ?>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-status ueldo-dashboard-box-content-system-requirements-element-status-<?php echo esc_attr( $system_data['status'] ); ?>"><?php echo esc_html( $system_data['value'] ); ?></div>

                                <div class="ueldo-dashboard-box-content-system-requirements-element-content">

                                     <h4><?php echo esc_html( __( 'ZIP files upload allowed', 'ueldo' ) ); ?></h4>
                                     <?php echo !empty( $system_data['notice'] ) ? wpautop( $system_data['notice'] ) : ''; ?>

                                </div>

                                <?php

                                    # clear temporary variables
                                    unset( $system_data, $mime_type, $mime_type_found );

                                ?>

                            </div>

                        </div>

                    </div>

                </div>

                <div class="ueldo-dashboard-column">

                    <div class="ueldo-dashboard-box">

                         <div class="ueldo-dashboard-box-heading">

                             <h3><?php echo esc_html( __( 'Support', 'ueldo' ) ); ?></h3>
                             <p><?php echo esc_html( __( 'Have any questions or problems with this theme? Please check online theme documentation and feel free to send me and email, I\'ll do my best to help!', 'ueldo' ) ); ?></p>

                         </div>

                         <div class="ueldo-dashboard-box-content">

                             <p>

                                 <a href="<?php echo esc_url( ueldo_get_external_url( 'theme-online-documentation' ) ); ?>" target="_blank" class="button button-secondary"><?php echo esc_html( __( 'Online documentation', 'ueldo' ) ); ?></a>
                                 <span class="ueldo-dashboard-box-content-buttons-divider"><?php echo esc_html( __( 'or', 'ueldo' ) ); ?></span>
                                 <a href="mailto:support@martanian.com?subject=<?php echo esc_html( __( 'Support question about Ueldo WordPress Theme', 'ueldo' ) ); ?>" class="button button-primary"><?php echo esc_html( __( 'Contact with Martanian', 'ueldo' ) ); ?></a>

                             </p>

                             <p><?php echo esc_html( __( 'Please note that support is not provided on weekends. I do my best to answer to all questions as quick as possible.', 'ueldo' ) ); ?></p>

                         </div>

                    </div>

                    <div class="ueldo-dashboard-box">

                        <div class="ueldo-dashboard-box-heading">

                            <h3><?php echo esc_html( __( 'Updates history', 'ueldo' ) ); ?></h3>
                            <p><?php echo esc_html( __( 'Check theme updates history here, check what was fixed, updated and added with each theme versions.', 'ueldo' ) ); ?></p>

                        </div>

                        <div class="ueldo-dashboard-box-content">

                            <div class="ueldo-dashboard-box-content-updates-history">

                                <?php

                                    # get and display updates history
                                    echo ueldo_display_theme_updates_history();

                                ?>

                            </div>

                        </div>

                    </div>

                </div>

            </div>

        </div>
        <?php
    }

   /**
    *
    * end of file.
    *
    */

?>