<?php

   /**
    *
    * dynamic theme styles cache class
    *
    */

    class ueldo_dynamic_theme_styles_cache {

       /**
        *
        * cached styles array
        *
        */

        public static $cached_styles = array();

       /**
        *
        * cache file enqueued flag
        *
        */

        public static $cache_file_enqueued = false;

       /**
        *
        * get base cache directory path
        *
        */

        public static function get_cache_dir_path( $url = false ) {

            # get upload directory path
            $upload_dir = wp_upload_dir();

            # get custom directory path
            $custom_dir = '/ueldo-plugin/_dynamic-styles-cache/';

            # check uploads directory
            if( !self::check_uploads_directory( $upload_dir['basedir'], $custom_dir ) ) return( false );

            # return result
            return( $url == false ? esc_attr( $upload_dir['basedir'] . $custom_dir ) : esc_attr( $upload_dir['baseurl'] . $custom_dir ) );
        }

       /**
        *
        * check if custom uploads directory exists - if not, create it
        *
        */

        public static function check_uploads_directory( $basedir, $dir ) {

            # remove first slash from directory path
            $dir = substr( $dir, 1 );

            # remove last slash from directory path and explode directory
            $dir = explode( '/', substr( $dir, 0, ( strlen( $dir ) - 1 ) ) );

            # current path helper
            $current_path = '/';

            # walk for each directory
            for( $i = 0; $i < count( $dir ); $i++ ) {

                # update current path helper
                $current_path .= $dir[$i] .'/';

                # check if directory exists
                if( !file_exists( $basedir . $current_path ) ) {

                    # create directory
                    $result = mkdir( $basedir . $current_path, 0755 );

                    # failed?
                    if( $result == false ) return( false );
                }
            }

            # all goes fine
            return( true );
        }

       /**
        *
        * check if we should get style from cache
        * or generate new one
        *
        */

        public static function can_generate() {

            # check if cache is disabled
            if( ueldo_get_theme_options_value( 'dynamic-theme-styles-cache', false, 'enabled' ) == 'no' ) return( true );

            # switch by "clear cache" option value
            switch( ueldo_get_theme_options_value( 'dynamic-theme-styles-cache', false, 'clear-cache' ) ) {

                # all the time when logged in
                case 'all-the-time-when-logged-in':

                    # return result
                    return( is_user_logged_in() );

                break;

                # manually only
                case 'manually-only':

                    # manually only, so now it's not allowed
                    return( false );

                break;
            }

            # is't not allowed
            return( false );
        }

       /**
        *
        * can we save the styles cache?
        *
        */

        public static function can_save() {

            # check if cache is disabled
            return( ueldo_get_theme_options_value( 'dynamic-theme-styles-cache', false, 'enabled' ) == 'yes' );
        }

       /**
        *
        * are styles cached for this page?
        *
        */

        public static function are_styles_cached() {

            # get cache dir path
            $cache_dir = self::get_cache_dir_path();

            # do we have cache dir path?
            if( $cache_dir == false ) return( false );

            # is cache file exists?
            $exists = file_exists( $cache_dir . self::get_filename() );

            # enqueue if cache file exists
            if( $exists == true ) {

                # enqueue cached style
                self::enqueue_cached_style();
            }

            # return result
            return( $exists );
        }

       /**
        *
        * get filename for cached styles
        *
        */

        public static function get_filename() {

            # theme options cache
            global $ueldo_cache_option;

            # get the language key
            $lang_key = ueldo_get_current_language_key();

            # define page ID
            $page_id = get_the_ID();

            # is it the blog page?
            if( ueldo_is_blog_page() ) {

                # is it not a single post page?
                if( !is_single() ) $page_id = $ueldo_cache_option -> get_option( 'page_for_posts' );
            }

            # is it the 404 page?
            if( is_404() ) $page_id = ueldo_get_theme_options_value( '404-page-id', esc_attr( $lang_key ) );

            # return result
            return( esc_attr( $page_id ) .'_'. esc_attr( $lang_key ) .'.css' );
        }

       /**
        *
        * get cached style
        *
        */

        public static function save_cache_file() {

            # get cache dir path
            $cache_dir = self::get_cache_dir_path();

            # do we have cache dir path?
            if( $cache_dir == false ) return( false );

            # file name
            $filename = $cache_dir . self::get_filename();

            # create file
            $file = fopen( $filename, 'w+' );

            # is file writable?
            if( $file !== false && is_writable( $filename ) ) {

                # write styles to file
                if( fwrite( $file, ueldo_minify_css( implode( ' ', self::$cached_styles ) ) ) !== false ) {

                    # close file handle
                    fclose( $file );

                    # all goes fine
                    return( true );
                }
            }

            # something goes wrong
            return( false );
        }

       /**
        *
        * save generated style in cache
        *
        */

        public static function save_style_in_cache( $group, $style ) {

            # save style in cache
            self::$cached_styles[esc_attr( $group )] = $style;

            # it's time to display all styles
            if( ( ueldo_plugins::is_active_plugin( 'visual-composer' ) == true && $group == 'vc' ) || ( ueldo_plugins::is_active_plugin( 'visual-composer' ) == false && $group == 'general' ) ) {

                # save cache file and enqueue it
                if( self::save_cache_file() == true ) self::enqueue_cached_style();
                else {

                    # something goes wrong - enqueue inline styles
                    wp_add_inline_style( 'ueldo-stylesheet', ueldo_minify_css( self::$cached_styles['general'] .' '. self::$cached_styles['customizer'] ) );

                    # enqueue inline styles for vc
                    wp_add_inline_style( 'ueldo-visual-composer-stylesheet', ueldo_minify_css( self::$cached_styles['vc'] ) );
                }
            }
        }

       /**
        *
        * enqueue cached style to document
        *
        */

        public static function enqueue_cached_style() {

            # is cache file enqueued?
            if( self::$cache_file_enqueued == false ) {

                # add cache file to document
                wp_enqueue_style( 'ueldo-cached-styles', self::get_cache_dir_path( true ) . esc_attr( self::get_filename() ), false, null );

                # update flag
                self::$cache_file_enqueued = true;
            }
        }

       /**
        *
        * delete all caches
        *
        */

        public static function delete_all_caches() {

            # get cache dir path
            $cache_dir = self::get_cache_dir_path();

            # do we have cache dir path?
            if( $cache_dir == false ) return( false );

            # get all cached files
            $cached_files = array_diff( scandir( $cache_dir ), array( '..', '.' ) );

            # do we have any cached files found?
            if( $cached_files !== false && is_array( $cached_files ) ) {

                # walk for each cached file
                foreach( $cached_files as $cached_file ) {

                    # remove file
                    unlink( $cache_dir . $cached_file );
                }
            }

            # remove temporary array
            unset( $cached_files );
        }

       /**
        *
        * end of methods.
        *
        */
    }

   /**
    *
    * end of class.
    *
    */

?>