<?php

   /**
    *
    * base functions
    *
    */

    # get path to wordpress core
    function ueldo_icons_uploader_ajax_core_path() {

        # explode the content path
        $exploded = explode( 'wp-content', $_SERVER['SCRIPT_FILENAME'] );

        # path up to themes directory
        return( $exploded[0] );
    }

    # check if connection is legal
    function ueldo_check_icons_uploader_ajax_call_correctness() {

        # is the http referer correct?
        if( strpos( $_SERVER['HTTP_REFERER'], '?page=ueldo_icons_uploader' ) === false ) return( false );

        # is the call made from current domain?
        if( strpos( $_SERVER['HTTP_REFERER'], $_SERVER['HTTP_HOST'] ) === false ) return( false );

        # return result
        return( is_user_logged_in() && current_user_can( 'manage_options' ) );
    }

   /**
    *
    * configurations
    *
    */

    # include wordpress core
    define( 'WP_USE_THEMES', false );
    require( ueldo_icons_uploader_ajax_core_path() .'wp-load.php' );

    # check if user is logged-in
    if( ueldo_check_icons_uploader_ajax_call_correctness() == false ) exit( esc_html( __( 'Permission denied.', 'ueldo' ) ) );

    # do we have pack key?
    if( !isset( $_POST ) || !isset( $_POST['pack_key'] ) ) exit( esc_html( __( 'Incorrect package key (ErrID: 01).', 'ueldo' ) ) );

   /**
    *
    * function for tree deletion
    *
    */

    function ueldo_icons_uploader_ajax_delete_tree( $dir ) {

        # walk for each directory elements
        foreach( array_diff( scandir( $dir ), array( '.', '..' ) ) as $file ) {

            # remove directory or file
            ( is_dir( "$dir/$file" ) ) ? ueldo_icons_uploader_ajax_delete_tree( "$dir/$file" ) : unlink( "$dir/$file" );
        }

        # remove directory
        return rmdir( $dir );
    }

   /**
    *
    * remove selected icon library
    *
    */

    # get custom icons
    $icons = get_option( 'ueldo_custom_icons' );

    # get the pack key to remove
    $pack_key = esc_attr( $_POST['pack_key'] );

    # do we have icon pack with selected key?
    if( $icons == false || !isset( $icons[$pack_key] ) ) exit( esc_html( __( 'Incorrect package key (ErrID: 02).', 'ueldo' ) ) );

    # remove package with selected key
    unset( $icons[$pack_key] );

    # update option
    update_option( 'ueldo_custom_icons', $icons );

    # explode pack key
    $pack_key_exploded = explode( '_', $pack_key );

    # get the pack ID
    $packID = $pack_key_exploded[( count( $pack_key_exploded ) - 1 )];

    # remove pack directory
    ueldo_icons_uploader_ajax_delete_tree( ueldo_get_icons_uploader_packs_dir_path() .'pack-'. esc_attr( $packID ) .'/' );

    # all goes fine
    exit( 'OK' );

   /**
    *
    * end of ajax file.
    *
    */

?>