<?php

   /**
    *
    * check if any custom icon is added
    *
    */

    function ueldo_plugin_is_any_custom_icon_added() {

        # get global variables
        global $ueldo_cache_option;

        # get icons list
        $icons = $ueldo_cache_option -> get_option( 'ueldo_custom_icons' );

        # return result
        return( $icons != false );
    }

   /**
    *
    * check if selected icon family exists
    *
    */

    function ueldo_plugin_custom_icon_exists( $library ) {

        # get global variables
        global $ueldo_cache_option;

        # get icons list
        $icons = $ueldo_cache_option -> get_option( 'ueldo_custom_icons' );

        # return result
        return( $icons != false && isset( $icons[$library] ) );
    }

   /**
    *
    * register icons uploader page
    *
    */

    add_action( 'admin_menu', 'ueldo_plugin_add_icons_uploader_page' );
    function ueldo_plugin_add_icons_uploader_page() {

        # add theme page for icons uploader
        $ueldo_icons_uploader_page = add_submenu_page(
            'ueldo_dashboard',
            esc_html( __( 'Add Custom Icons', 'ueldo' ) ),
            esc_html( __( 'Add Custom Icons', 'ueldo' ) ),
            'manage_options',
            'ueldo_icons_uploader',
            'ueldo_show_icons_uploader_page'
        );

        # load scripts and styles for icons uploader page
        add_action( 'load-'. $ueldo_icons_uploader_page, 'ueldo_load_scripts_for_icons_uploader_page' );
    }

   /**
    *
    * add action - enqueue scripts and styles for icons uploader page
    *
    */

    function ueldo_load_scripts_for_icons_uploader_page() {

        # add action for "admin_enqueue_scripts" hook
        add_action( 'admin_enqueue_scripts', 'ueldo_scripts_and_styles_for_icons_uploader_page' );
    }

   /**
    *
    * all scripts and styles needed by icons uploader page
    *
    */

    function ueldo_scripts_and_styles_for_icons_uploader_page() {

        # enqueue media library
        wp_enqueue_media();

        # enqueue icons uploader script
        wp_enqueue_script( 'ueldo-plugin-icons-uploader-javascript-functions', ueldo_plugin_get_url() .'_parts/_icons-uploader/icons-uploader.js', array( 'jquery' ), null, true );

        # localize strings for scripts
        wp_localize_script( 'ueldo-plugin-icons-uploader-javascript-functions', 'ueldo_plugin_icons_uploader_javascript_functions_l10n', array(
            'media_title' => esc_html( __( 'Select or upload icons package', 'ueldo' ) ),
            'button' => esc_html( __( 'Use this icons package', 'ueldo' ) ),
            'ajax_path' => ueldo_plugin_get_url() .'_parts/_icons-uploader/icons-uploader-ajax.php',
            'icons_pack_removed' => esc_html( __( 'Icons pack removed.', 'ueldo' ) )
        ));

        # enqueue icons uploader stylesheet
        wp_enqueue_style( 'ueldo-plugin-icons-uploader-stylesheet', ueldo_plugin_get_url() .'_parts/_icons-uploader/icons-uploader.css', false, null );

        # enqueue custom icons stylesheet files
        ueldo_plugin_enqueue_custom_icons_stylesheet();
    }

   /**
    *
    * register settings
    *
    */

    add_action( 'admin_init', 'ueldo_register_icons_uploader_settings' );
    function ueldo_register_icons_uploader_settings() {

        # add theme options settings section
        add_settings_section( 'ueldo_icons_uploader_settings', '', null, 'ueldo_icons_uploader' );

        # add settings field: general theme options
        add_settings_field( 'ueldo_icons_uploader_options', '', null, 'ueldo_icons_uploader', 'ueldo_icons_uploader_settings' );
        register_setting( 'ueldo_icons_uploader', 'ueldo_icons_uploader_options', 'ueldo_proceed_icons_uploader_upload' );
    }

   /**
    *
    * proceed icons uploader upload
    *
    */

    function ueldo_proceed_icons_uploader_upload( $input ) {

        # incorrect input
        if( !is_array( $input ) || !isset( $input['path'] ) || !isset( $input['name'] ) ) return( false );

        # enable wordpress file system
        WP_Filesystem();

        # get upload directory path
        $upload_dir = wp_upload_dir();

        # get dir name for icons pack
        $dirname = ueldo_get_dir_name_for_icons_pack();

        # check if upload directory is writable
        if( !is_writable( ueldo_get_icons_uploader_packs_dir_path() ) ) {

            # register new setting error
            add_settings_error( 'ueldo_icons_uploader', 'upload-dir-not-writable', esc_html( __( 'Upload directory is not writable.', 'ueldo' ) ), 'error' );

            # exit the function
            return( false );
        }

        # unzip file
        $result = unzip_file( $upload_dir['path'] .'/'. esc_attr( $input['path'] ), ueldo_get_icons_uploader_packs_dir_path() . $dirname );

        # add icons collection if unzipped correctly
        if( $result === true ) {

            # check if font directory is writable
            if( !is_writable( ueldo_get_icons_uploader_packs_dir_path() . $dirname .'/font' ) ) {

                # register new setting error
                add_settings_error( 'ueldo_icons_uploader', 'uploaded-font-dir-not-writable', esc_html( __( 'Uploaded font directory is not writable.', 'ueldo' ) ), 'error' );

                # exit the function
                return( false );
            }

            # add icons to collection
            ueldo_add_icons_collection( $dirname, $input['name'] );

            # all goes fine
            return( true );
        }

        else {

            # register new setting error
            add_settings_error( 'ueldo_icons_uploader', 'unzip-failed', esc_html( __( 'Unzip failed, please try again.', 'ueldo' ) ), 'error' );

            # exit the function
            return( false );
        }
    }

   /**
    *
    * get the dir name for new icons pack
    *
    */

    function ueldo_get_dir_name_for_icons_pack() {

        # prepare package name
        $packname = 'pack';

        # prepare result packname
        $result_packname = $packname .'-1';

        # prepare the list of icons packages directories
        $dirs = array();

        # walk for each directory
        foreach( glob( ueldo_get_icons_uploader_packs_dir_path() .'*', GLOB_ONLYDIR ) as $dir ) {

            # get only directory name
            $dirs[] = str_replace( ueldo_get_icons_uploader_packs_dir_path(), '', $dir );
        }

        # prepare extra id value
        $extra_id = 2;

        # find unique pack name
        while( in_array( $result_packname, $dirs ) ) {

            # update packname
            $result_packname = $packname .'-'. $extra_id;

            # update extra id
            $extra_id += 1;
        }

        # remove temporary variables
        unset( $dirs, $packname, $extra_dir, $dir );

        # return result
        return( $result_packname );
    }

   /**
    *
    * get the icons uploader packs directory path
    *
    */

    function ueldo_get_icons_uploader_packs_dir_path( $url = false ) {

        # get the upload directory
        $upload_dir = wp_upload_dir();

        # get custom directory path
        $custom_dir = '/ueldo-plugin/_icons-uploader/_packs/';

        # check uploads directory
        if( !ueldo_plugin_check_icons_uploader_uploads_directory( $upload_dir['basedir'], $custom_dir ) ) return( false );

        # return result
        return( $url == false ? esc_attr( $upload_dir['basedir'] . $custom_dir ) : esc_attr( $upload_dir['baseurl'] . $custom_dir ) );
    }

   /**
    *
    * check if custom uploads directory exists - if not, create it
    *
    */

    function ueldo_plugin_check_icons_uploader_uploads_directory( $basedir, $dir ) {

        # remove first slash from directory path
        $dir = substr( $dir, 1 );

        # remove last slash from directory path and explode directory
        $dir = explode( '/', substr( $dir, 0, ( strlen( $dir ) - 1 ) ) );

        # current path helper
        $current_path = '/';

        # walk for each directory
        for( $i = 0; $i < count( $dir ); $i++ ) {

            # update current path helper
            $current_path .= $dir[$i] .'/';

            # check if directory exists
            if( !file_exists( $basedir . $current_path ) ) {

                # create directory
                $result = mkdir( $basedir . $current_path, 0755 );

                # failed?
                if( $result == false ) {

                    # register new setting error
                    add_settings_error( 'ueldo_icons_uploader', 'upload-directory-creation-failed', esc_html( __( 'Can not create uploads directory; permission problems.', 'ueldo' ) ), 'error' );

                    # exit the function
                    return( false );
                }
            }
        }

        # all goes fine
        return( true );
    }

   /**
    *
    * display settings errors
    *
    */

    function ueldo_display_icons_uploader_settings_errors() {

        # get settings errors
        $errors = get_settings_errors( 'ueldo_icons_uploader' );

        # do we have any?
        if( $errors == array() ) return( '' );

        # display each settings errors
        foreach( $errors as $error_id => $error ) {

            ?>
            <div class="<?php echo esc_attr( $error['type'] ); ?>">

                <p><?php echo esc_html( $error['message'] ); ?></p>

            </div>
            <?php
        }
    }

   /**
    *
    * get unique name for new icon collection
    *
    */

    function ueldo_get_unique_name_for_icons_collection( $name ) {

        # global variables
        global $ueldo_cache_option;

        # get other icons fonts
        $icon_fonts = $ueldo_cache_option -> get_option( 'ueldo_custom_icons' );

        # do we have custom icons fonts added?
        if( $icon_fonts != false ) {

            # array of icon names
            $icon_fonts_names = array();

            # walk for each icon font
            foreach( $icon_fonts as $icon_font ) {

                # update icon fonts names
                $icon_fonts_names[] = $icon_font['name'];
            }

            # do we have the same name already added?
            if( in_array( $name, $icon_fonts_names, true ) ) {

                # generate unique name
                $name = ueldo_generate_unique_name_for_icons_collection( $name, $icon_fonts_names );
            }
        }

        # return result
        return( $name );
    }

   /**
    *
    * generate unique name for new icon collection
    *
    */

    function ueldo_generate_unique_name_for_icons_collection( $name, $names, $unique_id = false ) {

        # unique id
        if( $unique_id == false ) $unique_id = 2;

        # new name variable
        $new_name = trim( $name ) .' '. $unique_id;

        # return result
        return( in_array( $new_name, $names, true ) ? ueldo_generate_unique_name_for_icons_collection( $name, $names, ( $unique_id + 1 ) ) : $new_name );
    }

   /**
    *
    * add new icons collection
    *
    */

    function ueldo_add_icons_collection( $dirname, $name ) {

        # get unique name for icons collection
        $name = ueldo_get_unique_name_for_icons_collection( $name );

        # get the unique package id
        $packID = str_replace( 'pack-', '', $dirname );

        # get the css file content
        $response = wp_remote_get( ueldo_get_icons_uploader_packs_dir_path( true ) . esc_attr( $dirname ) .'/font/flaticon.css' );

        # is correct?
        if( wp_remote_retrieve_header( $response, 'content-type' ) != 'text/css' ) {

            # register new setting error
            add_settings_error( 'ueldo_icons_uploader', 'css-file-not-found', esc_html( __( 'Invalid icons package - could not find css file.', 'ueldo' ) ), 'error' );

            # exit the function
            return( false );
        }

        # replace font name
        $css_content = str_replace( '"Flaticon"', '"Flaticon'. esc_attr( $packID ) .'"', wp_remote_retrieve_body( $response ) );

        # replace font name without quotes
        $css_content = str_replace( 'font-family: Flaticon;', 'font-family: Flaticon'. esc_attr( $packID ) .';', $css_content );

        # replace font class names
        $css_content = str_replace( 'flaticon-', 'flaticon'. esc_attr( $packID ) .'-', $css_content );

        # remove margin left style
        $css_content = str_replace( 'margin-left: 20px;', 'margin-left: 0;', $css_content );

        # update file content
        if( !ueldo_update_file_content( ueldo_get_icons_uploader_packs_dir_path() . esc_attr( $dirname ) .'/font/flaticon.css', $css_content ) ) {

            # register new setting error
            add_settings_error( 'ueldo_icons_uploader', 'css-file-not-saved', esc_html( __( 'Can not update css file - server permission issue.', 'ueldo' ) ), 'error' );

            # exit the function
            return( false );
        }

        # get the array of all icons
        $icons = ueldo_parse_icons_font_css( $css_content );

        # unique key for icon font
        $uniqueKey = str_replace( '-', '_', esc_attr( sanitize_title( $name ) ) ) .'_'. esc_attr( $packID );

        # prepare icon font option array
        $option = array(
            $uniqueKey => array(
                'path' => ueldo_get_icons_uploader_packs_dir_path( true ) . esc_attr( $dirname ) .'/font/flaticon.css',
                'name' => esc_html( $name ),
                'unique_key' => $uniqueKey,
                'icons' => $icons
            )
        );

        # get current options value
        $options = get_option( 'ueldo_custom_icons' );

        # there's nothing found?
        if( $options == false ) $options = array();

        # update option
        update_option( 'ueldo_custom_icons', array_merge( $options, $option ) );

        # add message
        add_settings_error( 'ueldo_icons_uploader', 'updated', esc_html( __( 'New icons pack added!', 'ueldo' ) ), 'updated' );

        # all goes fine
        return( true );
    }

   /**
    *
    * update file contents
    *
    */

    function ueldo_update_file_content( $path, $content ) {

        # get the handle
        if( !$handle = @fopen( $path, 'w+' ) ) return( false );

        # write to file
        if( fwrite( $handle, $content ) === false ) return( false );

        # close the handler
        fclose( $handle );

        # all goes fine
        return( true );
    }

   /**
    *
    * parse font icons class to get the array of icons
    *
    */

    function ueldo_parse_icons_font_css( $content ) {

        # remove content before
        $content = explode( '}', substr( $content, strpos( $content, '.flaticon' ) ) );

        # results array
        $result = array();

        # walk for each class name
        for( $i = 0; $i < count( $content ); $i++ ) {

            # remove strings before
            $content[$i] = substr( $content[$i], ( strpos( $content[$i], '.' ) + 1 ) );

            # remove strings after
            $content[$i] = substr( $content[$i], 0, strpos( $content[$i], ':' ) );

            # update results array
            if( !empty( $content[$i] ) ) $result[] = $content[$i];
        }

        # return result
        return( $result );
    }

   /**
    *
    * this function displays icons uploader page
    *
    */

    function ueldo_show_icons_uploader_page() {

        # get global variables
        global $ueldo_cache_option;

        ?>
        <div class="wrap">

            <div class="ueldo-icons-uploader-wrapper">

                <div class="ueldo-icons-uploader">

                    <div class="ueldo-icons-uploader-padding">

                        <h3><?php echo esc_html( __( 'Upload custom icons from FlatIcon', 'ueldo' ) ); ?></h3>
                        <p><?php echo esc_html( __( 'Use this tool to upload any pack of custom icons from the', 'ueldo' ) ); ?> <a href="<?php echo esc_url( ueldo_get_external_url( 'flaticon' ) ); ?>" target="_blank"><?php echo esc_html( __( 'FlatIcon', 'ueldo' ) ); ?></a>.</p>

                        <div class="ueldo-icons-uploader-alert-box">

                            <p><a href="https://ueldo.com/documentation/icons-and-images-used-in-demo-templates/" target="_blank"><?php echo esc_html( __( 'Click here to find a list of all icons used on each demo templates!', 'ueldo' ) ); ?></a></p>

                        </div>

                    </div>

                    <div class="ueldo-icons-uploader-options">

                        <div class="ueldo-icons-uploader-options-group">

                            <?php

                                # icons uploader settings errors
                                ueldo_display_icons_uploader_settings_errors();

                            ?>

                            <button type="button" class="button button-secondary ueldo-icons-uploader-button"><?php echo esc_html( __( 'Upload icons .zip file', 'ueldo' ) ); ?></button>

                            <div class="ueldo-icons-uploader-options-group-summary" data-visible="no">

                                <form action="options.php" method="post" enctype="multipart/form-data" name="ueldo-options-form">

                                    <?php

                                        # main settings fields
                                        settings_fields( 'ueldo_icons_uploader' );

                                        # main settings section
                                        do_settings_sections( 'ueldo_icons_uploader_settings' );

                                    ?>

                                    <h4><?php echo esc_html( __( 'Package name:', 'ueldo' ) ); ?></h4>

                                    <input type="text" name="ueldo_icons_uploader_options[name]" value="" class="ueldo-icons-uploader-package-name-field" />
                                    <input type="hidden" name="ueldo_icons_uploader_options[path]" value="" class="ueldo-icons-uploader-package-path-field" />

                                    <div class="ueldo-icons-uploader-proceed-button">

                                        <?php

                                            # submit button
                                            submit_button( esc_html( __( 'Add icons', 'ueldo' ) ) );

                                        ?>

                                    </div>

                                </form>

                            </div>

                        </div>

                    </div>

                </div>

                <div class="ueldo-remove-icons-pack-confirm" data-confirm-for="">

                    <div class="ueldo-remove-icons-pack-confirm-content">

                        <div class="ueldo-remove-icons-pack-confirm-content-padding">

                            <h4><?php echo esc_html( __( 'Please confirm this action', 'ueldo' ) ); ?></h4>
                            <p><?php echo esc_html( __( 'This action can not be undone; all icons from this pack used on your website will be replaced with default FontAwesome icon.', 'ueldo' ) ); ?></p>

                            <button type="button" class="button button-primary" data-action="confirm"><?php echo esc_html( __( 'Confirm the deletion', 'ueldo' ) ); ?></button>
                            <button type="button" class="button" data-action="cancel"><?php echo esc_html( __( 'Cancel', 'ueldo' ) ); ?></button>

                        </div>

                    </div>

                </div>

                <?php

                    # get all packages
                    $custom_icons = $ueldo_cache_option -> get_option( 'ueldo_custom_icons' );

                    # do we have any icons added?
                    if( $custom_icons != false ) {

                        ?>
                        <div class="ueldo-uploaded-icons-list">

                            <div class="ueldo-uploaded-icons-list-padding">

                                <h3><?php echo esc_html( __( 'List of already uploaded icons', 'ueldo' ) ); ?></h3>
                                <p><?php echo esc_html( __( 'Find all icons uploaded before:', 'ueldo' ) ); ?></p>

                            </div>

                            <div class="ueldo-uploaded-icons-list-options">

                                <div class="ueldo-uploaded-icons-list-options-group">

                                    <?php

                                        # walk for each package
                                        foreach( $custom_icons as $pack ) {

                                            ?>
                                            <div class="ueldo-uploaded-icons-list-single-pack" data-icon-pack-key="<?php echo esc_attr( $pack['unique_key'] ); ?>">

                                                <div class="ueldo-uploaded-icons-list-single-pack-preview">

                                                    <?php

                                                        # walk for each icon
                                                        foreach( $pack['icons'] as $icon ) {

                                                            ?>
                                                            <div class="ueldo-uploaded-icons-list-single-pack-preview-icon-container">

                                                                <i class="<?php echo esc_attr( $icon ); ?>" title="<?php echo esc_attr( $icon ); ?>"></i>

                                                            </div>
                                                            <?php
                                                        }

                                                    ?>

                                                </div>

                                                <div class="ueldo-uploaded-icons-list-single-pack-description">

                                                    <h4><?php echo esc_html( $pack['name'] ); ?></h4>

                                                    <p><?php echo esc_html( __( 'Key:', 'ueldo' ) ); ?> <?php echo esc_html( $pack['unique_key'] ); ?></p>
                                                    <p><?php echo esc_html( __( 'Icons:', 'ueldo' ) ); ?> <?php echo count( $pack['icons'] ); ?></p>

                                                    <button type="button" class="button button-secondary ueldo-delete-icons-pack" data-icon-pack-key="<?php echo esc_attr( $pack['unique_key'] ); ?>"><?php echo esc_html( __( 'Delete', 'ueldo' ) ); ?></button>

                                                </div>

                                            </div>
                                            <?php

                                        # end of loop
                                        }

                                    ?>

                                </div>

                            </div>

                        </div>
                        <?php

                    # end of custom icons list.
                    }

                ?>

            </div>

        </div>
        <?php
    }

   /**
    *
    * add custom icons library to visual composer iconpicker
    *
    */

    class ueldo_plugin_add_vc_icon_library {

       /**
        *
        * catch all class calls
        *
        */

        public static function __callStatic( $name, $args ) {

            # get global cache object
            global $ueldo_cache_option;

            # get all custom icon fonts
            $icon_fonts = $ueldo_cache_option -> get_option( 'ueldo_custom_icons' );

            # prepare results array
            $result = array();

            # do we have icon library?
            if( !isset( $icon_fonts[$name] ) || !isset( $icon_fonts[$name]['icons'] ) ) return( false );

            # walk for each icons
            foreach( $icon_fonts[$name]['icons'] as $icon ) {

                # update results array
                $result[] = array( $icon => $icon );
            }

            # return result
            return( $result );
        }

       /**
        *
        * end of methods.
        *
        */
    }

   /**
    *
    * end of file.
    *
    */

?>