<?php

   /**
    *
    * register import/export options page
    *
    */

    add_action( 'admin_menu', 'ueldo_plugin_add_import_export_options_page' );
    function ueldo_plugin_add_import_export_options_page() {

        # openssl library is not available?
        if( ueldo_plugin_is_openssl_available() == false ) return;

        # add theme page for import / export options
        $ueldo_import_export_options_page = add_submenu_page(
            'ueldo_dashboard',
            esc_html( __( 'Import / Export Options', 'ueldo' ) ),
            esc_html( __( 'Import / Export Options', 'ueldo' ) ),
            'manage_options',
            'ueldo_import_export_options',
            'ueldo_show_import_export_options_page'
        );

        # load scripts and styles for import / export options page
        add_action( 'load-'. $ueldo_import_export_options_page, 'ueldo_load_scripts_for_import_export_options_page' );
    }

   /**
    *
    * add action - enqueue scripts and styles for import / export options page
    *
    */

    function ueldo_load_scripts_for_import_export_options_page() {

        # add action for "admin_enqueue_scripts" hook
        add_action( 'admin_enqueue_scripts', 'ueldo_scripts_and_styles_for_import_export_options_page' );
    }

   /**
    *
    * all scripts and styles needed by import / export options page
    *
    */

    function ueldo_scripts_and_styles_for_import_export_options_page() {

        # enqueue icons uploader script
        wp_enqueue_script( 'ueldo-plugin-import-export-options-javascript-functions', ueldo_plugin_get_url() .'_parts/_import-export-options/import-export-options.js', array( 'jquery' ), null, true );

        # enqueue icons uploader stylesheet
        wp_enqueue_style( 'ueldo-plugin-import-export-options-stylesheet', ueldo_plugin_get_url() .'_parts/_import-export-options/import-export-options.css', false, null );
    }

   /**
    *
    * register settings
    *
    */

    add_action( 'admin_init', 'ueldo_register_import_export_options_settings' );
    function ueldo_register_import_export_options_settings() {

        # add theme options settings section
        add_settings_section( 'ueldo_import_export_options_settings', '', null, 'ueldo_import_export_options' );

        # add settings field: general theme options
        add_settings_field( 'ueldo_import_export_options_options', '', null, 'ueldo_import_export_options', 'ueldo_import_export_options_settings' );
        register_setting( 'ueldo_import_export_options', 'ueldo_import_export_options_options', 'ueldo_proceed_import_export_options_change' );
    }

   /**
    *
    * get all theme options data, encrypted
    *
    */

    function ueldo_import_export_theme_options_get_data() {

        # get theme options
        $data = array(
            'ueldo_theme_options' => get_option( 'ueldo_theme_options' )
        );

        # prepare languages array
        $languages = array( 'all' );

        # is multilingual?
        if( ueldo_is_multilingual() ) {

            # update languages array
            $languages = array_merge( $languages, ueldo_get_languages_list() );
        }

        # walk for each language
        foreach( $languages as $language ) {

            # walk for all editor keys
            foreach( ueldo_get_editor_keys() as $key ) {

                # get the option key
                $option_key = esc_attr( $key . strtolower( esc_attr( $language ) ) );

                # get the content for editor key
                $content = get_option( $option_key );

                # do we have the content?
                if( $content !== false ) $data[$option_key] = $content;

                # remove temporary variables
                unset( $content );
            }
        }

        # remove temporary variables
        unset( $languages, $language, $key );

        # return result
        return( ueldo_import_export_options_encrypt_decrypt( 'encrypt', json_encode( $data ) ) );
    }

   /**
    *
    * proceed the import or default data restoration
    *
    */

    function ueldo_proceed_import_export_options_change( $input ) {

        # incorrect input
        if( !is_array( $input ) || !isset( $input['action'] ) ) return( false );

        # do we have the action set?
        if( !isset( $input['action'] ) || !in_array( $input['action'], array( 'import', 'restore-default' ), true ) ) {

            # register new setting error
            add_settings_error( 'ueldo_import_export_options', 'invalid-action-key', esc_html( __( 'Invalid action.', 'ueldo' ) ), 'error' );

            # exit the function
            return( false );
        }

        # switch by action
        switch( $input['action'] ) {

            # import new theme options
            case 'import':

                # do we have encrypted options set?
                if( empty( $input['options-encrypted'] ) ) {

                    # register new setting error
                    add_settings_error( 'ueldo_import_export_options', 'empty-encrypted-options', esc_html( __( 'Imported options can not be empty.', 'ueldo' ) ), 'error' );

                    # exit the function
                    return( false );
                }

                # decrypt
                $decryption = ueldo_import_export_options_encrypt_decrypt( 'decrypt', $input['options-encrypted'] );

                # incorrect decryption
                if( $decryption === false ) {

                    # register new setting error
                    add_settings_error( 'ueldo_import_export_options', 'incorrect-encrypted-options', esc_html( __( 'Incorrect imported options - please make sure that you have put correct options to import field.', 'ueldo' ) ), 'error' );

                    # exit the function
                    return( false );
                }

                # parse json
                $decryption = json_decode( $decryption, true );

                # incorrect json
                if( !is_array( $decryption ) ) {

                    # register new setting error
                    add_settings_error( 'ueldo_import_export_options', 'incorrect-encrypted-options-json', esc_html( __( 'Incorrect imported options - please make sure that you have put correct options to import field.', 'ueldo' ) ), 'error' );

                    # exit the function
                    return( false );
                }

                # remove all current theme options and start the console log
                $console = ueldo_import_export_options_remove_all_theme_options();

                # walk for each new options
                foreach( $decryption as $option_key => $option_value ) {

                    # update options
                    update_option( $option_key, $option_value );

                    # add console log
                    $console[] = '['. date( 'Y-m-d H:i:s' ) .'] added: '. esc_attr( $option_key );
                }

                # register output
                add_settings_error( 'ueldo_import_export_options', 'import-correct', $console, 'updated' );

                # finish the function
                return( true );

            break;

            # restore default theme options
            case 'restore-default':

                # remove all current theme options and start the console log
                $console = ueldo_import_export_options_remove_all_theme_options();

                # register output
                add_settings_error( 'ueldo_import_export_options', 'restore-default-correct', $console, 'updated' );

                # finish the function
                return( true );

            break;
        }

        # finish the function
        return( false );
    }

   /**
    *
    * remove all theme options
    *
    */

    function ueldo_import_export_options_remove_all_theme_options() {

        # console logs
        $console = array();

        # walk for each available options
        foreach( wp_load_alloptions() as $key => $value ) {

            # do we have the match?
            if( strpos( $key, 'ueldo_' ) !== false && strpos( $key, 'widget' ) === false && $key != 'ueldo_import_export_options_options' ) {

                # remove theme option
                delete_option( $key );

                # add console log
                $console[] = '['. date( 'Y-m-d H:i:s' ) .'] removed: '. esc_attr( $key );
            }
        }

        # remove theme mods
        remove_theme_mod( 'background_color' );
        remove_theme_mod( 'background_position_x' );
        remove_theme_mod( 'background_position_y' );
        remove_theme_mod( 'background_repeat' );
        remove_theme_mod( 'background_attachment' );
        remove_theme_mod( 'background_size' );
        remove_theme_mod( 'background_image' );

        # add console log
        $console[] = '['. date( 'Y-m-d H:i:s' ) .'] theme background mods removed';

        # return console
        return( $console );
    }

   /**
    *
    * display settings errors
    *
    */

    function ueldo_display_import_export_options_settings_errors() {

        # get settings errors
        $errors = get_settings_errors( 'ueldo_import_export_options' );

        # do we have any?
        if( $errors == array() ) return( '' );

        ?>
        <div class="ueldo-import-export-options-wrapper">
        <?php

        # display each settings errors
        foreach( $errors as $error_id => $error ) {

            # is import update?
            if( in_array( $error['code'], array( 'import-correct', 'restore-default-correct' ), true ) ) {

                ?>
                <div class="<?php echo esc_attr( $error['type'] ); ?>">

                    <p><?php echo esc_html( $error['code'] == 'import-correct' ? esc_html( __( 'Successful import!', 'ueldo' ) ) : esc_html( __( 'Default theme options restored successfully!', 'ueldo' ) ) ); ?></p>
                    <pre><?php foreach( $error['message'] as $message ) { echo esc_html( $message ) ."\n"; } ?></pre>

                </div>
                <?php
            }

            # other messages
            else {

                ?>
                <div class="<?php echo esc_attr( $error['type'] ); ?>">

                    <p><?php echo esc_html( $error['message'] ); ?></p>

                </div>
                <?php
            }
        }

        ?>
        </div>
        <?php
    }

   /**
    *
    * this function displays import / export options page
    *
    */

    function ueldo_show_import_export_options_page() {

        ?>
        <div class="wrap">

            <div class="ueldo-import-export-options-confirm">

                <div class="ueldo-import-export-options-confirm-content">

                    <div class="ueldo-import-export-options-confirm-content-padding">

                        <h4><?php echo esc_html( __( 'Please confirm this action', 'ueldo' ) ); ?></h4>
                        <p><?php echo esc_html( __( 'All current theme options will be removed; this action can not be undone.', 'ueldo' ) ); ?></p>

                        <button type="button" class="button button-primary" data-action="confirm"><?php echo esc_html( __( 'Confirm', 'ueldo' ) ); ?></button>
                        <button type="button" class="button" data-action="cancel"><?php echo esc_html( __( 'Cancel', 'ueldo' ) ); ?></button>

                    </div>

                </div>

            </div>

            <?php

                # display settings errors, if exists
                ueldo_display_import_export_options_settings_errors();

            ?>

            <div class="ueldo-import-export-options-wrapper">

                <div class="ueldo-import-export-options">

                    <div class="ueldo-import-export-options-padding">

                        <h3><?php echo esc_html( __( 'Export theme options', 'ueldo' ) ); ?></h3>
                        <p><?php echo esc_html( __( 'The box below contains all theme options encoded as a string, so you can copy it and paste to "Import theme options" container on another website (built with Ueldo theme); you can also save this options in .txt file and keep it on your local computer or another server, to use it in the future as a backup copy.', 'ueldo' ) ); ?></p>

                    </div>

                    <div class="ueldo-import-export-options-options">

                        <div class="ueldo-import-export-options-options-group">

                            <textarea rows="5" cols="5" class="ueldo-import-export-options-options-export-theme-options" readonly><?php echo esc_html( ueldo_import_export_theme_options_get_data() ); ?></textarea>
                            <button class="button button-secondary ueldo-import-export-options-options-export-theme-options-button"><?php echo esc_html( __( 'Export as .txt file', 'ueldo' ) ); ?></button>

                        </div>

                    </div>

                </div>

            </div>

            <div class="ueldo-import-export-options-wrapper">

                <div class="ueldo-import-export-options" data-action-type="import">

                    <div class="ueldo-import-export-options-padding">

                        <h3><?php echo esc_html( __( 'Import theme options', 'ueldo' ) ); ?></h3>
                        <p><?php echo esc_html( __( 'Put the theme options below to import it to this website.', 'ueldo' ) ); ?></p>

                    </div>

                    <div class="ueldo-import-export-options-options">

                        <div class="ueldo-import-export-options-options-group">

                            <form action="options.php" method="post" enctype="multipart/form-data" name="ueldo-options-form">

                                <?php

                                    # main settings fields
                                    settings_fields( 'ueldo_import_export_options' );

                                    # main settings section
                                    do_settings_sections( 'ueldo_import_export_options_settings' );

                                ?>

                                <input type="hidden" name="ueldo_import_export_options_options[action]" value="import" />
                                <textarea rows="5" cols="5" name="ueldo_import_export_options_options[options-encrypted]"></textarea>

                                <div class="ueldo-import-export-options-warning-notice"><?php echo esc_html( __( 'Please be careful! This will overwrite all existing theme options; this operation can not be undone.', 'ueldo' ) ); ?></div>

                                <?php

                                    # submit button
                                    submit_button( esc_html( __( 'Import theme options', 'ueldo' ) ) );

                                ?>

                            </form>

                        </div>

                    </div>

                </div>

            </div>

            <div class="ueldo-import-export-options-wrapper">

                <div class="ueldo-import-export-options" data-action-type="restore-default">

                    <div class="ueldo-import-export-options-padding">

                        <h3><?php echo esc_html( __( 'Restore default theme options', 'ueldo' ) ); ?></h3>
                        <p><?php echo esc_html( __( 'This option will remove all custom theme options and restore default values. This will not remove any pages, posts or media libraries.', 'ueldo' ) ); ?></p>

                    </div>

                    <div class="ueldo-import-export-options-options">

                        <div class="ueldo-import-export-options-options-group">

                            <form action="options.php" method="post" enctype="multipart/form-data" name="ueldo-options-form">

                                <?php

                                    # main settings fields
                                    settings_fields( 'ueldo_import_export_options' );

                                    # main settings section
                                    do_settings_sections( 'ueldo_import_export_options_settings' );

                                ?>

                                <input type="hidden" name="ueldo_import_export_options_options[action]" value="restore-default" />
                                <div class="ueldo-import-export-options-warning-notice"><?php echo esc_html( __( 'Please be careful! This will remove all existing theme options; this operation can not be undone.', 'ueldo' ) ); ?></div>

                                <?php

                                    # submit button
                                    submit_button( esc_html( __( 'Restore default theme options', 'ueldo' ) ) );

                                ?>

                            </form>

                        </div>

                    </div>

                </div>

            </div>

        </div>
        <?php
    }

   /**
    *
    * encryp / decrypt class
    *
    */

    function ueldo_import_export_options_encrypt_decrypt( $action, $data ) {

        # encryption method
        $encrypt_method = 'AES-256-CBC';

        # get the secret key
        $key = hash( 'sha256', 'ueldo-import-export-options-secret-key' );

        # iv - encrypt method AES-256-CBC expects 16 bytes
        $iv = substr( hash( 'sha256', 'ueldo-import-export-options-secret-iv' ), 0, 16 );

        # switch by action
        switch( $action ) {

            # encryption
            case 'encrypt': return( base64_encode( openssl_encrypt( $data, $encrypt_method, $key, 0, $iv ) ) );

            # decryption
            case 'decrypt': return( openssl_decrypt( base64_decode( $data ), $encrypt_method, $key, 0, $iv ) );
        }
    }

   /**
    *
    * end of file.
    *
    */

?>