<?php

   /**
    *
    * base functions
    *
    */

    # get path to wordpress core
    function ueldo_languages_sync_ajax_core_path() {

        # explode the content path
        $exploded = explode( 'wp-content', $_SERVER['SCRIPT_FILENAME'] );

        # path up to themes directory
        return( $exploded[0] );
    }

    # check if connection is legal
    function ueldo_check_languages_sync_ajax_call_correctness() {

        # is the http referer correct?
        if( strpos( $_SERVER['HTTP_REFERER'], '?page=ueldo_languages_sync' ) === false ) return( false );

        # is the call made from current domain?
        if( strpos( $_SERVER['HTTP_REFERER'], $_SERVER['HTTP_HOST'] ) === false ) return( false );

        # return result
        return( is_user_logged_in() && current_user_can( 'manage_options' ) );
    }

   /**
    *
    * configurations
    *
    */

    # include wordpress core
    define( 'WP_USE_THEMES', false );
    require( ueldo_languages_sync_ajax_core_path() .'wp-load.php' );

    # check if user is logged-in
    if( ueldo_check_languages_sync_ajax_call_correctness() == false ) exit( esc_html( __( 'Permission denied.', 'ueldo' ) ) );

    # do we have pack key?
    if( !isset( $_POST ) || !isset( $_POST['current_lang'] ) || !isset( $_POST['new_lang'] ) ) exit( esc_html( __( 'Incorrect input data.', 'ueldo' ) ) );

    # get theme options
    $options = get_option( 'ueldo_theme_options' );

    # there's no any options found?
    if( $options == false ) exit( esc_html( __( 'Could not get any theme options.', 'ueldo' ) ) );

   /**
    *
    * replace current language value with new language value
    *
    */

    function ueldo_languages_sync_ajax_set_same_values( $array, $current_lang, $new_lang ) {

        # there's no new language?
        if( !isset( $array[esc_attr( $new_lang )] ) ) {

            # current language exists?
            if( isset( $array[esc_attr( $current_lang )] ) ) unset( $array[esc_attr( $current_lang )] );
        }

        # there is a new language value
        else {

            # copy the value from new to current
            $array[esc_attr( $current_lang )] = $array[esc_attr( $new_lang )];
        }

        # return array
        return( $array );
    }

   /**
    *
    * update all wp_editor contents
    *
    */

    function ueldo_languages_sync_ajax_update_all_contents( $current_lang, $new_lang ) {

        # walk for each keys
        foreach( ueldo_get_editor_keys() as $key ) {

            # prepare content keys
            $keys = array(
                'current-lang' => esc_attr( $key . strtolower( esc_attr( $current_lang ) ) ),
                'new-lang' => esc_attr( $key . strtolower( esc_attr( $new_lang ) ) )
            );

            # get the content for new language
            $new_lang_content = get_option( $keys['new-lang'] );

            # content for new language exists
            if( $new_lang_content !== false ) update_option( $keys['current-lang'], $new_lang_content );

            # content for new language doesn't exists
            else delete_option( $keys['current-lang'] );

            # remove temporary variables
            unset( $new_lang_content );
        }
    }

   /**
    *
    * walk through theme options array
    *
    */

    # prepare updated options array
    $options_updated = $options;

    # walk for each theme options
    foreach( $options as $option_key => $option_value ) {

        # is this option an array?
        if( is_array( $option_value ) ) {

            # is it not an multidimensional array?
            if( count( $option_value ) == count( $option_value, COUNT_RECURSIVE ) ) $options_updated[$option_key] = ueldo_languages_sync_ajax_set_same_values( $option_value, esc_attr( $_POST['current_lang'] ), esc_attr( $_POST['new_lang'] ) );
            else {

                # walk for each child option
                foreach( $option_value as $child_key => $child_value ) {

                    # is this option an array?
                    if( is_array( $child_value ) ) $options_updated[$option_key][$child_key] = ueldo_languages_sync_ajax_set_same_values( $child_value, esc_attr( $_POST['current_lang'] ), esc_attr( $_POST['new_lang'] ) );
                }
            }
        }
    }

    # update all contents values
    ueldo_languages_sync_ajax_update_all_contents( esc_attr( $_POST['current_lang'] ), esc_attr( $_POST['new_lang'] ) );

    # update theme options array
    if( update_option( 'ueldo_theme_options', $options_updated ) ) exit( 'OK' );

    # something goes wrong
    exit( esc_html( __( 'Could not update theme options.', 'ueldo' ) ) );

   /**
    *
    * end of ajax file.
    *
    */

?>