<?php

   /**
    *
    * register languages sync page
    *
    */

    add_action( 'admin_menu', 'ueldo_plugin_add_languages_sync_page' );
    function ueldo_plugin_add_languages_sync_page() {

        # do we have any language added?
        if( !ueldo_is_multilingual() || ueldo_get_languages_list() == false ) return;

        # add theme page for languages sync
        $ueldo_languages_sync_page = add_submenu_page(
            'ueldo_dashboard',
            esc_html( __( 'Languages Sync', 'ueldo' ) ),
            esc_html( __( 'Languages Sync', 'ueldo' ) ),
            'manage_options',
            'ueldo_languages_sync',
            'ueldo_show_languages_sync_page'
        );

        # load scripts and styles for languages sync page
        add_action( 'load-'. $ueldo_languages_sync_page, 'ueldo_load_scripts_for_languages_sync_page' );
    }

   /**
    *
    * add action - enqueue scripts and styles for languages sync page
    *
    */

    function ueldo_load_scripts_for_languages_sync_page() {

        # add action for "admin_enqueue_scripts" hook
        add_action( 'admin_enqueue_scripts', 'ueldo_scripts_and_styles_for_languages_sync_page' );
    }

   /**
    *
    * all scripts and styles needed by languages sync page
    *
    */

    function ueldo_scripts_and_styles_for_languages_sync_page() {

        # enqueue icons uploader script
        wp_enqueue_script( 'ueldo-plugin-languages-sync-javascript-functions', ueldo_plugin_get_url() .'_parts/_languages-sync/languages-sync.js', array( 'jquery' ), null, true );

        # localize strings for scripts
        wp_localize_script( 'ueldo-plugin-languages-sync-javascript-functions', 'ueldo_plugin_languages_sync_javascript_functions_l10n', array(
            'ajax_path' => ueldo_plugin_get_url() .'_parts/_languages-sync/languages-sync-ajax.php',
            'redirect_path' => esc_attr( $_SERVER['REQUEST_URI'] ) .'&updated=true'
        ));

        # enqueue icons uploader stylesheet
        wp_enqueue_style( 'ueldo-plugin-languages-sync-stylesheet', ueldo_plugin_get_url() .'_parts/_languages-sync/languages-sync.css', false, null );

        # add inline css style
        wp_add_inline_style( 'ueldo-plugin-languages-sync-stylesheet', '.ueldo-languages-sync-single-language .ueldo-languages-sync-logo-preview { background: url( "'. esc_attr( get_template_directory_uri() ) .'/_assets/_img/_theme-options/transparency.png" ) repeat; }' );
    }

   /**
    *
    * get and translate theme options value
    *
    */

    function ueldo_languages_sync_get_and_translate_theme_options_value( $section, $language = false, $subsection = false ) {

        # global variables
        global $ueldo_languages_sync_cache;

        # do we have font section?
        if( $section == 'fonts' || ( $section == 'side-menu' && $subsection == 'menu-link-font' ) ) {

            # get font options
            $font = array(
                'family' => ueldo_get_theme_options_value( $section, $language, esc_attr( $subsection ) .'-family' ),
                'weight' => ueldo_get_theme_options_value( $section, $language, esc_attr( $subsection ) .'-weight' ),
                'subset' => ueldo_get_theme_options_value( $section, $language, esc_attr( $subsection ) .'-subset' ),
                'smoothing' => ueldo_get_theme_options_value( $section, $language, esc_attr( $subsection ) .'-smoothing' )
            );

            # prepare the result
            $result = esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( $font['family'] ) .'<br />'. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( $font['weight'] ) .'<br />'. ( !empty( $font['subset'] ) ? ( esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( $font['subset'] ) .'<br />' ) : '' ) . esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( $font['smoothing'] == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) );
        }

        # other sections
        else {

            # get theme options value
            $result = ueldo_get_theme_options_value( $section, $language, $subsection );

            # switch by section and subsection
            switch( $section . esc_attr( $subsection != false ? esc_attr( '-'. $subsection ) : '' ) ) {

                # 404 page
                case '404-page-id':

                    # default?
                    if( $result == 'default' ) return( esc_html( __( 'Use default 404 page', 'ueldo' ) ) );

                    # walk through each page
                    foreach( $ueldo_languages_sync_cache -> get_data( 'pages' ) as $single_page ) {

                        # do we havet the match?
                        if( $result == esc_attr( $single_page -> ID ) ) return( esc_html( $single_page -> post_title ) );
                    }

                    # still here? return default
                    return( esc_html( __( 'Use default 404 page', 'ueldo' ) ) );

                break;

                # get content from
                case 'footer-content-get-content-from':
                case 'header-get-content-from':
                case 'header-get-second-content-from':

                    # default?
                    if( $result == 'default' ) {

                        # header or footer?
                        return( $section == 'header' ? esc_html( __( 'Use default theme header', 'ueldo' ) ) : esc_html( __( 'Use default theme footer', 'ueldo' ) ) );
                    }

                    else {

                        # get "headers and footers" available pages
                        $hefos = $ueldo_languages_sync_cache -> get_data( 'hefos' );

                        # do we have "headers and footers" added?
                        if( $hefos != false && $hefos != null && is_array( $hefos ) ) {

                            # walk through each "headers and footers"
                            foreach( $hefos as $hefo ) {

                                # do we have the match?
                                if( $result == esc_attr( $hefo -> ID ) ) return( esc_html( $hefo -> post_title ) );
                            }
                        }

                        # still here? return default
                        return( $section == 'header' ? esc_html( __( 'Use default theme header', 'ueldo' ) ) : esc_html( __( 'Use default theme footer', 'ueldo' ) ) );
                    }

                break;

                # footer position
                case 'footer-content-position':

                    # static or fixed to bottom?
                    return( $result == 'static' ? esc_html( __( 'Static', 'ueldo' ) ) : esc_html( __( 'Fixed to bottom', 'ueldo' ) ) );

                break;

                # header position
                case 'header-position':

                    # flying or static?
                    return( $result == 'flying' ? esc_html( __( 'Flying', 'ueldo' ) ) : esc_html( __( 'Static', 'ueldo' ) ) );

                break;

                # yes / no
                case 'header-use-second-header':
                case 'rtl-is-rtl':

                    # yes or no?
                    return( $result == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) );

                break;

                # auto / yes / no
                case 'rtl-load-rtl-admin-styles':

                    # return result
                    return( $result == 'auto' ? esc_html( __( 'Auto', 'ueldo' ) ) : ( $result == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) ) );

                break;

                # side-menu menu key
                case 'side-menu-menu-key':

                    # first available menu
                    $first_menu = '';

                    # walk for each available menus
                    foreach( $ueldo_languages_sync_cache -> get_data( 'menus' ) as $menu_name => $menu_key ) {

                        # there's no first menu set?
                        if( empty( $first_menu ) ) $first_menu = $menu_name;

                        # compare with menu key
                        if( $result == esc_attr( $menu_key ) ) return( $menu_name );
                    }

                    # return first available menu
                    return( $first_menu );

                break;

                # vc sections on blog pages
                case 'vc-sections-on-blog-pages-posts-list-above':
                case 'vc-sections-on-blog-pages-posts-list-under':
                case 'vc-sections-on-blog-pages-single-post-above':
                case 'vc-sections-on-blog-pages-single-post-under':
                case 'vc-sections-on-blog-pages-archive-above':
                case 'vc-sections-on-blog-pages-archive-under':
                case 'vc-sections-on-blog-pages-search-above':
                case 'vc-sections-on-blog-pages-search-under':

                    # default?
                    if( $result == 'none' ) {

                        # header or footer?
                        return( esc_html( __( 'None', 'ueldo' ) ) );
                    }

                    else {

                        # get "headers and footers" available pages
                        $hefos = $ueldo_languages_sync_cache -> get_data( 'hefos' );

                        # do we have "headers and footers" added?
                        if( $hefos != false && $hefos != null && is_array( $hefos ) ) {

                            # walk through each "headers and footers"
                            foreach( $hefos as $hefo ) {

                                # do we have the match?
                                if( $result == esc_attr( $hefo -> ID ) ) return( esc_html( $hefo -> post_title ) );
                            }
                        }

                        # still here? return default
                        return( esc_html( __( 'None', 'ueldo' ) ) );
                    }

                break;
            }
        }

        # return result
        return( $result );
    }

   /**
    *
    * this function displays languages sync page
    *
    */

    function ueldo_show_languages_sync_page() {

        # get global variables
        global $ueldo_cache_option;

        # get the languages array
        $languages = array_merge( array( 'default' ), ueldo_get_languages_list() );

        ?>
        <div class="wrap">

            <div class="ueldo-languages-sync-confirm">

                <div class="ueldo-languages-sync-confirm-content">

                    <div class="ueldo-languages-sync-confirm-content-padding">

                        <h4><?php echo esc_html( __( 'Please confirm this action', 'ueldo' ) ); ?></h4>
                        <p><?php echo esc_html( __( 'This action can not be undone; all current data for selected language will be overwritten.', 'ueldo' ) ); ?></p>

                        <button type="button" class="button button-primary" data-action="confirm"><?php echo esc_html( __( 'Confirm the sync', 'ueldo' ) ); ?></button>
                        <button type="button" class="button" data-action="cancel"><?php echo esc_html( __( 'Cancel', 'ueldo' ) ); ?></button>

                    </div>

                </div>

            </div>

            <div class="ueldo-languages-sync-wrapper">

                <div class="ueldo-languages-sync-container">

                    <?php

                        # do we have update?
                        if( isset( $_GET['updated'] ) && $_GET['updated'] == 'true' ) {

                            ?>
                            <div class="ueldo-languages-sync-messages">

                                <div class="updated">

                                    <p><?php echo esc_html( __( 'Successful synchronization!', 'ueldo' ) ); ?></p>

                                </div>

                            </div>
                            <?php
                        }

                        # walk for each language
                        for( $i = 0; $i < count( $languages ); $i++ ) {

                            # language key for editor
                            $lang_key = $languages[$i] == 'default' ? 'all' : strtolower( esc_attr( $languages[$i] ) );

                            # get the language name
                            if( $languages[$i] == 'default' ) $language_name = esc_html( __( 'Default', 'ueldo' ) );
                            else $language_name = ueldo_get_language_name( $languages[$i] );

                            ?>
                            <div class="ueldo-languages-sync-single-language">

                                <div class="ueldo-languages-sync-single-language-name-container">

                                    <div class="ueldo-languages-sync-single-language-name"><?php echo esc_html( $language_name ); ?></div>

                                </div>

                                <div class="ueldo-languages-sync-single-language-data">

                                    <h3><?php echo esc_html( __( '404 page', 'ueldo' ) ); ?></h3>
                                    <table>

                                        <tr>

                                            <td><?php echo esc_html( __( '404 page:', 'ueldo' ) ); ?></td>
                                            <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( '404-page-id', esc_attr( $lang_key ) ) ); ?></td>

                                        </tr>

                                    </table>

                                    <h3><?php echo esc_html( __( 'Facebook FanPage', 'ueldo' ) ); ?></h3>
                                    <table>

                                        <tr>

                                            <td><?php echo esc_html( __( 'URL:', 'ueldo' ) ); ?></td>
                                            <td><?php echo ueldo_languages_sync_get_and_translate_theme_options_value( 'facebook-fanpage-url', esc_attr( $lang_key ) ); ?></td>

                                        </tr>

                                    </table>

                                    <h3><?php echo esc_html( __( 'Fonts', 'ueldo' ) ); ?></h3>
                                    <table>

                                        <tr>

                                            <td><?php echo esc_html( __( 'General font:', 'ueldo' ) ); ?></td>
                                            <td><?php echo ueldo_languages_sync_get_and_translate_theme_options_value( 'fonts', esc_attr( $lang_key ), 'general-font' ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'General bold font:', 'ueldo' ) ); ?></td>
                                            <td><?php echo ueldo_languages_sync_get_and_translate_theme_options_value( 'fonts', esc_attr( $lang_key ), 'general-bold-font' ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Menu font:', 'ueldo' ) ); ?></td>
                                            <td><?php echo ueldo_languages_sync_get_and_translate_theme_options_value( 'fonts', esc_attr( $lang_key ), 'menu-font' ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Headings font:', 'ueldo' ) ); ?></td>
                                            <td><?php echo ueldo_languages_sync_get_and_translate_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-font' ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Headings slim font:', 'ueldo' ) ); ?></td>
                                            <td><?php echo ueldo_languages_sync_get_and_translate_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-slim-font' ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Headings bold font:', 'ueldo' ) ); ?></td>
                                            <td><?php echo ueldo_languages_sync_get_and_translate_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-bold-font' ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Headings subtitle font:', 'ueldo' ) ); ?></td>
                                            <td><?php echo ueldo_languages_sync_get_and_translate_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-subtitle-font' ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Form fields font:', 'ueldo' ) ); ?></td>
                                            <td><?php echo ueldo_languages_sync_get_and_translate_theme_options_value( 'fonts', esc_attr( $lang_key ), 'form-fields-font' ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Blockquote font:', 'ueldo' ) ); ?></td>
                                            <td><?php echo ueldo_languages_sync_get_and_translate_theme_options_value( 'fonts', esc_attr( $lang_key ), 'blockquote-font' ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Alert messages font:', 'ueldo' ) ); ?></td>
                                            <td><?php echo ueldo_languages_sync_get_and_translate_theme_options_value( 'fonts', esc_attr( $lang_key ), 'alert-messages-font' ); ?></td>

                                        </tr>

                                    </table>

                                    <h3><?php echo esc_html( __( 'Footer content', 'ueldo' ) ); ?></h3>
                                    <table>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Get content from:', 'ueldo' ) ); ?></td>
                                            <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'footer-content', esc_attr( $lang_key ), 'get-content-from' ) ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Position:', 'ueldo' ) ); ?></td>
                                            <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'footer-content', esc_attr( $lang_key ), 'position' ) ); ?></td>

                                        </tr>

                                    </table>

                                    <?php

                                        # get footer content
                                        $content = ueldo_get_theme_options_value( 'footer-content', 'ueldo_theme_options_footer_content_'. strtolower( esc_attr( $lang_key ) ) );

                                        # is not empty?
                                        if( !empty( $content ) ) {

                                            ?>
                                            <div class="ueldo-languages-sync-content-preview"><?php echo wpautop( $content ); ?></div>
                                            <?php
                                        }

                                        # remove the content variable
                                        unset( $content );

                                    ?>

                                    <h3><?php echo esc_html( __( 'Header', 'ueldo' ) ); ?></h3>
                                    <table>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Get content from:', 'ueldo' ) ); ?></td>
                                            <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'header', esc_attr( $lang_key ), 'get-content-from' ) ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Position:', 'ueldo' ) ); ?></td>
                                            <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'header', esc_attr( $lang_key ), 'position' ) ); ?></td>

                                        </tr>

                                        <?php

                                            # only if header-position is set to "static"
                                            if( ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'position' ) == 'static' ) {

                                                ?>
                                                <tr>

                                                    <td><?php echo esc_html( __( 'Use second header:', 'ueldo' ) ); ?></td>
                                                    <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'header', esc_attr( $lang_key ), 'use-second-header' ) ); ?></td>

                                                </tr>

                                                <tr>

                                                    <td><?php echo esc_html( __( 'Get second header content from:', 'ueldo' ) ); ?></td>
                                                    <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'header', esc_attr( $lang_key ), 'get-second-content-from' ) ); ?></td>

                                                </tr>

                                                <tr>

                                                    <td><?php echo esc_html( __( 'Second header visible from:', 'ueldo' ) ); ?></td>
                                                    <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'header', esc_attr( $lang_key ), 'second-header-visible-from' ) ); ?>px</td>

                                                </tr>
                                                <?php

                                            # end of second header options
                                            }

                                        ?>

                                    </table>

                                    <?php

                                        # do we have default header bar?
                                        if( ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'get-content-from' ) == 'default' ) {

                                            ?>
                                            <h3><?php echo esc_html( __( 'Default header logo image', 'ueldo' ) ); ?></h3>
                                            <div class="ueldo-languages-sync-logo-preview">

                                                <img src="<?php echo esc_attr( ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'default-logo-image' ) ); ?>" />

                                            </div>
                                            <?php

                                        # end of default header bar logo
                                        }

                                        # do we have second header bar also default?
                                        if( ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'position' ) == 'static' && ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'use-second-header' ) == 'yes' && ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'get-second-content-from' ) == 'default' ) {

                                            ?>
                                            <h3><?php echo esc_html( __( 'Second header logo image', 'ueldo' ) ); ?></h3>
                                            <div class="ueldo-languages-sync-logo-preview">

                                                <img src="<?php echo esc_attr( ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'second-header-logo-image' ) ); ?>" />

                                            </div>
                                            <?php

                                        # end of second header bar default logo image
                                        }

                                        # is loader animation enabled and logo is used?
                                        if( ueldo_get_theme_options_value( 'loader-animation', false, 'enabled' ) == 'yes' && ueldo_get_theme_options_value( 'loader-animation', false, 'add-logo' ) != 'no' ) {

                                            ?>
                                            <h3><?php echo esc_html( __( 'Loader animation logo image', 'ueldo' ) ); ?></h3>
                                            <div class="ueldo-languages-sync-logo-preview">

                                                <img src="<?php echo esc_attr( ueldo_get_theme_options_value( 'loader-animation', esc_attr( $lang_key ), 'logo-image' ) ); ?>" />

                                            </div>
                                            <?php
                                        }

                                        # is responsive, flying menu enabled?
                                        if( ueldo_get_theme_options_value( 'side-menu', false, 'enabled' ) == 'yes' ) {

                                            ?>
                                            <h3><?php echo esc_html( __( 'Side menu', 'ueldo' ) ); ?></h3>
                                            <table>

                                                <tr>

                                                    <td><?php echo esc_html( __( 'Menu:', 'ueldo' ) ); ?></td>
                                                    <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'side-menu', esc_attr( $lang_key ), 'menu-key' ) ); ?></td>

                                                </tr>

                                                <tr>

                                                    <td><?php echo esc_html( __( 'Menu links font:', 'ueldo' ) ); ?></td>
                                                    <td><?php echo ueldo_languages_sync_get_and_translate_theme_options_value( 'side-menu', esc_attr( $lang_key ), 'menu-link-font' ); ?></td>

                                                </tr>

                                            </table>
                                            <?php

                                            # get additional content before responsive menu
                                            $content = ueldo_get_theme_options_value( 'side-menu', 'ueldo_theme_options_responsive_menu_additional_content_before_'. strtolower( esc_attr( $lang_key ) ) );

                                            # is not empty?
                                            if( !empty( $content ) ) {

                                                ?>
                                                <h3><?php echo esc_html( __( 'Additional content before responsive menu', 'ueldo' ) ); ?></h3>
                                                <div class="ueldo-languages-sync-content-preview"><?php echo wpautop( $content ); ?></div>
                                                <?php
                                            }

                                            # remove the content variable
                                            unset( $content );

                                            # get additional content after responsive menu
                                            $content = ueldo_get_theme_options_value( 'side-menu', 'ueldo_theme_options_responsive_menu_additional_content_after_'. strtolower( esc_attr( $lang_key ) ) );

                                            # is not empty?
                                            if( !empty( $content ) ) {

                                                ?>
                                                <h3><?php echo esc_html( __( 'Additional content after responsive menu', 'ueldo' ) ); ?></h3>
                                                <div class="ueldo-languages-sync-content-preview"><?php echo wpautop( $content ); ?></div>
                                                <?php
                                            }

                                            # remove the content variable
                                            unset( $content );
                                        }

                                    ?>

                                    <h3><?php echo esc_html( __( 'RTL languages', 'ueldo' ) ); ?></h3>
                                    <table>

                                        <tr>

                                            <td><?php echo esc_html( __( 'RTL enabled?', 'ueldo' ) ); ?></td>
                                            <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'rtl', esc_attr( $lang_key ), 'is-rtl' ) ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Load RTL styles for admin pages?', 'ueldo' ) ); ?></td>
                                            <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'rtl', esc_attr( $lang_key ), 'load-rtl-admin-styles' ) ); ?></td>

                                        </tr>

                                    </table>

                                    <?php

                                        # walk for each "under single blog post" content elements
                                        for( $j = 1; $j < ( ( ( int ) ueldo_get_theme_options_value( 'under-single-blog-post-content-elements', false, 'elements-count' ) ) + 1 ); $j++ ) {

                                            # is the element type set to "custom-code"?
                                            if( ueldo_get_theme_options_value( 'under-single-blog-post-content-elements', false, 'element-'. esc_attr( $j ) .'-type' ) == 'custom-code' ) {

                                                # get the content
                                                $content = ueldo_get_theme_options_value( 'side-menu', 'ueldo_theme_options_under_single_blog_post_content_elements_element_'. esc_attr( $j ) .'_'. strtolower( esc_attr( $lang_key ) ) );

                                                # is the content empty?
                                                if( !empty( $content ) ) {

                                                    ?>
                                                    <h3><?php echo esc_html( __( 'Under single blog post content elements', 'ueldo' ) ); ?><br /> (<?php echo esc_html( __( 'element:', 'ueldo' ) ); ?> <?php echo esc_html( $j ); ?>)</h3>
                                                    <div class="ueldo-languages-sync-content-preview"><?php echo wpautop( $content ); ?></div>
                                                    <?php
                                                }
                                            }
                                        }

                                        # remove temporary variables
                                        unset( $j );

                                    ?>

                                    <h3><?php echo esc_html( __( 'Additional Visual Composer sections on Blog pages', 'ueldo' ) ); ?></h3>
                                    <table class="ueldo-languages-sync-single-language-data-last-table">

                                        <tr>

                                            <td><?php echo esc_html( __( 'Main posts list - blog - pages (top):', 'ueldo' ) ); ?></td>
                                            <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'vc-sections-on-blog-pages', esc_attr( $lang_key ), 'posts-list-above' ) ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Main posts list - blog - pages (bottom):', 'ueldo' ) ); ?></td>
                                            <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'vc-sections-on-blog-pages', esc_attr( $lang_key ), 'posts-list-under' ) ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Single blog post pages (top):', 'ueldo' ) ); ?></td>
                                            <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'vc-sections-on-blog-pages', esc_attr( $lang_key ), 'single-post-above' ) ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Single blog post pages (bottom):', 'ueldo' ) ); ?></td>
                                            <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'vc-sections-on-blog-pages', esc_attr( $lang_key ), 'single-post-under' ) ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Archive pages (top):', 'ueldo' ) ); ?></td>
                                            <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'vc-sections-on-blog-pages', esc_attr( $lang_key ), 'archive-above' ) ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Archive pages (bottom):', 'ueldo' ) ); ?></td>
                                            <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'vc-sections-on-blog-pages', esc_attr( $lang_key ), 'archive-under' ) ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Search pages (top):', 'ueldo' ) ); ?></td>
                                            <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'vc-sections-on-blog-pages', esc_attr( $lang_key ), 'search-above' ) ); ?></td>

                                        </tr>

                                        <tr>

                                            <td><?php echo esc_html( __( 'Search pages (bottom):', 'ueldo' ) ); ?></td>
                                            <td><?php echo esc_html( ueldo_languages_sync_get_and_translate_theme_options_value( 'vc-sections-on-blog-pages', esc_attr( $lang_key ), 'search-under' ) ); ?></td>

                                        </tr>

                                    </table>

                                </div>

                                <div class="ueldo-languages-sync-single-language-sync-options">

                                    <h3><?php echo esc_html( __( 'Update language options for', 'ueldo' ) ); ?> <?php echo esc_html( $language_name ); ?></h3>
                                    <p><?php echo esc_html( __( 'Set as same options as for:', 'ueldo' ) ); ?></p>

                                    <?php

                                        # walk for each language
                                        for( $j = 0; $j < count( $languages ); $j++ ) {

                                            # get language name
                                            $name = $languages[$j] == 'default' ? esc_html( __( 'Default', 'ueldo' ) ) : ueldo_get_language_name( $languages[$j] );

                                            # is it the same language name as for current box?
                                            if( $name != $language_name ) {

                                                ?>
                                                <button type="button" class="button button-secondary ueldo-languages-sync-proceed" data-current-language-key="<?php echo esc_attr( $lang_key ); ?>" data-new-language-key="<?php echo esc_attr( $languages[$j] == 'default' ? 'all' : strtolower( esc_attr( $languages[$j] ) ) ); ?>"><?php echo esc_html( $name ); ?></button>
                                                <?php
                                            }

                                        # end of languages list
                                        }

                                    ?>

                                </div>

                            </div>
                            <?php

                        # end of languages loop
                        }

                    ?>

                </div>

            </div>

        </div>
        <?php
    }

   /**
    *
    * cache class for languages sync
    *
    */

    class ueldo_languages_sync_cache {

       /**
        *
        * cached data array
        *
        */

        public $data = array();

       /**
        *
        * get value from cached data array
        *
        */

        public function get_data( $key ) {

            # is key correct?
            if( !in_array( $key, array( 'pages', 'hefos', 'menus' ), true ) ) return( false );

            # do we have this key saved in cache data?
            if( !isset( $this -> data[esc_attr( $key )] ) ) {

                # switch by data key
                switch( $key ) {

                    # get pages list
                    case 'pages': $this -> data[esc_attr( $key )] = get_pages(); break;

                    # get custom headers and footers list
                    case 'hefos': $this -> data[esc_attr( $key )] = ueldo_get_all_hefos_array(); break;

                    # get menus list
                    case 'menus': $this -> data[esc_attr( $key )] = ueldo_get_all_menus_array(); break;
                }
            }

            # return cached data
            return( $this -> data[esc_attr( $key )] );
        }

       /**
        *
        * end of class.
        *
        */
    }

    # object of languages sync cache class
    $ueldo_languages_sync_cache = new ueldo_languages_sync_cache;

   /**
    *
    * end of file.
    *
    */

?>