<?php

   /**
    *
    * installation class for "accountant" demo template
    *
    */

    class ueldo_demo_contents_loader_base extends ueldo_demo_contents_loader_installation_helper {

       /**
        *
        * install template or its parts
        *
        */

        public static function install( $parts, $icons ) {

           /**
            *
            * install revolution slider
            *
            */

            if( $parts == 'all' || in_array( 'revolution-slider-sliders', $parts, true ) ) {

                # upload revolution slider and get its id
                if( ( $slider_id = ueldo_add_demo_assets::upload_revslider( 'accountant-home-page' ) ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:revslider|context:accountant-home-page}', 'alias="'. esc_attr( $slider_id ) .'"' );

                    # remove temporary variables
                    unset( $slider_id );
                }
            }

           /**
            *
            * install forms
            *
            */

            if( $parts == 'all' || in_array( 'forms', $parts, true ) ) {

                # add form in contact form 7 plugin and get its id
                if( ( $form_id = ueldo_add_demo_assets::add_contact_form() ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:contactform7|context:accountant|inside:false}', 'id="'. esc_attr( $form_id ) .'"' );

                    # remove temporary variables
                    unset( $form_id );
                }

                # add form in mc4wp plugin and get its id
                if( ( $form_id = ueldo_add_demo_assets::add_mc4wp_form( 'accountant-footer' ) ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:mc4wp|context:accountant-footer|inside:true}', 'id=``'. esc_attr( $form_id ) .'``' );

                    # remove temporary variables
                    unset( $form_id );
                }
            }

           /**
            *
            * install blog posts
            *
            */

            if( $parts == 'all' || in_array( 'posts', $parts, true ) ) {

                # do we have default image ID?
                if( self::get_solution( 'default-image-id' ) == false ) {

                    # add solution with default image ID
                    self::add_solution( 'default-image-id', ueldo_add_demo_assets::add_image( 'default-image' ) );
                }

                # get current user data
                $current_user = wp_get_current_user();

                # add blog post
                $new_post_id = ueldo_add_demo_assets::add_blog_post( array(
                    'title' => esc_html( __( '5 universal ways to increase your Company income', 'ueldo' ) ),
                    'content' => false,
                    'thumbnail' => self::get_solution( 'default-image-id' ),
                    'category' => array( wp_create_category( esc_html( __( 'Important notes', 'ueldo' ) ) ) ),
                    'tags' => array(
                        esc_html( __( 'Company growth', 'ueldo' ) ),
                        esc_html( __( 'Tax changes', 'ueldo' ) )
                    ),
                    'comments' => array(
                        array(
                            'author' => esc_html( __( 'Mike', 'ueldo' ) ),
                            'author-email' => esc_html( __( 'mike@example.com', 'ueldo' ) ),
                         			'content' => 'Curabitur sagittis, quam lacinia mattis placerat, turpis felis ullamcorper arcu, quis dictum magna erat egestas magna. Pellentesque pharetra nisi sit amet lorem aliquet convallis. Maecenas gravida est erat, nec cursus nunc suscipit et. Maecenas vitae augue felis. Cras porttitor pellentesque malesuada. Suspendisse ultricies nulla nec nulla interdum, non tristique ex dignissim. Quisque fringilla velit eu ipsum interdum tincidunt.',
                            'replies' => array(
                                array(
                                    'author' => esc_html( $current_user -> display_name ),
                                    'author-email' => esc_html( $current_user -> user_email ),
                                    'content' => 'Nulla porta sodales sem vel tempus. Vivamus interdum ante ex, ut imperdiet ex vestibulum ut. In pretium diam a viverra lacinia. Fusce cursus, arcu nec pharetra imperdiet, neque lorem malesuada lectus, in egestas elit massa a erat. Donec efficitur sem vitae magna facilisis feugiat. Integer rhoncus augue a sollicitudin semper. Aliquam quis augue at libero imperdiet consequat molestie semper risus. In hac habitasse platea dictumst.',
                                    'user_id' => esc_attr( $current_user -> ID )
                                )
                            )
                        ),
                        array(
                         			'author' => esc_html( __( 'Monica', 'ueldo' ) ),
                         			'author-email' => esc_html( __( 'monica@example.com', 'ueldo' ) ),
                         			'content' => 'Etiam semper velit et vehicula ullamcorper. Proin at massa in nisl finibus iaculis at eget nunc. Duis rhoncus, justo quis dignissim pretium, turpis ipsum semper orci, quis porttitor nunc ante sit amet tortor. Proin dictum consectetur ex, ac venenatis nunc pulvinar in. Maecenas luctus vitae dui sollicitudin dictum. Nam rutrum condimentum diam, vel venenatis risus vehicula vel. Vivamus suscipit, velit euismod porta consectetur, eros justo fermentum ante.'
                        )
                    )
                ));

                # wait until previous post is added
                if( $new_post_id !== false ) {

                    # clear temporary variable
                    unset( $new_post_id );

                    # add blog post
                    $new_post_id = ueldo_add_demo_assets::add_blog_post( array(
                        'title' => esc_html( __( 'We are approaching the level of 400 clients of our company', 'ueldo' ) ),
                        'content' => false,
                        'thumbnail' => self::get_solution( 'default-image-id' ),
                        'category' => array( wp_create_category( esc_html( __( 'Important notes', 'ueldo' ) ) ) ),
                        'tags' => array(
                            esc_html( __( 'Company growth', 'ueldo' ) ),
                            esc_html( __( 'VAT tax', 'ueldo' ) )
                        ),
                        'comments' => array(
                            array(
                             			'author' => esc_html( __( 'Monica', 'ueldo' ) ),
                             			'author-email' => esc_html( __( 'monica@example.com', 'ueldo' ) ),
                             			'content' => 'Mauris facilisis a libero commodo mattis. Donec tempus enim vitae lacus pretium rhoncus. Proin ut varius purus. Vestibulum mattis finibus orci, vel commodo urna egestas vitae. In lectus purus, gravida ac eros et, mattis pellentesque magna. Nunc bibendum porta ante blandit venenatis. Pellentesque aliquam ac elit in fringilla. Mauris dictum, arcu et placerat ultrices, nunc est commodo leo, et pharetra purus nisl ut turpis. Proin tincidunt tellus turpis, vitae consectetur nisl condimentum sed.',
                                'replies' => array(
                                    array(
                                        'author' => esc_html( $current_user -> display_name ),
                                        'author-email' => esc_html( $current_user -> user_email ),
                                        'content' => 'Morbi aliquam magna non consectetur tincidunt. Nam sem dui, consectetur et tortor vitae, volutpat mollis nibh. Pellentesque id tempor mauris. Vivamus pulvinar turpis viverra enim condimentum, sed varius justo mattis. Sed viverra eros at sem semper consectetur. Proin eu facilisis justo. Duis vehicula mi id diam faucibus laoreet. Duis nec venenatis libero, sit amet iaculis lacus. Praesent ac feugiat est. Vestibulum commodo ultrices elementum. Nulla nec fringilla felis.',
                                        'user_id' => esc_attr( $current_user -> ID )
                                    )
                                )
                            )
                        )
                    ));

                    # wait until previous post is added
                    if( $new_post_id !== false ) {

                        # clear temporary variable
                        unset( $new_post_id );

                        # add blog post
                        $new_post_id = ueldo_add_demo_assets::add_blog_post( array(
                            'title' => esc_html( __( 'Course about changes in tax law will start in the next month', 'ueldo' ) ),
                            'content' => false,
                            'thumbnail' => self::get_solution( 'default-image-id' ),
                            'category' => array( wp_create_category( esc_html( __( 'Important notes', 'ueldo' ) ) ) ),
                            'tags' => array(
                                esc_html( __( 'Tax changes', 'ueldo' ) ),
                                esc_html( __( 'Trainings', 'ueldo' ) )
                            )
                        ));

                        # wait until previous post is added
                        if( $new_post_id !== false ) {

                            # clear temporary variable
                            unset( $new_post_id );

                            # add blog post
                            ueldo_add_demo_assets::add_blog_post( array(
                                'title' => esc_html( __( 'New rules for VAT tax applies since the next year', 'ueldo' ) ),
                                'content' => false,
                                'thumbnail' => self::get_solution( 'default-image-id' ),
                                'category' => array( wp_create_category( esc_html( __( 'Important notes', 'ueldo' ) ) ) ),
                                'tags' => array(
                                    esc_html( __( 'Tax changes', 'ueldo' ) ),
                                    esc_html( __( 'VAT tax', 'ueldo' ) )
                                ),
                                'comments' => array(
                                    array(
                                     			'author' => esc_html( __( 'Tom', 'ueldo' ) ),
                                     			'author-email' => esc_html( __( 'tom@example.com', 'ueldo' ) ),
                                     			'content' => 'Donec placerat sagittis dolor eu dignissim. Mauris sagittis tellus tortor, convallis volutpat eros pharetra vitae. Quisque augue augue, porttitor ac tortor ac, elementum ultricies augue. In imperdiet tellus pulvinar eros bibendum, ultrices tempor arcu rutrum. Morbi dapibus faucibus convallis. Integer fringilla turpis iaculis diam rutrum luctus. In imperdiet dapibus dictum. Cras porta et lacus eget semper.'
                                    )
                                )
                            ));
                        }
                    }
                }

                # remove temporary variables
                unset( $current_user );

                # posts per page
                update_option( 'posts_per_page', '2' );
            }

           /**
            *
            * add pages, but not fill it with contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # add pages and get its ids
                $pages_ids = ueldo_add_demo_assets::add_empty_pages( 'page', array(
                    '404-page' => esc_html( __( '404 page', 'ueldo' ) ),
                    'about-us' => esc_html( __( 'About us', 'ueldo' ) ),
                    'blog' => esc_html( __( 'Blog', 'ueldo' ) ),
                    'cashflow-advising' => esc_html( __( 'Cashflow Advising', 'ueldo' ) ),
                    'contact' => esc_html( __( 'Contact', 'ueldo' ) ),
                    'home' => esc_html( __( 'Home', 'ueldo' ) ),
                    'mutual-funds' => esc_html( __( 'Mutual Funds', 'ueldo' ) ),
                    'tax-consulting' => esc_html( __( 'Tax Consulting', 'ueldo' ) )
                ));

                # add headers, footers and extras
                $hefos_ids = ueldo_add_demo_assets::add_empty_pages( 'ueldohefo', array(
                    'single-blog-post-background-top' => esc_html( __( 'Single blog post background top', 'ueldo' ) ),
                    'footer' => esc_html( __( 'Footer', 'ueldo' ) ),
                    'header' => esc_html( __( 'Header', 'ueldo' ) )
                ));

                # add solution
                self::add_solution( 'pages-ids', array_merge( $pages_ids, $hefos_ids ) );

                # show page on front
                update_option( 'show_on_front', 'page' );

                # update blog posts page ID
                if( $pages_ids['blog'] != null && $pages_ids['blog'] != false ) update_option( 'page_for_posts', $pages_ids['blog'] );

                # update home page ID
                if( $pages_ids['home'] != null && $pages_ids['home'] != false ) update_option( 'page_on_front', $pages_ids['home'] );

                # remove temporary variables
                unset( $pages_ids );
            }

           /**
            *
            * install menus
            *
            */

            if( $parts == 'all' || in_array( 'menus', $parts, true ) ) {

                # add new menu
                if( is_int( $menu_id = ueldo_add_demo_assets::add_menu( 'accountant-main-menu', self::get_solution( 'pages-ids' ), true ) ) ) {

                    # add solution
                    self::add_solution( 'main-menu-id', esc_attr( $menu_id ) );
                }
            }

           /**
            *
            * get dynamic elements replacements
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) || in_array( 'pages', $parts, true ) ) {

                # get dynamic elements replacements
                $replacements = self::get_dynamic_elements_replacements( self::find_dynamic_elements( self::get_vc_contents() ), $icons, self::get_default_replacements() );
            }

           /**
            *
            * install theme options
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) ) {

                # update theme options
                update_option( 'ueldo_theme_options', self::get_theme_options_array() );

                # set additional content before side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_before_all', self::do_content_replacements( self::get_vc_contents( 'additional-before-side-menu' ), $replacements ) );

                # set additional content after side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_after_all', self::do_content_replacements( self::get_vc_contents( 'additional-after-side-menu' ), $replacements ) );

                # clear theme mods - background color and image
                remove_theme_mod( 'background_color' );
                remove_theme_mod( 'background_position_x' );
                remove_theme_mod( 'background_position_y' );
                remove_theme_mod( 'background_repeat' );
                remove_theme_mod( 'background_attachment' );
                remove_theme_mod( 'background_size' );
                remove_theme_mod( 'background_image' );
            }

           /**
            *
            * fill pages contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # walk for each pages
                foreach( self::get_solution( 'pages-ids' ) as $page_slug => $page_id ) {

                    # not for blog page
                    if( $page_slug == 'blog' ) continue;

                    # update page content
                    $result = wp_update_post( array(
                        'ID' => esc_attr( $page_id ),
                        'post_content' => self::do_content_replacements( self::get_vc_contents( esc_attr( $page_slug ) ), $replacements )
                    ));
                }

                # remove temporary variables
                unset( $replacements );
            }

           /**
            *
            * update permalinks structure
            *
            */

            if( $parts == 'all' || in_array( 'permalinks-structure', $parts, true ) ) {

                # global variable
                global $wp_rewrite;

                # write the rule
                $wp_rewrite -> set_permalink_structure( '/%postname%/' );

                # set the option
                update_option( 'rewrite_rules', false );

                # flush the rules and tell it to write htaccess
                $wp_rewrite -> flush_rules( true );
            }

           /**
            *
            * demo data installed
            *
            */

            exit( '{ "status": "ok" }' );
        }

       /**
        *
        * get possible data parts
        *
        */

        public static function get_possible_data_parts() {

            # return result
            return( array(
                'menus' => esc_html( __( 'Menus', 'ueldo' ) ),
                'posts' => esc_html( __( 'Posts', 'ueldo' ) ),
                'pages' => esc_html( __( 'Pages', 'ueldo' ) ),
                'theme-options' => esc_html( __( 'Theme options', 'ueldo' ) ),
                'forms' => esc_html( __( 'Forms', 'ueldo' ) ),
                'revolution-slider-sliders' => esc_html( __( 'Revolution Slider sliders', 'ueldo' ) ),
                'permalinks-structure' => esc_html( __( 'Permalinks structure', 'ueldo' ) )
            ));
        }

       /**
        *
        * get list of required plugins
        *
        */

        public static function get_required_plugins( $parts ) {

            # all data
            if( !is_array( $parts ) && $parts == 'all' ) {

                # return list of required plugins
                return( array(
                    'ueldo',
                    'visual-composer',
                    'revolution-slider',
                    'contact-form-7',
                    'mailchimp-for-wp'
                ));
            }

            # selected parts
            else {

                # prepare array of required plugins
                $result = array( 'ueldo' );

                # do we have to add pages?
                if( in_array( 'pages', $parts, true ) ) {

                    # return list of required plugins
                    return( array(
                        'visual-composer',
                        'revolution-slider',
                        'contact-form-7',
                        'mailchimp-for-wp'
                    ));
                }

                # do we have to add theme options?
                if( in_array( 'theme-options', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'visual-composer' ) );
                }

                # do we have to add forms?
                if( in_array( 'forms', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'contact-form-7', 'mailchimp-for-wp' ) );
                }

                # do we have to add revolution slider sliders?
                if( in_array( 'revolution-slider-sliders', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'revolution-slider' ) );
                }

                # return result
                return( $result );
            }
        }

       /**
        *
        * get default replacements
        *
        */

        public static function get_default_replacements() {

            # add logo image
            $logo_image_id = ueldo_add_demo_assets::add_image( 'accountant-logo-demo-like' );

            # add services menu
            $services_menu_id = ueldo_add_demo_assets::add_menu( 'accountant-services' );

            # add pages menu
            $pages_menu_id = ueldo_add_demo_assets::add_menu( 'accountant-pages' );

            # return result
            return( array(
                '{ueldopredefinedsections:googlemap|context:accountant-new-york}' => 'google_map_id="1"',
                '{ueldopredefinedsections:googlemap|context:accountant-miami}' => 'google_map_id="2"',
                '{ueldopredefinedsections:googlemap|context:accountant-dublin}' => 'google_map_id="3"',
                '{ueldopredefinedsections:menu|context:accountant-services}' => ( $services_menu_id == false ? '' : 'menu_id="'. esc_attr( $services_menu_id ) .'"' ),
                '{ueldopredefinedsections:menu|context:accountant-pages}' => ( $pages_menu_id == false ? '' : 'menu_id="'. esc_attr( $pages_menu_id ) .'"' ),
                '{ueldopredefinedsections:image|context:accountant-logo-demo-like}' => ( $logo_image_id == false ? '' : 'image="'. esc_attr( $logo_image_id ) .'"' )
            ));
        }

       /**
        *
        * get trusted solution
        *
        */

        public static function get_trusted_solution( $type, $solution ) {

            # do we have solution found?
            if( !empty( $solution ) ) return( $solution );

            # switch by solution type
            switch( $type ) {

                # get most similar elements
                case 'main-menu-slug': return( self::get_most_similar_element( 'menu_slug', esc_html( __( 'Main menu - Accountant template', 'ueldo' ) ) ) );
                case '404-page-id': return( self::get_most_similar_element( 'page', esc_html( __( '404 page', 'ueldo' ) ) ) );
                case 'footer-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Footer', 'ueldo' ) ) ) );
                case 'header-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Header', 'ueldo' ) ) ) );
                case 'single-blog-post-background-top-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Single blog post background top', 'ueldo' ) ) ) );
            }

            # nothing found
            return( false );
        }

       /**
        *
        * get theme options array
        *
        */

        public static function get_theme_options_array() {

            # return result
            return( array(
                '404-page-id' => array( 'all' => self::get_trusted_solution( '404-page-id', self::get_solution( 'pages-ids', '404-page' ) ) ),
                'blog-posts-list-style' => array(
                    'posts-list-style' => 'default',
                    'display-post-data-under-title' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'yes'
                ),
                'blog-sidebar' => array(
                    'posts-list' => 'no',
                    'single-post' => 'no',
                    'responsive-style' => 'static'
                ),
                'boxed-website' => array(
                    'enabled' => 'no',
                    'large-content-width' => '1100',
                    'large-content-space' => '50',
                    'medium-content-width' => '890',
                    'medium-content-space' => '50',
                    'small-content-width' => '665',
                    'small-content-space' => '50'
                ),
                'comment-textarea-at-top' => 'yes',
                'dynamic-theme-styles-cache' => array(
                    'enabled' => 'no',
                    'clear-cache' => 'all-the-time-when-logged-in'
                ),
                'facebook-fanpage-url' => array( 'all' => 'https://www.facebook.com/envato' ),
                'featured-image-on-lists-only' => 'no',
                'fonts' => array(
                    'general-font-family' => array( 'all' => 'Roboto' ),
                    'general-font-weight' => array( 'all' => '300' ),
                    'general-font-subset' => array( 'all' => 'latin' ),
                    'general-font-smoothing' => array( 'all' => 'yes' ),
                    'general-bold-font-family' => array( 'all' => 'Roboto' ),
                    'general-bold-font-weight' => array( 'all' => '600' ),
                    'general-bold-font-subset' => array( 'all' => 'latin' ),
                    'general-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-font-family' => array( 'all' => 'Roboto' ),
                    'menu-font-weight' => array( 'all' => '500' ),
                    'menu-font-subset' => array( 'all' => 'latin' ),
                    'menu-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-font-family' => array( 'all' => 'Roboto' ),
                    'headings-font-weight' => array( 'all' => '500' ),
                    'headings-font-subset' => array( 'all' => 'latin' ),
                    'headings-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-slim-font-family' => array( 'all' => 'Roboto' ),
                    'headings-slim-font-weight' => array( 'all' => '300' ),
                    'headings-slim-font-subset' => array( 'all' => 'latin' ),
                    'headings-slim-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-bold-font-family' => array( 'all' => 'Roboto' ),
                    'headings-bold-font-weight' => array( 'all' => '900' ),
                    'headings-bold-font-subset' => array( 'all' => 'latin' ),
                    'headings-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-subtitle-font-family' => array( 'all' => 'Roboto' ),
                    'headings-subtitle-font-weight' => array( 'all' => '700' ),
                    'headings-subtitle-font-subset' => array( 'all' => 'latin' ),
                    'headings-subtitle-font-smoothing' => array( 'all' => 'yes' ),
                    'buttons-font-family' => array( 'all' => 'Roboto' ),
                    'buttons-font-weight' => array( 'all' => '700' ),
                    'buttons-font-subset' => array( 'all' => 'latin' ),
                    'buttons-font-smoothing' => array( 'all' => 'yes' ),
                    'form-fields-font-family' => array( 'all' => 'Roboto' ),
                    'form-fields-font-weight' => array( 'all' => '400' ),
                    'form-fields-font-subset' => array( 'all' => 'latin' ),
                    'form-fields-font-smoothing' => array( 'all' => 'yes' ),
                    'blockquote-font-family' => array( 'all' => 'Roboto' ),
                    'blockquote-font-weight' => array( 'all' => '500' ),
                    'blockquote-font-subset' => array( 'all' => 'latin' ),
                    'blockquote-font-smoothing' => array( 'all' => 'yes' ),
                    'alert-messages-font-family' => array( 'all' => 'Roboto' ),
                    'alert-messages-font-weight' => array( 'all' => '400' ),
                    'alert-messages-font-subset' => array( 'all' => 'latin' ),
                    'alert-messages-font-smoothing' => array( 'all' => 'yes' )
                ),
                'footer-content' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'footer-page-id', self::get_solution( 'pages-ids', 'footer' ) ) ),
                    'position' => array( 'all' => 'static' )
                ),
                'google-maps' => array(
                    'api-key' => '',
                    'next-map-id' => '4',
                    'google-map-1-title' => esc_html( __( 'New York office', 'ueldo' ) ),
                    'google-map-1-center-lat' => '40.713689',
                    'google-map-1-center-lng' => '-74.005294',
                    'google-map-1-zoom' => '16',
                    'google-map-1-markers-next-marker-id' => '2',
                    'google-map-1-markers-marker-1-title' => esc_html( __( 'Marker', 'ueldo' ) ),
                    'google-map-1-markers-marker-1-lat' => '40.713689',
                    'google-map-1-markers-marker-1-lng' => '-74.005294',
                    'google-map-1-markers-marker-1-use-custom-marker' => 'no',
                    'google-map-1-markers-marker-1-custom-icon-library' => 'fontawesome',
                    'google-map-1-markers-marker-1-custom-icon' => 'fa fa-address-book',
                    'google-map-1-markers-marker-1-custom-icon-size' => '18',
                    'google-map-1-markers-marker-1-custom-icon-width' => '36',
                    'google-map-1-markers-marker-1-custom-icon-height' => '36',
                    'google-map-1-markers-marker-1-custom-icon-border-radius' => 'circle',
                    'google-map-1-markers-marker-1-custom-icon-border-radius-px' => '4',
                    'google-map-1-markers-marker-1-custom-icon-color' => '#121c82',
                    'google-map-1-markers-marker-1-custom-icon-background-color' => '#fff',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-horizontal-length' => '0',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-vertical-length' => '5',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-blur-radius' => '20',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-spread-radius' => '0',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-color' => 'rgba( 0, 0, 0, 0.1 )',
                    'google-map-1-markers-marker-1-custom-marker-image' => '',
                    'google-map-1-custom-style' => '[{"featureType":"administrative","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":20}]},{"featureType":"road","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":40}]},{"featureType":"water","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-10},{"lightness":30}]},{"featureType":"landscape.man_made","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":10}]},{"featureType":"landscape.natural","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":60}]},{"featureType":"poi","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]},{"featureType":"transit","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]}]',
                    'google-map-2-title' => esc_html( __( 'Miami office', 'ueldo' ) ),
                    'google-map-2-center-lat' => '25.771694',
                    'google-map-2-center-lng' => '-80.190123',
                    'google-map-2-zoom' => '16',
                    'google-map-2-markers-next-marker-id' => '2',
                    'google-map-2-markers-marker-1-title' => esc_html( __( 'Marker', 'ueldo' ) ),
                    'google-map-2-markers-marker-1-lat' => '25.771694',
                    'google-map-2-markers-marker-1-lng' => '-80.190123',
                    'google-map-2-markers-marker-1-use-custom-marker' => 'no',
                    'google-map-2-markers-marker-1-custom-icon-library' => 'fontawesome',
                    'google-map-2-markers-marker-1-custom-icon' => 'fa fa-address-book',
                    'google-map-2-markers-marker-1-custom-icon-size' => '18',
                    'google-map-2-markers-marker-1-custom-icon-width' => '36',
                    'google-map-2-markers-marker-1-custom-icon-height' => '36',
                    'google-map-2-markers-marker-1-custom-icon-border-radius' => 'circle',
                    'google-map-2-markers-marker-1-custom-icon-border-radius-px' => '4',
                    'google-map-2-markers-marker-1-custom-icon-color' => '#121c82',
                    'google-map-2-markers-marker-1-custom-icon-background-color' => '#fff',
                    'google-map-2-markers-marker-1-custom-icon-box-shadow-horizontal-length' => '0',
                    'google-map-2-markers-marker-1-custom-icon-box-shadow-vertical-length' => '5',
                    'google-map-2-markers-marker-1-custom-icon-box-shadow-blur-radius' => '20',
                    'google-map-2-markers-marker-1-custom-icon-box-shadow-spread-radius' => '0',
                    'google-map-2-markers-marker-1-custom-icon-box-shadow-color' => 'rgba( 0, 0, 0, 0.1 )',
                    'google-map-2-markers-marker-1-custom-marker-image' => '',
                    'google-map-2-custom-style' => '[{"featureType":"administrative","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":20}]},{"featureType":"road","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":40}]},{"featureType":"water","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-10},{"lightness":30}]},{"featureType":"landscape.man_made","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":10}]},{"featureType":"landscape.natural","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":60}]},{"featureType":"poi","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]},{"featureType":"transit","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]}]',
                    'google-map-3-title' => esc_html( __( 'Dublin office', 'ueldo' ) ),
                    'google-map-3-center-lat' => '53.349524',
                    'google-map-3-center-lng' => '-6.260238',
                    'google-map-3-zoom' => '16',
                    'google-map-3-markers-next-marker-id' => '2',
                    'google-map-3-markers-marker-1-title' => esc_html( __( 'Marker', 'ueldo' ) ),
                    'google-map-3-markers-marker-1-lat' => '53.349524',
                    'google-map-3-markers-marker-1-lng' => '-6.260238',
                    'google-map-3-markers-marker-1-use-custom-marker' => 'no',
                    'google-map-3-markers-marker-1-custom-icon-library' => 'fontawesome',
                    'google-map-3-markers-marker-1-custom-icon' => 'fa fa-address-book',
                    'google-map-3-markers-marker-1-custom-icon-size' => '18',
                    'google-map-3-markers-marker-1-custom-icon-width' => '36',
                    'google-map-3-markers-marker-1-custom-icon-height' => '36',
                    'google-map-3-markers-marker-1-custom-icon-border-radius' => 'circle',
                    'google-map-3-markers-marker-1-custom-icon-border-radius-px' => '4',
                    'google-map-3-markers-marker-1-custom-icon-color' => '#121c82',
                    'google-map-3-markers-marker-1-custom-icon-background-color' => '#fff',
                    'google-map-3-markers-marker-1-custom-icon-box-shadow-horizontal-length' => '0',
                    'google-map-3-markers-marker-1-custom-icon-box-shadow-vertical-length' => '5',
                    'google-map-3-markers-marker-1-custom-icon-box-shadow-blur-radius' => '20',
                    'google-map-3-markers-marker-1-custom-icon-box-shadow-spread-radius' => '0',
                    'google-map-3-markers-marker-1-custom-icon-box-shadow-color' => 'rgba( 0, 0, 0, 0.1 )',
                    'google-map-3-markers-marker-1-custom-marker-image' => '',
                    'google-map-3-custom-style' => '[{"featureType":"administrative","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":20}]},{"featureType":"road","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":40}]},{"featureType":"water","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-10},{"lightness":30}]},{"featureType":"landscape.man_made","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":10}]},{"featureType":"landscape.natural","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":60}]},{"featureType":"poi","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]},{"featureType":"transit","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]}]'
                ),
                'header' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'header-page-id', self::get_solution( 'pages-ids', 'header' ) ) ),
                    'position' => array( 'all' => 'flying' ),
                    'use-second-header' => array( 'all' => 'no' ),
                    'get-second-content-from' => array( 'all' => 'default' ),
                    'second-header-visible-from' => array( 'all' => '400' ),
                    'default-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'second-header-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) )
                ),
                'lazy-load-images' => array(
                    'enabled' => 'no',
                    'threshold' => '0'
                ),
                'loader-animation' => array(
                    'enabled' => 'yes',
                    'style' => '01',
                    'add-logo' => 'no',
                    'space-between-logo-and-spinner' => '30',
                    'logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'custom-colors-enabled' => 'no',
                    'custom-colors-background' => '#fff',
                    'custom-colors-spinner' => '#e46e00'
                ),
                'local-scrolling-links-animation' => array(
                    'enabled' => 'yes',
                    'animation-speed' => '1000'
                ),
                'opening-hours-status' => array( 'next-status-id' => '1' ),
                'rtl' => array(
                    'is-rtl' => array( 'all' => 'no' ),
                    'load-rtl-admin-styles' => array( 'all' => 'auto' )
                ),
                'side-menu' => array(
                    'style' => 'flying-default-hidden',
                    'menu-key' => array( 'all' => self::get_trusted_solution( 'main-menu-slug', self::get_main_menu_slug() ) ),
                    'menu-link-font-family' => array( 'all' => 'Roboto' ),
                    'menu-link-font-weight' => array( 'all' => '500' ),
                    'menu-link-font-subset' => array( 'all' => 'latin' ),
                    'menu-link-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-position' => 'left',
                    'menu-links-alignment' => 'left',
                    'opacity-animation-enabled' => 'yes',
                    'submenu-links' => 'visible-on-click-as-new-layer',
                    'menu-vertical-alignment' => 'top',
                    'custom-sizes-enabled' => 'yes',
                    'custom-sizes-container-width' => '300',
                    'custom-sizes-menu-link-font-size' => '16',
                    'custom-sizes-menu-link-font-line-height' => '1.0',
                    'custom-sizes-menu-link-font-letter-spacing' => '0',
                    'custom-sizes-menu-link-padding-top-bottom' => '18',
                    'custom-sizes-menu-link-padding-left-right' => '25',
                    'custom-sizes-menu-link-margin-top-bottom' => '0',
                    'custom-sizes-menu-link-margin-left-right' => '0',
                    'custom-sizes-menu-link-bottom-border-width' => '1',
                    'custom-sizes-display-bottom-border-for-last-menu-link' => 'display',
                    'custom-sizes-menu-icon-font-size' => '10',
                    'custom-sizes-menu-icon-margin-top' => '0',
                    'custom-sizes-menu-margin-between-icon-and-title' => '10',
                    'custom-sizes-padding-top-bottom-additional-element-before-menu' => '20',
                    'custom-sizes-padding-left-right-additional-element-before-menu' => '30',
                    'custom-sizes-margin-top-additional-element-before-menu' => '0',
                    'custom-sizes-margin-right-additional-element-before-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-before-menu' => '0',
                    'custom-sizes-margin-left-additional-element-before-menu' => '0',
                    'custom-sizes-padding-top-bottom-additional-element-after-menu' => '20',
                    'custom-sizes-padding-left-right-additional-element-after-menu' => '30',
                    'custom-sizes-margin-top-additional-element-after-menu' => '0',
                    'custom-sizes-margin-right-additional-element-after-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-after-menu' => '0',
                    'custom-sizes-margin-left-additional-element-after-menu' => '0'
                ),
                'single-blog-post-style' => array(
                    'display-post-data-under-title' => 'yes',
                    'blog-post-data-and-title-centered' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'yes'
                ),
                'submit-button-position-in-comment-reply-form' => array( 'all' => 'left' ),
                'translate-publication-dates' => 'yes',
                'twitter-api' => array(
                    'oauth-key' => '',
                    'oauth-secret-key' => ''
                ),
                'under-single-blog-post-content-elements' => array(
                    'elements-count' => '3',
                    'element-1-type' => 'tags-and-categories-with-facebook',
                    'element-1-similar-posts-style' => '02',
                    'element-2-type' => 'author-box',
                    'element-2-similar-posts-style' => '02',
                    'element-3-type' => 'next-previous-posts-navigation',
                    'element-3-similar-posts-style' => '02',
                    'element-4-type' => '',
                    'element-4-similar-posts-style' => '02',
                    'element-5-type' => '',
                    'element-5-similar-posts-style' => '02',
                    'element-6-type' => '',
                    'element-6-similar-posts-style' => '02'
                ),
                'vc-sections-on-blog-pages' => array(
                    'posts-list-above' => array( 'all' => 'none' ),
                    'posts-list-under' => array( 'all' => 'none' ),
                    'single-post-above' => array( 'all' => self::get_trusted_solution( 'single-blog-post-background-top-page-id', self::get_solution( 'pages-ids', 'single-blog-post-background-top' ) ) ),
                    'single-post-under' => array( 'all' => 'none' ),
                    'archive-above' => array( 'all' => 'none' ),
                    'archive-under' => array( 'all' => 'none' ),
                    'search-above' => array( 'all' => 'none' ),
                    'search-under' => array( 'all' => 'none' )
                ),
                'visual-composer-custom-fonts' => array( 'next-font-id' => '1' ),
                'styles' => array(
                    'general-colors-main-color' => '#e46e00',
                    'general-colors-elements-inset-border-color' => '#f1f1f1',
                    'general-colors-google-map-marker-icon-color' => '#121c82',
                    'info-box-element-background-color' => '#ffffff',
                    'info-box-element-border-color' => '#ffffff',
                    'buttons-global-button-background-color' => '#e46e00',
                    'buttons-global-button-border-color' => '#e46e00',
                    'general-colors-elements-hover-border-color' => '#e0e2ef',
                    'buttons-global-button-background-color-hover' => '#121c82',
                    'buttons-global-button-border-color-hover' => '#121c82',
                    'buttons-global-button-box-shadow-hover' => '0px 10px 35px 0px rgba(18,28,130,0.15)',
                    'general-colors-headings-subtitle-color' => '#e46e00',
                    'general-colors-blog-post-data-color' => '#e46e00',
                    'header-bar-and-menu-link-color' => 'rgba(255,255,255,0.65)',
                    'header-bar-and-menu-background-color' => '#121c82',
                    'header-bar-and-menu-active-or-hover-link-color' => '#ffffff',
                    'header-bar-and-menu-submenu-background-color' => '#e46e00',
                    'header-bar-and-menu-submenu-element-link-color' => 'rgba(255,255,255,0.75)',
                    'general-colors-image-box-shadow' => '-8px 8px 75px 0px rgba(0,0,0,0.1)',
                    'general-colors-blockquote-color' => '#e46e00',
                    'side-menu-box-shadow' => '-5px 0px 65px 0px rgba(10,10,10,0.2)',
                    'side-menu-background-color' => '#ffffff',
                    'side-menu-link-color' => '#313131',
                    'side-menu-active-link-color' => '#e46e00',
                    'side-menu-link-border-bottom-color' => 'rgba(49,49,49,0.04)',
                    'side-menu-link-color-hover' => '#e46e00',
                    'side-menu-link-icon-color' => '#313131',
                    'side-menu-link-icon-color-hover' => '#e46e00',
                    'side-menu-active-link-icon-color' => '#e46e00',
                    'side-menu-link-border-bottom-color-hover' => 'rgba(49,49,49,0.04)',
                    'side-menu-link-background-color-hover' => 'rgba(255,255,255,0)',
                    'side-menu-active-link-border-bottom-color' => 'rgba(49,49,49,0.04)',
                    'forms-checkbox-radio-main-color' => '#e46e00'
                )
            ));
        }

       /**
        *
        * get default contents
        *
        */

        public static function get_vc_contents( $page_slug = false ) {

            # array of pages contents
            $contents = array(

                'home' => '[vc_section full_width="stretch_row_content"][vc_row][vc_column][rev_slider {ueldopredefinedsections:revslider|context:accountant-home-page}][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15051095649436234567890"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-6 vc_col-md-6"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_26533239603333"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_88896000282779" large_width_type="calc" large_width_calc_px="30"][ueldo_shortcode_heading class_name="ueldo_vc_element_4292534967993234567890" heading_tag="h1" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_4073697892297" heading_text="'. esc_html( __( 'Full Service Tax & Accounting Advisor', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Sed non lobortis est, at rhoncus urna. Nullam blandit eros erat, id bibendum justo egestas ut. Maecenas at cursus odio. Suspendisse vulputate ligula ac neque ornare accumsan.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15051096886171" large_height="25"][ueldo_shortcode_button class_name="ueldo_vc_element_81233523339880" button_text="'. esc_html( __( 'Schedule Consultation', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6"][ueldo_shortcode_gap class_name="ueldo_vc_element_15054553092061" large_height="0" small_custom_sizes="yes"][ueldo_shortcode_card class_name="ueldo_vc_element_15047747410359" padding_top="45" padding_right="45" padding_bottom="45" padding_left="45"][ueldo_shortcode_info_box class_name="ueldo_vc_element_28656804629591" content_alignment="left" content_position="inline" heading_vertical_alignment="top" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'tax-consulting%2F|title:'. rawurlencode( esc_html( __( 'Tax consulting', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Tax Consulting', 'ueldo' ) ) .'" info_box_subtitle="Quisque quis varius dolor, eget sagittis nulla. Donec eu mauris lobortis, accumsan est eu." info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-calculator|url:https://www.flaticon.com/free-icon/calculator_490446|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_icon_color_hover="#121c82" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_69543013998670" large_height="30"][ueldo_shortcode_info_box class_name="ueldo_vc_element_96703527886489" content_alignment="left" content_position="inline" heading_vertical_alignment="top" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'mutual-funds%2F|title:'. rawurlencode( esc_html( __( 'Mutual funds', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Mutual Funds', 'ueldo' ) ) .'" info_box_subtitle="Pellentesque eu dui sed risus sagittis suscipit in viverra ex. Sed gravida, quam id tempus." info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-money|url:https://www.flaticon.com/free-icon/money_489939|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_icon_color_hover="#121c82" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_96374122238620" large_height="30"][ueldo_shortcode_info_box class_name="ueldo_vc_element_30232861557760" content_alignment="left" content_position="inline" heading_vertical_alignment="top" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'cashflow-advising%2F|title:'. rawurlencode( esc_html( __( 'Cashflow Advising', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Cashflow Advising', 'ueldo' ) ) .'" info_box_subtitle="Nulla dictum tempus metus, ac iaculis sapien interdum id. Nunc rhoncus nunc suscipit arcu." info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-transfer-money,flaticon-money|url:https://www.flaticon.com/free-icon/transfer-money_489950|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_icon_color_hover="#121c82" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_card][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15047786501696"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15051112306352" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15051112388967" heading_text="'. esc_html( __( '300+ companies already trust us', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Nam aliquet egestas justo, non maximus velit lobortis accumsan. Ut magna enim, faucibus a odio nec, feugiat finibus odio. Praesent quis rhoncus risus. Vivamus maximus sit amet libero sed dictum. Vestibulum venenatis nunc et feugiat blandit. Mauris sagittis lobortis ultricies.</p>[ueldo_next_prev_loop_icons loop_id="15051118076458"][/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_1505111978806" large_height="25"][/vc_column][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_loop class_name="ueldo_vc_element_15051118076458" columns="4" one_column_from="extra_small" use_separate_next_prev_arrows="separated" custom_next_prev_arrows_settings="custom_settings" arrow_border_radius="2" arrow_border_width="1" autochange_enabled="yes"][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_61436773145650"][ueldo_shortcode_image class_name="ueldo_vc_element_78765855501020" horizontal_alignment="center" large_width_type="px" large_width_px="216" large_height_px="55" small_custom_sizes="yes" small_width_type="px" small_width_px="173" small_height_px="44" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="216" extra_small_height_px="55" custom_colors_enabled="custom_settings" image_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_12059336192316"][ueldo_shortcode_image class_name="ueldo_vc_element_70576765522563" horizontal_alignment="center" large_width_type="px" large_width_px="216" large_height_px="55" small_custom_sizes="yes" small_width_type="px" small_width_px="173" small_height_px="44" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="216" extra_small_height_px="55" custom_colors_enabled="custom_settings" image_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_65346986245021"][ueldo_shortcode_image class_name="ueldo_vc_element_27480100435567" horizontal_alignment="center" large_width_type="px" large_width_px="216" large_height_px="55" small_custom_sizes="yes" small_width_type="px" small_width_px="173" small_height_px="44" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="216" extra_small_height_px="55" custom_colors_enabled="custom_settings" image_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_58703097032460"][ueldo_shortcode_image class_name="ueldo_vc_element_94109817375146" horizontal_alignment="center" large_width_type="px" large_width_px="216" large_height_px="55" small_custom_sizes="yes" small_width_type="px" small_width_px="173" small_height_px="44" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="216" extra_small_height_px="55" custom_colors_enabled="custom_settings" image_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_19235140700540"][ueldo_shortcode_image class_name="ueldo_vc_element_57954699732187" horizontal_alignment="center" large_width_type="px" large_width_px="216" large_height_px="55" small_custom_sizes="yes" small_width_type="px" small_width_px="173" small_height_px="44" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="216" extra_small_height_px="55" custom_colors_enabled="custom_settings" image_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_89382218480468"][ueldo_shortcode_image class_name="ueldo_vc_element_58370592011825" horizontal_alignment="center" large_width_type="px" large_width_px="216" large_height_px="55" small_custom_sizes="yes" small_width_type="px" small_width_px="173" small_height_px="44" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="216" extra_small_height_px="55" custom_colors_enabled="custom_settings" image_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_63452955952266"][ueldo_shortcode_image class_name="ueldo_vc_element_37984375533952" horizontal_alignment="center" large_width_type="px" large_width_px="216" large_height_px="55" small_custom_sizes="yes" small_width_type="px" small_width_px="173" small_height_px="44" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="216" extra_small_height_px="55" custom_colors_enabled="custom_settings" image_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_42971133237338"][ueldo_shortcode_image class_name="ueldo_vc_element_23077010573892" horizontal_alignment="center" large_width_type="px" large_width_px="216" large_height_px="55" small_custom_sizes="yes" small_width_type="px" small_width_px="173" small_height_px="44" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="216" extra_small_height_px="55" custom_colors_enabled="custom_settings" image_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][/ueldo_shortcode_loop][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_36692181162893" large_height="30"][/vc_column][/vc_row][/vc_section][vc_section][vc_row full_width="stretch_row_content_no_spaces" el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_tabs class_name="ueldo_vc_element_1505110600015" tabs_content_style="style-03" content_position="right"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_15051106244304" single_tab_title="'. esc_html( __( 'Accountants with 20 years of experience', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_68540699304527" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_89195747577401" heading_text="'. esc_html( __( 'Accountants with over 20 years of experience', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Phasellus euismod ipsum laoreet, placerat enim interdum, porttitor erat. Ut gravida dolor a arcu consectetur elementum. Vestibulum id facilisis dui. Curabitur rhoncus nulla sit amet augue euismod pulvinar.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_37276748316403" large_height="25"][ueldo_shortcode_button class_name="ueldo_vc_element_60277500741495" button_text="'. esc_html( __( 'Find out more about us', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'about-us%2F|title:'. rawurlencode( esc_html( __( 'About us', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15051137890599"][/vc_column][/vc_row][vc_row content_placement="middle"][vc_column offset="vc_col-lg-6 vc_col-md-6"][ueldo_shortcode_heading class_name="ueldo_vc_element_82885062226842" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_28110244518812" heading_text="'. esc_html( __( 'Every year more and more companies are appreciating us', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Phasellus euismod ipsum laoreet, placerat enim interdum, porttitor erat. Ut gravida dolor a arcu consectetur elementum. Vestibulum id facilisis dui. Curabitur rhoncus nulla sit amet augue euismod pulvinar.[/vc_column_text][ueldo_shortcode_heading class_name="ueldo_vc_element_23830052033673" heading_tag="h3" display_heading_subtitle="no" heading_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'services%2Ftax-consulting%2F|title:'. rawurlencode( esc_html( __( 'Tax consulting', 'ueldo' ) ) ) .'||" custom_margins_enabled="custom_margins" custom_margin_top="60" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1320337384133" heading_text="'. esc_html( __( 'Prices starts at', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_63918463999612" heading_text="'. esc_html( __( '$49', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_17247193020227" heading_text="'. esc_html( __( '/ mo', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]for full-service accounting advisement[/vc_column_text][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6"][ueldo_shortcode_gap class_name="ueldo_vc_element_15054581830338" large_height="0" small_custom_sizes="yes"][vc_line_chart type="line" legend="" x_values="2013; 2014; 2015; 2016; 2017" values="%5B%7B%22title%22%3A%22'. esc_html( __( 'Clients', 'ueldo' ) ) .'%22%2C%22y_values%22%3A%22205%3B%20228%3B%20242%3B%20297%3B%20382%22%2C%22color%22%3A%22blue%22%7D%5D" animation="easeOutQuart"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15051159413673"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column width="2/3" offset="vc_hidden-sm vc_hidden-xs"][ueldo_shortcode_heading class_name="ueldo_vc_element_81863629142812" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_38307266512301" heading_text="'. esc_html( __( 'Recent News & Articles', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_button class_name="ueldo_vc_element_38635541013260" button_text="'. esc_html( __( 'Read all', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'blog|title:'. rawurlencode( esc_html( __( 'Blog', 'ueldo' ) ) ) .'||" button_alignment="center"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_83790511362860"][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row content_placement="middle"][vc_column width="1/2" offset="vc_hidden-lg vc_hidden-md"][ueldo_shortcode_heading class_name="ueldo_vc_element_73720466756941" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_53387831792526" heading_text="'. esc_html( __( 'Recent News & Articles', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_button class_name="ueldo_vc_element_40699737093808" button_text="'. esc_html( __( 'Read all', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'blog|title:'. rawurlencode( esc_html( __( 'Blog', 'ueldo' ) ) ) .'||" button_alignment="center"][/ueldo_shortcode_button][/vc_column][vc_column width="1/2" offset="vc_hidden-lg vc_hidden-md"][ueldo_shortcode_gap class_name="ueldo_vc_element_15054633959592" large_height="0" extra_small_custom_sizes="yes"][ueldo_shortcode_post_page_box class_name="ueldo_vc_element_29446427154421" box_style="02"][/vc_column][/vc_row][vc_row][vc_column offset="vc_hidden-lg vc_hidden-md"][ueldo_shortcode_gap class_name="ueldo_vc_element_15047812026988" large_height="0" small_custom_sizes="yes" small_height="30"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-4 vc_col-md-4 vc_hidden-sm vc_hidden-xs"][ueldo_shortcode_post_page_box class_name="ueldo_vc_element_96110307081337" box_style="02"][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4"][ueldo_shortcode_post_page_box class_name="ueldo_vc_element_22516756782410" post_no="latest_minus_1" box_style="02"][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4"][ueldo_shortcode_gap class_name="ueldo_vc_element_15054634120232" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_post_page_box class_name="ueldo_vc_element_67008343205834" post_no="latest_minus_2" box_style="02"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_69733172862606"][/vc_column][/vc_row][/vc_section]',

                'about-us' => '[vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_150528670594" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_1505286235844" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" color="rgba(255,255,255,0.01)" color_add_border="yes" color_border_width="10" color_border_color="#fdf4eb" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="30" large_height_type="calc" large_height_calc_px="200" large_margin_top="180" large_margin_left="-15" small_layer_custom_sizes="yes" small_width_type="calc" small_width_calc_operator="+" small_width_calc_px="30" small_height_type="calc" small_height_calc_px="95" small_margin_top="75" small_margin_left="-15" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="90" extra_small_height_type="calc" extra_small_height_calc_px="95" extra_small_margin_top="75" extra_small_margin_left="45"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-6 vc_col-md-6"][ueldo_shortcode_heading class_name="ueldo_vc_element_15052867883913" heading_tag="h1" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_150528679375" heading_text="'. esc_html( __( 'Many Times Rewarded Accounting Services', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_gap class_name="ueldo_vc_element_15053953100636" medium_custom_sizes="yes" medium_height="45"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15052856573185"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15052856610319" large_width_type="px" large_width_px="30" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15052856681143" large_width_type="calc" large_width_calc_px="30" small_custom_sizes="yes"][ueldo_shortcode_heading class_name="ueldo_vc_element_15052849547603" heading_tag="h5" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15052849665292" heading_text="Dulla gravida eros egestas velit. Mauris imperdiet, risus ante eu felis. Aenean aliquet. Aliquam id lectus. Ut sagittis, nunc commodo ligula, sed tortor. Fusce dui non nisl eu lectus. Vivamus pede. Morbi massa vel libero." custom_font_size_and_line_height_enabled="custom_settings" font_size="20" line_height="1.6"][/ueldo_shortcode_heading][vc_column_text]Cras at arcu a velit suscipit id, bibendum ac, semper convallis. Suspendisse turpis egestas. Praesent vitae ante. Vivamus sed libero. Maecenas bibendum tellus, volutpat tempus purus eu bibendum libero quis dui. Integer erat at erat volutpat. Nulla vestibulum dictum libero, egestas ipsum primis in augue. Vivamus nec tristique eu.[/vc_column_text][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_4246678567614" medium_custom_sizes="yes" medium_height="45"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15052857708371"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_1505285775129" large_width_type="calc" large_width_calc_px="30" small_custom_sizes="yes"][ueldo_shortcode_image class_name="ueldo_vc_element_93415408376827" large_height_px="450" small_custom_sizes="yes" small_height_px="360" margin_bottom="0"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6"][ueldo_shortcode_gap class_name="ueldo_vc_element_15054617649069" large_height="0" small_custom_sizes="yes" small_height="30"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15052857863657"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15052857891604" large_width_type="px" large_width_px="30" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15052857997638" large_width_type="calc" large_width_calc_px="30" small_custom_sizes="yes"][ueldo_shortcode_image class_name="ueldo_vc_element_62158906259676" large_height_px="610" medium_custom_sizes="yes" medium_height_px="595" small_custom_sizes="yes" small_height_px="360" margin_bottom="0"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_7068221364532" medium_custom_sizes="yes" medium_height="45"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15052858219253"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15052858251442" large_width_type="calc" large_width_calc_px="30" small_custom_sizes="yes"][vc_column_text]Quisque ut arcu. Cras at arcu a velit suscipit id, bibendum ac, semper convallis. Suspendisse turpis egestas. Praesent vitae ante. Vivamus sed libero. Maecenas bibendum tellus, volutpat tempus purus.<br /><br /> Nulla vestibulum dictum libero, egestas ipsum primis in augue. Vivamus nec tristique eu, posuere commodo, tortor eros, ut justo consequat ac, ornare dolor sit amet nunc. Maecenas rhoncus. Morbi ut diam.[/vc_column_text][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_15052859453679" large_height="51" medium_custom_sizes="yes" medium_height="88" small_custom_sizes="yes" small_height="30"][ueldo_shortcode_button class_name="ueldo_vc_element_15052859165238" button_text="'. esc_html( __( 'Schedule Consultation', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15052893311269"][/vc_column][/vc_row][vc_row][vc_column offset="vc_col-lg-3 vc_col-md-2 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_icon class_name="ueldo_vc_element_13941347404618" icon_alignment="center" {ueldopredefinedsections:icon|key:flaticon-money|url:https://www.flaticon.com/free-icon/money_489939|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e46e00"][ueldo_shortcode_heading class_name="ueldo_vc_element_1505289347615" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15052893544803" heading_text="'. esc_html( __( 'Simple plans & pricing', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Pellentesque scelerisque rutrum eros, non auctor sapien. Etiam blandit tempor nunc ac blandit. Sed ac nunc ex. Sed dictum enim vitae semper finibus. Maecenas mattis venenatis lorem sed dignissim.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15052895730019" large_height="25"][/vc_column][vc_column offset="vc_col-lg-3 vc_col-md-2 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-4 vc_col-md-4"][ueldo_shortcode_pricing_table class_name="ueldo_vc_element_48844305961036" pricing_table_style="02" content_alignment="center" title="'. esc_html( __( 'Startup', 'ueldo' ) ) .'" icon_fontawesome="fa fa-star" margin_bottom="0"][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_21797632369563"]'. wp_kses( __( 'Send up to <strong>10</strong> invoices and quotes', 'ueldo' ), array( 'strong' => array() ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_38474448872243"]'. wp_kses( __( 'Enter up to <strong>10</strong> bills', 'ueldo' ), array( 'strong' => array() ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_40504956058779"]'. wp_kses( __( 'Reconcile up to <strong>30</strong> bank transactions', 'ueldo' ), array( 'strong' => array() ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_24760593293181"]'. wp_kses( __( '30 minutes of consultancy', 'ueldo' ), array( 'strong' => array() ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_button class_name="ueldo_vc_element_55514565621144" button_text="'. esc_html( __( 'Choose the plan', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Choose the plan', 'ueldo' ) ) ) .'||" button_alignment="center"][/ueldo_shortcode_button][/ueldo_shortcode_pricing_table][/vc_column][vc_column offset="vc_col-lg-4 vc_col-md-4"][ueldo_shortcode_gap class_name="ueldo_vc_element_5149421508714" large_height="0" small_custom_sizes="yes" small_height="30"][ueldo_shortcode_pricing_table class_name="ueldo_vc_element_62358354620581" pricing_table_style="02" content_alignment="center" title="'. esc_html( __( 'Standard', 'ueldo' ) ) .'" price_value="49" show_ribbon="yes" icon_fontawesome="fa fa-star" level_icons_repeat_number="2" margin_bottom="0" custom_colors_enabled="custom_settings" background_color="#ffffff" background_color_hover="#ffffff" border_color="#e0e2ef" box_shadow_blur_radius="35" box_shadow_color="rgba(0,0,0,0.05)" box_shadow_color_hover="rgba(0,0,0,0.05)" ribbon_background_color="#121c82" ribbon_text_color="#ffffff" level_icons_color="rgba(0,0,0,0.03)"][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_64676466746514"]'. wp_kses( __( 'Send up to <strong>30</strong> invoices and quotes', 'ueldo' ), array( 'strong' => array() ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_87938997298679"]'. wp_kses( __( 'Enter up to <strong>30</strong> bills', 'ueldo' ), array( 'strong' => array() ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_78947739596936"]'. wp_kses( __( 'Reconcile up to <strong>60</strong> bank transactions', 'ueldo' ), array( 'strong' => array() ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_90178743258998"]'. wp_kses( __( '1 hour of consultancy', 'ueldo' ), array( 'strong' => array() ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_button class_name="ueldo_vc_element_60723602673945" button_text="'. esc_html( __( 'Choose the plan', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Choose the plan', 'ueldo' ) ) ) .'||" button_alignment="center"][/ueldo_shortcode_button][/ueldo_shortcode_pricing_table][/vc_column][vc_column offset="vc_col-lg-4 vc_col-md-4"][ueldo_shortcode_gap class_name="ueldo_vc_element_7980485065711" large_height="0" small_custom_sizes="yes" small_height="30"][ueldo_shortcode_pricing_table class_name="ueldo_vc_element_64675526358504" pricing_table_style="02" content_alignment="center" title="'. esc_html( __( 'No limits', 'ueldo' ) ) .'" price_value="99" icon_fontawesome="fa fa-star" level_icons_repeat_number="3" margin_bottom="0"][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_97564981830670"]'. wp_kses( __( 'Send <strong>Unlimited</strong> invoices and quotes', 'ueldo' ), array( 'strong' => array() ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_32316438294830"]'. wp_kses( __( 'Enter <strong>unlimited</strong> bills', 'ueldo' ), array( 'strong' => array() ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_75203996968957"]'. wp_kses( __( 'Reconcile <strong>unlimited</strong> bank transactions', 'ueldo' ), array( 'strong' => array() ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_22691796311099"]'. wp_kses( __( '24 hours of consultancy', 'ueldo' ), array( 'strong' => array() ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_button class_name="ueldo_vc_element_16138386463245" button_text="'. esc_html( __( 'Choose the plan', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Choose the plan', 'ueldo' ) ) ) .'||" button_alignment="center"][/ueldo_shortcode_button][/ueldo_shortcode_pricing_table][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_35330920670477"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_full_width_testimonials class_name="ueldo_vc_element_1505290552044" animation_style="on_center"][ueldo_shortcode_full_width_testimonials_single_testimonial class_name="ueldo_vc_element_7933237091585" author_description="'. esc_html( __( 'CEO of ExampleInsurance, Inc.', 'ueldo' ) ) .'" other_image_on_hover="yes"][vc_column_text]Ut finibus ex non nunc dapibus consectetur. Nullam vitae massa malesuada, luctus libero vel, pellentesque leo. Donec sit amet massa a sapien viverra vehicula. In iaculis tristique risus, sit amet convallis odio porta at. Mauris ex sapien, elementum quis augue vestibulum, gravida aliquet dui. Cras auctor auctor lectus quis tempor. Nulla id augue lectus. Aenean neque dolor, volutpat maximus erat sed.[/vc_column_text][/ueldo_shortcode_full_width_testimonials_single_testimonial][ueldo_shortcode_full_width_testimonials_single_testimonial class_name="ueldo_vc_element_1809844050730" author_name="'. esc_html( __( 'Susane Smith', 'ueldo' ) ) .'" author_description="'. esc_html( __( 'Director on JustAnotherInsurance & Co.', 'ueldo' ) ) .'" other_image_on_hover="yes"][vc_column_text]Ut finibus ex non nunc dapibus consectetur. Nullam vitae massa malesuada, luctus libero vel, pellentesque leo. Donec sit amet massa a sapien viverra vehicula. In iaculis tristique risus, sit amet convallis odio porta at. Mauris ex sapien, elementum quis augue vestibulum, gravida aliquet dui. Cras auctor auctor lectus quis tempor. Nulla id augue lectus. Aenean neque dolor, volutpat maximus erat sed.[/vc_column_text][/ueldo_shortcode_full_width_testimonials_single_testimonial][ueldo_shortcode_full_width_testimonials_single_testimonial class_name="ueldo_vc_element_9492085804908" author_name="'. esc_html( __( 'Tom Smith', 'ueldo' ) ) .'" author_description="'. esc_html( __( 'Owner of SomeCreditCard, Inc.', 'ueldo' ) ) .'" other_image_on_hover="yes"][vc_column_text]Ut finibus ex non nunc dapibus consectetur. Nullam vitae massa malesuada, luctus libero vel, pellentesque leo. Donec sit amet massa a sapien viverra vehicula. In iaculis tristique risus, sit amet convallis odio porta at. Mauris ex sapien, elementum quis augue vestibulum, gravida aliquet dui. Cras auctor auctor lectus quis tempor. Nulla id augue lectus. Aenean neque dolor, volutpat maximus erat sed.[/vc_column_text][/ueldo_shortcode_full_width_testimonials_single_testimonial][ueldo_shortcode_full_width_testimonials_single_testimonial class_name="ueldo_vc_element_9274631219335" author_name="'. esc_html( __( 'Martha Smith', 'ueldo' ) ) .'" author_description="'. esc_html( __( 'Sales Manager at DentalPayExample, Inc.', 'ueldo' ) ) .'" other_image_on_hover="yes"][vc_column_text]Ut finibus ex non nunc dapibus consectetur. Nullam vitae massa malesuada, luctus libero vel, pellentesque leo. Donec sit amet massa a sapien viverra vehicula. In iaculis tristique risus, sit amet convallis odio porta at. Mauris ex sapien, elementum quis augue vestibulum, gravida aliquet dui. Cras auctor auctor lectus quis tempor. Nulla id augue lectus. Aenean neque dolor, volutpat maximus erat sed.[/vc_column_text][/ueldo_shortcode_full_width_testimonials_single_testimonial][/ueldo_shortcode_full_width_testimonials][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_47316419862879"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_hidden-lg vc_hidden-md"][ueldo_shortcode_icon class_name="ueldo_vc_element_49104799816300" icon_alignment="center" {ueldopredefinedsections:icon|key:flaticon-laptop,flaticon-computer|url:https://www.flaticon.com/free-icon/laptop_490440|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e46e00"][ueldo_shortcode_heading class_name="ueldo_vc_element_92356194587004" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_61646707446737" heading_text="'. esc_html( __( 'Meet the team', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Ut finibus ex non nunc dapibus consectetur. Nullam vitae massa malesuada, luctus libero vel, pellentesque leo donec sit amet.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15054598584035" large_height="0" small_custom_sizes="yes" small_height="25"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/3" offset="vc_hidden-sm vc_hidden-xs"][ueldo_shortcode_icon class_name="ueldo_vc_element_73972662200263" {ueldopredefinedsections:icon|key:flaticon-laptop,flaticon-computer|url:https://www.flaticon.com/free-icon/laptop_490440|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e46e00"][ueldo_shortcode_heading class_name="ueldo_vc_element_84039945554393" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_94833929241595" heading_text="'. esc_html( __( 'Meet the team', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Ut finibus ex non nunc dapibus consectetur. Nullam vitae massa malesuada, luctus libero vel, pellentesque leo donec sit amet.[/vc_column_text][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8"][ueldo_shortcode_presentation class_name="ueldo_vc_element_15052930911822"][ueldo_shortcode_presentation_element class_name="ueldo_vc_element_15052930979515"][ueldo_shortcode_presentation_point_of_interest class_name="ueldo_vc_element_92270305825188" position_y="48%" position_x="22%" custom_colors_enabled="custom_settings" point_animation_shadow_color="#e46e00"]<strong>'. esc_html( __( 'Tom Jones', 'ueldo' ) ) .'</strong><br /><br /> Orci varius natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Aliquam quis placerat magna.[/ueldo_shortcode_presentation_point_of_interest][ueldo_shortcode_presentation_point_of_interest class_name="ueldo_vc_element_83788949507625" position_y="51%" position_x="30.50%" custom_colors_enabled="custom_settings" point_animation_shadow_color="#e46e00"]<strong>'. esc_html( __( 'Susane Smith', 'ueldo' ) ) .'</strong><br /><br /> Vestibulum ex lorem, commodo quis libero sed, rhoncus lacinia diam. Nulla fringilla tortor ut neque pellentesque.[/ueldo_shortcode_presentation_point_of_interest][ueldo_shortcode_presentation_point_of_interest class_name="ueldo_vc_element_39247963355974" position_y="52%" position_x="45%" custom_colors_enabled="custom_settings" point_animation_shadow_color="#e46e00"]<strong>'. esc_html( __( 'Monica Wayne', 'ueldo' ) ) .'</strong><br /><br /> Cras tristique a libero nec ultrices. Ut facilisis sem at volutpat pulvinar. Nam laoreet risus quis tristique bibendum.[/ueldo_shortcode_presentation_point_of_interest][ueldo_shortcode_presentation_point_of_interest class_name="ueldo_vc_element_54278952839586" position_y="48%" position_x="57%" custom_colors_enabled="custom_settings" point_animation_shadow_color="#e46e00"]<strong>'. esc_html( __( 'Tom Robbinson', 'ueldo' ) ) .'</strong><br /><br /> Suspendisse bibendum nulla sit amet lobortis lacinia. Aliquam non libero posuere, pellentesque risus ut.[/ueldo_shortcode_presentation_point_of_interest][ueldo_shortcode_presentation_point_of_interest class_name="ueldo_vc_element_45718234657820" position_y="51%" position_x="71%" custom_colors_enabled="custom_settings" point_animation_shadow_color="#e46e00"]<strong>'. esc_html( __( 'Anthony Smith', 'ueldo' ) ) .'</strong><br /><br /> Donec placerat justo vitae est facilisis, nec faucibus mauris suscipit. Praesent turpis nisi, consequat nec dolor.[/ueldo_shortcode_presentation_point_of_interest][ueldo_shortcode_presentation_point_of_interest class_name="ueldo_vc_element_71682490852282" position_y="46%" position_x="83%" custom_colors_enabled="custom_settings" point_animation_shadow_color="#e46e00"]<strong>'. esc_html( __( 'Sophia Raul', 'ueldo' ) ) .'</strong><br /><br /> Pellentesque commodo libero sed sapien porta ullamcorper. Morbi quis metus ut lacus rhoncus facilisis eu at.[/ueldo_shortcode_presentation_point_of_interest][/ueldo_shortcode_presentation_element][/ueldo_shortcode_presentation][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_86709351416943"][/vc_column][/vc_row][/vc_section]',

                'tax-consulting' => '[vc_section full_width="stretch_row"][vc_row][vc_column offset="vc_hidden-xs"][ueldo_shortcode_gap class_name="ueldo_vc_element_15053034945024"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15053036583049"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15053036624348" large_width_percentage="100%" large_content_alignment="center"][ueldo_shortcode_icon class_name="ueldo_vc_element_15053036064203" icon_alignment="inline" {ueldopredefinedsections:icon|key:flaticon-calculator|url:https://www.flaticon.com/free-icon/calculator_490446|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" custom_colors_enabled="custom_settings" icon_color="#e46e00"][ueldo_shortcode_heading class_name="ueldo_vc_element_15053035054361" heading_tag="h1" text_align="inline" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0" custom_margin_left="30"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15053035197021" heading_text="'. esc_html( __( 'Tax Consulting', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1505374530949" heading_text="'. esc_html( __( 'Services', 'ueldo' ) ) .'" font_family="headings-slim-font"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_15053706382342"][/vc_column][/vc_row][vc_row][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_gap class_name="ueldo_vc_element_73548436859851" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_icon class_name="ueldo_vc_element_98537412739970" {ueldopredefinedsections:icon|key:flaticon-calculator|url:https://www.flaticon.com/free-icon/calculator_490446|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="15" custom_colors_enabled="custom_settings" icon_color="#e46e00"][ueldo_shortcode_heading class_name="ueldo_vc_element_70965645475903" heading_tag="h1" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_94715830742297" heading_text="'. esc_html( __( 'Tax Consulting', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_4954362502929" heading_text="'. esc_html( __( 'Services', 'ueldo' ) ) .'" font_family="headings-slim-font"][/ueldo_shortcode_heading][ueldo_shortcode_gap class_name="ueldo_vc_element_65046393346787" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][ueldo_shortcode_heading class_name="ueldo_vc_element_15053079713675" heading_tag="h5" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15053079835079" heading_text="Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus tincidunt ipsum at diam tempus dictum. Mauris et eros orci." custom_font_size_and_line_height_enabled="custom_settings" font_size="20" line_height="1.6"][/ueldo_shortcode_heading][ueldo_shortcode_gap class_name="ueldo_vc_element_35763677461356" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/3"][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus tincidunt ipsum at diam tempus dictum. Mauris et eros orci. Phasellus egestas enim dui. Suspendisse eget augue massa. Vivamus lacinia id ante sed ultrices.<br /><br /> Sed porta scelerisque erat, quis volutpat sem vulputate id. Nullam imperdiet, odio quis luctus faucibus, purus enim ultricies justo, ac rutrum nisi leo et diam. Sed ullamcorper diam eget metus.[/vc_column_text][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_42467852812410" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][vc_column_text]Phasellus a dapibus lacus. Quisque condimentum vel arcu sed imperdiet. Suspendisse leo mauris, varius ut arcu eu, luctus scelerisque mauris. Donec quam urna, consequat vel placerat eget.<br /><br /> Sed porta scelerisque erat, quis volutpat sem vulputate id. Nullam imperdiet, odio quis luctus faucibus, purus enim ultricies justo, ac rutrum nisi leo et diam. Sed ullamcorper diam eget metus.[/vc_column_text][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_25053745766605"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15053703778052" custom_layer_sizes="custom_settings" color="rgba(255,255,255,0.01)" color_add_border="yes" color_border_width="10" color_border_color="#fdf4eb" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="30" large_height_type="calc" large_height_calc_px="30" large_margin_top="15" large_margin_left="-15" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="60" extra_small_margin_top="-20" extra_small_margin_left="30"][ueldo_shortcode_image class_name="ueldo_vc_element_15053703195925" large_height_px="450" small_custom_sizes="yes" small_height_px="550" extra_small_custom_sizes="yes" extra_small_height_px="360" margin_bottom="0"][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_1505464085653" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_heading class_name="ueldo_vc_element_15053733187307" heading_tag="h3" text_align="center" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Required informations', 'ueldo' ) ) .'" custom_margin_bottom="45"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15053733252785" heading_text="'. esc_html( __( 'Important documents & brochures', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15053738896764" vertical_alignment="top"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15054642333375" large_width_percentage="0%" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="60"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_73747195370824" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="8" small_custom_sizes="yes" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="120"][ueldo_shortcode_button class_name="ueldo_vc_element_40233215824342" button_type="two-line-button" button_text="'. esc_html( __( 'File size: 34kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Brochure', 'ueldo' ) ) .'" second_line_text_font_family="headings-slim-font" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Download', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_53593489094420" large_height="16"][ueldo_shortcode_button class_name="ueldo_vc_element_85328251383350" button_type="two-line-button" button_text="'. esc_html( __( 'File size: 28kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Registration form', 'ueldo' ) ) .'" second_line_text_font_family="headings-slim-font" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Download', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_fontawesome="fa fa-file-word-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_29432503213238" large_height="0" small_custom_sizes="yes" small_height="16"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_2519360767755" large_width_type="px" large_width_px="16" small_custom_sizes="yes" small_width_percentage="0%" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="60"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_2072081366774" large_width_percentage="0%" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="60"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_73463858470235" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="8" small_custom_sizes="yes" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="120"][ueldo_shortcode_button class_name="ueldo_vc_element_66665638883498" button_type="two-line-button" button_visible_on_devices="large,small,extra-small" button_text="'. esc_html( __( 'File size: 41kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Recommendations', 'ueldo' ) ) .'" second_line_text_font_family="headings-slim-font" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Download', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_61323758961318" button_type="two-line-button" button_visible_on_devices="medium" button_text="'. esc_html( __( 'File size: 41kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Recomms.', 'ueldo' ) ) .'" second_line_text_font_family="headings-slim-font" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Download', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_15054640972356" large_height="0" extra_small_custom_sizes="yes"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_30342556701594"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/4" offset="vc_col-lg-3 vc_col-md-3 vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_icon class_name="ueldo_vc_element_15053783487926" icon_alignment="center" {ueldopredefinedsections:icon|key:flaticon-graph,flaticon-graphic|url:https://www.flaticon.com/free-icon/graph_489919|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e46e00"][ueldo_shortcode_heading class_name="ueldo_vc_element_58050453118206" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_95998866018672" heading_text="'. esc_html( __( '21 years of experience', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Nam sollicitudin erat eget suscipit tincidunt. Phasellus nec sollicitudin leo. Pellentesque elementum tellus sit amet lacus cursus, in rhoncus elit congue. Fusce tristique feugiat egestas. Nunc tortor quam, venenatis.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_10980068585362" large_height="25"][/vc_column][vc_column width="1/4" offset="vc_col-lg-3 vc_col-md-3 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_heading class_name="ueldo_vc_element_98429837448242" heading_tag="h3" text_align="center" heading_subtitle_text="'. esc_html( __( 'How it works?', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_95505341066889" heading_text="'. esc_html( __( 'What is the process like?', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Duis posuere turpis mauris. Donec et fringilla dui. Curabitur lacinia mattis neque et pulvinar.</p>[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_23942516107811" button_text="'. esc_html( __( 'Schedule Consultation', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Schedule Consultation', 'ueldo' ) ) ) .'||" button_alignment="center" custom_sizes_enabled="custom_settings" standard_button_use_static_height="no"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_86005945653140"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/3" offset="vc_hidden-xs"][ueldo_shortcode_heading class_name="ueldo_vc_element_76332730920196" heading_tag="h3" heading_subtitle_text="'. esc_html( __( 'How it works?', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_10520789906103" heading_text="'. esc_html( __( 'What is the process like?', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Duis posuere turpis mauris. Donec et fringilla dui. Curabitur lacinia mattis neque et pulvinar.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_52881772458334" large_height="30" small_custom_sizes="yes" small_height="0"][ueldo_shortcode_button class_name="ueldo_vc_element_94328903735803" button_text="'. esc_html( __( 'Schedule Consultation', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Schedule Consultation', 'ueldo' ) ) ) .'||" custom_sizes_enabled="custom_settings" standard_button_use_static_height="no"][/ueldo_shortcode_button][/vc_column][vc_column width="2/3"][ueldo_shortcode_tabs_box class_name="ueldo_vc_element_89361560745243"][ueldo_shortcode_tabs_box_single_tab class_name="ueldo_vc_element_52265169269584" title="'. esc_html( __( 'Analysing', 'ueldo' ) ) .'"]Maecenas risus lectus, sodales in nunc vitae, luctus sagittis eros. Integer quis tortor nec dolor dapibus ultricies id suscipit magna. Duis posuere turpis mauris. Donec et fringilla dui. Curabitur lacinia mattis neque et pulvinar. Pellentesque habitant morbi.<br /> <h6>Etiam placerat elementum ligula</h6><br /> Tristique senectus et netus et malesuada fames ac turpis egestas. Nam ut nisi dolor. Fusce rhoncus augue justo, vel ornare magna suscipit vitae. Suspendisse ac nisi quam. Proin non nulla tempor, pretium sapien in.[/ueldo_shortcode_tabs_box_single_tab][ueldo_shortcode_tabs_box_single_tab class_name="ueldo_vc_element_47145630064020" title="'. esc_html( __( 'Planning', 'ueldo' ) ) .'"]Duis a venenatis nulla, sed eleifend ante. Sed id urna arcu. Aenean porttitor risus sit amet metus lobortis congue. Aliquam molestie vestibulum risus congue sollicitudin. Etiam scelerisque erat vitae ultricies elementum. Nulla ut sollicitudin ex.<br /> <h6>Sed venenatis neque.</h6><br /> Nulla mattis, leo sed laoreet iaculis, purus sapien gravida erat, eu cursus enim dui ac tellus. Quisque consectetur nec nisl sed dignissim. Mauris libero felis, fringilla eu odio vel, porttitor dapibus ipsum. Sed vulputate ex ac tristique pretium.[/ueldo_shortcode_tabs_box_single_tab][ueldo_shortcode_tabs_box_single_tab class_name="ueldo_vc_element_53210284767242" title="'. esc_html( __( 'Implementation', 'ueldo' ) ) .'"]Nam ut nisi dolor. Fusce rhoncus augue justo, vel ornare magna suscipit vitae. Nullam bibendum ullamcorper vehicula. Suspendisse ac nisi quam. Proin non nulla tempor, pretium sapien in, feugiat nisi. Etiam placerat elementum ligula sit.<br /> <h6>Amet pellentesque nunc non.</h6><br /> Sapien posuere, porttitor ipsum id, aliquet nulla. Nullam vel gravida nibh. Sed ac efficitur urna. Morbi sit amet elit purus. Aliquam sagittis suscipit justo, eu tincidunt eros mollis sit amet. Donec dignissim interdum enim, sed egestas est dictum vel. Phasellus ut mi sed erat.[/ueldo_shortcode_tabs_box_single_tab][/ueldo_shortcode_tabs_box][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_30342556701594"][/vc_column][/vc_row][/vc_section]',

                'cashflow-advising' => '[vc_section full_width="stretch_row"][vc_row][vc_column offset="vc_hidden-xs"][ueldo_shortcode_gap class_name="ueldo_vc_element_15053034945024"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15053036583049"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15053036624348" large_width_percentage="100%" large_content_alignment="center"][ueldo_shortcode_icon class_name="ueldo_vc_element_15053036064203" icon_alignment="inline" {ueldopredefinedsections:icon|key:flaticon-transfer-money,flaticon-money|url:https://www.flaticon.com/free-icon/transfer-money_489950|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" custom_colors_enabled="custom_settings" icon_color="#e46e00"][ueldo_shortcode_heading class_name="ueldo_vc_element_15053035054361" heading_tag="h1" text_align="inline" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0" custom_margin_left="30"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15053035197021" heading_text="'. esc_html( __( 'Cashflow Advising', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1505374530949" heading_text="'. esc_html( __( 'Services', 'ueldo' ) ) .'" font_family="headings-slim-font"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_15053706382342"][/vc_column][/vc_row][vc_row][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_gap class_name="ueldo_vc_element_73548436859851" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_icon class_name="ueldo_vc_element_98537412739970" {ueldopredefinedsections:icon|key:flaticon-transfer-money,flaticon-money|url:https://www.flaticon.com/free-icon/transfer-money_489950|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="15" custom_colors_enabled="custom_settings" icon_color="#e46e00"][ueldo_shortcode_heading class_name="ueldo_vc_element_70965645475903" heading_tag="h1" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_94715830742297" heading_text="'. esc_html( __( 'Cashflow Advising', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_4954362502929" heading_text="'. esc_html( __( 'Services', 'ueldo' ) ) .'" font_family="headings-slim-font"][/ueldo_shortcode_heading][ueldo_shortcode_gap class_name="ueldo_vc_element_65046393346787" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][ueldo_shortcode_heading class_name="ueldo_vc_element_15053079713675" heading_tag="h5" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15053079835079" heading_text="Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus tincidunt ipsum at diam tempus dictum. Mauris et eros orci." custom_font_size_and_line_height_enabled="custom_settings" font_size="20" line_height="1.6"][/ueldo_shortcode_heading][ueldo_shortcode_gap class_name="ueldo_vc_element_35763677461356" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/3"][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus tincidunt ipsum at diam tempus dictum. Mauris et eros orci. Phasellus egestas enim dui. Suspendisse eget augue massa. Vivamus lacinia id ante sed ultrices.<br /><br /> Sed porta scelerisque erat, quis volutpat sem vulputate id. Nullam imperdiet, odio quis luctus faucibus, purus enim ultricies justo, ac rutrum nisi leo et diam. Sed ullamcorper diam eget metus.[/vc_column_text][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_42467852812410" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][vc_column_text]Phasellus a dapibus lacus. Quisque condimentum vel arcu sed imperdiet. Suspendisse leo mauris, varius ut arcu eu, luctus scelerisque mauris. Donec quam urna, consequat vel placerat eget.<br /><br /> Sed porta scelerisque erat, quis volutpat sem vulputate id. Nullam imperdiet, odio quis luctus faucibus, purus enim ultricies justo, ac rutrum nisi leo et diam. Sed ullamcorper diam eget metus.[/vc_column_text][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_25053745766605"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15053703778052" custom_layer_sizes="custom_settings" color="rgba(255,255,255,0.01)" color_add_border="yes" color_border_width="10" color_border_color="#fdf4eb" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="30" large_height_type="calc" large_height_calc_px="30" large_margin_top="15" large_margin_left="-15" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="60" extra_small_margin_top="-20" extra_small_margin_left="30"][ueldo_shortcode_image class_name="ueldo_vc_element_15053703195925" large_height_px="450" small_custom_sizes="yes" small_height_px="550" extra_small_custom_sizes="yes" extra_small_height_px="360" margin_bottom="0"][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_1505464085653" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_heading class_name="ueldo_vc_element_15053733187307" heading_tag="h3" text_align="center" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Required informations', 'ueldo' ) ) .'" custom_margin_bottom="45"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15053733252785" heading_text="'. esc_html( __( 'Important documents & brochures', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15053738896764" vertical_alignment="top"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15054642333375" large_width_percentage="0%" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="60"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_73747195370824" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="8" small_custom_sizes="yes" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="120"][ueldo_shortcode_button class_name="ueldo_vc_element_40233215824342" button_type="two-line-button" button_text="'. esc_html( __( 'File size: 34kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Brochure', 'ueldo' ) ) .'" second_line_text_font_family="headings-slim-font" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Download', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_53593489094420" large_height="16"][ueldo_shortcode_button class_name="ueldo_vc_element_85328251383350" button_type="two-line-button" button_text="'. esc_html( __( 'File size: 28kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Registration form', 'ueldo' ) ) .'" second_line_text_font_family="headings-slim-font" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Download', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_fontawesome="fa fa-file-word-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_29432503213238" large_height="0" small_custom_sizes="yes" small_height="16"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_2519360767755" large_width_type="px" large_width_px="16" small_custom_sizes="yes" small_width_percentage="0%" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="60"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_2072081366774" large_width_percentage="0%" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="60"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_73463858470235" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="8" small_custom_sizes="yes" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="120"][ueldo_shortcode_button class_name="ueldo_vc_element_66665638883498" button_type="two-line-button" button_visible_on_devices="large,small,extra-small" button_text="'. esc_html( __( 'File size: 41kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Recommendations', 'ueldo' ) ) .'" second_line_text_font_family="headings-slim-font" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Download', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_61323758961318" button_type="two-line-button" button_visible_on_devices="medium" button_text="'. esc_html( __( 'File size: 41kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Recomms.', 'ueldo' ) ) .'" second_line_text_font_family="headings-slim-font" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Download', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_15054640972356" large_height="0" extra_small_custom_sizes="yes"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_30342556701594"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/4" offset="vc_col-lg-3 vc_col-md-3 vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_icon class_name="ueldo_vc_element_15053783487926" icon_alignment="center" {ueldopredefinedsections:icon|key:flaticon-graph,flaticon-graphic|url:https://www.flaticon.com/free-icon/graph_489919|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e46e00"][ueldo_shortcode_heading class_name="ueldo_vc_element_58050453118206" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_95998866018672" heading_text="'. esc_html( __( '21 years of experience', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Nam sollicitudin erat eget suscipit tincidunt. Phasellus nec sollicitudin leo. Pellentesque elementum tellus sit amet lacus cursus, in rhoncus elit congue. Fusce tristique feugiat egestas. Nunc tortor quam, venenatis.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_10980068585362" large_height="25"][/vc_column][vc_column width="1/4" offset="vc_col-lg-3 vc_col-md-3 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_heading class_name="ueldo_vc_element_98429837448242" heading_tag="h3" text_align="center" heading_subtitle_text="'. esc_html( __( 'How it works?', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_95505341066889" heading_text="'. esc_html( __( 'What is the process like?', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Duis posuere turpis mauris. Donec et fringilla dui. Curabitur lacinia mattis neque et pulvinar.</p>[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_23942516107811" button_text="'. esc_html( __( 'Schedule Consultation', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Schedule Consultation', 'ueldo' ) ) ) .'||" button_alignment="center" custom_sizes_enabled="custom_settings" standard_button_use_static_height="no"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_86005945653140"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/3" offset="vc_hidden-xs"][ueldo_shortcode_heading class_name="ueldo_vc_element_76332730920196" heading_tag="h3" heading_subtitle_text="'. esc_html( __( 'How it works?', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_10520789906103" heading_text="'. esc_html( __( 'What is the process like?', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Duis posuere turpis mauris. Donec et fringilla dui. Curabitur lacinia mattis neque et pulvinar.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_52881772458334" large_height="30" small_custom_sizes="yes" small_height="0"][ueldo_shortcode_button class_name="ueldo_vc_element_94328903735803" button_text="'. esc_html( __( 'Schedule Consultation', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Schedule Consultation', 'ueldo' ) ) ) .'||" custom_sizes_enabled="custom_settings" standard_button_use_static_height="no"][/ueldo_shortcode_button][/vc_column][vc_column width="2/3"][ueldo_shortcode_tabs_box class_name="ueldo_vc_element_89361560745243"][ueldo_shortcode_tabs_box_single_tab class_name="ueldo_vc_element_52265169269584" title="'. esc_html( __( 'Analysing', 'ueldo' ) ) .'"]Maecenas risus lectus, sodales in nunc vitae, luctus sagittis eros. Integer quis tortor nec dolor dapibus ultricies id suscipit magna. Duis posuere turpis mauris. Donec et fringilla dui. Curabitur lacinia mattis neque et pulvinar. Pellentesque habitant morbi.<br /> <h6>Etiam placerat elementum ligula</h6><br /> Tristique senectus et netus et malesuada fames ac turpis egestas. Nam ut nisi dolor. Fusce rhoncus augue justo, vel ornare magna suscipit vitae. Suspendisse ac nisi quam. Proin non nulla tempor, pretium sapien in.[/ueldo_shortcode_tabs_box_single_tab][ueldo_shortcode_tabs_box_single_tab class_name="ueldo_vc_element_47145630064020" title="'. esc_html( __( 'Planning', 'ueldo' ) ) .'"]Duis a venenatis nulla, sed eleifend ante. Sed id urna arcu. Aenean porttitor risus sit amet metus lobortis congue. Aliquam molestie vestibulum risus congue sollicitudin. Etiam scelerisque erat vitae ultricies elementum. Nulla ut sollicitudin ex.<br /> <h6>Sed venenatis neque.</h6><br /> Nulla mattis, leo sed laoreet iaculis, purus sapien gravida erat, eu cursus enim dui ac tellus. Quisque consectetur nec nisl sed dignissim. Mauris libero felis, fringilla eu odio vel, porttitor dapibus ipsum. Sed vulputate ex ac tristique pretium.[/ueldo_shortcode_tabs_box_single_tab][ueldo_shortcode_tabs_box_single_tab class_name="ueldo_vc_element_53210284767242" title="'. esc_html( __( 'Implementation', 'ueldo' ) ) .'"]Nam ut nisi dolor. Fusce rhoncus augue justo, vel ornare magna suscipit vitae. Nullam bibendum ullamcorper vehicula. Suspendisse ac nisi quam. Proin non nulla tempor, pretium sapien in, feugiat nisi. Etiam placerat elementum ligula sit.<br /> <h6>Amet pellentesque nunc non.</h6><br /> Sapien posuere, porttitor ipsum id, aliquet nulla. Nullam vel gravida nibh. Sed ac efficitur urna. Morbi sit amet elit purus. Aliquam sagittis suscipit justo, eu tincidunt eros mollis sit amet. Donec dignissim interdum enim, sed egestas est dictum vel. Phasellus ut mi sed erat.[/ueldo_shortcode_tabs_box_single_tab][/ueldo_shortcode_tabs_box][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_30342556701594"][/vc_column][/vc_row][/vc_section]',

                'mutual-funds' => '[vc_section full_width="stretch_row"][vc_row][vc_column offset="vc_hidden-xs"][ueldo_shortcode_gap class_name="ueldo_vc_element_15053034945024"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15053036583049"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15053036624348" large_width_percentage="100%" large_content_alignment="center"][ueldo_shortcode_icon class_name="ueldo_vc_element_15053036064203" icon_alignment="inline" {ueldopredefinedsections:icon|key:flaticon-money|url:https://www.flaticon.com/free-icon/money_489939|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" custom_colors_enabled="custom_settings" icon_color="#e46e00"][ueldo_shortcode_heading class_name="ueldo_vc_element_15053035054361" heading_tag="h1" text_align="inline" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0" custom_margin_left="30"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1505374530949" heading_text="'. esc_html( __( 'Running an', 'ueldo' ) ) .'" font_family="headings-slim-font"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15053035197021" heading_text="'. esc_html( __( 'Mutual Fund', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_15053706382342"][/vc_column][/vc_row][vc_row][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_gap class_name="ueldo_vc_element_73548436859851" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_icon class_name="ueldo_vc_element_98537412739970" {ueldopredefinedsections:icon|key:flaticon-money|url:https://www.flaticon.com/free-icon/money_489939|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="15" custom_colors_enabled="custom_settings" icon_color="#e46e00"][ueldo_shortcode_heading class_name="ueldo_vc_element_70965645475903" heading_tag="h1" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_94715830742297" heading_text="'. esc_html( __( 'Running an', 'ueldo' ) ) .'" font_family="headings-slim-font"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_4954362502929" heading_text="'. esc_html( __( 'Mutual Fund', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_gap class_name="ueldo_vc_element_65046393346787" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][ueldo_shortcode_heading class_name="ueldo_vc_element_15053079713675" heading_tag="h5" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15053079835079" heading_text="Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus tincidunt ipsum at diam tempus dictum. Mauris et eros orci." custom_font_size_and_line_height_enabled="custom_settings" font_size="20" line_height="1.6"][/ueldo_shortcode_heading][ueldo_shortcode_gap class_name="ueldo_vc_element_35763677461356" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/3"][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus tincidunt ipsum at diam tempus dictum. Mauris et eros orci. Phasellus egestas enim dui. Suspendisse eget augue massa. Vivamus lacinia id ante sed ultrices.<br /><br /> Sed porta scelerisque erat, quis volutpat sem vulputate id. Nullam imperdiet, odio quis luctus faucibus, purus enim ultricies justo, ac rutrum nisi leo et diam. Sed ullamcorper diam eget metus.[/vc_column_text][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_42467852812410" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][vc_column_text]Phasellus a dapibus lacus. Quisque condimentum vel arcu sed imperdiet. Suspendisse leo mauris, varius ut arcu eu, luctus scelerisque mauris. Donec quam urna, consequat vel placerat eget.<br /><br /> Sed porta scelerisque erat, quis volutpat sem vulputate id. Nullam imperdiet, odio quis luctus faucibus, purus enim ultricies justo, ac rutrum nisi leo et diam. Sed ullamcorper diam eget metus.[/vc_column_text][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_25053745766605"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15053703778052" custom_layer_sizes="custom_settings" color="rgba(255,255,255,0.01)" color_add_border="yes" color_border_width="10" color_border_color="#fdf4eb" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="30" large_height_type="calc" large_height_calc_px="30" large_margin_top="15" large_margin_left="-15" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="60" extra_small_margin_top="-20" extra_small_margin_left="30"][ueldo_shortcode_image class_name="ueldo_vc_element_15053703195925" large_height_px="450" small_custom_sizes="yes" small_height_px="550" extra_small_custom_sizes="yes" extra_small_height_px="360" margin_bottom="0"][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_1505464085653" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_heading class_name="ueldo_vc_element_15053733187307" heading_tag="h3" text_align="center" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Required informations', 'ueldo' ) ) .'" custom_margin_bottom="45"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15053733252785" heading_text="'. esc_html( __( 'Important documents & brochures', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15053738896764" vertical_alignment="top"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15054642333375" large_width_percentage="0%" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="60"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_73747195370824" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="8" small_custom_sizes="yes" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="120"][ueldo_shortcode_button class_name="ueldo_vc_element_40233215824342" button_type="two-line-button" button_text="'. esc_html( __( 'File size: 34kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Brochure', 'ueldo' ) ) .'" second_line_text_font_family="headings-slim-font" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Download', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_53593489094420" large_height="16"][ueldo_shortcode_button class_name="ueldo_vc_element_85328251383350" button_type="two-line-button" button_text="'. esc_html( __( 'File size: 28kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Registration form', 'ueldo' ) ) .'" second_line_text_font_family="headings-slim-font" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Download', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_fontawesome="fa fa-file-word-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_29432503213238" large_height="0" small_custom_sizes="yes" small_height="16"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_2519360767755" large_width_type="px" large_width_px="16" small_custom_sizes="yes" small_width_percentage="0%" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="60"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_2072081366774" large_width_percentage="0%" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="60"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_73463858470235" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="8" small_custom_sizes="yes" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="120"][ueldo_shortcode_button class_name="ueldo_vc_element_66665638883498" button_type="two-line-button" button_visible_on_devices="large,small,extra-small" button_text="'. esc_html( __( 'File size: 41kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Recommendations', 'ueldo' ) ) .'" second_line_text_font_family="headings-slim-font" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Download', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_61323758961318" button_type="two-line-button" button_visible_on_devices="medium" button_text="'. esc_html( __( 'File size: 41kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Recomms.', 'ueldo' ) ) .'" second_line_text_font_family="headings-slim-font" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Download', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_15054640972356" large_height="0" extra_small_custom_sizes="yes"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_30342556701594"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/4" offset="vc_col-lg-3 vc_col-md-3 vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_icon class_name="ueldo_vc_element_15053783487926" icon_alignment="center" {ueldopredefinedsections:icon|key:flaticon-graph,flaticon-graphic|url:https://www.flaticon.com/free-icon/graph_489919|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e46e00"][ueldo_shortcode_heading class_name="ueldo_vc_element_58050453118206" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_95998866018672" heading_text="'. esc_html( __( '21 years of experience', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Nam sollicitudin erat eget suscipit tincidunt. Phasellus nec sollicitudin leo. Pellentesque elementum tellus sit amet lacus cursus, in rhoncus elit congue. Fusce tristique feugiat egestas. Nunc tortor quam, venenatis.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_10980068585362" large_height="25"][/vc_column][vc_column width="1/4" offset="vc_col-lg-3 vc_col-md-3 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_heading class_name="ueldo_vc_element_98429837448242" heading_tag="h3" text_align="center" heading_subtitle_text="'. esc_html( __( 'How it works?', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_95505341066889" heading_text="'. esc_html( __( 'What is the process like?', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Duis posuere turpis mauris. Donec et fringilla dui. Curabitur lacinia mattis neque et pulvinar.</p>[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_23942516107811" button_text="'. esc_html( __( 'Schedule Consultation', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Schedule Consultation', 'ueldo' ) ) ) .'||" button_alignment="center" custom_sizes_enabled="custom_settings" standard_button_use_static_height="no"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_86005945653140"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/3" offset="vc_hidden-xs"][ueldo_shortcode_heading class_name="ueldo_vc_element_76332730920196" heading_tag="h3" heading_subtitle_text="'. esc_html( __( 'How it works?', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_10520789906103" heading_text="'. esc_html( __( 'What is the process like?', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Duis posuere turpis mauris. Donec et fringilla dui. Curabitur lacinia mattis neque et pulvinar.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_52881772458334" large_height="30" small_custom_sizes="yes" small_height="0"][ueldo_shortcode_button class_name="ueldo_vc_element_94328903735803" button_text="'. esc_html( __( 'Schedule Consultation', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Schedule Consultation', 'ueldo' ) ) ) .'||" custom_sizes_enabled="custom_settings" standard_button_use_static_height="no"][/ueldo_shortcode_button][/vc_column][vc_column width="2/3"][ueldo_shortcode_tabs_box class_name="ueldo_vc_element_89361560745243"][ueldo_shortcode_tabs_box_single_tab class_name="ueldo_vc_element_52265169269584" title="'. esc_html( __( 'Analysing', 'ueldo' ) ) .'"]Maecenas risus lectus, sodales in nunc vitae, luctus sagittis eros. Integer quis tortor nec dolor dapibus ultricies id suscipit magna. Duis posuere turpis mauris. Donec et fringilla dui. Curabitur lacinia mattis neque et pulvinar. Pellentesque habitant morbi.<br /> <h6>Etiam placerat elementum ligula</h6><br /> Tristique senectus et netus et malesuada fames ac turpis egestas. Nam ut nisi dolor. Fusce rhoncus augue justo, vel ornare magna suscipit vitae. Suspendisse ac nisi quam. Proin non nulla tempor, pretium sapien in.[/ueldo_shortcode_tabs_box_single_tab][ueldo_shortcode_tabs_box_single_tab class_name="ueldo_vc_element_47145630064020" title="'. esc_html( __( 'Planning', 'ueldo' ) ) .'"]Duis a venenatis nulla, sed eleifend ante. Sed id urna arcu. Aenean porttitor risus sit amet metus lobortis congue. Aliquam molestie vestibulum risus congue sollicitudin. Etiam scelerisque erat vitae ultricies elementum. Nulla ut sollicitudin ex.<br /> <h6>Sed venenatis neque.</h6><br /> Nulla mattis, leo sed laoreet iaculis, purus sapien gravida erat, eu cursus enim dui ac tellus. Quisque consectetur nec nisl sed dignissim. Mauris libero felis, fringilla eu odio vel, porttitor dapibus ipsum. Sed vulputate ex ac tristique pretium.[/ueldo_shortcode_tabs_box_single_tab][ueldo_shortcode_tabs_box_single_tab class_name="ueldo_vc_element_53210284767242" title="'. esc_html( __( 'Implementation', 'ueldo' ) ) .'"]Nam ut nisi dolor. Fusce rhoncus augue justo, vel ornare magna suscipit vitae. Nullam bibendum ullamcorper vehicula. Suspendisse ac nisi quam. Proin non nulla tempor, pretium sapien in, feugiat nisi. Etiam placerat elementum ligula sit.<br /> <h6>Amet pellentesque nunc non.</h6><br /> Sapien posuere, porttitor ipsum id, aliquet nulla. Nullam vel gravida nibh. Sed ac efficitur urna. Morbi sit amet elit purus. Aliquam sagittis suscipit justo, eu tincidunt eros mollis sit amet. Donec dignissim interdum enim, sed egestas est dictum vel. Phasellus ut mi sed erat.[/ueldo_shortcode_tabs_box_single_tab][/ueldo_shortcode_tabs_box][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_30342556701594"][/vc_column][/vc_row][/vc_section]',

                'contact' => '[vc_section][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15052187378086" custom_layer_sizes="custom_settings" color="#fdf4eb" large_height_type="px" large_height_px="99" small_layer_custom_sizes="yes" small_height_type="px" small_height_px="60"][ueldo_shortcode_gap class_name="ueldo_vc_element_15052171241146" large_height="30"][ueldo_shortcode_tabs class_name="ueldo_vc_element_15052133250812" tabs_content_style="style-03" content_position="right" tabs_selector_style="style-03" tabs_selector_style_03_alignment="left" circle_navigation_alignment="left" base_height="640" custom_tab_image_enabled="yes" custom_colors_enabled="custom_settings" tabs_selector_border_color="#e46e00" tabs_selector_border_color_hover="#e46e00" tabs_selector_border_between_items_color="#d86800" tabs_selector_background_color="#e46e00" tabs_selector_active_element_background_color="#d86800" tabs_selector_box_shadow_color="rgba(255,255,255,0.01)" tabs_selector_box_shadow_color_hover="rgba(216,104,0,0.05)" tabs_selector_title_color="#ffffff" tabs_selector_title_color_hover="#ffffff" tabs_content_background_color="#ffffff"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_14486448504738" single_tab_title="'. esc_html( __( 'New York, NY', 'ueldo' ) ) .'" image_content_type="google-map" {ueldopredefinedsections:googlemap|context:accountant-new-york}][ueldo_shortcode_heading class_name="ueldo_vc_element_15052165748164" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15052165879295" heading_text="'. esc_html( __( 'New York office', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Nullam mauris erat, viverra cursus orci feugiat, sollicitudin pretium justo. Quisque sit amet porta sem, vel accumsan.<br /><br /> <strong>'. esc_html( __( 'Location:', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( '1234 Example Street, New York, NY', 'ueldo' ) ) .'[/vc_column_text][vc_row_inner][vc_column_inner width="1/2"][vc_column_text]<strong>'. esc_html( __( 'E-mail:', 'ueldo' ) ) .'</strong><br /> <a href="'. esc_url( __( 'mailto:ny-office@example.com', 'ueldo' ) ) .'">'. esc_html( __( 'ny-office@example.com', 'ueldo' ) ) .'</a><br /><br /> <strong>'. esc_html( __( 'Phone:', 'ueldo' ) ) .'</strong><br /> <a href="tel:18001234567">1-800-123-4567</a>[/vc_column_text][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]<strong>'. esc_html( __( 'Monday - Friday:', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( '8:00am - 6:00pm', 'ueldo' ) ) .'<br /><br /> <strong>'. esc_html( __( 'Saturday:', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( '9:00am - 3:00pm', 'ueldo' ) ) .'[/vc_column_text][/vc_column_inner][/vc_row_inner][ueldo_shortcode_gap class_name="ueldo_vc_element_89631885291563"][/ueldo_shortcode_tabs_single_tab][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_22870071262084" single_tab_title="'. esc_html( __( 'Miami, FL', 'ueldo' ) ) .'" image_content_type="google-map" {ueldopredefinedsections:googlemap|context:accountant-miami}][ueldo_shortcode_heading class_name="ueldo_vc_element_15052166279901" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15052166346923" heading_text="'. esc_html( __( 'Miami office', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Nullam mauris erat, viverra cursus orci feugiat, sollicitudin pretium justo. Quisque sit amet porta sem, vel accumsan.<br /><br /> <strong>'. esc_html( __( 'Location:', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( '54321 Example Street, Los Angeles, CA', 'ueldo' ) ) .'[/vc_column_text][vc_row_inner][vc_column_inner width="1/2"][vc_column_text]<strong>'. esc_html( __( 'E-mail:', 'ueldo' ) ) .'</strong><br /> <a href="'. esc_url( __( 'mailto:miami-office@example.com', 'ueldo' ) ) .'">'. esc_html( __( 'miami-office@example.com', 'ueldo' ) ) .'</a><br /><br /> <strong>'. esc_html( __( 'Phone:', 'ueldo' ) ) .'</strong><br /> <a href="tel:18001234567">1-800-123-4567</a>[/vc_column_text][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]<strong>'. esc_html( __( 'Monday - Friday:', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( '8:00am - 6:00pm', 'ueldo' ) ) .'<br /><br /> <strong>'. esc_html( __( 'Saturday:', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( '9:00am - 3:00pm', 'ueldo' ) ) .'[/vc_column_text][/vc_column_inner][/vc_row_inner][ueldo_shortcode_gap class_name="ueldo_vc_element_72723723061845"][/ueldo_shortcode_tabs_single_tab][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_45955147703421" single_tab_title="'. esc_html( __( 'Dublin, Ireland', 'ueldo' ) ) .'" image_content_type="google-map" {ueldopredefinedsections:googlemap|context:accountant-dublin}][ueldo_shortcode_heading class_name="ueldo_vc_element_1505216644821" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1505216651253" heading_text="'. esc_html( __( 'Dublin office', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Nullam mauris erat, viverra cursus orci feugiat, sollicitudin pretium justo. Quisque sit amet porta sem, vel accumsan.<br /><br /> <strong>'. esc_html( __( 'Location:', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( '12345 Example Street, Dublin, Ireland', 'ueldo' ) ) .'[/vc_column_text][vc_row_inner][vc_column_inner width="1/2"][vc_column_text]<strong>'. esc_html( __( 'E-mail:', 'ueldo' ) ) .'</strong><br /> <a href="'. esc_url( __( 'mailto:dublin-office@example.com', 'ueldo' ) ) .'">'. esc_html( __( 'dublin-office@example.com', 'ueldo' ) ) .'</a><br /><br /> <strong>'. esc_html( __( 'Phone:', 'ueldo' ) ) .'</strong><br /> <a href="tel:18001234567">1-800-123-4567</a>[/vc_column_text][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]<strong>'. esc_html( __( 'Monday - Friday:', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( '8:00am - 6:00pm', 'ueldo' ) ) .'<br /><br /> <strong>'. esc_html( __( 'Saturday:', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( '9:00am - 3:00pm', 'ueldo' ) ) .'[/vc_column_text][/vc_column_inner][/vc_row_inner][ueldo_shortcode_gap class_name="ueldo_vc_element_48169257652998"][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][ueldo_shortcode_gap class_name="ueldo_vc_element_9692918178491"][/vc_column][/vc_row][/vc_section][vc_section][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/6" offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8"][ueldo_shortcode_icon class_name="ueldo_vc_element_15052162779169" icon_alignment="center" {ueldopredefinedsections:icon|key:flaticon-support,flaticon-technology|url:https://www.flaticon.com/free-icon/support_490449|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e46e00"][ueldo_shortcode_heading class_name="ueldo_vc_element_15052161726111" heading_tag="h1" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15052161806629" heading_text="'. esc_html( __( 'Contact us today!', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Fusce a sapien enim. Aliquam ac dolor risus. Maecenas imperdiet rhoncus nulla, sed porta metus condimentum in. Vestibulum facilisis ultricies metus, at venenatis urna. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15052210237777" large_height="25"][contact-form-7 {ueldopredefinedsections:contactform7|context:accountant|inside:false}][/vc_column][vc_column width="1/6" offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15052210332389"][/vc_column][/vc_row][/vc_section]',

                '404-page' => '[vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15052211685246"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_heading class_name="ueldo_vc_element_15052212108909" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="15"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15052212217949" heading_text="404" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" font_size="72" line_height="1" letter_spacing="-2" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_15052213051965" heading_tag="h1" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15052213142543" heading_text="'. esc_html( __( 'Nothing found here...', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Morbi sit amet elementum enim. Mauris in velit accumsan, pulvinar nibh id, ornare nisi. Nam sollicitudin convallis sapien, interdum porta nisi viverra a. Proin elit tortor, accumsan vitae massa sed, bibendum rutrum nulla.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15052231138129" large_height="10"][ueldo_shortcode_button class_name="ueldo_vc_element_15052230980402" button_text="'. esc_html( __( 'Go to home page', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'|title:'. rawurlencode( esc_html( __( 'Go to home page', 'ueldo' ) ) ) .'||" button_alignment="center"][/ueldo_shortcode_button][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15167890505887" large_height="0" extra_small_custom_sizes="yes"][ueldo_shortcode_card class_name="ueldo_vc_element_15047747410359" padding_top="45" padding_right="45" padding_bottom="45" padding_left="45"][ueldo_shortcode_info_box class_name="ueldo_vc_element_28656804629591" content_alignment="left" content_position="inline" heading_vertical_alignment="top" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'tax-consulting%2F|title:'. rawurlencode( esc_html( __( 'Tax consulting', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Tax Consulting', 'ueldo' ) ) .'" info_box_subtitle="Quisque quis varius dolor, eget sagittis nulla. Donec eu mauris lobortis, accumsan est eu." info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-calculator|url:https://www.flaticon.com/free-icon/calculator_490446|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_icon_color_hover="#121c82" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_69543013998670" large_height="30"][ueldo_shortcode_info_box class_name="ueldo_vc_element_96703527886489" content_alignment="left" content_position="inline" heading_vertical_alignment="top" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'mutual-funds%2F|title:'. rawurlencode( esc_html( __( 'Mutual funds', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Mutual Funds', 'ueldo' ) ) .'" info_box_subtitle="Pellentesque eu dui sed risus sagittis suscipit in viverra ex. Sed gravida, quam id tempus." info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-money|url:https://www.flaticon.com/free-icon/money_489939|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_icon_color_hover="#121c82" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_96374122238620" large_height="30"][ueldo_shortcode_info_box class_name="ueldo_vc_element_30232861557760" content_alignment="left" content_position="inline" heading_vertical_alignment="top" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'cashflow-advising%2F|title:'. rawurlencode( esc_html( __( 'Cashflow Advising', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Cashflow Advising', 'ueldo' ) ) .'" info_box_subtitle="Nulla dictum tempus metus, ac iaculis sapien interdum id. Nunc rhoncus nunc suscipit arcu." info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-transfer-money,flaticon-money|url:https://www.flaticon.com/free-icon/transfer-money_489950|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_icon_color_hover="#121c82" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_card][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15052211284765"][/vc_column][/vc_row][/vc_section]',

                'footer' => '[vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15111778397301" layer_for_row_or_section="section" color="#fdf4eb"][ueldo_shortcode_gap class_name="ueldo_vc_element_66381890958373" large_height="45"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_icon class_name="ueldo_vc_element_23293886661679" icon_alignment="center" {ueldopredefinedsections:icon|key:flaticon-percentage,flaticon-signs|url:https://www.flaticon.com/free-icon/percentage_490441|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e46e00"][ueldo_shortcode_heading class_name="ueldo_vc_element_69965992637938" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_83226995159806" heading_text="'. esc_html( __( '-30% off for accounting services *', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_59493593384471" heading_tag="h6" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_99657458592998" heading_text="'. esc_html( __( '* for new companies, during one year', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Proin tincidunt venenatis elit. Quisque gravida, arcu quis dapibus placerat, eros sapien pellentesque nisl, in aliquam eros arcu et dolor. Maecenas pellentesque, risus et ornare pretium, nulla dolor euismod purus.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_63822740972591" large_height="25"][/vc_column][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/12" offset="vc_col-lg-3 vc_col-md-2 vc_col-xs-12 vc_hidden-xs"][/vc_column][vc_column width="5/6" offset="vc_col-lg-6 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_form class_name="ueldo_vc_element_8159161989666" form_shortcode="`{`mc4wp_form {ueldopredefinedsections:mc4wp|context:accountant-footer|inside:true}`}`" custom_colors_enabled="custom_settings" form_field_border_color="#ead3bc" form_field_border_color_hover="#cccccc" form_field_border_color_focus="#aaaaaa" form_field_background_color="#f9ede2" form_field_placeholder_text_color="#888888" form_field_inset_box_shadow_blur_radius="0" form_field_inset_box_shadow_color="rgba(251,248,247,0.01)" inside_field_icon_color="#dddddd" submit_button_text_color="#ffffff" submit_button_text_color_hover="#ffffff" submit_button_box_shadow_color="rgba(255,255,255,0.01)"][/vc_column][vc_column width="1/12" offset="vc_col-lg-3 vc_col-md-2 vc_col-xs-12 vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_20209630461390"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15051291532252"][/vc_column][/vc_row][vc_row][vc_column width="1/2" offset="vc_col-lg-3 vc_col-md-3"][ueldo_shortcode_heading class_name="ueldo_vc_element_42923527494081" heading_tag="h5" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_63737922162644" heading_text="'. esc_html( __( 'Accountants, LLC', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Nulla tempus imperdiet diam ac tincidunt. Ut ornare leo.<br /><br /> 2017 - '. date( 'Y' ) .' &copy; <a href="'. esc_url( ueldo_get_external_url( 'ueldo-com' ) ) .'" target="_blank">'. esc_html( __( 'Ueldo', 'ueldo' ) ) .'</a>[/vc_column_text][/vc_column][vc_column width="1/4" offset="vc_hidden-sm"][ueldo_shortcode_gap class_name="ueldo_vc_element_53782896936447" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_heading class_name="ueldo_vc_element_56557375085254" heading_tag="h5" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_81991386757854" heading_text="'. esc_html( __( 'Services', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_icon_list class_name="ueldo_vc_element_54488455102227" icon_fontawesome="fa fa-chevron-right" icon_sizes="custom_settings" icon_font_size="8" icon_width="8" icon_height="8" list_elements_from="menu" {ueldopredefinedsections:menu|context:accountant-services} margin_bottom="0"][/ueldo_shortcode_icon_list][/vc_column][vc_column width="1/4" offset="vc_hidden-sm"][ueldo_shortcode_gap class_name="ueldo_vc_element_39372444830016" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_heading class_name="ueldo_vc_element_74266668010939" heading_tag="h5" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_93406235681174" heading_text="'. esc_html( __( 'Other pages', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_icon_list class_name="ueldo_vc_element_99155084486336" icon_fontawesome="fa fa-chevron-right" icon_sizes="custom_settings" icon_font_size="8" icon_width="8" icon_height="8" list_elements_from="menu" {ueldopredefinedsections:menu|context:accountant-pages} margin_bottom="0"][/ueldo_shortcode_icon_list][/vc_column][vc_column width="1/2" offset="vc_col-lg-3 vc_col-md-3"][ueldo_shortcode_gap class_name="ueldo_vc_element_90461150561732" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_heading class_name="ueldo_vc_element_94639817334735" heading_tag="h5" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_22320927852734" heading_text="'. esc_html( __( 'Social media', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_button class_name="ueldo_vc_element_39433921558458" button_text="" button_text_alignment="center" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-facebook" custom_sizes_enabled="custom_settings" additional_margin_after="10" standard_button_padding_top="12" standard_button_padding_right="16" standard_button_padding_bottom="12" standard_button_padding_left="16" standard_button_use_static_height="no" standard_button_use_static_width="yes-pixels" standard_button_static_width="47" custom_colors_enabled="custom_settings" standard_button_background_color="#fdf4eb" standard_button_background_color_hover="#e46e00" standard_button_border_color="#fdf4eb" standard_button_border_color_hover="#e46e00" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="0" standard_button_box_shadow_blur_radius_hover="0" standard_button_box_shadow_color_hover="rgba(255,255,255,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#313131" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_88069231453912" button_text="" button_text_alignment="center" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-twitter" custom_sizes_enabled="custom_settings" additional_margin_after="10" standard_button_padding_top="12" standard_button_padding_right="16" standard_button_padding_bottom="12" standard_button_padding_left="16" standard_button_use_static_height="no" standard_button_use_static_width="yes-pixels" standard_button_static_width="47" custom_colors_enabled="custom_settings" standard_button_background_color="#fdf4eb" standard_button_background_color_hover="#e46e00" standard_button_border_color="#fdf4eb" standard_button_border_color_hover="#e46e00" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="0" standard_button_box_shadow_blur_radius_hover="0" standard_button_box_shadow_color_hover="rgba(255,255,255,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#313131" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_96452958986790" button_text="" button_text_alignment="center" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-linkedin" custom_sizes_enabled="custom_settings" standard_button_padding_top="12" standard_button_padding_right="16" standard_button_padding_bottom="12" standard_button_padding_left="16" standard_button_use_static_height="no" standard_button_use_static_width="yes-pixels" standard_button_static_width="47" custom_colors_enabled="custom_settings" standard_button_background_color="#fdf4eb" standard_button_background_color_hover="#e46e00" standard_button_border_color="#fdf4eb" standard_button_border_color_hover="#e46e00" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="0" standard_button_box_shadow_blur_radius_hover="0" standard_button_box_shadow_color_hover="rgba(255,255,255,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#313131" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-xs"][ueldo_shortcode_gap class_name="ueldo_vc_element_45724559994550" large_height="0" small_custom_sizes="yes"][/vc_column][/vc_row][vc_row][vc_column width="1/2" offset="vc_hidden-lg vc_hidden-md vc_hidden-xs"][ueldo_shortcode_heading class_name="ueldo_vc_element_57612300060590" heading_tag="h5" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_60581524543287" heading_text="'. esc_html( __( 'Services', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_icon_list class_name="ueldo_vc_element_92437880754707" icon_fontawesome="fa fa-chevron-right" icon_sizes="custom_settings" icon_font_size="8" icon_width="8" icon_height="8" list_elements_from="menu" {ueldopredefinedsections:menu|context:accountant-services} margin_bottom="0"][/ueldo_shortcode_icon_list][/vc_column][vc_column width="1/2" offset="vc_hidden-lg vc_hidden-md vc_hidden-xs"][ueldo_shortcode_heading class_name="ueldo_vc_element_71223397223959" heading_tag="h5" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_11803404494593" heading_text="'. esc_html( __( 'Other pages', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_icon_list class_name="ueldo_vc_element_57230453413812" icon_fontawesome="fa fa-chevron-right" icon_sizes="custom_settings" icon_font_size="8" icon_width="8" icon_height="8" list_elements_from="menu" {ueldopredefinedsections:menu|context:accountant-pages} margin_bottom="0"][/ueldo_shortcode_icon_list][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_64796220141546"][/vc_column][/vc_row][/vc_section]',

                'header' => '[vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible"][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_43779478697974" layer_for_row_or_section="section" color="#121c82" color_add_box_shadow="yes-outset" color_outset_box_shadow_vertical_length="10" color_outset_box_shadow_blur_radius="35" color_outset_box_shadow_color="rgba(62,51,44,0.25)"][ueldo_shortcode_gap class_name="ueldo_vc_element_17631595027239" large_height="0" small_custom_sizes="yes" small_height="17"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_78781772327250"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_17920633138680" large_width_type="px" large_width_px="171"][ueldo_shortcode_website_logo class_name="ueldo_vc_element_83126916160717" large_width_type="px" large_width_px="171" {ueldopredefinedsections:image|context:accountant-logo-demo-like}][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15052023343464" large_width_type="px" large_width_px="200" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="60"][ueldo_shortcode_button class_name="ueldo_vc_element_69655943834331" button_visible_on_devices="large,medium,small" button_text="1-800-123-4567" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" button_alignment="right" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-phone" custom_sizes_enabled="custom_settings" standard_button_padding_top="12" standard_button_padding_right="22" standard_button_padding_bottom="12" standard_button_padding_left="22" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="rgba(255,255,255,0.17)" standard_button_background_color_hover="#e46e00" standard_button_border_color="rgba(255,255,255,0.01)" standard_button_border_color_hover="rgba(255,255,255,0.01)" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_color_hover="rgba(228,110,0,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_73785307152675" button_visible_on_devices="extra-small" button_text="" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-phone" custom_sizes_enabled="custom_settings" additional_margin_before="20" standard_button_padding_top="12" standard_button_padding_right="22" standard_button_padding_bottom="12" standard_button_padding_left="22" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="rgba(255,255,255,0.17)" standard_button_background_color_hover="#e46e00" standard_button_border_color="rgba(255,255,255,0.01)" standard_button_border_color_hover="rgba(255,255,255,0.01)" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_color_hover="rgba(228,110,0,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15052012869457" large_width_type="calc" large_width_calc_px="371" large_content_alignment="right" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="231"][ueldo_shortcode_header_menu class_name="ueldo_vc_element_80705297655770" menu_style="04" menu_links_alignment="right" custom_sizes_enabled="custom_settings" margin_right="-15"][ueldo_shortcode_button class_name="ueldo_vc_element_15054568327742" button_visible_on_devices="small,extra-small" button_text="" action_after_click="show_hide_side_menu" button_alignment="right" show_button_icon="yes" button_icon_fontawesome="fa fa-bars" custom_sizes_enabled="custom_settings" standard_button_padding_top="0" standard_button_padding_right="0" standard_button_padding_bottom="0" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_border_radius="0" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="#121c82" standard_button_border_color="#121c82" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="0" standard_button_box_shadow_blur_radius_hover="0" standard_button_box_shadow_color_hover="rgba(255,255,255,0.01)" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="#ffffff"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_25731705415181" large_height="0" small_custom_sizes="yes" small_height="16"][/vc_column][/vc_row][/vc_section]',

                'single-blog-post-background-top' => '[vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15052965244219" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" color="#fdf4eb" large_height_type="px" large_height_px="120"][/vc_column][/vc_row][/vc_section]',

                'additional-before-side-menu' => '[vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_915054688357426" large_height="0"][/vc_column][/vc_row]',

                'additional-after-side-menu' => '[vc_row][vc_column][ueldo_shortcode_button class_name="ueldo_vc_element_15054671686836" button_text="'. esc_html( __( 'Contact us!', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us!', 'ueldo' ) ) ) .'||" button_alignment="center"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_15054688357426" large_height="30"][/vc_column][/vc_row]<p style="text-align: center">2017 - '. date( 'Y' ) .' &copy; <a href="'. esc_url( ueldo_get_external_url( 'ueldo-com' ) ) .'" target="_blank">'. esc_html( __( 'Ueldo', 'ueldo' ) ) .'</a></p>[vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_925054688357426" large_height="5"][/vc_column][/vc_row]'
            );

            # return result
            return( $page_slug == false ? $contents : ( isset( $contents[esc_attr( $page_slug )] ) ? $contents[esc_attr( $page_slug )] : false ) );
        }

       /**
        *
        * end of class methods.
        *
        */
    }

   /**
    *
    * end of file.
    *
    */

?>