<?php

   /**
    *
    * installation class for "barbershop" demo template
    *
    */

    class ueldo_demo_contents_loader_base extends ueldo_demo_contents_loader_installation_helper {

       /**
        *
        * install template or its parts
        *
        */

        public static function install( $parts, $icons ) {

           /**
            *
            * install revolution slider
            *
            */

            if( $parts == 'all' || in_array( 'revolution-slider-sliders', $parts, true ) ) {

                # upload revolution slider and get its id
                if( ( $slider_id = ueldo_add_demo_assets::upload_revslider( 'barber-shop' ) ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:revslider|context:barber-shop}', 'alias="'. esc_attr( $slider_id ) .'"' );

                    # remove temporary variables
                    unset( $slider_id );
                }
            }

           /**
            *
            * install forms
            *
            */

            if( $parts == 'all' || in_array( 'forms', $parts, true ) ) {

                # add form in contact form 7 plugin and get its id
                if( ( $form_id = ueldo_add_demo_assets::add_contact_form() ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:contactform7|context:barber-shop|inside:false}', 'id="'. esc_attr( $form_id ) .'"' );

                    # remove temporary variables
                    unset( $form_id );
                }
            }

           /**
            *
            * add pages, but not fill it with contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # add pages and get its ids
                $pages_ids = ueldo_add_demo_assets::add_empty_pages( 'page', array(
                    '404-page' => esc_html( __( '404 page', 'ueldo' ) ),
                    'home' => esc_html( __( 'Home', 'ueldo' ) )
                ));

                # add headers, footers and extras
                $hefos_ids = ueldo_add_demo_assets::add_empty_pages( 'ueldohefo', array(
                    'footer' => esc_html( __( 'Footer', 'ueldo' ) ),
                    'header' => esc_html( __( 'Header', 'ueldo' ) ),
                    'flying-header' => esc_html( __( 'Flying header', 'ueldo' ) )
                ));

                # add solution
                self::add_solution( 'pages-ids', array_merge( $pages_ids, $hefos_ids ) );

                # show page on front
                update_option( 'show_on_front', 'page' );

                # update home page ID
                if( $pages_ids['home'] != null && $pages_ids['home'] != false ) update_option( 'page_on_front', $pages_ids['home'] );

                # do we have 404 page correctly added?
                if( $pages_ids['404-page'] != null && $pages_ids['404-page'] != false ) {

                    # set custom post meta option for 404 page
                    add_post_meta( esc_attr( $pages_ids['404-page'] ), '_ueldo_custom_page_settings_meta_box_data', array(
                        'page_excerpt' => '',
                        'custom_header_id' => self::get_trusted_solution( 'flying-header-page-id', self::get_solution( 'pages-ids', 'flying-header' ) ),
                        'custom_header_position' => 'flying',
                        'use_second_header' => 'no',
                        'get_second_header_content_from' => 'default',
                        'second_header_visible_from' => '400',
                        'default_header_logo_image' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ),
                        'default_second_header_logo_image' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ),
                        'custom_footer_id' => 'none',
                        'custom_footer_position' => 'static'
                    ));
                }

                # remove temporary variables
                unset( $pages_ids );
            }

           /**
            *
            * install menus
            *
            */

            if( $parts == 'all' || in_array( 'menus', $parts, true ) ) {

                # add new menu
                if( is_int( $menu_id = ueldo_add_demo_assets::add_menu( 'barbershop-main-menu', self::get_solution( 'pages-ids' ), true ) ) ) {

                    # add solution
                    self::add_solution( 'main-menu-id', esc_attr( $menu_id ) );
                }
            }

           /**
            *
            * get dynamic elements replacements
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) || in_array( 'pages', $parts, true ) ) {

                # get dynamic elements replacements
                $replacements = self::get_dynamic_elements_replacements( self::find_dynamic_elements( self::get_vc_contents() ), $icons, self::get_default_replacements() );
            }

           /**
            *
            * install theme options
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) ) {

                # update theme options
                update_option( 'ueldo_theme_options', self::get_theme_options_array() );

                # set additional content before side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_before_all', self::do_content_replacements( self::get_vc_contents( 'additional-before-side-menu' ), $replacements ) );

                # set additional content after side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_after_all', self::do_content_replacements( self::get_vc_contents( 'additional-after-side-menu' ), $replacements ) );

                # clear theme mods - background color and image
                remove_theme_mod( 'background_color' );
                remove_theme_mod( 'background_position_x' );
                remove_theme_mod( 'background_position_y' );
                remove_theme_mod( 'background_repeat' );
                remove_theme_mod( 'background_attachment' );
                remove_theme_mod( 'background_size' );
                remove_theme_mod( 'background_image' );
            }

           /**
            *
            * fill pages contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # walk for each pages
                foreach( self::get_solution( 'pages-ids' ) as $page_slug => $page_id ) {

                    # update page content
                    $result = wp_update_post( array(
                        'ID' => esc_attr( $page_id ),
                        'post_content' => self::do_content_replacements( self::get_vc_contents( esc_attr( $page_slug ) ), $replacements )
                    ));
                }

                # remove temporary variables
                unset( $replacements );
            }

           /**
            *
            * update permalinks structure
            *
            */

            if( $parts == 'all' || in_array( 'permalinks-structure', $parts, true ) ) {

                # global variable
                global $wp_rewrite;

                # write the rule
                $wp_rewrite -> set_permalink_structure( '/%postname%/' );

                # set the option
                update_option( 'rewrite_rules', false );

                # flush the rules and tell it to write htaccess
                $wp_rewrite -> flush_rules( true );
            }

           /**
            *
            * demo data installed
            *
            */

            exit( '{ "status": "ok" }' );
        }

       /**
        *
        * get possible data parts
        *
        */

        public static function get_possible_data_parts() {

            # return result
            return( array(
                'menus' => esc_html( __( 'Menus', 'ueldo' ) ),
                'pages' => esc_html( __( 'Pages', 'ueldo' ) ),
                'theme-options' => esc_html( __( 'Theme options', 'ueldo' ) ),
                'forms' => esc_html( __( 'Forms', 'ueldo' ) ),
                'revolution-slider-sliders' => esc_html( __( 'Revolution Slider sliders', 'ueldo' ) ),
                'permalinks-structure' => esc_html( __( 'Permalinks structure', 'ueldo' ) )
            ));
        }

       /**
        *
        * get list of required plugins
        *
        */

        public static function get_required_plugins( $parts ) {

            # all data
            if( !is_array( $parts ) && $parts == 'all' ) {

                # return list of required plugins
                return( array(
                    'ueldo',
                    'visual-composer',
                    'revolution-slider',
                    'contact-form-7'
                ));
            }

            # selected parts
            else {

                # prepare array of required plugins
                $result = array( 'ueldo' );

                # do we have to add pages?
                if( in_array( 'pages', $parts, true ) ) {

                    # return list of required plugins
                    return( array(
                        'visual-composer',
                        'revolution-slider',
                        'contact-form-7'
                    ));
                }

                # do we have to add theme options?
                if( in_array( 'theme-options', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'visual-composer' ) );
                }

                # do we have to add forms?
                if( in_array( 'forms', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'contact-form-7' ) );
                }

                # do we have to add revolution slider sliders?
                if( in_array( 'revolution-slider-sliders', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'revolution-slider' ) );
                }

                # return result
                return( $result );
            }
        }

       /**
        *
        * get default replacements
        *
        */

        public static function get_default_replacements() {

            # add logo image
            $logo_image_id = ueldo_add_demo_assets::add_image( 'barber-shop-logo' );

            # return result
            return( array(
                '{ueldopredefinedsections:googlemap|context:barber-shop}' => 'google_map_id="1"',
                '{ueldopredefinedsections:openinghours|context:barber-shop}' => 'status="1"',
                '{ueldopredefinedsections:image|context:barber-shop-logo}' => ( $logo_image_id == false ? '' : 'image="'. esc_attr( $logo_image_id ) .'"' )
            ));
        }

       /**
        *
        * get trusted solution
        *
        */

        public static function get_trusted_solution( $type, $solution ) {

            # do we have solution found?
            if( !empty( $solution ) ) return( $solution );

            # switch by solution type
            switch( $type ) {

                # get most similar elements
                case 'main-menu-slug': return( self::get_most_similar_element( 'menu_slug', esc_html( __( 'Main menu - Barbershop template', 'ueldo' ) ) ) );
                case '404-page-id': return( self::get_most_similar_element( 'page', esc_html( __( '404 page', 'ueldo' ) ) ) );
                case 'footer-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Footer', 'ueldo' ) ) ) );
                case 'header-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Header', 'ueldo' ) ) ) );
                case 'flying-header-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Flying header', 'ueldo' ) ) ) );
            }

            # nothing found
            return( false );
        }

       /**
        *
        * get theme options array
        *
        */

        public static function get_theme_options_array() {

            # return result
            return( array(
                '404-page-id' => array( 'all' => self::get_trusted_solution( '404-page-id', self::get_solution( 'pages-ids', '404-page' ) ) ),
                'blog-posts-list-style' => array(
                    'posts-list-style' => 'default',
                    'display-post-data-under-title' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'yes'
                ),
                'blog-sidebar' => array(
                    'posts-list' => 'yes-right',
                    'single-post' => 'yes-right',
                    'responsive-style' => 'static'
                ),
                'boxed-website' => array(
                    'enabled' => 'no',
                    'large-content-width' => '1100',
                    'large-content-space' => '50',
                    'medium-content-width' => '890',
                    'medium-content-space' => '50',
                    'small-content-width' => '665',
                    'small-content-space' => '50'
                ),
                'comment-textarea-at-top' => 'yes',
                'dynamic-theme-styles-cache' => array(
                    'enabled' => 'no',
                    'clear-cache' => 'all-the-time-when-logged-in'
                ),
                'facebook-fanpage-url' => array( 'all' => 'https://www.facebook.com/envato' ),
                'featured-image-on-lists-only' => 'no',
                'fonts' => array(
                    'general-font-family' => array( 'all' => 'Roboto' ),
                    'general-font-weight' => array( 'all' => '300' ),
                    'general-font-subset' => array( 'all' => 'latin' ),
                    'general-font-smoothing' => array( 'all' => 'yes' ),
                    'general-bold-font-family' => array( 'all' => 'Roboto' ),
                    'general-bold-font-weight' => array( 'all' => '600' ),
                    'general-bold-font-subset' => array( 'all' => 'latin' ),
                    'general-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-font-family' => array( 'all' => 'Playfair Display' ),
                    'menu-font-weight' => array( 'all' => 'regular' ),
                    'menu-font-subset' => array( 'all' => 'latin' ),
                    'menu-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-font-family' => array( 'all' => 'Playfair Display' ),
                    'headings-font-weight' => array( 'all' => 'regular' ),
                    'headings-font-subset' => array( 'all' => 'latin' ),
                    'headings-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-slim-font-family' => array( 'all' => 'Playfair Display' ),
                    'headings-slim-font-weight' => array( 'all' => 'regular' ),
                    'headings-slim-font-subset' => array( 'all' => 'latin' ),
                    'headings-slim-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-bold-font-family' => array( 'all' => 'Playfair Display' ),
                    'headings-bold-font-weight' => array( 'all' => '700' ),
                    'headings-bold-font-subset' => array( 'all' => 'latin' ),
                    'headings-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-subtitle-font-family' => array( 'all' => 'Playfair Display' ),
                    'headings-subtitle-font-weight' => array( 'all' => '700' ),
                    'headings-subtitle-font-subset' => array( 'all' => 'latin' ),
                    'headings-subtitle-font-smoothing' => array( 'all' => 'yes' ),
                    'buttons-font-family' => array( 'all' => 'Playfair Display' ),
                    'buttons-font-weight' => array( 'all' => '700' ),
                    'buttons-font-subset' => array( 'all' => 'latin' ),
                    'buttons-font-smoothing' => array( 'all' => 'yes' ),
                    'form-fields-font-family' => array( 'all' => 'Roboto' ),
                    'form-fields-font-weight' => array( 'all' => '400' ),
                    'form-fields-font-subset' => array( 'all' => 'latin' ),
                    'form-fields-font-smoothing' => array( 'all' => 'yes' ),
                    'blockquote-font-family' => array( 'all' => 'Playfair Display' ),
                    'blockquote-font-weight' => array( 'all' => '700' ),
                    'blockquote-font-subset' => array( 'all' => 'latin' ),
                    'blockquote-font-smoothing' => array( 'all' => 'yes' ),
                    'alert-messages-font-family' => array( 'all' => 'Roboto' ),
                    'alert-messages-font-weight' => array( 'all' => '300' ),
                    'alert-messages-font-subset' => array( 'all' => 'latin' ),
                    'alert-messages-font-smoothing' => array( 'all' => 'yes' )
                ),
                'footer-content' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'footer-page-id', self::get_solution( 'pages-ids', 'footer' ) ) ),
                    'position' => array( 'all' => 'static' )
                ),
                'google-maps' => array(
                    'api-key' => '',
                    'next-map-id' => '2',
                    'google-map-1-title' => esc_html( __( 'Company location', 'ueldo' ) ),
                    'google-map-1-center-lat' => '40.713658',
                    'google-map-1-center-lng' => '-74.005367',
                    'google-map-1-zoom' => '16',
                    'google-map-1-markers-next-marker-id' => '2',
                    'google-map-1-markers-marker-1-title' => esc_html( __( 'Marker', 'ueldo' ) ),
                    'google-map-1-markers-marker-1-lat' => '40.713658',
                    'google-map-1-markers-marker-1-lng' => '-74.005367',
                    'google-map-1-markers-marker-1-use-custom-marker' => 'no',
                    'google-map-1-markers-marker-1-custom-icon-library' => 'fontawesome',
                    'google-map-1-markers-marker-1-custom-icon' => 'fa fa-address-book',
                    'google-map-1-markers-marker-1-custom-icon-size' => '18',
                    'google-map-1-markers-marker-1-custom-icon-width' => '36',
                    'google-map-1-markers-marker-1-custom-icon-height' => '36',
                    'google-map-1-markers-marker-1-custom-icon-border-radius' => 'circle',
                    'google-map-1-markers-marker-1-custom-icon-border-radius-px' => '4',
                    'google-map-1-markers-marker-1-custom-icon-color' => '#2f3a3e',
                    'google-map-1-markers-marker-1-custom-icon-background-color' => '#fff',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-horizontal-length' => '0',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-vertical-length' => '5',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-blur-radius' => '20',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-spread-radius' => '0',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-color' => 'rgba( 0, 0, 0, 0.1 )',
                    'google-map-1-markers-marker-1-custom-marker-image' => '',
                    'google-map-1-custom-style' => '[{"featureType":"administrative","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":20}]},{"featureType":"road","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":40}]},{"featureType":"water","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-10},{"lightness":30}]},{"featureType":"landscape.man_made","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":10}]},{"featureType":"landscape.natural","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":60}]},{"featureType":"poi","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]},{"featureType":"transit","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]}]'
                ),
                'header' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'header-page-id', self::get_solution( 'pages-ids', 'header' ) ) ),
                    'position' => array( 'all' => 'static' ),
                    'use-second-header' => array( 'all' => 'yes' ),
                    'get-second-content-from' => array( 'all' => self::get_trusted_solution( 'flying-header-page-id', self::get_solution( 'pages-ids', 'flying-header' ) ) ),
                    'second-header-visible-from' => array( 'all' => '400' ),
                    'default-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'second-header-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) )
                ),
                'lazy-load-images' => array(
                    'enabled' => 'no',
                    'threshold' => '0'
                ),
                'loader-animation' => array(
                    'enabled' => 'yes',
                    'style' => '01',
                    'add-logo' => 'no',
                    'space-between-logo-and-spinner' => '30',
                    'logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'custom-colors-enabled' => 'no',
                    'custom-colors-background' => '#fff',
                    'custom-colors-spinner' => '#2f3a3e'
                ),
                'local-scrolling-links-animation' => array(
                    'enabled' => 'yes',
                    'animation-speed' => '1000'
                ),
                'opening-hours-status' => array(
                    'next-status-id' => '2',
                    'status-1-title' => esc_html( __( 'Regular opening hours', 'ueldo' ) ),
                    'status-1-timezone' => 'use-browser',
                    'status-1-rules-next-rule-id' => '4',
                    'status-1-rules-rule-1-title' => esc_html( __( 'Monday - Friday', 'ueldo' ) ),
                    'status-1-rules-rule-1-apply-for-monday' => 'on',
                    'status-1-rules-rule-1-apply-for-tuesday' => 'on',
                    'status-1-rules-rule-1-apply-for-wednesday' => 'on',
                    'status-1-rules-rule-1-apply-for-thursday' => 'on',
                    'status-1-rules-rule-1-apply-for-friday' => 'on',
                    'status-1-rules-rule-1-all-day-closed' => 'no',
                    'status-1-rules-rule-1-next-opening-hours-id' => '2',
                    'status-1-rules-rule-1-opening-hours-1-ignored' => 'no',
                    'status-1-rules-rule-1-opening-hours-1-from-hour' => '10',
                    'status-1-rules-rule-1-opening-hours-1-from-minutes' => '00',
                    'status-1-rules-rule-1-opening-hours-1-to-hour' => '23',
                    'status-1-rules-rule-1-opening-hours-1-to-minutes' => '00',
                    'status-1-rules-rule-2-title' => esc_html( __( 'Saturday', 'ueldo' ) ),
                    'status-1-rules-rule-2-apply-for-saturday' => 'on',
                    'status-1-rules-rule-2-all-day-closed' => 'no',
                    'status-1-rules-rule-2-next-opening-hours-id' => '2',
                    'status-1-rules-rule-2-opening-hours-1-ignored' => 'no',
                    'status-1-rules-rule-2-opening-hours-1-from-hour' => '11',
                    'status-1-rules-rule-2-opening-hours-1-from-minutes' => '00',
                    'status-1-rules-rule-2-opening-hours-1-to-hour' => '18',
                    'status-1-rules-rule-2-opening-hours-1-to-minutes' => '00',
                    'status-1-rules-rule-3-title' => esc_html( __( 'Sunday', 'ueldo' ) ),
                    'status-1-rules-rule-3-apply-for-sunday' => 'on',
                    'status-1-rules-rule-3-all-day-closed' => 'yes',
                    'status-1-rules-rule-3-next-opening-hours-id' => '2',
                    'status-1-rules-rule-3-opening-hours-1-ignored' => 'no',
                    'status-1-rules-rule-3-opening-hours-1-from-hour' => '08',
                    'status-1-rules-rule-3-opening-hours-1-from-minutes' => '00',
                    'status-1-rules-rule-3-opening-hours-1-to-hour' => '16',
                    'status-1-rules-rule-3-opening-hours-1-to-minutes' => '00',
                    'status-1-exceptions-next-exception-id' => '1'
                ),
                'rtl' => array(
                    'is-rtl' => array( 'all' => 'no' ),
                    'load-rtl-admin-styles' => array( 'all' => 'auto' )
                ),
                'side-menu' => array(
                    'style' => 'flying-default-hidden',
                    'menu-key' => array( 'all' => self::get_trusted_solution( 'main-menu-slug', self::get_main_menu_slug() ) ),
                    'menu-link-font-family' => array( 'all' => 'Playfair Display' ),
                    'menu-link-font-weight' => array( 'all' => 'regular' ),
                    'menu-link-font-subset' => array( 'all' => 'latin' ),
                    'menu-link-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-position' => 'left',
                    'menu-links-alignment' => 'center',
                    'opacity-animation-enabled' => 'yes',
                    'submenu-links' => 'visible-always',
                    'menu-vertical-alignment' => 'middle',
                    'custom-sizes-enabled' => 'no',
                    'custom-sizes-container-width' => '300',
                    'custom-sizes-menu-link-font-size' => '14',
                    'custom-sizes-menu-link-font-line-height' => '1.0',
                    'custom-sizes-menu-link-font-letter-spacing' => '0',
                    'custom-sizes-menu-link-padding-top-bottom' => '15',
                    'custom-sizes-menu-link-padding-left-right' => '25',
                    'custom-sizes-menu-link-margin-top-bottom' => '0',
                    'custom-sizes-menu-link-margin-left-right' => '0',
                    'custom-sizes-menu-link-bottom-border-width' => '1',
                    'custom-sizes-display-bottom-border-for-last-menu-link' => 'display',
                    'custom-sizes-menu-icon-font-size' => '10',
                    'custom-sizes-menu-icon-margin-top' => '0',
                    'custom-sizes-menu-margin-between-icon-and-title' => '10',
                    'custom-sizes-padding-top-bottom-additional-element-before-menu' => '20',
                    'custom-sizes-padding-left-right-additional-element-before-menu' => '30',
                    'custom-sizes-margin-top-additional-element-before-menu' => '0',
                    'custom-sizes-margin-right-additional-element-before-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-before-menu' => '0',
                    'custom-sizes-margin-left-additional-element-before-menu' => '0',
                    'custom-sizes-padding-top-bottom-additional-element-after-menu' => '20',
                    'custom-sizes-padding-left-right-additional-element-after-menu' => '30',
                    'custom-sizes-margin-top-additional-element-after-menu' => '0',
                    'custom-sizes-margin-right-additional-element-after-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-after-menu' => '0',
                    'custom-sizes-margin-left-additional-element-after-menu' => '0'
                ),
                'single-blog-post-style' => array(
                    'display-post-data-under-title' => 'yes',
                    'blog-post-data-and-title-centered' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'yes'
                ),
                'submit-button-position-in-comment-reply-form' => array( 'all' => 'left' ),
                'translate-publication-dates' => 'yes',
                'twitter-api' => array(
                    'oauth-key' => '',
                    'oauth-secret-key' => ''
                ),
                'under-single-blog-post-content-elements' => array(
                    'elements-count' => '3',
                    'element-1-type' => 'tags-and-categories-with-facebook',
                    'element-1-similar-posts-style' => '02',
                    'element-2-type' => 'author-box',
                    'element-2-similar-posts-style' => '02',
                    'element-3-type' => 'next-previous-posts-navigation',
                    'element-3-similar-posts-style' => '02',
                    'element-4-type' => '',
                    'element-4-similar-posts-style' => '02',
                    'element-5-type' => '',
                    'element-5-similar-posts-style' => '02',
                    'element-6-type' => '',
                    'element-6-similar-posts-style' => '02'
                ),
                'vc-sections-on-blog-pages' => array(
                    'posts-list-above' => array( 'all' => 'none' ),
                    'posts-list-under' => array( 'all' => 'none' ),
                    'single-post-above' => array( 'all' => 'none' ),
                    'single-post-under' => array( 'all' => 'none' ),
                    'archive-above' => array( 'all' => 'none' ),
                    'archive-under' => array( 'all' => 'none' ),
                    'search-above' => array( 'all' => 'none' ),
                    'search-under' => array( 'all' => 'none' )
                ),
                'visual-composer-custom-fonts' => array( 'next-font-id' => '1' ),
                'styles' => array(
                    'general-colors-main-color' => '#2f3a3e',
                    'general-colors-google-map-marker-icon-color' => '#2f3a3e',
                    'buttons-global-button-background-color' => '#2f3a3e',
                    'buttons-global-button-border-color' => '#2f3a3e',
                    'buttons-global-button-background-color-hover' => '#232c33',
                    'buttons-global-button-border-color-hover' => '#232c33',
                    'buttons-global-button-box-shadow-hover' => '0px 10px 35px 0px rgba(35,44,51,0.25)',
                    'buttons-global-button-box-shadow' => '0px 10px 35px 0px rgba(47,58,62,0.25)',
                    'general-colors-website-background' => '#ffffff',
                    'general-colors-headings-color' => '#2f3a3e',
                    'general-colors-blog-post-data-color' => '#2f3a3e',
                    'general-colors-elements-hover-box-shadow' => '0px 0px 0px 0px rgba(255,255,255,0)',
                    'general-colors-image-box-shadow' => '0px 0px 0px 0px rgba(255,255,255,0)',
                    'general-colors-elements-hover-border-color' => '#e0d8d1',
                    'general-colors-elements-inset-border-color' => '#f1f1f1',
                    'font-size-h1' => '40',
                    'font-size-h2' => '32',
                    'info-box-element-background-color' => '#2f3a3e',
                    'info-box-element-border-color' => '#2f3a3e',
                    'forms-field-inset-box-shadow' => '0px 0px 0px 0px rgba(255,255,255,0)',
                    'forms-checkbox-radio-main-color' => '#bb987a',
                    'forms-field-border-color' => '#f1f1f1',
                    'forms-field-border-color-on-hover' => '#e0d8d1',
                    'forms-field-border-color-on-focus' => '#e0d8d1',
                    'header-bar-and-menu-background-color' => '#2f3a3e',
                    'header-bar-and-menu-box-shadow' => '0px 0px 0px 0px rgba(255,255,255,0)',
                    'font-size-menu-links' => '15',
                    'font-size-smallest-content' => '13',
                    'side-menu-box-shadow' => '-5px 0px 20px 0px rgba(113,94,78,0.25)',
                    'side-menu-background-color' => '#715e4e',
                    'side-menu-link-color' => 'rgba(255,255,255,0.4)',
                    'side-menu-link-border-bottom-color' => '#715e4e',
                    'side-menu-link-border-bottom-color-hover' => '#715e4e',
                    'side-menu-active-link-border-bottom-color' => '#715e4e'
                )
            ));
        }

       /**
        *
        * get default contents
        *
        */

        public static function get_vc_contents( $page_slug = false ) {

            # array of pages contents
            $contents = array(

                'home' => '[vc_section full_width="stretch_row_content" css=".vc_custom_1504685145111{margin-top: -76px !important;}"][vc_row full_width="stretch_row_content_no_spaces"][vc_column][rev_slider {ueldopredefinedsections:revslider|context:barber-shop}][/vc_column][/vc_row][/vc_section][vc_section el_id="services"][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15045139162529" large_height="75"][/vc_column][/vc_row][vc_row][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15045139521523" heading_tag="h1" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15045139601018" heading_text="'. esc_html( __( 'Traditional Barber Shop & Shave Parlor', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings" font_color="#bb987a" font_color_hover="#bb987a"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Sed id varius mi. Interdum et malesuada fames ac ante ipsum primis in faucibus. Duis in ante nibh. Nulla pellentesque fringilla suscipit. Nam non pellentesque eros. Donec tristique sagittis vehicula. Mauris varius neque quis nisi tristique sagittis. In semper feugiat consequat.</p>[/vc_column_text][/vc_column][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_45235042599275" custom_layer_sizes="custom_settings" color="rgba(255,255,255,0.01)" color_add_border="yes" color_border_width="5" color_border_color="#bb987a" large_width_type="px" large_width_px="583" large_height_type="px" large_height_px="555" large_layer_position="bottom_left" large_margin_bottom="-30" large_margin_left="45" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="472" medium_height_type="px" medium_height_px="459" medium_layer_position="bottom_left" medium_margin_bottom="-30" medium_margin_left="45" small_layer_visibility="no" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="90" extra_small_height_type="px" extra_small_height_px="60" extra_small_layer_position="bottom_left" extra_small_margin_bottom="-30" extra_small_margin_left="45"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_84579942984972" layer_z_index="15" custom_layer_sizes="custom_settings" color="rgba(255,255,255,0.01)" color_add_border="yes" color_border_width="5" color_border_color="#bb987a" large_layer_visibility="no" medium_layer_visibility="no" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="665" small_height_type="px" small_height_px="555" small_layer_position="bottom_left" small_margin_bottom="-30" small_margin_left="45" extra_small_layer_visibility="no"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_56902333169487" layer_title="'. esc_html( __( 'Top line', 'ueldo' ) ) .'" layer_z_index="15" custom_layer_sizes="custom_settings" color="#bb987a" large_width_type="px" large_width_px="583" large_height_type="px" large_height_px="5" large_margin_top="220" large_margin_left="45" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="388" medium_height_type="px" medium_height_px="5" medium_margin_top="220" medium_margin_left="45" small_layer_visibility="no" extra_small_layer_visibility="no"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_38897646249692" layer_title="'. esc_html( __( 'Left line', 'ueldo' ) ) .'" layer_z_index="15" custom_layer_sizes="custom_settings" color="#bb987a" large_width_type="px" large_width_px="5" large_height_type="px" large_height_px="555" large_margin_top="220" large_margin_left="45" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="5" medium_height_type="px" medium_height_px="459" medium_margin_top="220" medium_margin_left="45" small_layer_visibility="no" extra_small_layer_visibility="no"][ueldo_shortcode_gap class_name="ueldo_vc_element_15045143864368"][ueldo_shortcode_tabs class_name="ueldo_vc_element_15045149809358" tabs_content_style="style-04" content_position="right" tabs_selector_style="style-03" circle_navigation_alignment="left" image_container_border_radius="0" custom_tab_image_enabled="yes" tabs_04_content_border_radius="0" tabs_04_image_and_content_width="53%" tabs_04_content_padding_top="60" tabs_04_content_padding_right="0" tabs_04_content_padding_bottom="60" tabs_content_and_selector_space="75" tabs_selector_border_radius="0"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_91774526673278" single_tab_title="'. esc_html( __( 'Beard Shave', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_15045152328032" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_8434693538668" heading_text="'. esc_html( __( 'Unique man-made shave', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Nunc quis dui vel nibh mattis pulvinar vel ut neque. Integer erat libero, hendrerit dapibus congue non, gravida id mi. Suspendisse faucibus augue sed metus vehicula, sit amet tristique risus viverra. In mauris justo, accumsan sed eros a, congue venenatis neque. Curabitur eleifend.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15045152192931" large_height="25"][/ueldo_shortcode_tabs_single_tab][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_31265869437273" single_tab_title="'. esc_html( __( 'Beard Trim', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_27952799039089" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_6240913795415" heading_text="'. esc_html( __( 'Beard Trim with clippers and scissors', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Aliquam orci lacus, interdum at risus et, dapibus sagittis nulla. Quisque id massa sit amet massa lobortis dignissim ut et urna. Ut lacus nulla, dapibus id risus eget, viverra ultricies sem. Vestibulum facilisis vulputate ligula, aliquet fermentum arcu consequat vitae. Duis dapibus pretium sem, porttitor.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_5308491419167" large_height="25"][/ueldo_shortcode_tabs_single_tab][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_55917400260795" single_tab_title="'. esc_html( __( 'Cut & Shave', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_61351340187787" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_7814264631158" heading_text="'. esc_html( __( 'Expert & Highly Skilled Barbers', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Nullam diam metus, euismod tempor lacus eu, scelerisque varius purus. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Duis laoreet id magna vitae viverra. Phasellus nec ultricies odio. Fusce eu erat eget felis semper tempor nec at massa. Integer vitae.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_6120680283403" large_height="25"][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15120628389612" large_height="90"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15045190810366" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15045190876604" heading_text="'. esc_html( __( 'Find out more about us', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings" custom_font_color_enabled="custom_settings" font_color="#bb987a" font_color_hover="#bb987a"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Duis tristique lacinia urna, nec commodo ipsum vestibulum quis. Fusce non placerat urna. Phasellus facilisis gravida libero, et pulvinar magna lobortis ac. Integer dapibus ipsum tortor, in rutrum erat facilisis rutrum. Nullam imperdiet quam risus, nec tristique est rhoncus a.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15045208488864" large_height="25"][/vc_column][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][ueldo_shortcode_info_box class_name="ueldo_vc_element_21741045488958" info_box_title="'. esc_html( __( 'Since 1972', 'ueldo' ) ) .'" info_box_subtitle="'. esc_html( __( 'Decades of experience', 'ueldo' ) ) .'" info_element_border_radius="px" {ueldopredefinedsections:icon|key:flaticon-barbershop,flaticon-business|url:https://www.flaticon.com/free-icon/barbershop_534292|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_icon_color="#ffffff" info_element_icon_color_hover="#ffffff" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_26916253146427" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_info_box class_name="ueldo_vc_element_35358904289968" info_box_title="'. esc_html( __( '7 team members', 'ueldo' ) ) .'" info_box_subtitle="'. esc_html( __( 'High-skilled professionals', 'ueldo' ) ) .'" info_element_border_radius="px" {ueldopredefinedsections:icon|key:flaticon-hair-cut,flaticon-man|url:https://www.flaticon.com/free-icon/hair-cut_534296|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_icon_color="#ffffff" info_element_icon_color_hover="#ffffff" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_17928416774425" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_info_box class_name="ueldo_vc_element_11773555865598" info_box_title="'. esc_html( __( 'Best products only', 'ueldo' ) ) .'" info_box_subtitle="'. esc_html( __( 'Zero tolerance for low quality', 'ueldo' ) ) .'" info_element_border_radius="px" {ueldopredefinedsections:icon|key:flaticon-cream|url:https://www.flaticon.com/free-icon/cream_534286|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_icon_color="#ffffff" info_element_icon_color_hover="#ffffff" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces" el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15045208440293"][ueldo_shortcode_button class_name="ueldo_vc_element_1504519928091" button_text="'. esc_html( __( 'Schedule a Visit', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_text_alignment="center" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'%23contact|title:'. rawurlencode( esc_html( __( 'Schedule a Visit', 'ueldo' ) ) ) .'||" button_alignment="center"][/ueldo_shortcode_button][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15121396999098" layer_z_index="0" custom_layer_sizes="custom_settings" color="#daccc1" large_height_type="px" large_height_px="25" large_layer_position="bottom_left"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible" el_id="our-barbers"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_1504520268608" layer_for_row_or_section="section" color="#daccc1"][ueldo_shortcode_gap class_name="ueldo_vc_element_1504526567007" large_height="45"][/vc_column][/vc_row][vc_row content_placement="middle"][vc_column][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15045301714326"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15045301819661" large_width_type="px" large_width_px="82" large_content_alignment="right"][vc_column_text][ueldo_next_prev_loop_icons loop_id="15045282858198"][/vc_column_text][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_15045315412005" large_height="30"][ueldo_shortcode_loop class_name="ueldo_vc_element_15045282858198" columns="2" margin_between_columns="90" use_separate_next_prev_arrows="separated" custom_next_prev_arrows_settings="custom_settings" arrow_border_width="1" custom_colors_enabled="custom_settings" loop_background_color="#daccc1" next_prev_arrow_color="#2f3a3e" next_prev_arrow_container_background="#d2c3b7" next_prev_arrow_container_background_hover="#c3b3a6" next_prev_arrow_container_border_color="#d2c3b7" next_prev_arrow_container_border_color_hover="#c3b3a6" next_prev_arrow_container_box_shadow_color="rgba(255,255,255,0.01)" next_prev_arrow_container_box_shadow_color_hover="rgba(255,255,255,0.01)"][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_50303240295448"][ueldo_shortcode_gap class_name="ueldo_vc_element_15045303253229" large_height="57" small_custom_sizes="yes" small_height="30"][ueldo_shortcode_heading class_name="ueldo_vc_element_85446548424555" heading_subtitle_text="'. esc_html( __( 'Meet our Barbers', 'ueldo' ) ) .'" custom_heading_subtitle_font_color_enabled="custom_settings" heading_subtitle_font_color="#826a88"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_86575787564996" heading_text="'. esc_html( __( 'Mike McDonovan', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]In hac habitasse platea dictumst. Sed erat libero, fringilla nec sagittis vel, ornare vitae eros. Integer faucibus ligula sit amet felis feugiat iaculis. Duis ut mollis ipsum, ac pharetra tortor.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_57328815276737" large_height="10"][ueldo_shortcode_progress_bar class_name="ueldo_vc_element_92080799694366" progress_bar_duration="2000" progress_bar_value="95%" progress_bar_title="'. esc_html( __( 'Beard Shave', 'ueldo' ) ) .'" progress_bar_title_position="above-progress-bar" custom_colors_enabled="custom_settings" inactive_background_color="#c5b8ad" value_background_color="#bb987a" box_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_progress_bar class_name="ueldo_vc_element_36566145768912" progress_bar_duration="2000" progress_bar_value="82%" progress_bar_title="'. esc_html( __( 'Cut & Shave', 'ueldo' ) ) .'" progress_bar_title_position="above-progress-bar" margin_bottom="0" custom_colors_enabled="custom_settings" inactive_background_color="#c5b8ad" value_background_color="#bb987a" box_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_gap class_name="ueldo_vc_element_15047057345736" large_height="0" small_custom_sizes="yes" small_height="30"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_30246416688296"][vc_row_inner el_class="ueldo-vc-row-overflow-visible"][vc_column_inner][ueldo_shortcode_row_layer class_name="ueldo_vc_element_97890226149539" layer_z_index="15" custom_layer_sizes="custom_settings" color="rgba(255,255,255,0.01)" color_add_border="yes" color_border_width="5" color_border_color="#bb987a" large_width_type="px" large_width_px="505" large_height_type="px" large_height_px="450" large_layer_position="top_right" large_margin_top="30" large_margin_right="45" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="400" medium_height_type="px" medium_height_px="450" medium_layer_position="top_right" medium_margin_top="30" medium_margin_right="45" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="605" small_height_type="px" small_height_px="390" small_margin_top="30" small_margin_left="45" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="90" extra_small_height_type="px" extra_small_height_px="390" extra_small_margin_top="30" extra_small_margin_left="45"][ueldo_shortcode_image class_name="ueldo_vc_element_22608400351391" border_radius="0" large_height_px="450" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_spread_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/vc_column_inner][/vc_row_inner][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_22153548738881"][ueldo_shortcode_gap class_name="ueldo_vc_element_15045303330374" large_height="30"][ueldo_shortcode_heading class_name="ueldo_vc_element_59500065142291" heading_subtitle_text="'. esc_html( __( 'Meet our Barbers', 'ueldo' ) ) .'" custom_font_for_heading_subtitle="custom_settings" heading_subtitle_font_family="buttons-font" custom_heading_subtitle_font_color_enabled="custom_settings" heading_subtitle_font_color="#826a88"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_34461903023267" heading_text="'. esc_html( __( 'John Smith', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]In hac habitasse platea dictumst. Sed erat libero, fringilla nec sagittis vel, ornare vitae eros. Integer faucibus ligula sit amet felis feugiat iaculis. Duis ut mollis ipsum, ac pharetra tortor.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_85940475778593" large_height="10"][ueldo_shortcode_progress_bar class_name="ueldo_vc_element_58138816419405" progress_bar_duration="2000" progress_bar_value="95%" progress_bar_title="'. esc_html( __( 'Beard Shave', 'ueldo' ) ) .'" progress_bar_title_position="above-progress-bar" custom_colors_enabled="custom_settings" inactive_background_color="#c5b8ad" value_background_color="#bb987a" box_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_progress_bar class_name="ueldo_vc_element_37766612336700" progress_bar_duration="2000" progress_bar_value="82%" progress_bar_title="'. esc_html( __( 'Cut & Shave', 'ueldo' ) ) .'" progress_bar_title_position="above-progress-bar" margin_bottom="0" custom_colors_enabled="custom_settings" inactive_background_color="#c5b8ad" value_background_color="#bb987a" box_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_gap class_name="ueldo_vc_element_15047057559478" large_height="0" small_custom_sizes="yes" small_height="30"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_90930805263359"][vc_row_inner el_class="ueldo-vc-row-overflow-visible"][vc_column_inner][ueldo_shortcode_row_layer class_name="ueldo_vc_element_80927765696832" layer_z_index="15" custom_layer_sizes="custom_settings" color="rgba(255,255,255,0.01)" color_add_border="yes" color_border_width="5" color_border_color="#bb987a" large_width_type="px" large_width_px="505" large_height_type="px" large_height_px="450" large_layer_position="top_right" large_margin_top="30" large_margin_right="45" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="400" medium_height_type="px" medium_height_px="450" medium_layer_position="top_right" medium_margin_top="30" medium_margin_right="45" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="605" small_height_type="px" small_height_px="390" small_margin_top="30" small_margin_left="45" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="90" extra_small_height_type="px" extra_small_height_px="390" extra_small_margin_top="30" extra_small_margin_left="45"][ueldo_shortcode_image class_name="ueldo_vc_element_28548469756492" border_radius="0" large_height_px="450" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_spread_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/vc_column_inner][/vc_row_inner][/ueldo_shortcode_loop_cell][/ueldo_shortcode_loop][/vc_column][/vc_row][vc_row el_id="prices"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15120632409078" medium_custom_sizes="yes" medium_height="45" small_custom_sizes="yes" small_height="0"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15120685951351" layer_for_row_or_section="section" layer_z_index="0" color="#daccc1"][ueldo_shortcode_gap class_name="ueldo_vc_element_61966885442777" large_height="30" small_custom_sizes="yes" small_height="0"][ueldo_shortcode_heading class_name="ueldo_vc_element_15045312238599" heading_tag="h1" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15045312302262" heading_text="'. esc_html( __( 'Check the Prices', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/vc_column][/vc_row][vc_row][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][vc_column_text]<p style="text-align: center;">Praesent elementum, magna vestibulum fermentum ullamcorper, quam massa molestie lectus, gravida tincidunt magna tellus non orci. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Cras neque libero, fermentum nec consequat tincidunt, varius in metus.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15045335973492" large_height="70" medium_custom_sizes="yes" medium_height="45" small_custom_sizes="yes" small_height="10"][/vc_column][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_price_single class_name="ueldo_vc_element_69979894933059" title="'. esc_html( __( 'Shave', 'ueldo' ) ) .'" price="$35" custom_sizes_enabled="custom_settings" title_font_size="18" price_font_size="18" custom_colors_enabled="custom_settings" content_elements_background_color="#daccc1" delimiter_color="#c5b8ad"][ueldo_shortcode_gap class_name="ueldo_vc_element_15045329405555" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_11375940196939" title="'. esc_html( __( 'Cut & Shave', 'ueldo' ) ) .'" price="$60" custom_sizes_enabled="custom_settings" title_font_size="18" price_font_size="18" custom_colors_enabled="custom_settings" content_elements_background_color="#daccc1" delimiter_color="#c5b8ad"][ueldo_shortcode_gap class_name="ueldo_vc_element_40937729976145" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_74372970352787" title="'. esc_html( __( 'Beard Trim', 'ueldo' ) ) .'" price="$17" custom_sizes_enabled="custom_settings" title_font_size="18" price_font_size="18" custom_colors_enabled="custom_settings" content_elements_background_color="#daccc1" delimiter_color="#c5b8ad"][ueldo_shortcode_gap class_name="ueldo_vc_element_27974368607257" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_37704686917403" title="'. esc_html( __( 'Scissor Cut &amp; Style', 'ueldo' ) ) .'" price="$40" custom_sizes_enabled="custom_settings" title_font_size="18" price_font_size="18" custom_colors_enabled="custom_settings" content_elements_background_color="#daccc1" delimiter_color="#c5b8ad"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_92068946043427" large_height="0" small_custom_sizes="yes" small_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_18811311144307" title="'. esc_html( __( 'Long Hair Cut By Stylist', 'ueldo' ) ) .'" price="from $55" custom_sizes_enabled="custom_settings" title_font_size="18" price_font_size="18" custom_colors_enabled="custom_settings" content_elements_background_color="#daccc1" delimiter_color="#c5b8ad"][ueldo_shortcode_gap class_name="ueldo_vc_element_11958707588666" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_42922101932651" title="'. esc_html( __( 'Beard Color', 'ueldo' ) ) .'" price="$65" custom_sizes_enabled="custom_settings" title_font_size="18" price_font_size="18" custom_colors_enabled="custom_settings" content_elements_background_color="#daccc1" delimiter_color="#c5b8ad"][ueldo_shortcode_gap class_name="ueldo_vc_element_99959937363389" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_48570497484682" title="'. esc_html( __( 'Beard conditioning', 'ueldo' ) ) .'" price="$17" custom_sizes_enabled="custom_settings" title_font_size="18" price_font_size="18" custom_colors_enabled="custom_settings" content_elements_background_color="#daccc1" delimiter_color="#c5b8ad"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces" el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_91474529161670"][ueldo_shortcode_button class_name="ueldo_vc_element_15046054995787" button_text="'. esc_html( __( 'Schedule a Visit', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'%23contact|title:'. rawurlencode( esc_html( __( 'Schedule a Visit', 'ueldo' ) ) ) .'||" button_alignment="center"][/ueldo_shortcode_button][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15121402955249" layer_z_index="0" custom_layer_sizes="custom_settings" color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" large_height_type="px" large_height_px="25" large_layer_position="bottom_left"][/vc_column][/vc_row][/vc_section][vc_section el_class="ueldo-vc-section-overflow-visible" el_id="gallery"][vc_row][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15046058957103" large_height="75" small_custom_sizes="yes" small_height="60"][ueldo_shortcode_heading class_name="ueldo_vc_element_15045984825145" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1504598489637" heading_text="'. esc_html( __( 'BarberShop Gallery', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings" custom_font_color_enabled="custom_settings" font_color="#bb987a" font_color_hover="#bb987a"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Ut sagittis diam nec orci tempus, sit amet egestas sem pretium. Donec in lacus ac erat tempus mattis. Vestibulum ac sem vehicula, dictum dui ac, semper libero. Donec posuere placerat turpis, et aliquet nunc mattis eu. Vivamus consequat arcu lacus, eu rutrum.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15045987585564" large_height="30"][/vc_column][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_62467234400608" layer_title="'. esc_html( __( 'Top line', 'ueldo' ) ) .'" layer_z_index="12" custom_layer_sizes="custom_settings" color="#bb987a" large_width_type="px" large_width_px="1030" large_height_type="px" large_height_px="5" large_margin_top="30" large_margin_left="50" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="820" medium_height_type="px" medium_height_px="5" medium_margin_top="30" medium_margin_left="50" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="595" small_height_type="px" small_height_px="5" small_margin_top="30" small_margin_left="50" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_height_type="px" extra_small_height_px="5" extra_small_margin_top="30" extra_small_margin_left="50"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_90499203618739" layer_title="'. esc_html( __( 'Right line', 'ueldo' ) ) .'" layer_z_index="12" custom_layer_sizes="custom_settings" color="#bb987a" large_width_type="px" large_width_px="5" large_height_type="px" large_height_px="570" large_layer_position="top_right" large_margin_top="30" large_margin_right="45" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="5" small_height_type="calc" small_height_calc_px="90" small_layer_position="top_right" small_margin_top="30" small_margin_right="45"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_96949472038553" layer_title="'. esc_html( __( 'Bottom line', 'ueldo' ) ) .'" layer_z_index="12" custom_layer_sizes="custom_settings" color="#bb987a" large_width_type="px" large_width_px="1030" large_height_type="px" large_height_px="5" large_layer_position="bottom_left" large_margin_bottom="60" large_margin_left="50" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="820" medium_height_type="px" medium_height_px="5" medium_layer_position="bottom_left" medium_margin_bottom="60" medium_margin_left="50" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="595" small_height_type="px" small_height_px="5" small_layer_position="bottom_left" small_margin_bottom="60" small_margin_left="50" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_height_type="px" extra_small_height_px="5" extra_small_layer_position="bottom_left" extra_small_margin_bottom="60" extra_small_margin_left="50"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_57613148971086" layer_title="'. esc_html( __( 'Left line', 'ueldo' ) ) .'" layer_z_index="12" custom_layer_sizes="custom_settings" color="#bb987a" large_width_type="px" large_width_px="5" large_height_type="px" large_height_px="570" large_margin_top="30" large_margin_left="45" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="5" small_height_type="calc" small_height_calc_px="90" small_margin_top="30" small_margin_left="45"][ueldo_shortcode_loop class_name="ueldo_vc_element_15045987452431" rows="2" masonry_enabled="yes" custom_colors_enabled="custom_settings" loop_background_color="rgba(255,255,255,0)"][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_60321551027153"][ueldo_shortcode_image class_name="ueldo_vc_element_13429774029559" additional="gallery_image" gallery_slug="gallery" border_radius="0" margin_bottom="0"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_10191055073650"][ueldo_shortcode_image class_name="ueldo_vc_element_93756720397969" additional="gallery_image" gallery_slug="gallery" border_radius="0" margin_bottom="0"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_87897752779712"][ueldo_shortcode_image class_name="ueldo_vc_element_33922641170665" additional="gallery_image" gallery_slug="gallery" border_radius="0" margin_bottom="0"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_95714500497563"][ueldo_shortcode_image class_name="ueldo_vc_element_15672642989854" additional="gallery_image" gallery_slug="gallery" border_radius="0" margin_bottom="0"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_95601860017291" width="double"][ueldo_shortcode_image class_name="ueldo_vc_element_80865484171452" additional="gallery_image" gallery_slug="gallery" border_radius="0" margin_bottom="0"][/ueldo_shortcode_loop_cell][/ueldo_shortcode_loop][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15120635177236" large_height="30"][/vc_column][/vc_row][/vc_section][vc_section][vc_row content_placement="middle"][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_28149342882550" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_88966577550532" heading_text="'. esc_html( __( 'Opening hours', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings" custom_font_color_enabled="custom_settings" font_color="#bb987a" font_color_hover="#bb987a"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Pellentesque ut tellus sagittis, ultricies sem a, sodales mauris. Aliquam vitae ultricies metus. Aenean fermentum diam augue, venenatis fermentum ex consectetur nec. Donec sed ullamcorper nunc. Nullam gravida convallis erat, sit amet aliquam lorem pretium sed.</p>[/vc_column_text][/vc_column][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible" content_placement="middle"][vc_column offset="vc_col-lg-3 vc_col-md-2 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_44198927537978"][ueldo_shortcode_opening_hours_box class_name="ueldo_vc_element_35221941408855" {ueldopredefinedsections:openinghours|context:barber-shop} custom_sizes_enabled="custom_settings" border_radius="0"][ueldo_shortcode_opening_hours_box_element class_name="ueldo_vc_element_86011550047304"][ueldo_shortcode_opening_hours_box_element class_name="ueldo_vc_element_20495035608515" opening_hours_element_title="'. esc_html( __( 'Saturday', 'ueldo' ) ) .'" opening_hours_element_value="'. esc_html( __( '11:00am - 6:00pm', 'ueldo' ) ) .'"][ueldo_shortcode_opening_hours_box_element class_name="ueldo_vc_element_72393456762842" opening_hours_element_title="'. esc_html( __( 'Sunday', 'ueldo' ) ) .'" opening_hours_element_value="'. esc_html( __( 'Closed', 'ueldo' ) ) .'"][/ueldo_shortcode_opening_hours_box][/vc_column][vc_column offset="vc_col-lg-3 vc_col-md-2 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15046053058514"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15121254111096" layer_for_row_or_section="section" layer_z_index="0" color="#f2ede2"][ueldo_shortcode_gap class_name="ueldo_vc_element_12369930372863"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15046066735551" layer_z_index="15" custom_layer_sizes="custom_settings" color="rgba(255,255,255,0.01)" color_add_border="yes" color_border_width="5" color_border_color="#bb987a" large_width_type="px" large_width_px="535" large_height_type="px" large_height_px="450" large_margin_top="30" large_margin_left="45" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="430" medium_height_type="px" medium_height_px="450" medium_margin_top="30" medium_margin_left="45" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="318" small_height_type="px" small_height_px="450" small_margin_top="40" small_margin_left="45" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="90" extra_small_height_type="px" extra_small_height_px="450" extra_small_margin_top="30" extra_small_margin_left="45"][ueldo_shortcode_image class_name="ueldo_vc_element_15046066236416" border_radius="0" large_height_px="450"][/vc_column][vc_column width="1/2"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15046067940457"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15046067969259" large_width_type="px" large_width_px="60" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_1504606804503" large_width_type="calc" large_width_calc_px="60" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15047091133756" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_icon class_name="ueldo_vc_element_15046072856681" {ueldopredefinedsections:icon|key:flaticon-razor,flaticon-cut|url:https://www.flaticon.com/free-icon/razor_534279|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="55" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#bb987a"][ueldo_shortcode_heading class_name="ueldo_vc_element_15046067277694" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_67020599539110" heading_text="'. esc_html( __( 'Get the discount!', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Etiam scelerisque, risus vel vehicula imperdiet, libero velit viverra nisi, quis molestie nunc sem nec orci. Donec nec eleifend massa, quis malesuada lectus. Sed eu sollicitudin dui, vel tincidunt purus.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15046076344812" large_height="25"][ueldo_shortcode_button class_name="ueldo_vc_element_15046076411682" button_text="'. esc_html( __( 'Schedule a Visit', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'%23contact|title:'. rawurlencode( esc_html( __( 'Schedule a Visit', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_72719118386623" large_height="90"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15121261213628" layer_for_row_or_section="section" layer_z_index="0" color="#f2ede2"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_heading class_name="ueldo_vc_element_15046015890321" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15046015955601" heading_text="'. esc_html( __( 'References', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Pellentesque ut tellus sagittis, ultricies sem a, sodales mauris. Aliquam vitae ultricies metus. Aenean fermentum diam augue, venenatis fermentum ex consectetur nec. Donec sed ullamcorper nunc.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_96655152641876" large_height="25" extra_small_custom_sizes="yes" extra_small_height="10"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15046069315955"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15046069347136" large_width_type="px" large_width_px="78"][vc_column_text][ueldo_next_prev_loop_icons loop_id="150460593966"][/vc_column_text][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_33015542820223" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/2"][ueldo_shortcode_loop class_name="ueldo_vc_element_150460593966" columns="1" use_separate_next_prev_arrows="separated" custom_colors_enabled="custom_settings" loop_background_color="#f2ede2" next_prev_arrow_color="#2f3a3e" next_prev_arrow_container_background="#ece5d9" next_prev_arrow_container_background_hover="#ded3c3"][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_88400427390116"][ueldo_shortcode_quote class_name="ueldo_vc_element_65016065563603" author_subtitle="'. esc_html( __( 'Regular Customer', 'ueldo' ) ) .'" custom_sizes_enabled="custom_settings" quote_box_border_radius="0" custom_colors_enabled="custom_settings" quote_box_background_color="#ece5d9" quote_box_background_color_hover="#ece5d9" quote_box_border_color="#ece5d9" quote_box_border_color_hover="#ece5d9" quote_box_box_shadow_color="rgba(255,255,255,0.01)" quote_box_box_shadow_color_hover="rgba(255,255,255,0.01)" quote_author_image_box_shadow_color="rgba(255,255,255,0.01)"]Curabitur interdum ornare eros vitae lacinia. Curabitur a tempor lacus. Morbi eu lacus mi. Praesent efficitur rhoncus diam, vel sollicitudin lectus suscipit sed. Donec lobortis magna ac enim ornare tincidunt.[/ueldo_shortcode_quote][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_21077040479194"][ueldo_shortcode_quote class_name="ueldo_vc_element_14465327320425" author_subtitle="'. esc_html( __( 'Regular Customer', 'ueldo' ) ) .'" custom_sizes_enabled="custom_settings" quote_box_border_radius="0" custom_colors_enabled="custom_settings" quote_box_background_color="#ece5d9" quote_box_background_color_hover="#ece5d9" quote_box_border_color="#ece5d9" quote_box_border_color_hover="#ece5d9" quote_box_box_shadow_color="rgba(255,255,255,0.01)" quote_box_box_shadow_color_hover="rgba(255,255,255,0.01)" quote_author_image_box_shadow_color="rgba(255,255,255,0.01)"]Curabitur interdum ornare eros vitae lacinia. Curabitur a tempor lacus. Morbi eu lacus mi. Praesent efficitur rhoncus diam, vel sollicitudin lectus suscipit sed. Donec lobortis magna ac enim ornare tincidunt.[/ueldo_shortcode_quote][/ueldo_shortcode_loop_cell][/ueldo_shortcode_loop][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_73136718235804" large_height="90" extra_small_custom_sizes="yes" extra_small_height="60"][/vc_column][/vc_row][/vc_section]',

                '404-page' => '[vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15046895629583" small_custom_sizes="yes"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15046895686002" heading_tag="h1" text_align="center" heading_subtitle_text="'. esc_html( __( '404 page', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15046895958469" heading_text="'. esc_html( __( 'Nothing found here...', 'ueldo' ) ) .'" font_family="buttons-font"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Donec dictum ultrices risus, et iaculis orci laoreet at. Cras vulputate ligula a ante auctor, id eleifend metus facilisis. Proin volutpat nisl nec sollicitudin tempus. Quisque interdum ornare lectus, eu placerat metus mattis in. Aenean nec ullamcorper elit, eget suscipit est.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15046898234175" large_height="25"][ueldo_shortcode_button class_name="ueldo_vc_element_15046897903968" button_text="'. esc_html( __( 'Go back to home page', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'|title:'. rawurlencode( esc_html( __( 'Home page', 'ueldo' ) ) ) .'||" button_alignment="center" custom_colors_enabled="custom_settings" standard_button_background_color="#bb987a" standard_button_border_color="#bb987a" standard_button_box_shadow_color="rgba(187,152,122,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff"][/ueldo_shortcode_button][/vc_column][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15046895380084" small_custom_sizes="yes" small_height="0"][/vc_column][/vc_row][/vc_section]',

                'header' => '[vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible"][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_286015022059735" large_height="0" small_custom_sizes="yes" small_height="13"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_2915046853561368"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_2915046856220261" large_width_percentage="22%" small_custom_sizes="yes" small_width_percentage="35%"][ueldo_shortcode_website_logo class_name="ueldo_vc_element_291504686557877" large_width_type="px" large_width_px="168" {ueldopredefinedsections:image|context:barber-shop-logo}][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_2915046853589974" large_width_percentage="56%" large_content_alignment="center" small_custom_sizes="yes" small_width_percentage="0%"][ueldo_shortcode_header_menu class_name="ueldo_vc_element_2915046853644553" menu_links_alignment="center" custom_sizes_enabled="custom_settings" menu_element_padding_left_right_for_01_03="12" custom_colors_enabled="custom_settings" menu_element_background_color="rgba(255,255,255,0.01)" menu_element_color="#ffffff" active_menu_element_color="#bb987a" active_menu_element_with_child_elements_color="#ffffff" active_menu_element_bottom_line_color="#ffffff" submenu_background_color="#ffffff" box_shadow_vertical_length="0" box_shadow_blur_radius="0" box_shadow_color="rgba(255,255,255,0.01)" submenu_element_bottom_border_color="rgba(0,0,0,0.05)" submenu_element_link_color="rgba(255,255,255,0.6)" submenu_element_link_color_hover="#ffffff"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_291504685754783" large_width_percentage="22%" large_content_alignment="right" small_custom_sizes="yes" small_width_percentage="65%" small_content_alignment="right"][ueldo_shortcode_button class_name="ueldo_vc_element_2771281454721164" button_visible_on_devices="large,medium,small" button_text="1-800-123-4567" standard_button_text_font_family="general-font" button_text_alignment="center" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" button_alignment="inline" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-phone"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_2119067228031669" button_visible_on_devices="extra-small" button_text="" standard_button_text_font_family="general-font" button_text_alignment="center" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" button_alignment="inline" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-phone"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_2885158859836786" button_visible_on_devices="small,extra-small" button_text="" action_after_click="show_hide_side_menu" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-bars" custom_sizes_enabled="custom_settings" additional_margin_before="30" standard_button_padding_top="0" standard_button_padding_right="0" standard_button_padding_bottom="0" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_border_radius="0" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="rgba(255,255,255,0)" standard_button_background_color_hover="rgba(255,255,255,0)" standard_button_border_color="rgba(255,255,255,0)" standard_button_border_color_hover="rgba(255,255,255,0)" standard_button_box_shadow_vertical_length="0" standard_button_box_shadow_blur_radius="0" standard_button_box_shadow_color="rgba(47,58,62,0.01)" standard_button_box_shadow_vertical_length_hover="0" standard_button_box_shadow_blur_radius_hover="0" standard_button_box_shadow_color_hover="rgba(255,255,255,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#ffffff" standard_button_icon_color_hover="#ffffff"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_226469772723558" large_height="0" small_custom_sizes="yes" small_height="13"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_delimiter class_name="ueldo_vc_element_215046850627789" large_height="1" margin_bottom="0" custom_colors_enabled="custom_settings" background_color="rgba(231,163,122,0.2)"][/vc_column][/vc_row][/vc_section]',

                'flying-header' => '[vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible"][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_915046874776116" layer_for_row_or_section="section" color_add_box_shadow="yes-outset" color_outset_box_shadow_vertical_length="10" color_outset_box_shadow_blur_radius="35" color_outset_box_shadow_color="rgba(47,58,62,0.25)"][ueldo_shortcode_gap class_name="ueldo_vc_element_86015022059735" large_height="0" small_custom_sizes="yes" small_height="13"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_915046853561368"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_915046856220261" large_width_percentage="22%" small_custom_sizes="yes" small_width_percentage="35%"][ueldo_shortcode_website_logo class_name="ueldo_vc_element_91504686557877" large_width_type="px" large_width_px="168" {ueldopredefinedsections:image|context:barber-shop-logo}][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_915046853589974" large_width_percentage="56%" large_content_alignment="center" small_custom_sizes="yes" small_width_percentage="0%"][ueldo_shortcode_header_menu class_name="ueldo_vc_element_915046853644553" menu_links_alignment="center" custom_sizes_enabled="custom_settings" menu_element_padding_left_right_for_01_03="12" custom_colors_enabled="custom_settings" menu_element_color="#ffffff" active_menu_element_color="#bb987a" active_menu_element_with_child_elements_color="#ffffff" active_menu_element_bottom_line_color="#ffffff" submenu_background_color="#ffffff" box_shadow_vertical_length="0" box_shadow_blur_radius="0" box_shadow_color="rgba(255,255,255,0.01)" submenu_element_bottom_border_color="rgba(0,0,0,0.05)" submenu_element_link_color="rgba(255,255,255,0.6)" submenu_element_link_color_hover="#ffffff"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_91504685754783" large_width_percentage="22%" large_content_alignment="right" small_custom_sizes="yes" small_width_percentage="65%" small_content_alignment="right"][ueldo_shortcode_button class_name="ueldo_vc_element_771281454721164" button_visible_on_devices="large,medium,small" button_text="1-800-123-4567" standard_button_text_font_family="general-font" button_text_alignment="center" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" button_alignment="inline" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-phone" custom_colors_enabled="custom_settings" standard_button_background_color="#384144" standard_button_background_color_hover="#bb987a" standard_button_border_color="#384144" standard_button_border_color_hover="#bb987a" standard_button_box_shadow_color="rgba(56,65,68,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_119067228031669" button_visible_on_devices="extra-small" button_text="" standard_button_text_font_family="general-font" button_text_alignment="center" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" button_alignment="inline" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-phone" custom_colors_enabled="custom_settings" standard_button_background_color="#384144" standard_button_background_color_hover="#bb987a" standard_button_border_color="#384144" standard_button_border_color_hover="#bb987a" standard_button_box_shadow_color="rgba(56,65,68,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_885158859836786" button_visible_on_devices="small,extra-small" button_text="" standard_button_text_font_family="general-font" button_text_alignment="center" action_after_click="show_hide_side_menu" button_alignment="inline" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-bars" custom_sizes_enabled="custom_settings" additional_margin_before="30" standard_button_padding_top="0" standard_button_padding_right="0" standard_button_padding_bottom="0" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_border_radius="0" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color_hover="#2f3a3e" standard_button_border_color_hover="#2f3a3e" standard_button_box_shadow_vertical_length="0" standard_button_box_shadow_blur_radius="0" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="0" standard_button_box_shadow_blur_radius_hover="0" standard_button_box_shadow_color_hover="rgba(255,255,255,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="#ffffff"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_26469772723558" large_height="0" small_custom_sizes="yes" small_height="13"][/vc_column][/vc_row][/vc_section]',

                'footer' => '[vc_section el_id="contact"][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15046169037323"][/vc_column][/vc_row][vc_row][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][vc_column_text]<strong>'. esc_html( __( 'Location:', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( '5000 Example Street, Los Angeles, CA', 'ueldo' ) ) .'<br /><br /> <strong>'. esc_html( __( 'E-mail:', 'ueldo' ) ) .'</strong><br /> <a href="'. esc_url( __( 'mailto:contact@example.com', 'ueldo' ) ) .'">'. esc_html( __( 'contact@example.com', 'ueldo' ) ) .'</a>[/vc_column_text][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15047025501032" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][vc_column_text]<strong>'. esc_html( __( 'Payment methods:', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Cash, Credit Cards, PayPal', 'ueldo' ) ) .'<br /><br /> <strong>'. esc_html( __( 'Follow us on Social Media:', 'ueldo' ) ) .'</strong><br /> <a href="#">'. esc_html( __( 'Facebook', 'ueldo' ) ) .'</a>, <a href="#">'. esc_html( __( 'Twitter', 'ueldo' ) ) .'</a>, <a href="#">'. esc_html( __( 'Google+', 'ueldo' ) ) .'</a>[/vc_column_text][/vc_column][vc_column offset="vc_col-lg-4 vc_col-md-4 vc_hidden-sm vc_col-xs-12 vc_hidden-xs"][ueldo_shortcode_button class_name="ueldo_vc_element_83899336662000" button_type="two-line-button" button_text="'. esc_html( __( 'Call us today!', 'ueldo' ) ) .'" second_line_text_font_family="general-font" button_alignment="right" show_button_icon="yes" button_icon_position="before" {ueldopredefinedsections:icon|key:flaticon-scissors,flaticon-cut|url:https://www.flaticon.com/free-icon/scissors_534270|slug:button_icon_} custom_sizes_enabled="custom_settings" two_line_button_title_font_size="26" two_line_button_subtitle_font_size="15" two_line_button_icon_size="45" two_line_button_margin_between_icon_and_button_texts="15" two_line_button_border_radius="0" custom_colors_enabled="custom_settings" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_icon_color="#bb987a" two_line_button_icon_color_hover="#bb987a"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_66206485963564" large_height="20"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_20292239733816"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_46685264727965" large_width_percentage="100%" large_content_alignment="right"][ueldo_shortcode_social_media_feed class_name="ueldo_vc_element_84900999663514" type="facebook_like_button" facebook_like_button_layout="button_count" facebook_like_button_share="yes"][/ueldo_shortcode_social_media_feed][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column offset="vc_col-lg-12 vc_hidden-lg vc_col-md-12 vc_hidden-md vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_36158010559590" large_height="0" small_custom_sizes="yes"][ueldo_shortcode_button class_name="ueldo_vc_element_75338255701382" button_type="two-line-button" button_text="'. esc_html( __( 'Call us today!', 'ueldo' ) ) .'" second_line_text_font_family="general-font" show_button_icon="yes" button_icon_position="before" {ueldopredefinedsections:icon|key:flaticon-scissors,flaticon-cut|url:https://www.flaticon.com/free-icon/scissors_534270|slug:button_icon_} custom_sizes_enabled="custom_settings" two_line_button_title_font_size="26" two_line_button_subtitle_font_size="15" two_line_button_icon_size="45" two_line_button_margin_between_icon_and_button_texts="15" two_line_button_border_radius="0" custom_colors_enabled="custom_settings" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_icon_color="#bb987a" two_line_button_icon_color_hover="#bb987a"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_54710826288759" large_height="20"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_19312588541046"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_69830928049152" large_width_percentage="100%"][ueldo_shortcode_social_media_feed class_name="ueldo_vc_element_76763637779524" type="facebook_like_button" facebook_like_button_layout="button_count" facebook_like_button_share="yes"][/ueldo_shortcode_social_media_feed][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_72169001727807"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_93093397562985" layer_title="'. esc_html( __( 'Top line', 'ueldo' ) ) .'" layer_z_index="15" custom_layer_sizes="custom_settings" color="#bb987a" large_width_type="px" large_width_px="1070" large_height_type="px" large_height_px="5" large_margin_top="30" large_margin_left="45" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="860" medium_height_type="px" medium_height_px="5" medium_margin_top="30" medium_margin_left="45" small_layer_custom_sizes="yes" small_width_type="calc" small_width_calc_px="90" small_height_type="px" small_height_px="5" small_margin_top="30" small_margin_left="45"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_16748499476703" layer_title="'. esc_html( __( 'Right line', 'ueldo' ) ) .'" layer_z_index="15" custom_layer_sizes="custom_settings" color="#bb987a" large_width_type="px" large_width_px="5" large_height_type="px" large_height_px="653" large_layer_position="top_right" large_margin_top="35" large_margin_right="15" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="5" medium_height_type="px" medium_height_px="700" medium_layer_position="top_right" medium_margin_top="35" medium_margin_right="15" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="5" small_height_type="calc" small_height_calc_px="40" small_layer_position="top_right" small_margin_top="35" small_margin_right="45"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_31736838478011" layer_title="'. esc_html( __( 'Bottom line', 'ueldo' ) ) .'" layer_z_index="15" custom_layer_sizes="custom_settings" color="#bb987a" large_width_type="px" large_width_px="1070" large_height_type="px" large_height_px="5" large_layer_position="bottom_left" large_margin_bottom="30" large_margin_left="45" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="860" medium_height_type="px" medium_height_px="5" medium_layer_position="bottom_left" medium_margin_bottom="30" medium_margin_left="45" small_layer_custom_sizes="yes" small_width_type="calc" small_width_calc_px="90" small_height_type="px" small_height_px="5" small_layer_position="bottom_left" small_margin_left="45"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_12209858931131" layer_title="'. esc_html( __( 'Left line', 'ueldo' ) ) .'" layer_z_index="15" custom_layer_sizes="custom_settings" color="#bb987a" large_width_type="px" large_width_px="5" large_height_type="px" large_height_px="653" large_margin_top="35" large_margin_left="45" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="5" medium_height_type="px" medium_height_px="700" medium_margin_top="35" medium_margin_left="45" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="5" small_height_type="calc" small_height_calc_px="40" small_margin_top="35" small_margin_left="45"][ueldo_shortcode_google_map class_name="ueldo_vc_element_46803738815077" border_radius="0" large_height_px="723" medium_custom_sizes="yes" medium_height_px="770" small_custom_sizes="yes" small_height_px="450" margin_bottom="0" {ueldopredefinedsections:googlemap|context:barber-shop}][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_85550035014208" large_height="0" small_custom_sizes="yes" small_height="45"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15046217732463"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15046217763917" large_width_type="px" large_width_px="30" small_custom_sizes="yes" small_width_type="px" small_width_px="75"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15046217837928" large_width_type="calc" large_width_calc_px="75" small_custom_sizes="yes" small_width_type="calc" small_width_calc_px="150"][ueldo_shortcode_heading class_name="ueldo_vc_element_89376419981743" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="20"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_88940739712462" heading_text="'. esc_html( __( 'Contact us!', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings"][/ueldo_shortcode_heading][contact-form-7 {ueldopredefinedsections:contactform7|context:barber-shop|inside:false}][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_50360571863777" large_height="0" small_custom_sizes="yes" small_height="45"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_21608234590548" large_height="45"][vc_column_text]2017 - '. date( 'Y' ) .' &copy; <a href="'. esc_url( ueldo_get_external_url( 'ueldo-com' ) ) .'" target="_blank">'. esc_html( __( 'Ueldo WordPress theme', 'ueldo' ) ) .'</a> '. esc_html( __( 'by', 'ueldo' ) ) .' <a href="'. esc_url( ueldo_get_external_url( 'martanian-com' ) ) .'" target="_blank">Martanian</a>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_64878811301878" large_height="25"][/vc_column][/vc_row][/vc_section]',

                'additional-before-side-menu' => '[vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_website_logo class_name="ueldo_vc_element_81504686557877" horizontal_alignment="center" large_height_type="px" large_height_px="38" margin_top="20" margin_bottom="30" {ueldopredefinedsections:image|context:barber-shop-logo}][ueldo_shortcode_button class_name="ueldo_vc_element_15047128971637" button_text="'. esc_html( __( 'Close menu', 'ueldo' ) ) .'" action_after_click="show_hide_side_menu" button_alignment="center" show_button_icon="yes" button_icon_fontawesome="fa fa-times" custom_colors_enabled="custom_settings" standard_button_background_color="#614f42" standard_button_border_color="#614f42" standard_button_box_shadow_color="rgba(97,79,66,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][/vc_column][/vc_row]',

                'additional-after-side-menu' => ''
            );

            # return result
            return( $page_slug == false ? $contents : ( isset( $contents[esc_attr( $page_slug )] ) ? $contents[esc_attr( $page_slug )] : false ) );
        }

       /**
        *
        * end of class methods.
        *
        */
    }

   /**
    *
    * end of file.
    *
    */

?>