<?php

   /**
    *
    * installation class for "cafe" demo template
    *
    */

    class ueldo_demo_contents_loader_base extends ueldo_demo_contents_loader_installation_helper {

       /**
        *
        * install template or its parts
        *
        */

        public static function install( $parts, $icons ) {

           /**
            *
            * install revolution slider
            *
            */

            if( $parts == 'all' || in_array( 'revolution-slider-sliders', $parts, true ) ) {

                # upload revolution slider and get its id
                if( ( $slider_id = ueldo_add_demo_assets::upload_revslider( 'cafe' ) ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:revslider|context:cafe}', 'alias="'. esc_attr( $slider_id ) .'"' );

                    # remove temporary variables
                    unset( $slider_id );
                }
            }

           /**
            *
            * install forms
            *
            */

            if( $parts == 'all' || in_array( 'forms', $parts, true ) ) {

                # add form in contact form 7 plugin and get its id
                if( ( $form_id = ueldo_add_demo_assets::add_contact_form() ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:contactform7|context:cafe|inside:false}', 'id="'. esc_attr( $form_id ) .'"' );

                    # remove temporary variables
                    unset( $form_id );
                }
            }

           /**
            *
            * add pages, but not fill it with contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # add pages and get its ids
                $pages_ids = ueldo_add_demo_assets::add_empty_pages( 'page', array(
                    '404-page' => esc_html( __( '404 page', 'ueldo' ) ),
                    'home' => esc_html( __( 'Home', 'ueldo' ) )
                ));

                # add headers, footers and extras
                $hefos_ids = ueldo_add_demo_assets::add_empty_pages( 'ueldohefo', array(
                    'footer' => esc_html( __( 'Footer', 'ueldo' ) ),
                    'header' => esc_html( __( 'Header', 'ueldo' ) )
                ));

                # add solution
                self::add_solution( 'pages-ids', array_merge( $pages_ids, $hefos_ids ) );

                # show page on front
                update_option( 'show_on_front', 'page' );

                # update home page ID
                if( $pages_ids['home'] != null && $pages_ids['home'] != false ) update_option( 'page_on_front', $pages_ids['home'] );

                # remove temporary variables
                unset( $pages_ids );
            }

           /**
            *
            * install menus
            *
            */

            if( $parts == 'all' || in_array( 'menus', $parts, true ) ) {

                # add new menu
                if( is_int( $menu_id = ueldo_add_demo_assets::add_menu( 'cafe-main-menu', self::get_solution( 'pages-ids' ), true ) ) ) {

                    # add solution
                    self::add_solution( 'main-menu-id', esc_attr( $menu_id ) );
                }
            }

           /**
            *
            * get dynamic elements replacements
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) || in_array( 'pages', $parts, true ) ) {

                # get dynamic elements replacements
                $replacements = self::get_dynamic_elements_replacements( self::find_dynamic_elements( self::get_vc_contents() ), $icons, self::get_default_replacements() );
            }

           /**
            *
            * install theme options
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) ) {

                # update theme options
                update_option( 'ueldo_theme_options', self::get_theme_options_array() );

                # set additional content before side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_before_all', self::do_content_replacements( self::get_vc_contents( 'additional-before-side-menu' ), $replacements ) );

                # set additional content after side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_after_all', self::do_content_replacements( self::get_vc_contents( 'additional-after-side-menu' ), $replacements ) );

                # clear theme mods - background color and image
                remove_theme_mod( 'background_color' );
                remove_theme_mod( 'background_position_x' );
                remove_theme_mod( 'background_position_y' );
                remove_theme_mod( 'background_repeat' );
                remove_theme_mod( 'background_attachment' );
                remove_theme_mod( 'background_size' );
                remove_theme_mod( 'background_image' );
            }

           /**
            *
            * fill pages contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # walk for each pages
                foreach( self::get_solution( 'pages-ids' ) as $page_slug => $page_id ) {

                    # update page content
                    $result = wp_update_post( array(
                        'ID' => esc_attr( $page_id ),
                        'post_content' => self::do_content_replacements( self::get_vc_contents( esc_attr( $page_slug ) ), $replacements )
                    ));
                }

                # remove temporary variables
                unset( $replacements );
            }

           /**
            *
            * update permalinks structure
            *
            */

            if( $parts == 'all' || in_array( 'permalinks-structure', $parts, true ) ) {

                # global variable
                global $wp_rewrite;

                # write the rule
                $wp_rewrite -> set_permalink_structure( '/%postname%/' );

                # set the option
                update_option( 'rewrite_rules', false );

                # flush the rules and tell it to write htaccess
                $wp_rewrite -> flush_rules( true );
            }

           /**
            *
            * demo data installed
            *
            */

            exit( '{ "status": "ok" }' );
        }

       /**
        *
        * get possible data parts
        *
        */

        public static function get_possible_data_parts() {

            # return result
            return( array(
                'menus' => esc_html( __( 'Menus', 'ueldo' ) ),
                'pages' => esc_html( __( 'Pages', 'ueldo' ) ),
                'theme-options' => esc_html( __( 'Theme options', 'ueldo' ) ),
                'forms' => esc_html( __( 'Forms', 'ueldo' ) ),
                'revolution-slider-sliders' => esc_html( __( 'Revolution Slider sliders', 'ueldo' ) ),
                'permalinks-structure' => esc_html( __( 'Permalinks structure', 'ueldo' ) )
            ));
        }

       /**
        *
        * get list of required plugins
        *
        */

        public static function get_required_plugins( $parts ) {

            # all data
            if( !is_array( $parts ) && $parts == 'all' ) {

                # return list of required plugins
                return( array(
                    'ueldo',
                    'visual-composer',
                    'revolution-slider',
                    'contact-form-7'
                ));
            }

            # selected parts
            else {

                # prepare array of required plugins
                $result = array( 'ueldo' );

                # do we have to add pages?
                if( in_array( 'pages', $parts, true ) ) {

                    # return list of required plugins
                    return( array(
                        'visual-composer',
                        'revolution-slider',
                        'contact-form-7'
                    ));
                }

                # do we have to add theme options?
                if( in_array( 'theme-options', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'visual-composer' ) );
                }

                # do we have to add forms?
                if( in_array( 'forms', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'contact-form-7' ) );
                }

                # do we have to add revolution slider sliders?
                if( in_array( 'revolution-slider-sliders', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'revolution-slider' ) );
                }

                # return result
                return( $result );
            }
        }

       /**
        *
        * get default replacements
        *
        */

        public static function get_default_replacements() {

            # add logo image
            $logo_image_id = ueldo_add_demo_assets::add_image( 'cafe-logo' );

            # return result
            return( array(
                '{ueldopredefinedsections:googlemap|context:cafe}' => 'google_map_id="1"',
                '{ueldopredefinedsections:openinghours|context:cafe}' => 'status="1"',
                '{ueldopredefinedsections:image|context:cafe-logo}' => ( $logo_image_id == false ? '' : 'image="'. esc_attr( $logo_image_id ) .'"' )
            ));
        }

       /**
        *
        * get trusted solution
        *
        */

        public static function get_trusted_solution( $type, $solution ) {

            # do we have solution found?
            if( !empty( $solution ) ) return( $solution );

            # switch by solution type
            switch( $type ) {

                # get most similar elements
                case 'main-menu-slug': return( self::get_most_similar_element( 'menu_slug', esc_html( __( 'Main menu - Caf&eacute; template', 'ueldo' ) ) ) );
                case '404-page-id': return( self::get_most_similar_element( 'page', esc_html( __( '404 page', 'ueldo' ) ) ) );
                case 'footer-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Footer', 'ueldo' ) ) ) );
                case 'header-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Header', 'ueldo' ) ) ) );
            }

            # nothing found
            return( false );
        }

       /**
        *
        * get theme options array
        *
        */

        public static function get_theme_options_array() {

            # return result
            return( array(
                '404-page-id' => array( 'all' => self::get_trusted_solution( '404-page-id', self::get_solution( 'pages-ids', '404-page' ) ) ),
                'blog-posts-list-style' => array(
                    'posts-list-style' => 'default',
                    'display-post-data-under-title' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'yes'
                ),
                'blog-sidebar' => array(
                    'posts-list' => 'yes-right',
                    'single-post' => 'yes-right',
                    'responsive-style' => 'static'
                ),
                'boxed-website' => array(
                    'enabled' => 'no',
                    'large-content-width' => '1100',
                    'large-content-space' => '50',
                    'medium-content-width' => '890',
                    'medium-content-space' => '50',
                    'small-content-width' => '665',
                    'small-content-space' => '50'
                ),
                'comment-textarea-at-top' => 'yes',
                'dynamic-theme-styles-cache' => array(
                    'enabled' => 'no',
                    'clear-cache' => 'all-the-time-when-logged-in'
                ),
                'facebook-fanpage-url' => array( 'all' => 'https://www.facebook.com/envato' ),
                'featured-image-on-lists-only' => 'no',
                'fonts' => array(
                    'general-font-family' => array( 'all' => 'Roboto' ),
                    'general-font-weight' => array( 'all' => '300' ),
                    'general-font-subset' => array( 'all' => 'latin' ),
                    'general-font-smoothing' => array( 'all' => 'yes' ),
                    'general-bold-font-family' => array( 'all' => 'Roboto' ),
                    'general-bold-font-weight' => array( 'all' => '600' ),
                    'general-bold-font-subset' => array( 'all' => 'latin' ),
                    'general-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-font-family' => array( 'all' => 'Asap Condensed' ),
                    'menu-font-weight' => array( 'all' => '500' ),
                    'menu-font-subset' => array( 'all' => 'latin' ),
                    'menu-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-font-family' => array( 'all' => 'Asap Condensed' ),
                    'headings-font-weight' => array( 'all' => '500' ),
                    'headings-font-subset' => array( 'all' => 'latin' ),
                    'headings-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-slim-font-family' => array( 'all' => 'Asap Condensed' ),
                    'headings-slim-font-weight' => array( 'all' => 'regular' ),
                    'headings-slim-font-subset' => array( 'all' => 'latin' ),
                    'headings-slim-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-bold-font-family' => array( 'all' => 'Asap Condensed' ),
                    'headings-bold-font-weight' => array( 'all' => '700' ),
                    'headings-bold-font-subset' => array( 'all' => 'latin' ),
                    'headings-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-subtitle-font-family' => array( 'all' => 'Asap Condensed' ),
                    'headings-subtitle-font-weight' => array( 'all' => '700' ),
                    'headings-subtitle-font-subset' => array( 'all' => 'latin' ),
                    'headings-subtitle-font-smoothing' => array( 'all' => 'yes' ),
                    'buttons-font-family' => array( 'all' => 'Asap Condensed' ),
                    'buttons-font-weight' => array( 'all' => '700' ),
                    'buttons-font-subset' => array( 'all' => 'latin' ),
                    'buttons-font-smoothing' => array( 'all' => 'yes' ),
                    'form-fields-font-family' => array( 'all' => 'Roboto' ),
                    'form-fields-font-weight' => array( 'all' => '400' ),
                    'form-fields-font-subset' => array( 'all' => 'latin' ),
                    'form-fields-font-smoothing' => array( 'all' => 'yes' ),
                    'blockquote-font-family' => array( 'all' => 'Asap Condensed' ),
                    'blockquote-font-weight' => array( 'all' => 'regular' ),
                    'blockquote-font-subset' => array( 'all' => 'latin' ),
                    'blockquote-font-smoothing' => array( 'all' => 'yes' ),
                    'alert-messages-font-family' => array( 'all' => 'Asap Condensed' ),
                    'alert-messages-font-weight' => array( 'all' => 'regular' ),
                    'alert-messages-font-subset' => array( 'all' => 'latin' ),
                    'alert-messages-font-smoothing' => array( 'all' => 'yes' )
                ),
                'footer-content' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'footer-page-id', self::get_solution( 'pages-ids', 'footer' ) ) ),
                    'position' => array( 'all' => 'static' )
                ),
                'google-maps' => array(
                    'api-key' => '',
                    'next-map-id' => '2',
                    'google-map-1-title' => esc_html( __( 'Locations', 'ueldo' ) ),
                    'google-map-1-center-lat' => '40.713658',
                    'google-map-1-center-lng' => '-74.005767',
                    'google-map-1-zoom' => '16',
                    'google-map-1-markers-next-marker-id' => '4',
                    'google-map-1-markers-marker-1-title' => esc_html( __( 'Location 1', 'ueldo' ) ),
                    'google-map-1-markers-marker-1-lat' => '40.713658',
                    'google-map-1-markers-marker-1-lng' => '-74.005367',
                    'google-map-1-markers-marker-1-use-custom-marker' => 'yes-image',
                    'google-map-1-markers-marker-1-custom-icon-library' => 'fontawesome',
                    'google-map-1-markers-marker-1-custom-icon' => 'fa fa-address-book',
                    'google-map-1-markers-marker-1-custom-icon-size' => '18',
                    'google-map-1-markers-marker-1-custom-icon-width' => '36',
                    'google-map-1-markers-marker-1-custom-icon-height' => '36',
                    'google-map-1-markers-marker-1-custom-icon-border-radius' => 'circle',
                    'google-map-1-markers-marker-1-custom-icon-border-radius-px' => '4',
                    'google-map-1-markers-marker-1-custom-icon-color' => '#f5bc4b',
                    'google-map-1-markers-marker-1-custom-icon-background-color' => '#fff',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-horizontal-length' => '0',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-vertical-length' => '5',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-blur-radius' => '20',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-spread-radius' => '0',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-color' => 'rgba( 0, 0, 0, 0.1 )',
                    'google-map-1-markers-marker-1-custom-marker-image' => esc_url( get_template_directory_uri() .'/_assets/_img/_templates-images/ueldo-cafe-map-marker.png' ),
                    'google-map-1-markers-marker-2-title' => esc_html( __( 'Location 2', 'ueldo' ) ),
                    'google-map-1-markers-marker-2-lat' => '40.712637',
                    'google-map-1-markers-marker-2-lng' => '-74.009493',
                    'google-map-1-markers-marker-2-use-custom-marker' => 'yes-image',
                    'google-map-1-markers-marker-2-custom-icon-library' => 'fontawesome',
                    'google-map-1-markers-marker-2-custom-icon' => 'fa fa-address-book',
                    'google-map-1-markers-marker-2-custom-icon-size' => '18',
                    'google-map-1-markers-marker-2-custom-icon-width' => '36',
                    'google-map-1-markers-marker-2-custom-icon-height' => '36',
                    'google-map-1-markers-marker-2-custom-icon-border-radius' => 'circle',
                    'google-map-1-markers-marker-2-custom-icon-border-radius-px' => '4',
                    'google-map-1-markers-marker-2-custom-icon-color' => '#f5bc4b',
                    'google-map-1-markers-marker-2-custom-icon-background-color' => '#fff',
                    'google-map-1-markers-marker-2-custom-icon-box-shadow-horizontal-length' => '0',
                    'google-map-1-markers-marker-2-custom-icon-box-shadow-vertical-length' => '5',
                    'google-map-1-markers-marker-2-custom-icon-box-shadow-blur-radius' => '20',
                    'google-map-1-markers-marker-2-custom-icon-box-shadow-spread-radius' => '0',
                    'google-map-1-markers-marker-2-custom-icon-box-shadow-color' => 'rgba( 0, 0, 0, 0.1 )',
                    'google-map-1-markers-marker-2-custom-marker-image' => esc_url( get_template_directory_uri() .'/_assets/_img/_templates-images/ueldo-cafe-map-marker.png' ),
                    'google-map-1-markers-marker-3-title' => esc_html( __( 'Location 3', 'ueldo' ) ),
                    'google-map-1-markers-marker-3-lat' => '40.715431',
                    'google-map-1-markers-marker-3-lng' => '-74.002710',
                    'google-map-1-markers-marker-3-use-custom-marker' => 'yes-image',
                    'google-map-1-markers-marker-3-custom-icon-library' => 'fontawesome',
                    'google-map-1-markers-marker-3-custom-icon' => 'fa fa-address-book',
                    'google-map-1-markers-marker-3-custom-icon-size' => '18',
                    'google-map-1-markers-marker-3-custom-icon-width' => '36',
                    'google-map-1-markers-marker-3-custom-icon-height' => '36',
                    'google-map-1-markers-marker-3-custom-icon-border-radius' => 'circle',
                    'google-map-1-markers-marker-3-custom-icon-border-radius-px' => '4',
                    'google-map-1-markers-marker-3-custom-icon-color' => '#f5bc4b',
                    'google-map-1-markers-marker-3-custom-icon-background-color' => '#fff',
                    'google-map-1-markers-marker-3-custom-icon-box-shadow-horizontal-length' => '0',
                    'google-map-1-markers-marker-3-custom-icon-box-shadow-vertical-length' => '5',
                    'google-map-1-markers-marker-3-custom-icon-box-shadow-blur-radius' => '20',
                    'google-map-1-markers-marker-3-custom-icon-box-shadow-spread-radius' => '0',
                    'google-map-1-markers-marker-3-custom-icon-box-shadow-color' => 'rgba( 0, 0, 0, 0.1 )',
                    'google-map-1-markers-marker-3-custom-marker-image' => esc_url( get_template_directory_uri() .'/_assets/_img/_templates-images/ueldo-cafe-map-marker.png' ),
                    'google-map-1-custom-style' => '[{"featureType":"administrative","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":20}]},{"featureType":"road","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":40}]},{"featureType":"water","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-10},{"lightness":30}]},{"featureType":"landscape.man_made","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":10}]},{"featureType":"landscape.natural","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":60}]},{"featureType":"poi","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]},{"featureType":"transit","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]}]',
                ),
                'header' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'header-page-id', self::get_solution( 'pages-ids', 'header' ) ) ),
                    'position' => array( 'all' => 'flying' ),
                    'use-second-header' => array( 'all' => 'no' ),
                    'get-second-content-from' => array( 'all' => 'default' ),
                    'second-header-visible-from' => array( 'all' => '400' ),
                    'default-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'second-header-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) )
                ),
                'lazy-load-images' => array(
                    'enabled' => 'no',
                    'threshold' => '0'
                ),
                'loader-animation' => array(
                    'enabled' => 'yes',
                    'style' => '01',
                    'add-logo' => 'no',
                    'space-between-logo-and-spinner' => '30',
                    'logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'custom-colors-enabled' => 'no',
                    'custom-colors-background' => '#fff',
                    'custom-colors-spinner' => '#f5bc4b',
                ),
                'local-scrolling-links-animation' => array(
                    'enabled' => 'yes',
                    'animation-speed' => '1000'
                ),
                'opening-hours-status' => array(
                    'next-status-id' => '2',
                    'status-1-title' => esc_html( __( 'Regular opening hours', 'ueldo' ) ),
                    'status-1-timezone' => 'use-browser',
                    'status-1-rules-next-rule-id' => '2',
                    'status-1-rules-rule-1-title' => esc_html( __( 'Everyday', 'ueldo' ) ),
                    'status-1-rules-rule-1-apply-for-monday' => 'on',
                    'status-1-rules-rule-1-apply-for-tuesday' => 'on',
                    'status-1-rules-rule-1-apply-for-wednesday' => 'on',
                    'status-1-rules-rule-1-apply-for-thursday' => 'on',
                    'status-1-rules-rule-1-apply-for-friday' => 'on',
                    'status-1-rules-rule-1-apply-for-saturday' => 'on',
                    'status-1-rules-rule-1-apply-for-sunday' => 'on',
                    'status-1-rules-rule-1-all-day-closed' => 'no',
                    'status-1-rules-rule-1-next-opening-hours-id' => '2',
                    'status-1-rules-rule-1-opening-hours-1-ignored' => 'no',
                    'status-1-rules-rule-1-opening-hours-1-from-hour' => '08',
                    'status-1-rules-rule-1-opening-hours-1-from-minutes' => '00',
                    'status-1-rules-rule-1-opening-hours-1-to-hour' => '22',
                    'status-1-rules-rule-1-opening-hours-1-to-minutes' => '00',
                    'status-1-exceptions-next-exception-id' => '1'
                ),
                'rtl' => array(
                    'is-rtl' => array( 'all' => 'no' ),
                    'load-rtl-admin-styles' => array( 'all' => 'auto' )
                ),
                'side-menu' => array(
                    'style' => 'flying-default-hidden',
                    'menu-key' => array( 'all' => self::get_trusted_solution( 'main-menu-slug', self::get_main_menu_slug() ) ),
                    'menu-link-font-family' => array( 'all' => 'Asap Condensed' ),
                    'menu-link-font-weight' => array( 'all' => '500' ),
                    'menu-link-font-subset' => array( 'all' => 'latin' ),
                    'menu-link-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-position' => 'left',
                    'menu-links-alignment' => 'center',
                    'opacity-animation-enabled' => 'yes',
                    'submenu-links' => 'visible-always',
                    'menu-vertical-alignment' => 'middle',
                    'custom-sizes-enabled' => 'yes',
                    'custom-sizes-container-width' => '300',
                    'custom-sizes-menu-link-font-size' => '18',
                    'custom-sizes-menu-link-font-line-height' => '1.0',
                    'custom-sizes-menu-link-font-letter-spacing' => '0',
                    'custom-sizes-menu-link-padding-top-bottom' => '15',
                    'custom-sizes-menu-link-padding-left-right' => '25',
                    'custom-sizes-menu-link-margin-top-bottom' => '0',
                    'custom-sizes-menu-link-margin-left-right' => '0',
                    'custom-sizes-menu-link-bottom-border-width' => '0',
                    'custom-sizes-display-bottom-border-for-last-menu-link' => 'display',
                    'custom-sizes-menu-icon-font-size' => '10',
                    'custom-sizes-menu-icon-margin-top' => '0',
                    'custom-sizes-menu-margin-between-icon-and-title' => '10',
                    'custom-sizes-padding-top-bottom-additional-element-before-menu' => '20',
                    'custom-sizes-padding-left-right-additional-element-before-menu' => '30',
                    'custom-sizes-margin-top-additional-element-before-menu' => '0',
                    'custom-sizes-margin-right-additional-element-before-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-before-menu' => '0',
                    'custom-sizes-margin-left-additional-element-before-menu' => '0',
                    'custom-sizes-padding-top-bottom-additional-element-after-menu' => '20',
                    'custom-sizes-padding-left-right-additional-element-after-menu' => '30',
                    'custom-sizes-margin-top-additional-element-after-menu' => '0',
                    'custom-sizes-margin-right-additional-element-after-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-after-menu' => '0',
                    'custom-sizes-margin-left-additional-element-after-menu' => '0'
                ),
                'single-blog-post-style' => array(
                    'display-post-data-under-title' => 'yes',
                    'blog-post-data-and-title-centered' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'yes'
                ),
                'submit-button-position-in-comment-reply-form' => array( 'all' => 'left' ),
                'translate-publication-dates' => 'yes',
                'twitter-api' => array(
                    'oauth-key' => '',
                    'oauth-secret-key' => ''
                ),
                'under-single-blog-post-content-elements' => array(
                    'elements-count' => '3',
                    'element-1-type' => 'tags-and-categories-with-facebook',
                    'element-1-similar-posts-style' => '02',
                    'element-2-type' => 'author-box',
                    'element-2-similar-posts-style' => '02',
                    'element-3-type' => 'next-previous-posts-navigation',
                    'element-3-similar-posts-style' => '02',
                    'element-4-type' => '',
                    'element-4-similar-posts-style' => '02',
                    'element-5-type' => '',
                    'element-5-similar-posts-style' => '02',
                    'element-6-type' => '',
                    'element-6-similar-posts-style' => '02'
                ),
                'vc-sections-on-blog-pages' => array(
                    'posts-list-above' => array( 'all' => 'none' ),
                    'posts-list-under' => array( 'all' => 'none' ),
                    'single-post-above' => array( 'all' => 'none' ),
                    'single-post-under' => array( 'all' => 'none' ),
                    'archive-above' => array( 'all' => 'none' ),
                    'archive-under' => array( 'all' => 'none' ),
                    'search-above' => array( 'all' => 'none' ),
                    'search-under' => array( 'all' => 'none' )
                ),
                'visual-composer-custom-fonts' => array( 'next-font-id' => '1' ),
                'styles' => array(
                    'general-colors-website-background' => '#ffffff',
                    'general-colors-image-box-shadow' => '0px 0px 0px 0px rgba(255,255,255,0)',
                    'general-colors-headings-color' => '#5a443d',
                    'general-colors-headings-subtitle-color' => '#f5bc4b',
                    'general-colors-blog-post-data-color' => '#f5bc4b',
                    'font-size-h1' => '42',
                    'font-size-h2' => '38',
                    'general-colors-main-color' => '#f5bc4b',
                    'general-colors-google-map-marker-icon-color' => '#f5bc4b',
                    'info-box-element-background-color' => '#fcfaf5',
                    'info-box-element-border-color' => '#fcfaf5',
                    'font-size-h3' => '28',
                    'buttons-global-button-background-color' => '#f5bc4b',
                    'buttons-global-button-border-color' => '#f5bc4b',
                    'buttons-global-button-background-color-hover' => '#5a443d',
                    'buttons-global-button-border-color-hover' => '#5a443d',
                    'buttons-global-button-box-shadow-hover' => '0px 10px 35px 0px rgba(90,68,61,0.25)',
                    'general-colors-elements-border-color' => '#f4f2eb',
                    'buttons-global-button-box-shadow' => '0px 10px 35px 0px rgba(245,188,75,0.25)',
                    'general-colors-elements-hover-border-color' => '#f4f2eb',
                    'forms-field-border-color' => '#f4f2eb',
                    'forms-field-inset-box-shadow' => '0px 0px 0px 0px rgba(255,255,255,0)',
                    'forms-field-border-color-on-hover' => '#e7e3e2',
                    'forms-field-background-color' => '#ffffff',
                    'forms-select-and-date-field-icon-border-color' => '#f4f2eb',
                    'forms-checkbox-radio-main-color' => '#f5bc4b',
                    'header-bar-and-menu-link-color' => '#5a443d',
                    'header-bar-and-menu-active-or-hover-link-color' => '#f5bc4b',
                    'header-bar-and-menu-submenu-background-color' => '#f5bc4b',
                    'font-size-menu-links' => '15',
                    'side-menu-box-shadow' => '-5px 0px 20px 0px rgba(72,52,47,0.15)',
                    'side-menu-background-color' => '#48342f',
                    'side-menu-link-color' => '#ffffff',
                    'side-menu-link-color-hover' => '#f7c360',
                    'side-menu-active-link-color' => '#f7c360'
                )
            ));
        }

       /**
        *
        * get default contents
        *
        */

        public static function get_vc_contents( $page_slug = false ) {

            # array of pages contents
            $contents = array(

                'home' => '[vc_section full_width="stretch_row_content" css=".vc_custom_1506580598668{margin-top: -1px !important;}"][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15064092309636"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_95749255160557" large_width_type="px" large_width_px="45" small_custom_sizes="yes" small_width_type="px" small_width_px="25" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_75596856523509" large_width_type="calc" large_width_calc_px="90" small_custom_sizes="yes" small_width_type="calc" small_width_calc_px="50" extra_small_custom_sizes="yes"][rev_slider {ueldopredefinedsections:revslider|context:cafe}][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_49445556920862" large_width_type="px" large_width_px="45" small_custom_sizes="yes" small_width_type="px" small_width_px="25" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_1506413297603" layer_title="'. esc_html( __( 'Section background', 'ueldo' ) ) .'" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" color="#fcfaf5" large_width_type="calc" large_width_calc_px="90" large_margin_left="45" small_layer_custom_sizes="yes" small_width_type="calc" small_width_calc_px="50" small_margin_left="25" extra_small_layer_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_66600899768649" large_height="75"][ueldo_shortcode_heading class_name="ueldo_vc_element_15064078169915" text_align="center" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Ueldo Coffee Shop', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5" custom_margin_bottom="60"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15064078303542" heading_text="'. esc_html( __( 'Welcome in our Caf&eacute;!', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][/vc_column][/vc_row][vc_row][vc_column width="1/2"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15064128625265"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15064128655212" large_width_type="calc" large_width_calc_px="15" extra_small_custom_sizes="yes"][ueldo_shortcode_info_box class_name="ueldo_vc_element_13440372023642" content_alignment="left" content_position="inline" heading_vertical_alignment="top" info_box_title="'. esc_html( __( 'Best coffee in the city!', 'ueldo' ) ) .'" info_box_subtitle="Phasellus vitae nibh nec orci sollicitudin lobortis. Praesent tincidunt turpis libero, eget tristique erat tristique a. Mauris interdum metus nibh, non sollicitudin leo ullamcorper." info_box_title_heading_type="h5" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-coffee-cup,flaticon-food|url:https://www.flaticon.com/free-icon/coffee-cup_227158|slug:info_element_icon_}][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_15064130699904" large_height="45"][ueldo_shortcode_info_box class_name="ueldo_vc_element_96630947038540" content_alignment="left" content_position="inline" heading_vertical_alignment="top" info_box_title="'. esc_html( __( 'Takeaway coffee & tea', 'ueldo' ) ) .'" info_box_subtitle="Curabitur vulputate sem ut mollis convallis. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean tincidunt augue non nulla gravida." info_box_title_heading_type="h5" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-coffee-cup,flaticon-food|url:https://www.flaticon.com/free-icon/coffee-cup_227134|slug:info_element_icon_}][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_1506604672533" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15064128804139"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15064128838971" large_width_type="px" large_width_px="15" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_150641289326" large_width_type="calc" large_width_calc_px="15" extra_small_custom_sizes="yes"][ueldo_shortcode_info_box class_name="ueldo_vc_element_29062782680641" content_alignment="left" content_position="inline" heading_vertical_alignment="top" info_box_title="'. esc_html( __( 'Free cookie for every order!', 'ueldo' ) ) .'" info_box_subtitle="Vivamus sollicitudin felis et ante rhoncus dignissim. Nam libero purus, consectetur et posuere at, venenatis sed tellus. Duis ex massa, viverra in vestibulum ut, blandit non massa." info_box_title_heading_type="h5" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-cookie,flaticon-food|url:https://www.flaticon.com/free-icon/cookie_227123|slug:info_element_icon_}][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_15064130780694" large_height="45"][ueldo_shortcode_info_box class_name="ueldo_vc_element_52131806282642" content_alignment="left" content_position="inline" heading_vertical_alignment="top" info_box_title="'. esc_html( __( 'Freshly ground coffee', 'ueldo' ) ) .'" info_box_subtitle="Phasellus vitae nibh nec orci sollicitudin lobortis. Praesent tincidunt turpis libero, eget tristique erat tristique a. Mauris interdum metus nibh, non sollicitudin leo ullamcorper." info_box_title_heading_type="h5" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-grinder,flaticon-food|url:https://www.flaticon.com/free-icon/grinder_227146|slug:info_element_icon_}][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15064133298761" large_height="75"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_23298955976053" large_height="75"][/vc_column][/vc_row][vc_row content_placement="middle"][vc_column width="1/12" offset="vc_col-lg-1 vc_col-md-1 vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_loop class_name="ueldo_vc_element_1506493825298" columns="2" use_separate_next_prev_arrows="separated" custom_next_prev_arrows_settings="custom_settings" arrow_border_radius="4" custom_colors_enabled="custom_settings" next_prev_arrow_color="#5b443e" next_prev_arrow_color_hover="#ffffff" next_prev_arrow_container_background="#f4f2eb" next_prev_arrow_container_background_hover="#f5bc4b" next_prev_arrow_container_box_shadow_color="rgba(255,255,255,0.01)" next_prev_arrow_container_box_shadow_color_hover="rgba(255,255,255,0.01)"][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_95830505347026"][ueldo_shortcode_gap class_name="ueldo_vc_element_78257154126624" large_height="75" small_custom_sizes="yes" small_height="0"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_6233082799059"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_23569502134521" large_width_type="px" large_width_px="61"][ueldo_shortcode_card class_name="ueldo_vc_element_58198898093120" border_width="0" padding_top="1" padding_right="15" padding_bottom="3" padding_left="15" custom_colors_enabled="custom_settings" box_shadow_color="rgba(255,255,255,0.01)" box_shadow_blur_radius_hover="0" box_shadow_color_hover="rgba(255,255,255,0.01)" background_color="#f5bc4b" background_color_hover="#f5bc4b"][ueldo_shortcode_heading class_name="ueldo_vc_element_84998541023694" heading_tag="p" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_74918199087637" heading_text="'. esc_html( __( 'NEW!', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings" font_color="#ffffff" font_color_hover="#ffffff"][/ueldo_shortcode_heading][/ueldo_shortcode_card][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_99375875893037" large_height="30"][ueldo_shortcode_heading class_name="ueldo_vc_element_8467888394338" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_60231726991992" heading_text="'. esc_html( __( 'New latte macchiato flavor available!', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Cras posuere nisl mi, egestas efficitur est rutrum sed. Donec pretium augue eget dignissim efficitur. Donec hendrerit, risus at blandit lacinia.[/vc_column_text][ueldo_shortcode_heading class_name="ueldo_vc_element_49221710331725" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_69984533017994" heading_text="$" custom_font_size_and_line_height_enabled="custom_settings" font_size="26"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_73524504113552" heading_text="4,99"][/ueldo_shortcode_heading][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_68324067141495"][ueldo_shortcode_image class_name="ueldo_vc_element_74187132997180" horizontal_alignment="center" border_radius="0" large_height_px="490" small_custom_sizes="yes" small_width_type="px" small_width_px="345" small_height_px="470" margin_bottom="0"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_82644540899888"][ueldo_shortcode_gap class_name="ueldo_vc_element_92012660942853" large_height="62" small_custom_sizes="yes" small_height="0"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_9380386894020"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_10723538407679" large_width_type="px" large_width_px="93"][ueldo_shortcode_card class_name="ueldo_vc_element_53408235163152" border_width="0" padding_top="1" padding_right="15" padding_bottom="3" padding_left="15" custom_colors_enabled="custom_settings" box_shadow_color="rgba(255,255,255,0.01)" box_shadow_blur_radius_hover="0" box_shadow_color_hover="rgba(255,255,255,0.01)" background_color="#f5bc4b" background_color_hover="#f5bc4b"][ueldo_shortcode_heading class_name="ueldo_vc_element_56172319247998" heading_tag="p" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_31233665360008" heading_text="'. esc_html( __( 'DISCOUNT!', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings" font_color="#ffffff" font_color_hover="#ffffff"][/ueldo_shortcode_heading][/ueldo_shortcode_card][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_53633785570289" large_height="30"][ueldo_shortcode_heading class_name="ueldo_vc_element_2564460659484" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_87288185645161" heading_text="'. esc_html( __( '-20% discount for Cappuccino coffee!', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Cras at ante vel turpis consectetur tempor euismod eget odio. Nulla semper mauris risus, ac mollis ex volutpat sed. Quisque nulla magna.[/vc_column_text][ueldo_shortcode_heading class_name="ueldo_vc_element_78572277622697" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_28840569608063" heading_text="$" custom_font_size_and_line_height_enabled="custom_settings" font_size="26"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_74523635925841" heading_text="2,99"][/ueldo_shortcode_heading][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_40032444194725"][ueldo_shortcode_image class_name="ueldo_vc_element_74873428540272" horizontal_alignment="center" border_radius="0" large_height_px="465" small_custom_sizes="yes" small_width_type="px" small_width_px="350" small_height_px="470" margin_bottom="0"][/ueldo_shortcode_loop_cell][/ueldo_shortcode_loop][/vc_column][vc_column offset="vc_col-lg-2 vc_col-md-2 vc_col-xs-12"][vc_column_text][ueldo_next_prev_loop_icons loop_id="1506493825298"][/vc_column_text][/vc_column][vc_column width="1/12" offset="vc_col-lg-1 vc_col-md-1 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_1512483631674"][/vc_column][/vc_row][/vc_section][vc_section][vc_row full_width="stretch_row_content_no_spaces" el_id="about-us"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_27949826056892" layer_title="'. esc_html( __( 'Background icon!', 'ueldo' ) ) .'" layer_z_index="3" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-coffee-cup,flaticon-food|url:https://www.flaticon.com/free-icon/coffee-cup_227158|slug:icon_} icon_size="150" icon_rotate="15deg" icon_color="#f4f0ec" extra_class_name="ueldo-vc-row-layer-overflow-visible" large_width_type="px" large_width_px="180" large_height_type="px" large_height_px="165" large_layer_position="bottom_right" large_margin_right="25" large_margin_bottom="-28"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_24895886521989" custom_layer_sizes="custom_settings" color="#fcfaf5" large_width_type="calc" large_width_calc_px="90" large_margin_left="45" small_layer_custom_sizes="yes" small_width_type="calc" small_width_calc_px="50" small_margin_left="25" extra_small_layer_custom_sizes="yes"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_81210980846" layer_title="'. esc_html( __( 'Border left', 'ueldo' ) ) .'" layer_z_index="11" custom_layer_sizes="custom_settings" color="#ffffff" large_width_type="px" large_width_px="45" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="25" extra_small_layer_visibility="no"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_32314414312" layer_title="'. esc_html( __( 'Border right', 'ueldo' ) ) .'" layer_z_index="11" custom_layer_sizes="custom_settings" color="#ffffff" large_width_type="px" large_width_px="45" large_layer_position="top_right" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="25" small_layer_position="top_right" extra_small_layer_visibility="no"][ueldo_shortcode_tabs class_name="ueldo_vc_element_57458842869393" tabs_content_style="style-03" content_position="right" image_container_border_radius="0" tabs_content_03_margin_between_image_content_content="0" custom_colors_enabled="custom_settings" tabs_content_background_color="#fcfaf5" images_container_box_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_35500133432455" single_tab_title="'. esc_html( __( 'Best coffee in the city', 'ueldo' ) ) .'"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15064242802665"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15064242831614" large_width_type="px" large_width_px="60" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15064242925894" large_width_type="calc" large_width_calc_px="60" small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15066018297618" large_height="0" small_custom_sizes="yes"][ueldo_shortcode_heading class_name="ueldo_vc_element_15064243005565" heading_subtitle_text="'. esc_html( __( 'Coffee lovers & enthusiasts', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15064243536343" heading_text="'. esc_html( __( 'True coffee passion', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]Maecenas tempus tellus id quam cursus, vitae hendrerit nunc pulvinar. Vestibulum condimentum accumsan nulla, quis faucibus erat interdum sed. Ut ac sagittis augue, nec tristique arcu. Pellentesque eget elit.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_150642525644" large_height="25"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15064252962293"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15064252998562" large_width_type="px" large_width_px="60" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_1506425309271" large_width_type="px" large_width_px="55"][ueldo_shortcode_heading class_name="ueldo_vc_element_15064253176165" heading_tag="h4" text_align="inline" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15064253307434" heading_text="'. esc_html( __( 'Since', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_1506425355235" large_width_type="calc" large_width_calc_px="115" small_custom_sizes="yes" small_width_type="calc" small_width_calc_px="55"][ueldo_shortcode_info_box class_name="ueldo_vc_element_6437471500157" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( 'More than 30 years of tradition', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="81" info_element_height="42" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="1984" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][/vc_column][/vc_row][/vc_section][vc_section][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_64638343504982" layer_title="'. esc_html( __( 'Background icon', 'ueldo' ) ) .'" layer_z_index="3" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-coffee-shop,flaticon-restaurant|url:https://www.flaticon.com/free-icon/coffee-shop_227137|slug:icon_} icon_size="150" icon_rotate="345deg" icon_color="#f4f0ec" extra_class_name="ueldo-vc-row-layer-overflow-visible" large_width_type="px" large_width_px="180" large_height_type="px" large_height_px="165" large_layer_position="bottom_left" large_margin_bottom="-28" large_margin_left="25"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_65522683031909" custom_layer_sizes="custom_settings" color="#fcfaf5" large_width_type="calc" large_width_calc_px="90" large_margin_left="45" small_layer_custom_sizes="yes" small_width_type="calc" small_width_calc_px="50" small_margin_left="25" extra_small_layer_custom_sizes="yes"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_45198411184" layer_title="'. esc_html( __( 'Border left', 'ueldo' ) ) .'" layer_z_index="11" custom_layer_sizes="custom_settings" color="#ffffff" large_width_type="px" large_width_px="45" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="25" extra_small_layer_visibility="no"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_75981032070" layer_title="'. esc_html( __( 'Border right', 'ueldo' ) ) .'" layer_z_index="11" custom_layer_sizes="custom_settings" color="#ffffff" large_width_type="px" large_width_px="45" large_layer_position="top_right" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="25" small_layer_position="top_right" extra_small_layer_visibility="no"][ueldo_shortcode_tabs class_name="ueldo_vc_element_30965279371770" tabs_content_style="style-03" image_container_border_radius="0" tabs_content_03_margin_between_image_content_content="0" custom_colors_enabled="custom_settings" tabs_content_background_color="#fcfaf5" images_container_box_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_81867817543654" single_tab_title="'. esc_html( __( 'Best coffee in the city', 'ueldo' ) ) .'"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15064236409894"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15064236512588" large_width_type="calc" large_width_calc_px="60" small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15066019398505" large_height="0" small_custom_sizes="yes"][ueldo_shortcode_opening_hours_status class_name="ueldo_vc_element_15064238732164" {ueldopredefinedsections:openinghours|context:cafe} horizontal_alignment="left" text_when_open="'. esc_html( __( 'We are open now!', 'ueldo' ) ) .'" custom_colors_enabled="custom_settings" background_color="#f4f2eb" background_color_hover="#f4f2eb" box_shadow_color="rgba(255,255,255,0.01)" box_shadow_color_hover="rgba(255,255,255,0.01)"][ueldo_shortcode_gap class_name="ueldo_vc_element_15064239164604"][ueldo_shortcode_heading class_name="ueldo_vc_element_51521149762836" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Opening hours', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5" custom_margin_bottom="60"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_41486629098249" heading_text="'. esc_html( __( 'We\'re open everyday between 8:00am - 10:00pm', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][ueldo_shortcode_button class_name="ueldo_vc_element_15064239272742" button_text="'. esc_html( __( 'Book a Table', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'%23contact|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_150660196793" large_height="0" small_custom_sizes="yes" small_height="15"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][/vc_column][/vc_row][/vc_section][vc_section el_id="prices"][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_80357888197802" large_height="75"][ueldo_shortcode_heading class_name="ueldo_vc_element_15064263143768" text_align="center" heading_subtitle_text="'. esc_html( __( 'Check our prices', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15064263297738" heading_text="'. esc_html( __( 'Prices & discounts', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][ueldo_shortcode_pricing_list class_name="ueldo_vc_element_15064288439707"][ueldo_shortcode_pricing_list_group class_name="ueldo_vc_element_24347279728934" title="'. esc_html( __( 'Coffee', 'ueldo' ) ) .'" {ueldopredefinedsections:icon|key:flaticon-coffee-cup,flaticon-food|url:https://www.flaticon.com/free-icon/coffee-cup_227121|slug:icon_}][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_80015803841389" title="'. esc_html( __( 'Caffe latte', 'ueldo' ) ) .'" price="$4,50"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_18510942566251" title="'. esc_html( __( 'Espresso', 'ueldo' ) ) .'" price="$3,50"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_89809247669078" title="'. esc_html( __( 'Espresso macchiato', 'ueldo' ) ) .'" price="$3,50"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_44621543575472" title="'. esc_html( __( 'Americano (black coffee)', 'ueldo' ) ) .'" price="$3,50"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_86222036348912" title="'. esc_html( __( 'White coffee', 'ueldo' ) ) .'" price="$3,75"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_46372988486031" title="'. esc_html( __( 'Cappuccino', 'ueldo' ) ) .'" price="$3,99"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_82046673578662" title="'. esc_html( __( 'Irish Coffee', 'ueldo' ) ) .'" price="$5,00"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_41880456745341" title="'. esc_html( __( 'Cinnamon Coffee', 'ueldo' ) ) .'" price="$5,25"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_73159120729046" title="'. esc_html( __( 'Cinnamon & Imbir Coffee', 'ueldo' ) ) .'" price="$5,30"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_3220832421567" title="'. esc_html( __( 'Takeaway pack', 'ueldo' ) ) .'" price="'. esc_html( __( 'free', 'ueldo' ) ) .'"][/ueldo_shortcode_pricing_list_group][ueldo_shortcode_pricing_list_group class_name="ueldo_vc_element_18334794682012" title="'. esc_html( __( 'Tea', 'ueldo' ) ) .'" description="Mauris venenatis risus nec metus maximus pharetra vitae in ante." {ueldopredefinedsections:icon|key:flaticon-tea-cup,flaticon-food|url:https://www.flaticon.com/free-icon/tea-cup_227157|slug:icon_}][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_20048409735438" title="'. esc_html( __( 'Earl Grey', 'ueldo' ) ) .'" price="$4,50"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_59180769936223" title="'. esc_html( __( 'Earl Gray with Milk', 'ueldo' ) ) .'" price="$3,50"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_42545745852571" title="'. esc_html( __( 'Black tea', 'ueldo' ) ) .'" price="$3,50"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_31923519398903" title="'. esc_html( __( 'English tea', 'ueldo' ) ) .'" price="$3,50"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_50376450702851" title="'. esc_html( __( 'Green tea', 'ueldo' ) ) .'" price="$3,75"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_27866496328245" title="'. esc_html( __( 'White tea', 'ueldo' ) ) .'" price="$3,99"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_25029019966466" title="'. esc_html( __( 'Oolong Tea', 'ueldo' ) ) .'" price="$5,00"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_37372898258921" title="'. esc_html( __( 'Pu-erh Tea', 'ueldo' ) ) .'" price="$5,25"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_24319875544945" title="'. esc_html( __( 'Tisanes', 'ueldo' ) ) .'" price="$5,30"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_5627505266718" title="'. esc_html( __( 'Takeaway pack', 'ueldo' ) ) .'" price="'. esc_html( __( 'free', 'ueldo' ) ) .'"][/ueldo_shortcode_pricing_list_group][/ueldo_shortcode_pricing_list][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15065002939355"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_150650229232" heading_tag="h3" heading_subtitle_text="'. esc_html( __( 'Amazing taste', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15065023078686" heading_text="'. esc_html( __( 'Freshly baked croissants', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Donec mi sem, porttitor quis ex sed, commodo accumsan lacus. Maecenas sollicitudin augue ac nibh luctus, vel elementum dui malesuada. Praesent ac neque mollis arcu sagittis pharetra.[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_15065048604462" button_text="'. esc_html( __( 'Book a Table', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'%23contact|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_15066050582047" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_image class_name="ueldo_vc_element_15065021857972" border_radius="0" large_height_px="320" medium_custom_sizes="yes" medium_height_px="270" small_custom_sizes="yes" small_height_px="398" extra_small_custom_sizes="yes" extra_small_height_px="270" margin_bottom="0"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15065021630357"][/vc_column][/vc_row][/vc_section][vc_section el_id="discounts"][vc_row full_width="stretch_row" content_placement="middle"][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15064995299044" custom_layer_sizes="custom_settings" color="#fcfaf5" large_width_type="calc" large_width_calc_px="90" large_margin_left="45" small_layer_custom_sizes="yes" small_width_type="calc" small_width_calc_px="50" small_margin_left="25" extra_small_layer_custom_sizes="yes"][ueldo_shortcode_image class_name="ueldo_vc_element_15064988669206" border_radius="0" large_height_px="450" margin_bottom="0"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15066032880912" large_height="0" small_custom_sizes="yes"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15064989105135"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15064989152124" large_width_type="px" large_width_px="30" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15064989322556" large_width_type="calc" large_width_calc_px="30" small_custom_sizes="yes"][ueldo_shortcode_heading class_name="ueldo_vc_element_15064983532285" heading_tag="h3" heading_subtitle_text="'. esc_html( __( 'More and more pleasure', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15064983902907" heading_text="'. esc_html( __( 'Have you seen our discounts app?', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Curabitur et ullamcorper ante. Morbi convallis viverra lorem ac elementum. Integer eleifend sodales quam non ultrices. Curabitur nec ipsum in ligula rutrum iaculis. Nulla a ante dignissim, finibus lacus ac, facilisis nisi.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15064991964745" large_height="25"][ueldo_shortcode_button class_name="ueldo_vc_element_10282650117922" button_type="two-line-button" button_visible_on_devices="large,medium,small" button_text="'. esc_html( __( 'Download from', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'App Store', 'ueldo' ) ) .'" button_alignment="inline" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-apple" custom_sizes_enabled="custom_settings" additional_margin_after="15" custom_colors_enabled="custom_settings" two_line_button_background_color="#f4f2eb" two_line_button_background_color_hover="#ece9df" two_line_button_border_color_hover="#ece9df" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_icon_color="#5a443d" two_line_button_icon_color_hover="#5a443d"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_83139813711965" button_type="two-line-button" button_visible_on_devices="large,medium,small" button_text="'. esc_html( __( 'Download from', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Google Play', 'ueldo' ) ) .'" button_alignment="inline" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-google" custom_colors_enabled="custom_settings" two_line_button_background_color="#f4f2eb" two_line_button_background_color_hover="#ece9df" two_line_button_border_color_hover="#ece9df" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_icon_color="#5a443d" two_line_button_icon_color_hover="#5a443d"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_button class_name="ueldo_vc_element_93754718074693" button_type="two-line-button" button_visible_on_devices="extra-small" button_text="'. esc_html( __( 'Download from', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'App Store', 'ueldo' ) ) .'" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-apple" custom_sizes_enabled="custom_settings" additional_margin_after="15" custom_colors_enabled="custom_settings" two_line_button_background_color="#f4f2eb" two_line_button_background_color_hover="#ece9df" two_line_button_border_color_hover="#ece9df" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_icon_color="#5a443d" two_line_button_icon_color_hover="#5a443d"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_78137612773331" large_height="0" extra_small_custom_sizes="yes" extra_small_height="10"][ueldo_shortcode_button class_name="ueldo_vc_element_74914718661915" button_type="two-line-button" button_visible_on_devices="extra-small" button_text="'. esc_html( __( 'Download from', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Google Play', 'ueldo' ) ) .'" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-google" custom_colors_enabled="custom_settings" two_line_button_background_color="#f4f2eb" two_line_button_background_color_hover="#ece9df" two_line_button_border_color_hover="#ece9df" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_icon_color="#5a443d" two_line_button_icon_color_hover="#5a443d"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_67584915189528" large_height="0" small_custom_sizes="yes"][/vc_column][/vc_row][/vc_section]',

                '404-page' => '[vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15065878595025" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" color="#faf8f8" large_width_type="calc" large_width_calc_px="90" large_margin_left="45" small_layer_custom_sizes="yes" small_width_type="calc" small_width_calc_px="50" small_margin_left="25" extra_small_layer_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15065878058869" large_height="75"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/6" offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15065879523628" heading_tag="h1" text_align="center" heading_subtitle_text="'. esc_html( __( '404 page', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15065879653656" heading_text="'. esc_html( __( 'Nothing found here!', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Etiam sed eros mauris. Pellentesque cursus fringilla felis at vulputate. Nullam vel auctor lacus, eget finibus diam. Duis venenatis non arcu gravida porttitor. Sed tellus neque, euismod vel tincidunt at, euismod mollis quam. In ullamcorper vulputate mi, a imperdiet erat fringilla a. Donec metus lectus.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_1506588071834" large_height="25"][ueldo_shortcode_button class_name="ueldo_vc_element_15065880765275" button_text="'. esc_html( __( 'Go back to home page', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'|title:'. rawurlencode( esc_html( __( 'Home page', 'ueldo' ) ) ) .'||" button_alignment="center"][/ueldo_shortcode_button][/vc_column][vc_column width="1/6" offset="vc_col-lg-2 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15065879450003" large_height="75"][/vc_column][/vc_row][/vc_section]',

                'header' => '[vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible"][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15065143509891" layer_for_row_or_section="section" color="#ffffff"][ueldo_shortcode_gap class_name="ueldo_vc_element_96109040477012" large_height="0" small_custom_sizes="yes" small_height="19"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15065145468597"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_97679190710467" large_width_type="px" large_width_px="136"][ueldo_shortcode_website_logo class_name="ueldo_vc_element_15065184155932" large_width_type="px" large_width_px="106" {ueldopredefinedsections:image|context:cafe-logo}][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_13638784621635" large_width_type="px" large_width_px="157"][ueldo_shortcode_button class_name="ueldo_vc_element_39413462554757" button_visible_on_devices="large,medium,small" button_text="'. esc_html( __( 'Book a Table', 'ueldo' ) ) .'" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-phone" custom_sizes_enabled="custom_settings" standard_button_padding_top="10" standard_button_padding_right="15" standard_button_padding_bottom="10" standard_button_padding_left="15" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="#f4f2eb" standard_button_border_color="#f4f2eb" standard_button_box_shadow_vertical_length="0" standard_button_box_shadow_blur_radius="0" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_text_color="#5a443d" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#f6bc4c" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_22259668027463" button_visible_on_devices="extra-small" button_text="" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-phone" custom_sizes_enabled="custom_settings" standard_button_padding_top="10" standard_button_padding_right="15" standard_button_padding_bottom="10" standard_button_padding_left="15" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="#f4f2eb" standard_button_border_color="#f4f2eb" standard_button_box_shadow_vertical_length="0" standard_button_box_shadow_blur_radius="0" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_text_color="#5a443d" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#f6bc4c" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_36103181323890" large_width_type="calc" large_width_calc_px="293" large_content_alignment="right"][ueldo_shortcode_header_menu class_name="ueldo_vc_element_15065135364024" menu_links_alignment="right" custom_sizes_enabled="custom_settings" margin_right="-15"][ueldo_shortcode_button class_name="ueldo_vc_element_1506601115759" button_visible_on_devices="small,extra-small" button_text="" action_after_click="show_hide_side_menu" button_alignment="right" show_button_icon="yes" button_icon_fontawesome="fa fa-bars" custom_sizes_enabled="custom_settings" standard_button_padding_top="0" standard_button_padding_right="0" standard_button_padding_bottom="0" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_border_radius="0" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="#ffffff" standard_button_background_color_hover="#ffffff" standard_button_border_color="#ffffff" standard_button_border_color_hover="#ffffff" standard_button_box_shadow_vertical_length="0" standard_button_box_shadow_blur_radius="0" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="0" standard_button_box_shadow_blur_radius_hover="0" standard_button_box_shadow_color_hover="rgba(255,255,255,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#5a443d" standard_button_icon_color_hover="#f5bc4b"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_11189346777736" large_height="0" small_custom_sizes="yes" small_height="19"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_inline_container class_name="ueldo_vc_element_1506514478944"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_33160555101956" large_width_type="px" large_width_px="45" small_custom_sizes="yes" small_width_type="px" small_width_px="25" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_37632780501565" large_width_type="calc" large_width_calc_px="90" small_custom_sizes="yes" small_width_type="calc" small_width_calc_px="50" extra_small_custom_sizes="yes"][ueldo_shortcode_delimiter class_name="ueldo_vc_element_15065143720556" large_height="1" margin_bottom="0" custom_colors_enabled="custom_settings" background_color="rgba(90,68,61,0.05)"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_51762979798379" large_width_type="px" large_width_px="45" small_custom_sizes="yes" small_width_type="px" small_width_px="25" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][/vc_section]',

                'footer' => '[vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_915065002939355"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible" content_placement="middle"][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_9150650229232" heading_tag="h3" heading_subtitle_text="'. esc_html( __( 'Only for coffee lovers!', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_939520218978340" heading_text="'. esc_html( __( 'Like us on social media and grab a', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_979926057863906" heading_text="'. esc_html( __( 'free coffee!', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]Vestibulum elementum accumsan augue. Duis eros purus, tristique et maximus auctor, pellentesque sit amet sapien. In hac habitasse platea dictumst. Integer dapibus vulputate libero sed rutrum. Mauris quis lorem id.[/vc_column_text][ueldo_shortcode_social_media_feed class_name="ueldo_vc_element_915065846770905" type="facebook_like_button" facebook_like_button_layout="button_count" facebook_like_button_share="yes"][/ueldo_shortcode_social_media_feed][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15066036339054" large_height="0" small_custom_sizes="yes" small_height="45"][ueldo_shortcode_image class_name="ueldo_vc_element_915065021857972" horizontal_alignment="center" border_radius="0" large_height_px="340" small_custom_sizes="yes" small_width_type="px" small_width_px="450" small_height_px="340" extra_small_custom_sizes="yes" extra_small_height_px="245" margin_bottom="0"][/vc_column][/vc_row][/vc_section][vc_section el_id="contact"][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_915065845667963"][ueldo_shortcode_heading class_name="ueldo_vc_element_915065053296208" text_align="center" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Be our guest', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5" custom_margin_bottom="60"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_915065053484166" heading_text="'. esc_html( __( 'Contact us today!', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][/vc_column][/vc_row][vc_row][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][vc_column_text]<strong>'. esc_html( __( 'Los Angeles Caf&eacute;', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( '54321 Example Street, Los Angeles, CA', 'ueldo' ) ) .'<br /><br /> '. esc_html( __( 'Phone:', 'ueldo' ) ) .' <a href="tel:18001234567">1-800-123-4567</a><br /> '. esc_html( __( 'E-mail:', 'ueldo' ) ) .' <a href="'. esc_url( __( 'mailto:la-cafe@example.com', 'ueldo' ) ) .'">'. esc_html( __( 'la-cafe@example.com', 'ueldo' ) ) .'</a>[/vc_column_text][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15066053619031" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][vc_column_text]<strong>'. esc_html( __( 'New York Caf&eacute;', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( '54321 Example Street, New York, NY', 'ueldo' ) ) .'<br /><br /> '. esc_html( __( 'Phone:', 'ueldo' ) ) .' <a href="tel:18001234567">1-800-123-4567</a><br /> '. esc_html( __( 'E-mail:', 'ueldo' ) ) .' <a href="'. esc_url( __( 'mailto:ny-cafe@example.com', 'ueldo' ) ) .'">'. esc_html( __( 'ny-cafe@example.com', 'ueldo' ) ) .'</a>[/vc_column_text][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15066037936506" large_height="0" small_custom_sizes="yes" small_height="45"][vc_column_text]<strong>'. esc_html( __( 'Seattle Caf&eacute;', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( '54321 Example Street, Seattle, WA', 'ueldo' ) ) .'<br /><br /> '. esc_html( __( 'Phone:', 'ueldo' ) ) .' <a href="tel:18001234567">1-800-123-4567</a><br /> '. esc_html( __( 'E-mail:', 'ueldo' ) ) .' <a href="'. esc_url( __( 'mailto:seattle-cafe@example.com', 'ueldo' ) ) .'">'. esc_html( __( 'seattle-cafe@example.com', 'ueldo' ) ) .'</a>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_24681388157714" large_height="75"][/vc_column][/vc_row][/vc_section][vc_section][vc_row full_width="stretch_row" content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15065121036997" custom_layer_sizes="custom_settings" color="#faf8f8" large_width_type="calc" large_width_calc_px="90" large_margin_left="45" small_layer_custom_sizes="yes" small_width_type="calc" small_width_calc_px="50" small_margin_left="25" extra_small_layer_custom_sizes="yes"][ueldo_shortcode_google_map class_name="ueldo_vc_element_15065091673426" border_radius="0" large_height_px="650" medium_custom_sizes="yes" medium_height_px="700" small_custom_sizes="yes" small_height_px="450" margin_bottom="0" {ueldopredefinedsections:googlemap|context:cafe}][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_55593159115185" large_height="0" small_custom_sizes="yes"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15065099672297"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_1506509969997" large_width_type="px" large_width_px="30" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15065099762107" large_width_type="calc" large_width_calc_px="30" small_custom_sizes="yes"][ueldo_shortcode_icon class_name="ueldo_vc_element_15065126628768" icon_alignment="inline" {ueldopredefinedsections:icon|key:flaticon-coffee-shop,flaticon-restaurant|url:https://www.flaticon.com/free-icon/coffee-shop_227137|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" custom_colors_enabled="custom_settings" icon_color="#f5bc4b"][ueldo_shortcode_heading class_name="ueldo_vc_element_15065099068149" heading_tag="h3" text_align="inline" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0" custom_margin_left="20"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15065099137107" heading_text="'. esc_html( __( 'Send us an email', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_gap class_name="ueldo_vc_element_15065127307589" large_height="30"][contact-form-7 {ueldopredefinedsections:contactform7|context:cafe|inside:false}][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_30039790813843" large_height="0" small_custom_sizes="yes"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_30972205469885" large_height="30"][vc_column_text]2017 - '. date( 'Y' ) .' &copy; <a href="'. esc_url( ueldo_get_external_url( 'ueldo-com' ) ) .'" target="_blank">'. esc_html( __( 'Ueldo', 'ueldo' ) ) .'</a> '. esc_html( __( 'WordPress theme by', 'ueldo' ) ) .' <a href="'. esc_url( ueldo_get_external_url( 'martanian-com' ) ) .'" target="_blank">Martanian</a>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15065120076187" large_height="10"][/vc_column][/vc_row][/vc_section]',

                'additional-before-side-menu' => '[vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_915066060871935" large_height="10"][ueldo_shortcode_button class_name="ueldo_vc_element_939413462554757" button_text="'. esc_html( __( 'Book a Table', 'ueldo' ) ) .'" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" button_alignment="center" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-phone" custom_sizes_enabled="custom_settings" standard_button_padding_top="10" standard_button_padding_right="15" standard_button_padding_bottom="10" standard_button_padding_left="15" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="#f7c360" standard_button_background_color_hover="#f7c360" standard_button_border_color="#f7c360" standard_button_border_color_hover="#f7c360" standard_button_box_shadow_vertical_length="0" standard_button_box_shadow_blur_radius="0" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][/vc_column][/vc_row]',

                'additional-after-side-menu' => '[vc_row][vc_column][ueldo_shortcode_social_media_feed class_name="ueldo_vc_element_15066061948732" type="facebook_like_button" facebook_like_button_layout="only_button"][/ueldo_shortcode_social_media_feed][ueldo_shortcode_gap class_name="ueldo_vc_element_815066060871935" large_height="10"][/vc_column][/vc_row]'
            );

            # return result
            return( $page_slug == false ? $contents : ( isset( $contents[esc_attr( $page_slug )] ) ? $contents[esc_attr( $page_slug )] : false ) );
        }

       /**
        *
        * end of class methods.
        *
        */
    }

   /**
    *
    * end of file.
    *
    */

?>