<?php

   /**
    *
    * installation class for "dentist" demo template
    *
    */

    class ueldo_demo_contents_loader_base extends ueldo_demo_contents_loader_installation_helper {

       /**
        *
        * install template or its parts
        *
        */

        public static function install( $parts, $icons ) {

           /**
            *
            * install revolution slider
            *
            */

            if( $parts == 'all' || in_array( 'revolution-slider-sliders', $parts, true ) ) {

                # upload revolution slider and get its id
                if( ( $slider_id = ueldo_add_demo_assets::upload_revslider( 'dentist-home-page' ) ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:revslider|context:dentist-home-page}', 'alias="'. esc_attr( $slider_id ) .'"' );

                    # remove temporary variables
                    unset( $slider_id );
                }
            }

           /**
            *
            * install forms
            *
            */

            if( $parts == 'all' || in_array( 'forms', $parts, true ) ) {

                # add form in contact form 7 plugin and get its id
                if( ( $form_id = ueldo_add_demo_assets::add_contact_form() ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:contactform7|context:dentist|inside:false}', 'id="'. esc_attr( $form_id ) .'"' );

                    # remove temporary variables
                    unset( $form_id );
                }
            }

           /**
            *
            * install blog posts
            *
            */

            if( $parts == 'all' || in_array( 'posts', $parts, true ) ) {

                # do we have default image ID?
                if( self::get_solution( 'default-image-id' ) == false ) {

                    # add solution with default image ID
                    self::add_solution( 'default-image-id', ueldo_add_demo_assets::add_image( 'default-image' ) );
                }

                # get current user data
                $current_user = wp_get_current_user();

                # add blog post
                $new_post_id = ueldo_add_demo_assets::add_blog_post( array(
                    'title' => esc_html( __( 'Longer opening hours everyday since September', 'ueldo' ) ),
                    'content' => false,
                    'thumbnail' => self::get_solution( 'default-image-id' ),
                    'category' => array( wp_create_category( esc_html( __( 'Dentist', 'ueldo' ) ) ) ),
                    'tags' => array(
                        esc_html( __( 'Dentist', 'ueldo' ) ),
                        esc_html( __( 'Opening hours', 'ueldo' ) )
                    ),
                    'comments' => array(
                        array(
                            'author' => esc_html( __( 'John', 'ueldo' ) ),
                            'author-email' => esc_html( __( 'john@example.com', 'ueldo' ) ),
                         			'content' => 'Aliquam erat volutpat. Nam ac odio in erat lobortis tempus a id urna. Vestibulum varius, ligula convallis ultrices volutpat, arcu elit pellentesque turpis, sit amet laoreet odio odio et risus. Nullam vehicula justo sit amet mauris molestie faucibus. Ut luctus sodales mauris, nec sagittis lorem congue a. In eget tincidunt nulla.'
                        ),
                        array(
                         			'author' => esc_html( $current_user -> display_name ),
                            'author-email' => esc_html( $current_user -> user_email ),
                         			'content' => 'Fusce vestibulum nisi vel ex efficitur pharetra. Ut sit amet dolor a risus vehicula mollis. Sed at enim quis tortor fermentum ornare sit amet at purus. Sed lobortis viverra sem sed congue. Vivamus et porta arcu. Donec faucibus eget dolor ut pharetra. Mauris et metus vitae dui rhoncus aliquet. Quisque nunc lacus, efficitur id ipsum at, elementum pretium libero.',
                            'user_id' => esc_attr( $current_user -> ID )
                        )
                    )
                ));

                # wait until previous post is added
                if( $new_post_id !== false ) {

                    # clear temporary variable
                    unset( $new_post_id );

                    # add blog post
                    $new_post_id = ueldo_add_demo_assets::add_blog_post( array(
                        'title' => esc_html( __( 'We received an Award for the Best Dentist in the Country', 'ueldo' ) ),
                        'content' => false,
                        'thumbnail' => self::get_solution( 'default-image-id' ),
                        'category' => array( wp_create_category( esc_html( __( 'Dentist', 'ueldo' ) ) ) ),
                        'tags' => array(
                            esc_html( __( 'Awards', 'ueldo' ) ),
                            esc_html( __( 'Dentist', 'ueldo' ) )
                        ),
                        'comments' => array(
                            array(
                             			'author' => esc_html( __( 'Susane', 'ueldo' ) ),
                             			'author-email' => esc_html( __( 'susane@example.com', 'ueldo' ) ),
                             			'content' => 'Integer ac blandit ipsum. Sed nunc ante, bibendum id eros eu, pellentesque malesuada augue. Duis nunc tellus, facilisis et justo eget, suscipit tincidunt mi. Praesent vel nibh luctus, semper velit facilisis, bibendum elit. Donec varius, elit id interdum molestie, purus lorem sollicitudin purus, ut dictum nulla felis quis lacus. Ut quis velit neque.',
                                'replies' => array(
                                    array(
                                        'author' => esc_html( $current_user -> display_name ),
                                        'author-email' => esc_html( $current_user -> user_email ),
                                        'content' => 'Duis quam erat, laoreet vel tempor sed, consectetur nec est. Donec nibh turpis, viverra a vehicula at, mattis eget magna. Mauris a mi elementum, molestie nunc vitae, placerat est. In venenatis ante et nunc congue varius. Nullam euismod consectetur commodo. Sed nec metus luctus, faucibus quam sed, tristique nisi. Quisque eu leo malesuada, tincidunt purus quis, tristique magna.',
                                        'user_id' => esc_attr( $current_user -> ID )
                                    )
                                )
                            ),
                            array(
                             			'author' => esc_html( __( 'John', 'ueldo' ) ),
                             			'author-email' => esc_html( __( 'john@example.com', 'ueldo' ) ),
                             			'content' => 'Donec tortor purus, cursus fermentum leo vel, finibus faucibus mi. Fusce nec turpis vitae massa malesuada molestie vitae vel turpis. Mauris ultrices lacinia lacus, in porta velit imperdiet sed. Interdum et malesuada fames ac ante ipsum primis in faucibus. Donec dignissim eleifend sapien, nec facilisis arcu mattis nec.'
                            )
                        )
                    ));

                    # wait until previous post is added
                    if( $new_post_id !== false ) {

                        # clear temporary variable
                        unset( $new_post_id );

                        # add blog post
                        ueldo_add_demo_assets::add_blog_post( array(
                            'title' => esc_html( __( 'New high-class equipment for Dental Radiology', 'ueldo' ) ),
                            'content' => false,
                            'thumbnail' => self::get_solution( 'default-image-id' ),
                            'category' => array( wp_create_category( esc_html( __( 'Dentist', 'ueldo' ) ) ) ),
                            'tags' => array(
                                esc_html( __( 'Dentist', 'ueldo' ) ),
                                esc_html( __( 'Services', 'ueldo' ) )
                            ),
                            'comments' => array(
                                array(
                                    'author' => esc_html( __( 'Mike', 'ueldo' ) ),
                                    'author-email' => esc_html( __( 'mike@example.com', 'ueldo' ) ),
                                    'content' => 'Quisque tempor ut justo sed consequat. Sed egestas placerat eros in molestie. Praesent sollicitudin, odio ut malesuada cursus, nulla mauris dignissim dolor, a luctus massa massa semper nibh. Phasellus vitae ornare dolor. Aenean blandit porttitor dapibus. Nunc ac metus urna. Vivamus placerat porta magna, vitae porttitor justo efficitur non.'
                                )
                            )
                        ));
                    }
                }

                # remove temporary variables
                unset( $current_user );

                # posts per page
                update_option( 'posts_per_page', '10' );
            }

           /**
            *
            * add pages, but not fill it with contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # add pages and get its ids
                $pages_ids = ueldo_add_demo_assets::add_empty_pages( 'page', array(
                    '404-page' => esc_html( __( '404 page', 'ueldo' ) ),
                    'about-us' => esc_html( __( 'About us', 'ueldo' ) ),
                    'blog' => esc_html( __( 'Blog', 'ueldo' ) ),
                    'contact' => esc_html( __( 'Contact', 'ueldo' ) ),
                    'dental-radiology' => esc_html( __( 'Dental Radiology', 'ueldo' ) ),
                    'esthetic-dentistry' => esc_html( __( 'Esthetic Dentistry', 'ueldo' ) ),
                    'general-dentistry' => esc_html( __( 'General Dentistry', 'ueldo' ) ),
                    'home' => esc_html( __( 'Home', 'ueldo' ) )
                ));

                # add headers, footers and extras
                $hefos_ids = ueldo_add_demo_assets::add_empty_pages( 'ueldohefo', array(
                    'blog-responsive-margin-top' => esc_html( __( 'Blog responsive margin top', 'ueldo' ) ),
                    'header' => esc_html( __( 'Header', 'ueldo' ) ),
                    'footer' => esc_html( __( 'Footer', 'ueldo' ) ),
                    'sticky-header' => esc_html( __( 'Sticky header', 'ueldo' ) )
                ));

                # add solution
                self::add_solution( 'pages-ids', array_merge( $pages_ids, $hefos_ids ) );

                # show page on front
                update_option( 'show_on_front', 'page' );

                # update blog posts page ID
                if( $pages_ids['blog'] != null && $pages_ids['blog'] != false ) update_option( 'page_for_posts', $pages_ids['blog'] );

                # update home page ID
                if( $pages_ids['home'] != null && $pages_ids['home'] != false ) update_option( 'page_on_front', $pages_ids['home'] );

                # remove temporary variables
                unset( $pages_ids );
            }

           /**
            *
            * install menus
            *
            */

            if( $parts == 'all' || in_array( 'menus', $parts, true ) ) {

                # add new menu
                if( is_int( $menu_id = ueldo_add_demo_assets::add_menu( 'dentist-main-menu', self::get_solution( 'pages-ids' ), true ) ) ) {

                    # add solution
                    self::add_solution( 'main-menu-id', esc_attr( $menu_id ) );
                }
            }

           /**
            *
            * configure sidebars & widgets
            *
            */

            if( $parts == 'all' || in_array( 'sidebars-and-widgets', $parts, true ) ) {

                # temporary variable
                $temp = array(
                    'sidebar_pages_menu_id' => ueldo_add_demo_assets::add_menu( 'dentist-sidebar-pages-menu' ),
                    'sidebar_services_menu_id' => ueldo_add_demo_assets::add_menu( 'dentist-sidebar-services-menu' )
                );

                # sidebars and widgets data array
                $sw_data = array(
                    'widget_categories' => array( '_multiwidget' => true ),
                    'widget_text' => array( '_multiwidget' => true ),
                    'widget_rss' => array( '_multiwidget' => true ),
                    'widget_search' => array(
                        '1' => array( 'title' => '' ),
                        '_multiwidget' => true
                    ),
                    'widget_recent-posts' => array( '_multiwidget' => true ),
                    'widget_recent-comments' => array( '_multiwidget' => true ),
                    'widget_archives' => array( '_multiwidget' => true ),
                    'widget_meta' => array( '_multiwidget' => true ),
                    'widget_pages' => array( '_multiwidget' => true ),
                    'widget_calendar' => array( '_multiwidget' => true ),
                    'widget_media_audio' => array( '_multiwidget' => true ),
                    'widget_media_image' => array( '_multiwidget' => true ),
                    'widget_media_video' => array( '_multiwidget' => true ),
                    'widget_tag_cloud' => array(
                        '1' => array(
                            'title' => esc_html( __( 'Tags', 'ueldo' ) ),
                            'count' => 0,
                            'taxonomy' => 'post_tag'
                        ),
                        '_multiwidget' => true
                    ),
                    'widget_nav_menu' => array(
                        '1' => array(
                            'title' => esc_html( __( 'Pages', 'ueldo' ) ),
                            'nav_menu' => esc_attr( $temp['sidebar_pages_menu_id'] )
                        ),
                        '2' => array(
                            'title' => esc_html( __( 'Services', 'ueldo' ) ),
                            'nav_menu' => esc_attr( $temp['sidebar_services_menu_id'] )
                        ),
                        '_multiwidget' => true
                    ),
                    'widget_custom_html' => array( '_multiwidget' => true ),
                    'widget_rev-slider-widget' => array( '_multiwidget' => true ),
                    'widget_ueldo_popular_posts_widget' => array(
                        '1' => array(
                            'posts_number' => '3',
                            'posts_from_last' => 'all',
                            'title' => esc_html( __( 'Popular posts', 'ueldo' ) )
                        ),
                        '_multiwidget' => true
                    ),
                    'widget_ueldo_call_to_action_widget' => array(
                        '1' => array(
                            'button_url' => ueldo_get_website_dir() .'contact/',
                            'background_image_url' => '',
                            'button_icon' => '',
                            'button_in_new_tab' => '',
                            'big_title' => esc_html( __( '-30%', 'ueldo' ) ),
                            'title' => esc_html( __( 'Limited offer!', 'ueldo' ) ),
                            'content' => 'Praesent ac feugiat est. Vestibulum commodo ultrices elementum. Nulla nec fringilla felis.',
                            'button_text' => esc_html( __( 'Schedule a Visit', 'ueldo' ) )
                        ),
                        '_multiwidget' => true
                    ),
                    'widget_media_gallery' => array( '_multiwidget' => true ),
                    'ueldo_custom_sidebars' => array(
                        'next-custom-sidebar-id' => '2',
                        'sidebars' => array( '1' => esc_html( __( 'Service Pages', 'ueldo' ) ) )
                    ),
                    'sidebars_widgets' => array(
                        'wp_inactive_widgets' => array(),
                        'ueldo-custom-sidebar-1' => array(
                            '0' => 'ueldo_call_to_action_widget-1',
                            '1' => 'nav_menu-2'
                        ),
                        'blog-sidebar' => array(
                            '0' => 'search-1',
                            '1' => 'ueldo_popular_posts_widget-1',
                            '2' => 'tag_cloud-1',
                            '3' => 'nav_menu-1'
                        ),
                        'array_version' => 3
                    )
                );

                # remove temporary variables
                unset( $temp );

                # walk for each options
                foreach( $sw_data as $option_key => $option_data ) {

                    # update option
                    update_option( $option_key, $option_data );
                }
            }

           /**
            *
            * get dynamic elements replacements
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) || in_array( 'pages', $parts, true ) ) {

                # get dynamic elements replacements
                $replacements = self::get_dynamic_elements_replacements( self::find_dynamic_elements( self::get_vc_contents() ), $icons, self::get_default_replacements() );
            }

           /**
            *
            * install theme options
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) ) {

                # update theme options
                update_option( 'ueldo_theme_options', self::get_theme_options_array() );

                # set additional content before side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_before_all', self::do_content_replacements( self::get_vc_contents( 'additional-before-side-menu' ), $replacements ) );

                # set additional content after side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_after_all', self::do_content_replacements( self::get_vc_contents( 'additional-after-side-menu' ), $replacements ) );

                # clear theme mods - background color and image
                remove_theme_mod( 'background_color' );
                remove_theme_mod( 'background_position_x' );
                remove_theme_mod( 'background_position_y' );
                remove_theme_mod( 'background_repeat' );
                remove_theme_mod( 'background_attachment' );
                remove_theme_mod( 'background_size' );
                remove_theme_mod( 'background_image' );
            }

           /**
            *
            * fill pages contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # walk for each pages
                foreach( self::get_solution( 'pages-ids' ) as $page_slug => $page_id ) {

                    # not for blog page
                    if( $page_slug == 'blog' ) continue;

                    # update page content
                    $result = wp_update_post( array(
                        'ID' => esc_attr( $page_id ),
                        'post_content' => self::do_content_replacements( self::get_vc_contents( esc_attr( $page_slug ) ), $replacements )
                    ));
                }

                # remove temporary variables
                unset( $replacements );
            }

           /**
            *
            * update permalinks structure
            *
            */

            if( $parts == 'all' || in_array( 'permalinks-structure', $parts, true ) ) {

                # global variable
                global $wp_rewrite;

                # write the rule
                $wp_rewrite -> set_permalink_structure( '/%postname%/' );

                # set the option
                update_option( 'rewrite_rules', false );

                # flush the rules and tell it to write htaccess
                $wp_rewrite -> flush_rules( true );
            }

           /**
            *
            * demo data installed
            *
            */

            exit( '{ "status": "ok" }' );
        }

       /**
        *
        * get possible data parts
        *
        */

        public static function get_possible_data_parts() {

            # return result
            return( array(
                'menus' => esc_html( __( 'Menus', 'ueldo' ) ),
                'posts' => esc_html( __( 'Posts', 'ueldo' ) ),
                'pages' => esc_html( __( 'Pages', 'ueldo' ) ),
                'theme-options' => esc_html( __( 'Theme options', 'ueldo' ) ),
                'forms' => esc_html( __( 'Forms', 'ueldo' ) ),
                'sidebars-and-widgets' => esc_html( __( 'Sidebars & widgets', 'ueldo' ) ),
                'revolution-slider-sliders' => esc_html( __( 'Revolution Slider sliders', 'ueldo' ) ),
                'permalinks-structure' => esc_html( __( 'Permalinks structure', 'ueldo' ) )
            ));
        }

       /**
        *
        * get list of required plugins
        *
        */

        public static function get_required_plugins( $parts ) {

            # all data
            if( !is_array( $parts ) && $parts == 'all' ) {

                # return list of required plugins
                return( array(
                    'ueldo',
                    'visual-composer',
                    'revolution-slider',
                    'contact-form-7'
                ));
            }

            # selected parts
            else {

                # prepare array of required plugins
                $result = array( 'ueldo' );

                # do we have to add pages?
                if( in_array( 'pages', $parts, true ) ) {

                    # return list of required plugins
                    return( array(
                        'visual-composer',
                        'revolution-slider',
                        'contact-form-7'
                    ));
                }

                # do we have to add theme options?
                if( in_array( 'theme-options', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'visual-composer' ) );
                }

                # do we have to add forms?
                if( in_array( 'forms', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'contact-form-7' ) );
                }

                # do we have to add revolution slider sliders?
                if( in_array( 'revolution-slider-sliders', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'revolution-slider' ) );
                }

                # return result
                return( $result );
            }
        }

       /**
        *
        * get default replacements
        *
        */

        public static function get_default_replacements() {

            # add logo image
            $logo_image_id = ueldo_add_demo_assets::add_image( 'dentist-logo' );

            # add social icons menu
            $social_menu_id = ueldo_add_demo_assets::add_menu( 'dentist-social-menu' );

            # return result
            return( array(
                '{ueldopredefinedsections:googlemap|context:dentist}' => 'google_map_id="1"',
                '{ueldopredefinedsections:openinghours|context:dentist}' => 'status="1"',
                '{ueldopredefinedsections:image|context:dentist-logo}' => ( $logo_image_id == false ? '' : 'image="'. esc_attr( $logo_image_id ) .'"' ),
                '{ueldopredefinedsections:sidebar|context:dentist}' => 'sidebar_id="ueldo-custom-sidebar-1"',
                '{ueldopredefinedsections:menu|context:dentist-social-menu}' => ( $social_menu_id == false ? '' : 'menu_id="'. esc_attr( $social_menu_id ) .'"' )
            ));
        }

       /**
        *
        * get trusted solution
        *
        */

        public static function get_trusted_solution( $type, $solution ) {

            # do we have solution found?
            if( !empty( $solution ) ) return( $solution );

            # switch by solution type
            switch( $type ) {

                # get most similar elements
                case 'main-menu-slug': return( self::get_most_similar_element( 'menu_slug', esc_html( __( 'Main menu - Dentist template', 'ueldo' ) ) ) );
                case '404-page-id': return( self::get_most_similar_element( 'page', esc_html( __( '404 page', 'ueldo' ) ) ) );
                case 'footer-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Footer', 'ueldo' ) ) ) );
                case 'header-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Header', 'ueldo' ) ) ) );
                case 'sticky-header-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Sticky header', 'ueldo' ) ) ) );
                case 'blog-responsive-margin-top-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Blog responsive margin top', 'ueldo' ) ) ) );
            }

            # nothing found
            return( false );
        }

       /**
        *
        * get theme options array
        *
        */

        public static function get_theme_options_array() {

            # return result
            return( array(
                '404-page-id' => array( 'all' => self::get_trusted_solution( '404-page-id', self::get_solution( 'pages-ids', '404-page' ) ) ),
                'blog-posts-list-style' => array(
                    'posts-list-style' => 'default',
                    'display-post-data-under-title' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'no'
                ),
                'blog-sidebar' => array(
                    'posts-list' => 'yes-right',
                    'single-post' => 'yes-right',
                    'responsive-style' => 'static'
                ),
                'boxed-website' => array(
                    'enabled' => 'no',
                    'large-content-width' => '1100',
                    'large-content-space' => '50',
                    'medium-content-width' => '890',
                    'medium-content-space' => '50',
                    'small-content-width' => '665',
                    'small-content-space' => '50'
                ),
                'comment-textarea-at-top' => 'yes',
                'facebook-fanpage-url' => array( 'all' => 'https://www.facebook.com/envato' ),
                'featured-image-on-lists-only' => 'no',
                'fonts' => array(
                    'general-font-family' => array( 'all' => 'Roboto' ),
                    'general-font-weight' => array( 'all' => '300' ),
                    'general-font-subset' => array( 'all' => 'latin' ),
                    'general-font-smoothing' => array( 'all' => 'yes' ),
                    'general-bold-font-family' => array( 'all' => 'Roboto' ),
                    'general-bold-font-weight' => array( 'all' => '600' ),
                    'general-bold-font-subset' => array( 'all' => 'latin' ),
                    'general-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-font-family' => array( 'all' => 'Roboto' ),
                    'menu-font-weight' => array( 'all' => '500' ),
                    'menu-font-subset' => array( 'all' => 'latin' ),
                    'menu-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-font-family' => array( 'all' => 'Roboto' ),
                    'headings-font-weight' => array( 'all' => '500' ),
                    'headings-font-subset' => array( 'all' => 'latin' ),
                    'headings-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-slim-font-family' => array( 'all' => 'Roboto' ),
                    'headings-slim-font-weight' => array( 'all' => '300' ),
                    'headings-slim-font-subset' => array( 'all' => 'latin' ),
                    'headings-slim-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-bold-font-family' => array( 'all' => 'Roboto' ),
                    'headings-bold-font-weight' => array( 'all' => '900' ),
                    'headings-bold-font-subset' => array( 'all' => 'latin' ),
                    'headings-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-subtitle-font-family' => array( 'all' => 'Roboto' ),
                    'headings-subtitle-font-weight' => array( 'all' => '700' ),
                    'headings-subtitle-font-subset' => array( 'all' => 'latin' ),
                    'headings-subtitle-font-smoothing' => array( 'all' => 'yes' ),
                    'buttons-font-family' => array( 'all' => 'Roboto' ),
                    'buttons-font-weight' => array( 'all' => '700' ),
                    'buttons-font-subset' => array( 'all' => 'latin' ),
                    'buttons-font-smoothing' => array( 'all' => 'yes' ),
                    'form-fields-font-family' => array( 'all' => 'Roboto' ),
                    'form-fields-font-weight' => array( 'all' => '400' ),
                    'form-fields-font-subset' => array( 'all' => 'latin' ),
                    'form-fields-font-smoothing' => array( 'all' => 'yes' ),
                    'blockquote-font-family' => array( 'all' => 'Roboto' ),
                    'blockquote-font-weight' => array( 'all' => '500' ),
                    'blockquote-font-subset' => array( 'all' => 'latin' ),
                    'blockquote-font-smoothing' => array( 'all' => 'yes' ),
                    'alert-messages-font-family' => array( 'all' => 'Roboto' ),
                    'alert-messages-font-weight' => array( 'all' => '400' ),
                    'alert-messages-font-subset' => array( 'all' => 'latin' ),
                    'alert-messages-font-smoothing' => array( 'all' => 'yes' )
                ),
                'footer-content' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'footer-page-id', self::get_solution( 'pages-ids', 'footer' ) ) ),
                    'position' => array( 'all' => 'static' )
                ),
                'google-maps' => array(
                    'api-key' => '',
                    'next-map-id' => '2',
                    'google-map-1-title' => esc_html( __( 'Company location', 'ueldo' ) ),
                    'google-map-1-center-lat' => '40.713658',
                    'google-map-1-center-lng' => '-74.005367',
                    'google-map-1-zoom' => '16',
                    'google-map-1-markers-next-marker-id' => '2',
                    'google-map-1-markers-marker-1-title' => esc_html( __( 'New marker', 'ueldo' ) ),
                    'google-map-1-markers-marker-1-lat' => '40.713658',
                    'google-map-1-markers-marker-1-lng' => '-74.005367',
                    'google-map-1-markers-marker-1-use-custom-marker' => 'yes-image',
                    'google-map-1-markers-marker-1-custom-icon-library' => 'fontawesome',
                    'google-map-1-markers-marker-1-custom-icon' => 'fa fa-address-book',
                    'google-map-1-markers-marker-1-custom-icon-size' => '18',
                    'google-map-1-markers-marker-1-custom-icon-width' => '36',
                    'google-map-1-markers-marker-1-custom-icon-height' => '36',
                    'google-map-1-markers-marker-1-custom-icon-border-radius' => 'circle',
                    'google-map-1-markers-marker-1-custom-icon-border-radius-px' => '4',
                    'google-map-1-markers-marker-1-custom-icon-color' => '#44806b',
                    'google-map-1-markers-marker-1-custom-icon-background-color' => '#fff',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-horizontal-length' => '0',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-vertical-length' => '5',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-blur-radius' => '20',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-spread-radius' => '0',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-color' => 'rgba( 0, 0, 0, 0.1 )',
                    'google-map-1-markers-marker-1-custom-marker-image' => esc_url( get_template_directory_uri() .'/_assets/_img/_templates-images/ueldo-dentist-map-marker.png' ),
                    'google-map-1-custom-style' => '[{"featureType":"administrative","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":20}]},{"featureType":"road","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":40}]},{"featureType":"water","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-10},{"lightness":30}]},{"featureType":"landscape.man_made","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":10}]},{"featureType":"landscape.natural","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":60}]},{"featureType":"poi","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]},{"featureType":"transit","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]}]'
                ),
                'header' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'header-page-id', self::get_solution( 'pages-ids', 'header' ) ) ),
                    'position' => array( 'all' => 'static' ),
                    'use-second-header' => array( 'all' => 'yes' ),
                    'get-second-content-from' => array( 'all' => self::get_trusted_solution( 'sticky-header-page-id', self::get_solution( 'pages-ids', 'sticky-header' ) ) ),
                    'second-header-visible-from' => array( 'all' => '730' ),
                    'default-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'second-header-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) )
                ),
                'lazy-load-images' => array(
                    'enabled' => 'no',
                    'threshold' => '0'
                ),
                'loader-animation' => array(
                    'enabled' => 'yes',
                    'style' => '01',
                    'add-logo' => 'no',
                    'space-between-logo-and-spinner' => '30',
                    'logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'custom-colors-enabled' => 'no',
                    'custom-colors-background' => '#fff',
                    'custom-colors-spinner' => '#44806b'
                ),
                'local-scrolling-links-animation' => array(
                    'enabled' => 'yes',
                    'animation-speed' => '1000'
                ),
                'opening-hours-status' => array(
                    'next-status-id' => '2',
                    'status-1-title' => esc_html( __( 'Opening hours', 'ueldo' ) ),
                    'status-1-timezone' => 'use-browser',
                    'status-1-rules-next-rule-id' => '5',
                    'status-1-rules-rule-1-title' => esc_html( __( 'Monday', 'ueldo' ) ),
                    'status-1-rules-rule-1-apply-for-monday' => 'on',
                    'status-1-rules-rule-1-all-day-closed' => 'no',
                    'status-1-rules-rule-1-next-opening-hours-id' => '2',
                    'status-1-rules-rule-1-opening-hours-1-ignored' => 'no',
                    'status-1-rules-rule-1-opening-hours-1-from-hour' => '10',
                    'status-1-rules-rule-1-opening-hours-1-from-minutes' => '00',
                    'status-1-rules-rule-1-opening-hours-1-to-hour' => '23',
                    'status-1-rules-rule-1-opening-hours-1-to-minutes' => '00',
                    'status-1-rules-rule-2-title' => esc_html( __( 'Tuesday - Thursday', 'ueldo' ) ),
                    'status-1-rules-rule-2-apply-for-tuesday' => 'on',
                    'status-1-rules-rule-2-apply-for-wednesday' => 'on',
                    'status-1-rules-rule-2-apply-for-thursday' => 'on',
                    'status-1-rules-rule-2-all-day-closed' => 'no',
                    'status-1-rules-rule-2-next-opening-hours-id' => '2',
                    'status-1-rules-rule-2-opening-hours-1-ignored' => 'no',
                    'status-1-rules-rule-2-opening-hours-1-from-hour' => '09',
                    'status-1-rules-rule-2-opening-hours-1-from-minutes' => '00',
                    'status-1-rules-rule-2-opening-hours-1-to-hour' => '14',
                    'status-1-rules-rule-2-opening-hours-1-to-minutes' => '00',
                    'status-1-rules-rule-3-title' => esc_html( __( 'Friday - Saturday', 'ueldo' ) ),
                    'status-1-rules-rule-3-apply-for-friday' => 'on',
                    'status-1-rules-rule-3-apply-for-saturday' => 'on',
                    'status-1-rules-rule-3-all-day-closed' => 'no',
                    'status-1-rules-rule-3-next-opening-hours-id' => '2',
                    'status-1-rules-rule-3-opening-hours-1-ignored' => 'no',
                    'status-1-rules-rule-3-opening-hours-1-from-hour' => '09',
                    'status-1-rules-rule-3-opening-hours-1-from-minutes' => '00',
                    'status-1-rules-rule-3-opening-hours-1-to-hour' => '23',
                    'status-1-rules-rule-3-opening-hours-1-to-minutes' => '00',
                    'status-1-rules-rule-4-title' => esc_html( __( 'Sunday', 'ueldo' ) ),
                    'status-1-rules-rule-4-apply-for-sunday' => 'on',
                    'status-1-rules-rule-4-all-day-closed' => 'yes',
                    'status-1-rules-rule-4-next-opening-hours-id' => '2',
                    'status-1-rules-rule-4-opening-hours-1-ignored' => 'no',
                    'status-1-rules-rule-4-opening-hours-1-from-hour' => '08',
                    'status-1-rules-rule-4-opening-hours-1-from-minutes' => '00',
                    'status-1-rules-rule-4-opening-hours-1-to-hour' => '16',
                    'status-1-rules-rule-4-opening-hours-1-to-minutes' => '00',
                    'status-1-exceptions-next-exception-id' => '1'
                ),
                'rtl' => array(
                    'is-rtl' => array( 'all' => 'no' ),
                    'load-rtl-admin-styles' => array( 'all' => 'auto' )
                ),
                'side-menu' => array(
                    'style' => 'flying-default-hidden',
                    'menu-key' => array( 'all' => self::get_trusted_solution( 'main-menu-slug', self::get_main_menu_slug() ) ),
                    'menu-link-font-family' => array( 'all' => 'Roboto' ),
                    'menu-link-font-weight' => array( 'all' => '300' ),
                    'menu-link-font-subset' => array( 'all' => 'latin' ),
                    'menu-link-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-position' => 'left',
                    'menu-links-alignment' => 'left',
                    'opacity-animation-enabled' => 'yes',
                    'submenu-links' => 'visible-always',
                    'menu-vertical-alignment' => 'middle',
                    'custom-sizes-enabled' => 'no',
                    'custom-sizes-container-width' => '300',
                    'custom-sizes-menu-link-font-size' => '14',
                    'custom-sizes-menu-link-font-line-height' => '1.0',
                    'custom-sizes-menu-link-font-letter-spacing' => '0',
                    'custom-sizes-menu-link-padding-top-bottom' => '15',
                    'custom-sizes-menu-link-padding-left-right' => '25',
                    'custom-sizes-menu-link-margin-top-bottom' => '0',
                    'custom-sizes-menu-link-margin-left-right' => '0',
                    'custom-sizes-menu-link-bottom-border-width' => '1',
                    'custom-sizes-display-bottom-border-for-last-menu-link' => 'display',
                    'custom-sizes-menu-icon-font-size' => '10',
                    'custom-sizes-menu-icon-margin-top' => '0',
                    'custom-sizes-menu-margin-between-icon-and-title' => '10',
                    'custom-sizes-padding-top-bottom-additional-element-before-menu' => '20',
                    'custom-sizes-padding-left-right-additional-element-before-menu' => '30',
                    'custom-sizes-margin-top-additional-element-before-menu' => '0',
                    'custom-sizes-margin-right-additional-element-before-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-before-menu' => '0',
                    'custom-sizes-margin-left-additional-element-before-menu' => '0',
                    'custom-sizes-padding-top-bottom-additional-element-after-menu' => '20',
                    'custom-sizes-padding-left-right-additional-element-after-menu' => '30',
                    'custom-sizes-margin-top-additional-element-after-menu' => '0',
                    'custom-sizes-margin-right-additional-element-after-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-after-menu' => '0',
                    'custom-sizes-margin-left-additional-element-after-menu' => '0'
                ),
                'single-blog-post-style' => array(
                    'display-post-data-under-title' => 'yes',
                    'blog-post-data-and-title-centered' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'no'
                ),
                'submit-button-position-in-comment-reply-form' => array( 'all' => 'left' ),
                'translate-publication-dates' => 'yes',
                'twitter-api' => array(
                    'oauth-key' => '',
                    'oauth-secret-key' => ''
                ),
                'under-single-blog-post-content-elements' => array(
                    'elements-count' => '3',
                    'element-1-type' => 'tags-and-categories-with-facebook',
                    'element-1-similar-posts-style' => '02',
                    'element-2-type' => 'author-box',
                    'element-2-similar-posts-style' => '02',
                    'element-3-type' => 'next-previous-posts-navigation',
                    'element-3-similar-posts-style' => '02',
                    'element-4-type' => '',
                    'element-4-similar-posts-style' => '02',
                    'element-5-type' => '',
                    'element-5-similar-posts-style' => '02',
                    'element-6-type' => '',
                    'element-6-similar-posts-style' => '02'
                ),
                'vc-sections-on-blog-pages' => array(
                    'posts-list-above' => array( 'all' => self::get_trusted_solution( 'blog-responsive-margin-top-page-id', self::get_solution( 'pages-ids', 'blog-responsive-margin-top' ) ) ),
                    'posts-list-under' => array( 'all' => 'none' ),
                    'single-post-above' => array( 'all' => self::get_trusted_solution( 'blog-responsive-margin-top-page-id', self::get_solution( 'pages-ids', 'blog-responsive-margin-top' ) ) ),
                    'single-post-under' => array( 'all' => 'none' ),
                    'archive-above' => array( 'all' => self::get_trusted_solution( 'blog-responsive-margin-top-page-id', self::get_solution( 'pages-ids', 'blog-responsive-margin-top' ) ) ),
                    'archive-under' => array( 'all' => 'none' ),
                    'search-above' => array( 'all' => self::get_trusted_solution( 'blog-responsive-margin-top-page-id', self::get_solution( 'pages-ids', 'blog-responsive-margin-top' ) ) ),
                    'search-under' => array( 'all' => 'none' )
                ),
                'visual-composer-custom-fonts' => array( 'next-font-id' => '1' ),
                'dynamic-theme-styles-cache' => array(
                    'enabled' => 'no',
                    'clear-cache' => 'all-the-time-when-logged-in'
                ),
                'styles' => array(
                    'general-colors-main-color' => '#44806b',
                    'general-colors-headings-color' => '#382b23',
                    'general-colors-blog-post-data-color' => '#44806b',
                    'general-colors-elements-hover-border-color' => '#d0dad7',
                    'general-colors-elements-inset-border-color' => '#f1f1f1',
                    'general-colors-google-map-marker-icon-color' => '#44806b',
                    'info-box-element-background-color' => '#ffffff',
                    'info-box-element-border-color' => '#ffffff',
                    'font-size-h1' => '42',
                    'font-size-h2' => '36',
                    'font-size-smallest-content' => '14',
                    'header-bar-and-menu-active-or-hover-link-color' => '#44806b',
                    'header-bar-and-menu-submenu-background-color' => '#44806b',
                    'buttons-global-button-background-color' => '#ffffff',
                    'buttons-global-button-text-color' => '#44806b',
                    'buttons-global-button-border-color' => '#f3f1ef',
                    'buttons-global-button-icon-color' => '#44806b',
                    'buttons-global-button-background-color-hover' => '#44806b',
                    'buttons-global-button-border-color-hover' => '#44806b',
                    'buttons-global-button-box-shadow-hover' => '0px 10px 35px 0px rgba(68,128,107,0.25)',
                    'gallery-image-overlay-background-color' => 'rgba(56,43,35,0.45)',
                    'gallery-image-buttons-box-shadow' => '0px 0px 60px 0px rgba(0,0,0,0.25)',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-background-color' => '#44806b',
                    'buttons-form-submit-button-border-color' => '#44806b',
                    'buttons-form-submit-button-box-shadow' => '0px 10px 35px 0px rgba(68,128,107,0.25)',
                    'buttons-form-submit-button-background-color-hover' => '#3f7764',
                    'buttons-form-submit-button-border-color-hover' => '#3f7764',
                    'buttons-form-submit-button-box-shadow-hover' => '0px 10px 35px 0px rgba(63,119,100,0.25)',
                    'forms-checkbox-radio-main-color' => '#44806b',
                    'general-colors-blockquote-color' => '#44806b',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-background-color' => '#44806b',
                    'buttons-call-to-action-widget-button-border-color' => '#44806b',
                    'buttons-call-to-action-widget-button-box-shadow' => '0px 10px 35px 0px rgba(68,128,107,0.25)',
                    'buttons-call-to-action-widget-button-background-color-hover' => '#3f7764',
                    'buttons-call-to-action-widget-button-border-color-hover' => '#3f7764',
                    'buttons-call-to-action-widget-button-box-shadow-hover' => '0px 10px 35px 0px rgba(63,119,100,0.25)',
                    'side-menu-box-shadow' => '-5px 0px 20px 0px rgba(56,43,35,0.15)',
                    'side-menu-background-color' => '#382b23',
                    'side-menu-link-color' => '#a79c95',
                    'side-menu-link-border-bottom-color' => 'rgba(255,255,255,0.03)',
                    'side-menu-link-border-bottom-color-hover' => 'rgba(255,255,255,0.03)',
                    'side-menu-active-link-border-bottom-color' => 'rgba(255,255,255,0.03)'
                )
            ));
        }

       /**
        *
        * get default contents
        *
        */

        public static function get_vc_contents( $page_slug = false ) {

            # array of pages contents
            $contents = array(

                'home' => '[vc_section full_width="stretch_row_content" css=".vc_custom_1511811050184{margin-top: -38px !important;}"][vc_row][vc_column][rev_slider {ueldopredefinedsections:revslider|context:dentist-home-page}][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_73855054048304"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_heading class_name="ueldo_vc_element_15035016293241" text_align="center" heading_subtitle_text="'. esc_html( __( 'Dental Clinic', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15035016814528" heading_text="'. esc_html( __( 'Dental care at the highest level', 'ueldo' ) ) .'" font_family="headings-slim-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_tabs class_name="ueldo_vc_element_15035018279901" custom_colors_enabled="custom_settings" tabs_selector_icon_color_hover="#cec4b9"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_69434456083924" single_tab_title="'. esc_html( __( 'Dental Implants', 'ueldo' ) ) .'" {ueldopredefinedsections:icon|key:flaticon-implants,flaticon-medical|url:https://www.flaticon.com/free-icon/implants_139382|slug:icon_}][ueldo_shortcode_inline_container class_name="ueldo_vc_element_67426186469696"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_75343348794116" large_width_percentage="15%" medium_custom_sizes="yes" medium_width_percentage="10%" medium_content_alignment="center" small_custom_sizes="yes" small_width_percentage="5%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_13011006860752" large_width_percentage="70%" large_content_alignment="center" medium_custom_sizes="yes" medium_width_percentage="80%" medium_content_alignment="center" small_custom_sizes="yes" small_width_percentage="90%" small_content_alignment="center"][vc_column_text]Aenean non mi id erat luctus viverra. Pellentesque dapibus risus in risus elementum, ac iaculis ante lacinia. Nunc pharetra molestie risus id tincidunt. Aliquam nec purus congue, varius ex tristique, gravida est. Curabitur eleifend volutpat lobortis. Sed consequat mollis laoreet. Aliquam quis semper augue. Nunc sodales aliquam nulla et eleifend. Aliquam erat volutpat. Proin at scelerisque purus. Aliquam consectetur vel lorem at commodo. Pellentesque dapibus risus in risus elementum.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_44347273033492" large_height="25"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_tabs_single_tab][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_68324075777354" single_tab_title="'. esc_html( __( 'Porcelain Veneers', 'ueldo' ) ) .'" {ueldopredefinedsections:icon|key:flaticon-implants,flaticon-medical|url:https://www.flaticon.com/free-icon/implants_139399|slug:icon_}][ueldo_shortcode_inline_container class_name="ueldo_vc_element_32734553571410"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_29037027081696" large_width_percentage="15%" medium_custom_sizes="yes" medium_width_percentage="10%" medium_content_alignment="center" small_custom_sizes="yes" small_width_percentage="5%" small_content_alignment="center"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_69171051280049" large_width_percentage="70%" large_content_alignment="center" medium_custom_sizes="yes" medium_width_percentage="80%" medium_content_alignment="center" small_custom_sizes="yes" small_width_percentage="90%" small_content_alignment="center"][vc_column_text]Fusce tincidunt felis diam, a tempor nisl eleifend sed. Nunc augue dui, rhoncus sit amet lacinia in, gravida tincidunt ex. Vestibulum et risus bibendum velit ultrices malesuada et a odio. Cras quis diam a lacus laoreet fermentum. Sed gravida quis nisi nec consectetur. Sed vel semper tortor, sit amet convallis risus. Phasellus ac rutrum ante. Vivamus id egestas enim. Etiam nec magna sapien. Nam fringilla posuere accumsan. Vivamus sagittis, diam in imperdiet imperdiet, lacus risus suscipit leo. Sed consequat.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_51017041882260" large_height="25"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_tabs_single_tab][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_29082791407002" single_tab_title="'. esc_html( __( 'Dental Crowns', 'ueldo' ) ) .'" {ueldopredefinedsections:icon|key:flaticon-molar,flaticon-medical|url:https://www.flaticon.com/free-icon/molar_139404|slug:icon_}][ueldo_shortcode_inline_container class_name="ueldo_vc_element_29955406198033"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_82299418098936" large_width_percentage="15%" medium_custom_sizes="yes" medium_width_percentage="10%" medium_content_alignment="center" small_custom_sizes="yes" small_width_percentage="5%" small_content_alignment="center"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_74777482197057" large_width_percentage="70%" large_content_alignment="center" medium_custom_sizes="yes" medium_width_percentage="80%" medium_content_alignment="center" small_custom_sizes="yes" small_width_percentage="90%" small_content_alignment="center"][vc_column_text]Etiam at condimentum eros, quis lobortis ligula. Etiam id odio vitae erat sagittis tristique. Aenean ac purus quis tellus fringilla lobortis sit amet vitae augue. Nunc viverra nulla sed mi lacinia placerat. Orci varius natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Integer et enim in orci scelerisque hendrerit ut vel est. Pellentesque non nibh non ipsum mollis auctor. Sed porttitor, dui et gravida interdum, metus orci sollicitudin mauris, at mollis mi nisi nec ligula. Phasellus nisl eros.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_60145265231660" large_height="25"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_tabs_single_tab][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_73970136618907" single_tab_title="'. esc_html( __( 'Teeth Whitening', 'ueldo' ) ) .'" {ueldopredefinedsections:icon|key:flaticon-molar,flaticon-medical|url:https://www.flaticon.com/free-icon/molar_139370|slug:icon_}][ueldo_shortcode_inline_container class_name="ueldo_vc_element_58521266876981"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_90270134652574" large_width_percentage="15%" medium_custom_sizes="yes" medium_width_percentage="10%" medium_content_alignment="center" small_custom_sizes="yes" small_width_percentage="5%" small_content_alignment="center"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_51173932361760" large_width_percentage="70%" large_content_alignment="center" medium_custom_sizes="yes" medium_width_percentage="80%" medium_content_alignment="center" small_custom_sizes="yes" small_width_percentage="90%" small_content_alignment="center"][vc_column_text]Suspendisse ipsum mauris, eleifend et erat ac, facilisis varius lectus. Sed tincidunt bibendum scelerisque. Etiam erat libero, venenatis sit amet lacinia eu, vehicula in mauris. Proin mattis tempor urna nec laoreet. Sed maximus placerat tortor, at tempus ipsum consequat nec. Aenean dictum vehicula lectus eu porta. Curabitur dapibus fringilla purus. Maecenas posuere lacinia lorem at hendrerit. Proin iaculis maximus mi, quis elementum lectus euismod sed. Vivamus volutpat gravida tincidunt. Praesent turpis elit.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_84342740683152" large_height="25"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_54177971519127"][/vc_column][/vc_row][/vc_section][vc_section][vc_row full_width="stretch_row_content_no_spaces" el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_tabs class_name="ueldo_vc_element_15035025785268" tabs_content_style="style-03" base_height="620"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_15035025993615" single_tab_title="'. esc_html( __( 'Dental services', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_15035026141182" heading_subtitle_text="'. esc_html( __( 'Full-time availability', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15035026347364" heading_text="'. esc_html( __( 'Professional dental services near your home', 'ueldo' ) ) .'" font_family="headings-slim-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Aenean non mi id erat luctus viverra. Pellentesque dapibus risus in risus elementum, ac iaculis ante lacinia. Nunc pharetra molestie risus id tincidunt. Aliquam nec purus congue, varius ex tristique, gravida est.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_21714274588811" large_height="25"][ueldo_shortcode_info_box class_name="ueldo_vc_element_4537729812885" content_alignment="left" content_position="inline" heading_vertical_alignment="top" info_box_title="'. esc_html( __( 'Long opening hours', 'ueldo' ) ) .'" info_box_subtitle="Aliquam eleifend diam libero, a efficitur ex tempor lacinia. Ut pharetra dapibus aliquam. Vestibulum non metus." info_element_width="38" info_element_height="38" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-clock,flaticon-square|url:https://www.flaticon.com/free-icon/clock_149313|slug:info_element_icon_} info_element_icon_custom_size_enabled="custom_settings" info_element_icon_custom_size="38" custom_colors_enabled="custom_settings" info_element_icon_color="#cec4b9" info_element_icon_color_hover="#cec4b9" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_23680819638346" large_height="30"][ueldo_shortcode_info_box class_name="ueldo_vc_element_5112788979415" content_alignment="left" content_position="inline" heading_vertical_alignment="top" info_box_title="'. esc_html( __( '24/7 emergency call', 'ueldo' ) ) .'" info_box_subtitle="Aliquam eleifend diam libero, a efficitur ex tempor lacinia. Ut pharetra dapibus aliquam. Vestibulum non metus." info_element_width="38" info_element_height="38" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-call-center,flaticon-technology|url:https://www.flaticon.com/free-icon/call-center_270999|slug:info_element_icon_} info_element_icon_custom_size_enabled="custom_settings" info_element_icon_custom_size="38" custom_colors_enabled="custom_settings" info_element_icon_color="#cec4b9" info_element_icon_color_hover="#cec4b9" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][/vc_column][/vc_row][/vc_section][vc_section el_id="opening-hours"][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_67516354459963"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15035054856661"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15035054892088" large_width_type="calc" large_width_calc_px="15"][ueldo_shortcode_heading class_name="ueldo_vc_element_15035052227946" heading_subtitle_text="'. esc_html( __( 'Visit our Clinic', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15035052881425" heading_text="'. esc_html( __( 'Opening hours', 'ueldo' ) ) .'" font_family="headings-slim-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Nulla at diam ornare, aliquam urna vel, commodo urna. Nam id risus a est luctus consectetur quis eget libero. Suspendisse potenti. Pellentesque habitant morbi tristique senectus et netus et malesuada fames.[/vc_column_text][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15035054998744" large_width_type="px" large_width_px="15"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15041656417589" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15035055174772"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_85587676599357" large_width_type="px" large_width_px="15" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_81757365506311" large_width_type="calc" large_width_calc_px="15" extra_small_custom_sizes="yes"][ueldo_shortcode_opening_hours_box class_name="ueldo_vc_element_15035053639183" switch_elements_to_one_line_from="small" {ueldopredefinedsections:openinghours|context:dentist}][ueldo_shortcode_opening_hours_box_element class_name="ueldo_vc_element_14811559028579" opening_hours_element_title="'. esc_html( __( 'Monday', 'ueldo' ) ) .'"][ueldo_shortcode_opening_hours_box_element class_name="ueldo_vc_element_81269661744190" opening_hours_element_title="'. esc_html( __( 'Tuesday - Thursday', 'ueldo' ) ) .'" opening_hours_element_value="'. esc_html( __( '9:00am - 2:00pm', 'ueldo' ) ) .'"][ueldo_shortcode_opening_hours_box_element class_name="ueldo_vc_element_22374531013656" opening_hours_element_title="'. esc_html( __( 'Friday - Saturday', 'ueldo' ) ) .'" opening_hours_element_value="'. esc_html( __( '9:00am - 11:00pm', 'ueldo' ) ) .'"][ueldo_shortcode_opening_hours_box_element class_name="ueldo_vc_element_43223190349463" opening_hours_element_title="'. esc_html( __( 'Sunday', 'ueldo' ) ) .'" opening_hours_element_value="'. esc_html( __( 'Closed', 'ueldo' ) ) .'"][/ueldo_shortcode_opening_hours_box][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15036463549717" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-clock,flaticon-square|url:https://www.flaticon.com/free-icon/clock_149313|slug:icon_} icon_size="150" icon_color="rgba(0,0,0,0.02)" icon_rotate="135deg" icon_alignment="right" large_width_type="px" large_width_px="150" large_height_type="px" large_height_px="150" large_layer_position="center_right" large_margin_top="-75" large_margin_right="-60"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_21030182149895"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15114317128635" layer_for_row_or_section="section" layer_z_index="0" color="#f3f1ef"][ueldo_shortcode_gap class_name="ueldo_vc_element_74081424419114"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_heading class_name="ueldo_vc_element_1503508452945" text_align="center" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Testimonials', 'ueldo' ) ) .'" custom_heading_subtitle_font_color_enabled="custom_settings" heading_subtitle_font_color="#44806b" custom_margin_bottom="55"][/ueldo_shortcode_heading][ueldo_shortcode_full_width_testimonials class_name="ueldo_vc_element_15035082374355" type="persons" author_name_position="under-person-images" content_position="above" custom_colors_enabled="custom_settings" background_color="#f3f1ef" author_name_color="#44806b" persons_images_box_shadow_color="rgba(255,255,255,0.01)" persons_images_box_shadow_color_hover="rgba(255,255,255,0.01)" active_person_image_box_shadow_color="rgba(0,0,0,0.2)" active_person_image_box_shadow_color_hover="rgba(0,0,0,0.2)" next_prev_arrow_color="#44806b" next_prev_arrow_container_background="#f3f1ef" next_prev_arrow_container_background_hover="#f3f1ef" next_prev_arrow_container_border_color="#f3f1ef" next_prev_arrow_container_border_color_hover="#f3f1ef" next_prev_arrow_container_box_shadow_color="rgba(255,255,255,0.01)" next_prev_arrow_container_box_shadow_color_hover="rgba(255,255,255,0.01)"][ueldo_shortcode_full_width_testimonials_single_testimonial class_name="ueldo_vc_element_86327794843274" author_name="'. esc_html( __( 'Gregory Queen', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_60518771671685" heading_tag="p" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_35133738614126" heading_text="Phasellus ligula dolor, sollicitudin quis pretium id, congue vel nulla. Etiam efficitur magna quis gravida faucibus. Pellentesque vel erat et lacus, rutrum nibh urna pellentesque, non vulputate neque ipsum. Cras commodo, neque nec." custom_font_size_and_line_height_enabled="custom_settings" font_size="21" line_height="1.8" custom_font_color_enabled="custom_settings" font_color="#382b23" font_color_hover="#382b23"][/ueldo_shortcode_heading][/ueldo_shortcode_full_width_testimonials_single_testimonial][ueldo_shortcode_full_width_testimonials_single_testimonial class_name="ueldo_vc_element_70655209146405" author_name="'. esc_html( __( 'John McDonovan', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_20557739469881" heading_tag="p" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_74346872948845" heading_text="Phasellus ligula dolor, sollicitudin quis pretium id, congue vel nulla. Etiam efficitur magna quis gravida faucibus. Pellentesque vel erat et lacus, rutrum nibh urna pellentesque, non vulputate neque ipsum. Cras commodo, neque nec." custom_font_size_and_line_height_enabled="custom_settings" font_size="21" line_height="1.8" custom_font_color_enabled="custom_settings" font_color="#382b23" font_color_hover="#382b23"][/ueldo_shortcode_heading][/ueldo_shortcode_full_width_testimonials_single_testimonial][ueldo_shortcode_full_width_testimonials_single_testimonial class_name="ueldo_vc_element_14760151364788" author_name="'. esc_html( __( 'Susane Doe', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_59720496075291" heading_tag="p" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_23882383315163" heading_text="Phasellus ligula dolor, sollicitudin quis pretium id, congue vel nulla. Etiam efficitur magna quis gravida faucibus. Pellentesque vel erat et lacus, rutrum nibh urna pellentesque, non vulputate neque ipsum. Cras commodo, neque nec." custom_font_size_and_line_height_enabled="custom_settings" font_size="21" line_height="1.8" custom_font_color_enabled="custom_settings" font_color="#382b23" font_color_hover="#382b23"][/ueldo_shortcode_heading][/ueldo_shortcode_full_width_testimonials_single_testimonial][ueldo_shortcode_full_width_testimonials_single_testimonial class_name="ueldo_vc_element_48806224217653" author_name="'. esc_html( __( 'Mike Green', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_88214805911692" heading_tag="p" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_91800210319664" heading_text="Phasellus ligula dolor, sollicitudin quis pretium id, congue vel nulla. Etiam efficitur magna quis gravida faucibus. Pellentesque vel erat et lacus, rutrum nibh urna pellentesque, non vulputate neque ipsum. Cras commodo, neque nec." custom_font_size_and_line_height_enabled="custom_settings" font_size="21" line_height="1.8" custom_font_color_enabled="custom_settings" font_color="#382b23" font_color_hover="#382b23"][/ueldo_shortcode_heading][/ueldo_shortcode_full_width_testimonials_single_testimonial][ueldo_shortcode_full_width_testimonials_single_testimonial class_name="ueldo_vc_element_95621505603694" author_name="'. esc_html( __( 'Helen Smith', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_95325176720622" heading_tag="p" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_81581888414687" heading_text="Phasellus ligula dolor, sollicitudin quis pretium id, congue vel nulla. Etiam efficitur magna quis gravida faucibus. Pellentesque vel erat et lacus, rutrum nibh urna pellentesque, non vulputate neque ipsum. Cras commodo, neque nec." custom_font_size_and_line_height_enabled="custom_settings" font_size="21" line_height="1.8" custom_font_color_enabled="custom_settings" font_color="#382b23" font_color_hover="#382b23"][/ueldo_shortcode_heading][/ueldo_shortcode_full_width_testimonials_single_testimonial][/ueldo_shortcode_full_width_testimonials][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_95334987137394"][/vc_column][/vc_row][/vc_section][vc_section el_id="pricing"][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_69277889511828"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_heading class_name="ueldo_vc_element_15035090586827" text_align="center" heading_subtitle_text="'. esc_html( __( 'Pricing table', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15035090747325" heading_text="Nullam tempor felis nulla eget venenati" font_family="headings-slim-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15035091202241"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15035091236811" large_width_percentage="15%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15035091321792" large_width_percentage="70%" large_content_alignment="center"][vc_column_text]Aliquam erat volutpat. Pellentesque suscipit elementum eleifend, ligula. Ut lorem. In malesuada quis, venenatis nisl am diam elit ornare interdum. Vitae wisi eget nibh condimentum et, pharetra sem.[/vc_column_text][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_15035094323526"][ueldo_shortcode_pricing_list class_name="ueldo_vc_element_15035092363523"][ueldo_shortcode_pricing_list_group class_name="ueldo_vc_element_15035092414588" title="'. esc_html( __( 'Dental services', 'ueldo' ) ) .'" {ueldopredefinedsections:icon|key:flaticon-premolar,flaticon-medical|url:https://www.flaticon.com/free-icon/premolar_139371|slug:icon_}][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_15035093232601" title="'. esc_html( __( 'Comprehensive oral exam (detailed)', 'ueldo' ) ) .'" price="$66"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_15035093339374" title="'. esc_html( __( 'X-ray (per exposure)', 'ueldo' ) ) .'" price="$45"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_1503509345141" title="'. esc_html( __( 'Scale and clean (removal of plaque and calculus)', 'ueldo' ) ) .'" price="$118"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_15035093572626" title="'. esc_html( __( 'Fluoride treatment', 'ueldo' ) ) .'" price="$84"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_15035093779356" title="'. esc_html( __( 'Fissure sealing (per tooth)', 'ueldo' ) ) .'" price="$59"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_1503509389167" title="'. esc_html( __( 'Tooth extraction', 'ueldo' ) ) .'" price="$184"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_15035094442042" title="'. esc_html( __( 'Preparation of root canal (chemo-mechanical) - one canal', 'ueldo' ) ) .'" price="$300"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_15035094693827" title="'. esc_html( __( 'Filling - anterior tooth', 'ueldo' ) ) .'" price="$149"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_15035094841805" title="'. esc_html( __( 'Filling - posterior tooth - 2 surfaces', 'ueldo' ) ) .'" price="$199"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_15035095322856" title="'. esc_html( __( 'Denture (complete maxillary)', 'ueldo' ) ) .'" price="$1299"][ueldo_shortcode_button class_name="ueldo_vc_element_96646974269701" button_visible_on_devices="large,extra-small" button_text="'. esc_html( __( 'Schedule a Visit', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" show_button_icon="yes" custom_sizes_enabled="custom_settings" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="#44806b" standard_button_background_color_hover="#3f7764" standard_button_border_color="#44806b" standard_button_border_color_hover="#3f7764" standard_button_box_shadow_vertical_length="10" standard_button_box_shadow_blur_radius="35" standard_button_box_shadow_color="rgba(68,128,107,0.25)" standard_button_box_shadow_color_hover="rgba(63,119,100,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_80601060691547" button_visible_on_devices="medium,small" button_text="'. esc_html( __( 'Schedule a Visit', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_position="under-left" custom_sizes_enabled="custom_settings" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="#44806b" standard_button_background_color_hover="#3f7764" standard_button_border_color="#44806b" standard_button_border_color_hover="#3f7764" standard_button_box_shadow_vertical_length="10" standard_button_box_shadow_blur_radius="35" standard_button_box_shadow_color="rgba(68,128,107,0.25)" standard_button_box_shadow_color_hover="rgba(63,119,100,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][/ueldo_shortcode_pricing_list_group][/ueldo_shortcode_pricing_list][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_54930364547060"][/vc_column][/vc_row][/vc_section][vc_section][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_heading class_name="ueldo_vc_element_15035096053213" text_align="center" heading_subtitle_text="'. esc_html( __( 'Meet our team', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15035096195813" heading_text="'. esc_html( __( 'High experienced doctors', 'ueldo' ) ) .'" font_family="headings-slim-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text][ueldo_next_prev_loop_icons loop_id="15035099112431"][/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15035632046218" large_height="25"][ueldo_shortcode_loop class_name="ueldo_vc_element_15035099112431" use_separate_next_prev_arrows="separated" custom_next_prev_arrows_settings="custom_settings" arrow_padding_top_bottom="9" arrow_padding_left_right="11" arrow_border_radius="4" arrow_border_width="1"][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_1654357463418"][ueldo_shortcode_image class_name="ueldo_vc_element_97329945125919" large_height_px="200" small_custom_sizes="yes" small_height_px="280" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(0,0,0,0.1)"][ueldo_shortcode_heading class_name="ueldo_vc_element_67250311067188" heading_tag="h4" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_8233205436375" heading_text="'. esc_html( __( 'Anthony Green', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<strong>'. esc_html( __( 'Owner', 'ueldo' ) ) .'</strong><br /><br /> Aliquam feugiat eget massa et eleifend. Cras eros libero, vulputate vel nunc vel, egestas luctus mauris. Nam nibh metus, eleifend non.[/vc_column_text][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_2944642927137"][ueldo_shortcode_image class_name="ueldo_vc_element_61075552764919" large_height_px="200" small_custom_sizes="yes" small_height_px="280" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(0,0,0,0.1)"][ueldo_shortcode_heading class_name="ueldo_vc_element_30870791043223" heading_tag="h4" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_5450568065793" heading_text="'. esc_html( __( 'Susane Smith', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<strong>'. esc_html( __( 'Dentist', 'ueldo' ) ) .'</strong><br /><br /> Aenean non mi id erat luctus viverra. Pellentesque dapibus risus in risus elementum, ac iaculis ante lacinia. Ut lorem. In malesuada quis.[/vc_column_text][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_7740971560897"][ueldo_shortcode_image class_name="ueldo_vc_element_73936068999562" large_height_px="200" small_custom_sizes="yes" small_height_px="280" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(0,0,0,0.1)"][ueldo_shortcode_heading class_name="ueldo_vc_element_48279697491811" heading_tag="h4" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1816026636338" heading_text="'. esc_html( __( 'Monica Wayne', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<strong>'. esc_html( __( 'Dentist', 'ueldo' ) ) .'</strong><br /><br /> Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Cras nunc nulla, hendrerit et eros at, commodo.[/vc_column_text][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_3774959856433"][ueldo_shortcode_image class_name="ueldo_vc_element_76138256642779" large_height_px="200" small_custom_sizes="yes" small_height_px="280" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(0,0,0,0.1)"][ueldo_shortcode_heading class_name="ueldo_vc_element_38542434085768" heading_tag="h4" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_6115985333482" heading_text="'. esc_html( __( 'Jessica Smith', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<strong>'. esc_html( __( 'Assistant', 'ueldo' ) ) .'</strong><br /><br /> Proin vulputate, neque sit amet feugiat ullamcorper, lacus magna finibus nisl, sed consectetur nisl enim non est. Curabitur susc.[/vc_column_text][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_2486466774825"][ueldo_shortcode_image class_name="ueldo_vc_element_53164768751048" large_height_px="200" small_custom_sizes="yes" small_height_px="280" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(0,0,0,0.1)"][ueldo_shortcode_heading class_name="ueldo_vc_element_76708170725949" heading_tag="h4" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_6058003781949" heading_text="'. esc_html( __( 'Mike Wayne', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<strong>'. esc_html( __( 'Dentist', 'ueldo' ) ) .'</strong><br /><br /> Nulla volutpat id libero sit amet placerat. Nunc pulvinar consectetur dui vel viverra. Integer id magna a sem commodo cursus non a dolor.[/vc_column_text][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_3857243601056"][ueldo_shortcode_image class_name="ueldo_vc_element_21168139717851" large_height_px="200" small_custom_sizes="yes" small_height_px="280" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(0,0,0,0.1)"][ueldo_shortcode_heading class_name="ueldo_vc_element_41568821322733" heading_tag="h4" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_3222475140373" heading_text="'. esc_html( __( 'Tom Jones', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<strong>'. esc_html( __( 'Assistant', 'ueldo' ) ) .'</strong><br /><br /> Pellentesque mollis ipsum ac venenatis aliquam. Fusce in massa vel diam efficitur gravida. Orci varius natoque penatibus et magnis.[/vc_column_text][/ueldo_shortcode_loop_cell][/ueldo_shortcode_loop][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_28465821141810"][/vc_column][/vc_row][/vc_section]',

                'about-us' => '[vc_section full_width="stretch_row" css=".vc_custom_1511811701790{margin-top: -38px !important;}"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15115129750872" layer_for_row_or_section="section" layer_z_index="0" color="#f3f1ef"][ueldo_shortcode_gap class_name="ueldo_vc_element_61194747666738" large_height="90"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_hidden-lg vc_hidden-md"][ueldo_shortcode_heading class_name="ueldo_vc_element_63328124398240" text_align="center" heading_subtitle_text="'. esc_html( __( 'Dental Practice', 'ueldo' ) ) .'" custom_heading_subtitle_font_color_enabled="custom_settings" heading_subtitle_font_color="#44806b"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15318210280696" heading_text="'. esc_html( __( 'Your Family Dentist', 'ueldo' ) ) .'" font_family="headings-slim-font"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Duis sed elit ac nisl molestie rutrum a a nunc. Maecenas mollis lacinia elit. Morbi quam orci, ultricies vitae condimentum non, pharetra vitae tortor. Ut blandit rutrum purus, vitae volutpat augue hendrerit in.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_97111177522343" large_height="25"][ueldo_shortcode_image class_name="ueldo_vc_element_66650156647839" horizontal_alignment="center" additional="video_button" video_title="" large_width_type="px" large_width_px="200" large_height_px="120" margin_bottom="0" custom_video_button_sizes_enabled="custom_settings" video_button_width="50" video_button_height="50" custom_colors_enabled="custom_settings" video_button_border_color="#44806b" video_button_background_color="#44806b" video_url="https://www.youtube.com/watch?v=6NC_ODHu5jg"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_hidden-sm vc_hidden-xs"][ueldo_shortcode_heading class_name="ueldo_vc_element_98857064886810" heading_subtitle_text="'. esc_html( __( 'Dental Practice', 'ueldo' ) ) .'" custom_heading_subtitle_font_color_enabled="custom_settings" heading_subtitle_font_color="#44806b"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_51994033731138" heading_text="'. esc_html( __( 'Your Family Dentist', 'ueldo' ) ) .'" font_family="headings-slim-font"][/ueldo_shortcode_heading][vc_column_text]Duis sed elit ac nisl molestie rutrum a a nunc. Maecenas mollis lacinia elit. Morbi quam orci, ultricies vitae condimentum non, pharetra vitae tortor. Ut blandit rutrum purus, vitae volutpat augue hendrerit in.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_87603615004228" large_height="25"][ueldo_shortcode_image class_name="ueldo_vc_element_34848402649632" additional="video_button" video_title="" large_width_type="px" large_width_px="200" large_height_px="120" margin_bottom="0" custom_video_button_sizes_enabled="custom_settings" video_button_width="50" video_button_height="50" custom_colors_enabled="custom_settings" video_button_border_color="#44806b" video_button_background_color="#44806b" video_url="https://www.youtube.com/watch?v=6NC_ODHu5jg"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6"][ueldo_shortcode_gap class_name="ueldo_vc_element_15041711457116" large_height="0" small_custom_sizes="yes"][ueldo_shortcode_timeline class_name="ueldo_vc_element_47904577937314" custom_colors_enabled="custom_settings" card_border_color="#e8e5e1" card_background_color="#ffffff" card_background_color_hover="#ffffff" card_box_shadow_color="rgba(255,255,255,0.01)" card_box_shadow_color_hover="rgba(0,0,0,0.05)" date_text_color="#ffffff" date_box_shadow_color="rgba(255,255,255,0.01)" timeline_line_box_shadow_color="rgba(255,255,255,0.01)" timeline_circle_background_color="#ffffff" timeline_circle_box_shadow_color="rgba(255,255,255,0.01)" next_prev_arrow_color="#eeeeee" next_prev_arrow_container_background="#ffffff" next_prev_arrow_container_background_hover="#ffffff" next_prev_arrow_container_box_shadow_color="rgba(255,255,255,0.01)" next_prev_arrow_container_box_shadow_color_hover="rgba(255,255,255,0.01)"][ueldo_shortcode_timeline_element class_name="ueldo_vc_element_79503498672396" date="1984"]Quisque quis ultrices lorem. Nullam mattis mollis velit commodo varius. Ut porta auctor justo eu rhoncus. Vivamus risus lectus, commodo in pulvinar at, facilisis.[/ueldo_shortcode_timeline_element][ueldo_shortcode_timeline_element class_name="ueldo_vc_element_27918645766126" date="1991"]Quisque quis ultrices lorem. Nullam mattis mollis velit commodo varius. Ut porta auctor justo eu rhoncus. Vivamus risus lectus, commodo in pulvinar at, facilisis.[/ueldo_shortcode_timeline_element][ueldo_shortcode_timeline_element class_name="ueldo_vc_element_29539582342899" date="2002"]Quisque quis ultrices lorem. Nullam mattis mollis velit commodo varius. Ut porta auctor justo eu rhoncus. Vivamus risus lectus, commodo in pulvinar at, facilisis.[/ueldo_shortcode_timeline_element][ueldo_shortcode_timeline_element class_name="ueldo_vc_element_35464361832012"]Quisque quis ultrices lorem. Nullam mattis mollis velit commodo varius. Ut porta auctor justo eu rhoncus. Vivamus risus lectus, commodo in pulvinar at, facilisis.[/ueldo_shortcode_timeline_element][/ueldo_shortcode_timeline][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15039259557725"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_21877418091300"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_76090258535765" large_width_type="calc" large_width_calc_base="25%" large_width_calc_px="23" small_custom_sizes="yes" small_width_type="calc" small_width_calc_base="50%" small_width_calc_px="15" extra_small_custom_sizes="yes"][ueldo_shortcode_info_box class_name="ueldo_vc_element_71182036460508" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( 'General Dentistry', 'ueldo' ) ) .'" info_box_subtitle="'. esc_html( __( '18 years of experience', 'ueldo' ) ) .'" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-teeth,flaticon-medical|url:https://www.flaticon.com/free-icon/teeth_139405|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#f3f1ef" info_element_background_color_hover="#f3f1ef" info_element_icon_color="#cec4b9" info_element_icon_color_hover="#cec4b9" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_15041712789805" large_height="0" small_custom_sizes="yes" small_height="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_87620284980805" large_width_type="px" large_width_px="30" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_40769997121806" large_width_type="calc" large_width_calc_base="25%" large_width_calc_px="23" small_custom_sizes="yes" small_width_type="calc" small_width_calc_base="50%" small_width_calc_px="15" extra_small_custom_sizes="yes"][ueldo_shortcode_info_box class_name="ueldo_vc_element_22215663556665" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( 'Esthetic Dentistry', 'ueldo' ) ) .'" info_box_subtitle="'. esc_html( __( 'Incredible results', 'ueldo' ) ) .'" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-tooth,flaticon-medical|url:https://www.flaticon.com/free-icon/tooth_139411|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#f3f1ef" info_element_background_color_hover="#f3f1ef" info_element_icon_color="#cec4b9" info_element_icon_color_hover="#cec4b9" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_15041712944343" large_height="0" small_custom_sizes="yes" small_height="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_26015415637256" large_width_type="px" large_width_px="30" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_88090948446853" large_width_type="calc" large_width_calc_base="25%" large_width_calc_px="23" small_custom_sizes="yes" small_width_type="calc" small_width_calc_base="50%" small_width_calc_px="15" extra_small_custom_sizes="yes"][ueldo_shortcode_info_box class_name="ueldo_vc_element_98317914108937" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( 'Caries Removal', 'ueldo' ) ) .'" info_box_subtitle="'. esc_html( __( 'High accuracy', 'ueldo' ) ) .'" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-molar,flaticon-medical|url:https://www.flaticon.com/free-icon/molar_139408|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#f3f1ef" info_element_background_color_hover="#f3f1ef" info_element_icon_color="#cec4b9" info_element_icon_color_hover="#cec4b9" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_1504172787995" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_27775643573134" large_width_type="px" large_width_px="30" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_89312515577835" large_width_type="calc" large_width_calc_base="25%" large_width_calc_px="23" small_custom_sizes="yes" small_width_type="calc" small_width_calc_base="50%" small_width_calc_px="15" extra_small_custom_sizes="yes"][ueldo_shortcode_info_box class_name="ueldo_vc_element_25378867726341" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( 'Porcelain Prostheses', 'ueldo' ) ) .'" info_box_subtitle="'. esc_html( __( 'Comfortable & Affordable', 'ueldo' ) ) .'" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-implants,flaticon-medical|url:https://www.flaticon.com/free-icon/implants_139382|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#f3f1ef" info_element_background_color_hover="#f3f1ef" info_element_icon_color="#cec4b9" info_element_icon_color_hover="#cec4b9" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_21031808942560"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_23302383949002"][/vc_column][/vc_row][vc_row content_placement="middle"][vc_column offset="vc_col-lg-3 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_72687522189816" text_align="center" heading_subtitle_text="'. esc_html( __( 'Team Qualifications', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_51255007267319" heading_text="'. esc_html( __( 'Payment & Financing', 'ueldo' ) ) .'" font_family="headings-slim-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Maecenas fermentum est ac urna suscipit pellentesque. Ut facilisis metus nec diam blandit, eget feugiat justo lacinia. In finibus, magna congue volutpat posuere, risus risus lacinia eros, at tincidunt turpis.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_51304722390583" large_height="25"][/vc_column][vc_column offset="vc_col-lg-3 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-2 vc_col-md-1 vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-10 vc_col-xs-12"][ueldo_shortcode_loop class_name="ueldo_vc_element_15039121234634" one_column_from="extra_small" rows="2" margin_between_columns="0" margin_between_rows="0"][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_58866860820213" large_padding_top="20" large_padding_bottom="20" large_border_right_width="1" large_border_bottom_width="1" extra_small_custom_sizes="yes" extra_small_padding_top="20" extra_small_padding_bottom="20" extra_small_border_bottom_width="1"][ueldo_shortcode_image class_name="ueldo_vc_element_2157868126483" horizontal_alignment="center" large_width_type="px" large_width_px="216" large_height_px="55" margin_bottom="0" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_spread_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_55600672911771" large_padding_top="20" large_padding_bottom="20" large_border_right_width="1" large_border_bottom_width="1" extra_small_custom_sizes="yes" extra_small_padding_top="20" extra_small_padding_bottom="20" extra_small_border_bottom_width="1"][ueldo_shortcode_image class_name="ueldo_vc_element_8817255649917" horizontal_alignment="center" large_width_type="px" large_width_px="216" large_height_px="55" margin_bottom="0" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_spread_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_22038527702247" large_padding_top="20" large_padding_bottom="20" large_border_bottom_width="1"][ueldo_shortcode_image class_name="ueldo_vc_element_15039172051958" horizontal_alignment="center" large_width_type="px" large_width_px="216" large_height_px="55" margin_bottom="0" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_spread_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_37475259477823" large_padding_top="20" large_padding_bottom="20" large_border_right_width="1" extra_small_custom_sizes="yes" extra_small_padding_top="20" extra_small_padding_bottom="20" extra_small_border_bottom_width="1"][ueldo_shortcode_image class_name="ueldo_vc_element_7907476375441" horizontal_alignment="center" large_width_type="px" large_width_px="216" large_height_px="55" margin_bottom="0" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_spread_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_95071260549365" large_padding_top="20" large_padding_bottom="20" large_border_right_width="1" extra_small_custom_sizes="yes" extra_small_padding_top="20" extra_small_padding_bottom="20" extra_small_border_bottom_width="1"][ueldo_shortcode_image class_name="ueldo_vc_element_4357551637361" horizontal_alignment="center" large_width_type="px" large_width_px="216" large_height_px="55" margin_bottom="0" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_spread_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_99355613252195" large_padding_top="20" large_padding_bottom="20"][ueldo_shortcode_image class_name="ueldo_vc_element_1962828246618" horizontal_alignment="center" large_width_type="px" large_width_px="216" large_height_px="55" margin_bottom="0" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_spread_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][/ueldo_shortcode_loop][ueldo_shortcode_gap class_name="ueldo_vc_element_15039129073797"][ueldo_shortcode_button class_name="ueldo_vc_element_15039113373534" button_text="'. esc_html( __( 'Schedule a Visit', 'ueldo' ) ) .'" button_alignment="center" show_button_icon="yes" custom_colors_enabled="custom_settings" standard_button_background_color="#44806b" standard_button_background_color_hover="#3f7764" standard_button_border_color="#44806b" standard_button_border_color_hover="#3f7764" standard_button_box_shadow_vertical_length="10" standard_button_box_shadow_blur_radius="35" standard_button_box_shadow_color="rgba(68,128,107,0.25)" standard_button_box_shadow_color_hover="rgba(63,119,100,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_text_shadow_color="rgba(255,255,255,0.01)" standard_button_text_shadow_color_hover="rgba(255,255,255,0.01)" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)" standard_button_icon_text_shadow_color="rgba(255,255,255,0.01)" standard_button_icon_text_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_button][/vc_column][vc_column offset="vc_col-lg-2 vc_col-md-1 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_40853464711739"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_loop class_name="ueldo_vc_element_15039138859909" rows="2" masonry_enabled="yes"][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_39243544039474" width="double"][ueldo_shortcode_image class_name="ueldo_vc_element_99136829605393" additional="gallery_image" gallery_slug="gallery" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(0,0,0,0.1)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_58500275081313"][ueldo_shortcode_image class_name="ueldo_vc_element_74393618293453" additional="gallery_image" gallery_slug="gallery" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(0,0,0,0.1)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_19666435434099"][ueldo_shortcode_card class_name="ueldo_vc_element_15039173095145" border_width="0" use_static_height="yes" padding_top="30" padding_bottom="30" custom_colors_enabled="custom_settings" box_shadow_color="rgba(255,255,255,0.01)" box_shadow_blur_radius_hover="0" box_shadow_color_hover="rgba(255,255,255,0.01)" background_color="#f3f1ef" background_color_hover="#f3f1ef" border_color="#f3f1ef" border_color_hover="#f3f1ef"][ueldo_shortcode_gap class_name="ueldo_vc_element_15041724795765" large_height="0" small_custom_sizes="yes" small_height="15" extra_small_custom_sizes="yes" extra_small_height="0"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_15039215511906" custom_layer_sizes="custom_settings" layer_type="icon" icon_fontawesome="fa fa-star-o" icon_size="128" icon_color="rgba(0,0,0,0.03)" large_layer_position="bottom_left" large_margin_bottom="-205" large_margin_left="-145" medium_layer_custom_sizes="yes" medium_layer_position="bottom_left" medium_margin_bottom="-205" medium_margin_left="-110" small_layer_custom_sizes="yes" small_layer_position="bottom_left" small_margin_bottom="-205" small_margin_left="-295" extra_small_layer_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="128" extra_small_height_type="px" extra_small_height_px="128" extra_small_layer_position="bottom_left" extra_small_margin_bottom="-30" extra_small_margin_left="-25"][ueldo_shortcode_heading class_name="ueldo_vc_element_19141973052958" heading_tag="h5" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_93413485204537" heading_text="'. esc_html( __( 'Great Customers', 'ueldo' ) ) .'" font_family="headings-slim-font" custom_font_color_enabled="custom_settings" font_color="#382b23" font_color_hover="#382b23"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_62707446134744" heading_tag="h5" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="15"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_91398046518834" heading_text="'. esc_html( __( 'References', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings" font_color="#382b23" font_color_hover="#382b23"][/ueldo_shortcode_heading][ueldo_shortcode_gap class_name="ueldo_vc_element_71914863560776" large_height="10" medium_custom_sizes="yes" medium_height="0" small_custom_sizes="yes" small_height="15"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15039212691121"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15039212721968" large_width_percentage="100%" large_content_alignment="center"][ueldo_shortcode_icon class_name="ueldo_vc_element_17597162641249" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="17" margin_right="2" custom_colors_enabled="custom_settings" icon_color="#44806b"][ueldo_shortcode_icon class_name="ueldo_vc_element_80717081934241" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="17" margin_right="2" margin_left="2" custom_colors_enabled="custom_settings" icon_color="#44806b"][ueldo_shortcode_icon class_name="ueldo_vc_element_70690255351289" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="17" margin_right="2" margin_left="2" custom_colors_enabled="custom_settings" icon_color="#44806b"][ueldo_shortcode_icon class_name="ueldo_vc_element_21273373360537" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="17" margin_right="2" margin_left="2" custom_colors_enabled="custom_settings" icon_color="#44806b"][ueldo_shortcode_icon class_name="ueldo_vc_element_39147408583179" icon_alignment="inline" icon_fontawesome="fa fa-star-half-o" custom_sizes_enabled="custom_settings" icon_size="17" margin_left="2" custom_colors_enabled="custom_settings" icon_color="#44806b"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_1503921428568" large_height="25" medium_custom_sizes="yes" medium_height="15" small_custom_sizes="yes" small_height="30"][vc_column_text]<p style="text-align: center;"><em>"Pellentesque hendrerit, nulla ut venenatis commodo, dolor eros"</em></p><p style="text-align: center;"><strong>'. esc_html( __( 'John Doe', 'ueldo' ) ) .'</strong></p>[/vc_column_text][/ueldo_shortcode_card][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_89682092359367"][ueldo_shortcode_image class_name="ueldo_vc_element_81863459218471" additional="gallery_image" gallery_slug="gallery" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(0,0,0,0.1)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_53555975753240"][ueldo_shortcode_image class_name="ueldo_vc_element_66666235687635" additional="gallery_image" gallery_slug="gallery" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(0,0,0,0.1)"][/ueldo_shortcode_loop_cell][/ueldo_shortcode_loop][ueldo_shortcode_gap class_name="ueldo_vc_element_15114321635931" large_height="30"][/vc_column][/vc_row][/vc_section][vc_section][vc_row content_placement="middle"][vc_column offset="vc_col-lg-3 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_39813511928729" text_align="center" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Team Qualifications', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_44756563970809" heading_text="'. esc_html( __( 'Certificates & References', 'ueldo' ) ) .'" font_family="headings-slim-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Maecenas fermentum est ac urna suscipit pellentesque. Ut facilisis metus nec diam blandit, eget feugiat justo lacinia. In finibus, magna congue volutpat posuere, risus risus lacinia eros, at tincidunt turpis.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_91251770488484" large_height="25"][/vc_column][vc_column offset="vc_col-lg-3 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4"][ueldo_shortcode_button class_name="ueldo_vc_element_35337083761551" button_type="two-line-button" button_text="'. esc_html( __( 'Download: 34kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Dr. John Doe', 'ueldo' ) ) .'" second_line_position="top" show_button_icon="yes" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_91576566187699" large_height="30"][ueldo_shortcode_button class_name="ueldo_vc_element_24304448631392" button_type="two-line-button" button_text="'. esc_html( __( 'Download: 22kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Ms. Johns Reference', 'ueldo' ) ) .'" second_line_position="top" show_button_icon="yes" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4"][ueldo_shortcode_gap class_name="ueldo_vc_element_90464348068880" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_button class_name="ueldo_vc_element_77485877241565" button_type="two-line-button" button_text="'. esc_html( __( 'Download: 29kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Dr. Susane Smith', 'ueldo' ) ) .'" second_line_position="top" show_button_icon="yes" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_68088293026305" large_height="30"][ueldo_shortcode_button class_name="ueldo_vc_element_81073259217718" button_type="two-line-button" button_text="'. esc_html( __( 'Download: 15kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Mr. Willis Reference', 'ueldo' ) ) .'" second_line_position="top" show_button_icon="yes" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4"][ueldo_shortcode_gap class_name="ueldo_vc_element_15041715863416" large_height="0" small_custom_sizes="yes" small_height="30"][ueldo_shortcode_button class_name="ueldo_vc_element_12562797172855" button_type="two-line-button" button_text="'. esc_html( __( 'Download: 52kb', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'Dr. Monica Wayne', 'ueldo' ) ) .'" second_line_position="top" show_button_icon="yes" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="20" two_line_button_use_static_width="yes-full-width"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15039127675205"][/vc_column][/vc_row][/vc_section]',

                'contact' => '[vc_section full_width="stretch_row_content" css=".vc_custom_1511812796798{margin-top: -38px !important;}"][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_google_map class_name="ueldo_vc_element_15039877254992" {ueldopredefinedsections:googlemap|context:dentist} border_radius="0" large_height_px="500" margin_bottom="0"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_5293926498713012345678"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-6 vc_col-md-6"][ueldo_shortcode_heading class_name="ueldo_vc_element_5281493261400712" heading_tag="h1" heading_subtitle_text="'. esc_html( __( 'Contact us', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_4897847502838512" heading_text="'. esc_html( __( 'Write or call us today!', 'ueldo' ) ) .'" font_family="headings-slim-font" custom_font_size_and_line_height_enabled="custom_settings" font_size="36" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Sed odio dolor, maximus quis hendrerit sed, luctus vel turpis. Mauris eget odio sodales, lobortis ex ac, eleifend arcu. Fusce metus lectus, mattis ut vulputate a, tempus vitae sem. Praesent magna quam, sollicitudin quis gravida.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15039943961085" large_height="25" small_custom_sizes="yes" small_height="10"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_51584046223493" vertical_alignment="top"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_35583875647450" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15"][ueldo_shortcode_info_box class_name="ueldo_vc_element_1993021639370" content_alignment="left" info_box_title="'. esc_html( __( 'Credit Cards accepted', 'ueldo' ) ) .'" info_box_subtitle="'. esc_html( __( 'No cash required', 'ueldo' ) ) .'" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-credit-card,flaticon-money|url:https://www.flaticon.com/free-icon/credit-card_134596|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_icon_color="#cec4b9" info_element_icon_color_hover="#cec4b9" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_10598710457613" large_width_type="px" large_width_px="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_29541072377325" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15"][ueldo_shortcode_info_box class_name="ueldo_vc_element_9527787684359" content_alignment="left" info_box_title="1-800-123-4567" info_box_subtitle="'. esc_html( __( '24/7 emergency call', 'ueldo' ) ) .'" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-call-center,flaticon-technology|url:https://www.flaticon.com/free-icon/call-center_270999|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_icon_color="#cec4b9" info_element_icon_color_hover="#cec4b9" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6"][ueldo_shortcode_gap class_name="ueldo_vc_element_15041766316995" large_height="0" small_custom_sizes="yes" small_height="45"][contact-form-7 {ueldopredefinedsections:contactform7|context:dentist|inside:false}][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_61643486771752"][ueldo_shortcode_delimiter class_name="ueldo_vc_element_151395431588" large_height="1" margin_bottom="0"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column offset="vc_col-lg-3 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-8"][ueldo_shortcode_gap class_name="ueldo_vc_element_1511432496954"][ueldo_shortcode_heading class_name="ueldo_vc_element_15039946671949" text_align="center" heading_subtitle_text="'. esc_html( __( 'Recent news', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15039946853122" heading_text="'. esc_html( __( 'Have you checked our blog?', 'ueldo' ) ) .'" font_family="general-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Curabitur a ultricies erat. Etiam tempor urna quis lacus iaculis imperdiet. Nunc hendrerit mollis est nec fermentum. Pellentesque sed auctor augue, interdum efficitur lacus. Phasellus et eros vel magna congue dapibus.</p>[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_15039951816595" button_text="'. esc_html( __( 'Go to blog', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'blog%2F|title:'. rawurlencode( esc_html( __( 'Blog', 'ueldo' ) ) ) .'||" button_alignment="center" show_button_icon="yes"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_15039952114941"][/vc_column][vc_column offset="vc_col-lg-3 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-4 vc_col-md-4"][ueldo_shortcode_post_page_box class_name="ueldo_vc_element_68271321081291"][ueldo_shortcode_gap class_name="ueldo_vc_element_64123812132040" large_height="0" small_custom_sizes="yes" small_height="30"][/vc_column][vc_column offset="vc_col-lg-4 vc_col-md-4"][ueldo_shortcode_post_page_box class_name="ueldo_vc_element_25009970137900" post_no="latest_minus_1"][ueldo_shortcode_gap class_name="ueldo_vc_element_89491986245379" large_height="0" small_custom_sizes="yes" small_height="30"][/vc_column][vc_column offset="vc_col-lg-4 vc_col-md-4"][ueldo_shortcode_post_page_box class_name="ueldo_vc_element_17289017298061" post_no="latest_minus_2"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15039951466389"][/vc_column][/vc_row][/vc_section]',

                'dental-radiology' => '[vc_section css=".vc_custom_1504176479803{margin-top: -38px !important;}"][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15040758825526" large_height="400"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15040758974187" layer_type="image"][/vc_column][/vc_row][/vc_section][vc_section][vc_row el_class="ueldo-row-with-sidebar-on-right"][vc_column width="3/4" el_class="ueldo-row-with-sidebar-content-column"][ueldo_shortcode_gap class_name="ueldo_vc_element_54854839505259"][ueldo_shortcode_heading class_name="ueldo_vc_element_15040127537094" heading_subtitle_text="'. esc_html( __( 'Our Services', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1504012766038912" heading_text="'. esc_html( __( 'Dental Radiology', 'ueldo' ) ) .'" font_family="headings-slim-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_card class_name="ueldo_vc_element_1504074519808" border_width="0" custom_colors_enabled="custom_settings" box_shadow_blur_radius_hover="0" box_shadow_color_hover="rgba(255,255,255,0.01)" background_color="#f3f1ef" background_color_hover="#f3f1ef"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15040133918724"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_18540283784161" extra_small_custom_sizes="yes"][ueldo_shortcode_info_box class_name="ueldo_vc_element_19394427925072" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( 'High precision and reliability', 'ueldo' ) ) .'" info_box_subtitle="'. esc_html( __( '18 years of experience', 'ueldo' ) ) .'" info_element_width="50" info_element_height="50" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-molar,flaticon-medical|url:https://www.flaticon.com/free-icon/molar_139408|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#f3f1ef" info_element_background_color_hover="#f3f1ef" info_element_icon_color="#cec4b9" info_element_icon_color_hover="#cec4b9" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_65389125054354" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15041757778862" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_info_box class_name="ueldo_vc_element_22160611080399" content_alignment="left" content_position="inline" info_box_title="1-800-123-4567" info_box_subtitle="24/7 emergency call" info_element_width="50" info_element_height="50" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-call-center,flaticon-technology|url:https://www.flaticon.com/free-icon/call-center_270999|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#f3f1ef" info_element_background_color_hover="#f3f1ef" info_element_icon_color="#cec4b9" info_element_icon_color_hover="#cec4b9" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_79517243894391"][vc_column_text]<p>Nullam porta arcu a efficitur ultricies. Curabitur mattis metus aliquam, tristique erat eget, ultricies odio. Aliquam lacinia placerat leo quis pretium. Vestibulum vulputate nisl mauris, non congue leo maximus sit amet. Maecenas sit amet mauris sed mi efficitur efficitur. Aenean molestie felis id nunc ultrices congue. Nullam pellentesque nec erat ut luctus. Aenean aliquam risus ac consequat dapibus. In eleifend pellentesque semper.</p>[/vc_column_text][vc_row_inner el_class="ueldo-vc-row-overflow-visible"][vc_column_inner width="1/2"][vc_column_text]<h6>Vitae wisi eget nibh condimentum:</h6><ul><li>Pharetra sem, rutrum sit amet, tincidunt,</li><li>Diam ut malesuada id, luctus augue imperdiet,</li><li>Convallis praesent blandit justo, condimentum,</li><li>Sagittis lacus iaculis et.</li></ul>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_215040758825526" large_height="25"][/vc_column_inner][vc_column_inner width="1/2"][/vc_column_inner][/vc_row_inner][ueldo_shortcode_heading class_name="ueldo_vc_element_15040772171522" heading_tag="h4" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15040772314207" heading_text="'. esc_html( __( 'Pricing details', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_price_single class_name="ueldo_vc_element_66664320077467" title="'. esc_html( __( 'Intraoral - Complete Series of Radiographic Images', 'ueldo' ) ) .'" description="'. esc_html( __( 'Dental X-Ray', 'ueldo' ) ) .'" price="$189"][ueldo_shortcode_gap class_name="ueldo_vc_element_90050411550572" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_57562256331450" title="'. esc_html( __( 'Intraoral - Periapical - First Radiographic Image', 'ueldo' ) ) .'" description="'. esc_html( __( 'Dental X-Ray', 'ueldo' ) ) .'" price="$49"][ueldo_shortcode_gap class_name="ueldo_vc_element_71028547523491" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_96086175638423" title="'. esc_html( __( 'Bitewing - Single Radiographic Image', 'ueldo' ) ) .'" description="'. esc_html( __( 'Dental X-Ray', 'ueldo' ) ) .'" price="$39"][ueldo_shortcode_gap class_name="ueldo_vc_element_46586822649067" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_62259467277126" title="'. esc_html( __( 'Panoramic Radiographic Image', 'ueldo' ) ) .'" description="'. esc_html( __( 'Dental X-Ray', 'ueldo' ) ) .'" price="$159"][ueldo_shortcode_gap class_name="ueldo_vc_element_71841910869451" small_custom_sizes="yes" small_height="0"][/vc_column][vc_column width="1/4" el_class="ueldo-row-with-sidebar-sidebar-column"][ueldo_shortcode_gap class_name="ueldo_vc_element_79561403264621"][vc_widget_sidebar {ueldopredefinedsections:sidebar|context:dentist}][ueldo_shortcode_gap class_name="ueldo_vc_element_88472555514686" large_height="25"][/vc_column][/vc_row][/vc_section]',

                'esthetic-dentistry' => '[vc_section css=".vc_custom_1504176479803{margin-top: -38px !important;}"][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15040758825526" large_height="400"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15040758974187" layer_type="image"][/vc_column][/vc_row][/vc_section][vc_section][vc_row el_class="ueldo-row-with-sidebar-on-right"][vc_column width="3/4" el_class="ueldo-row-with-sidebar-content-column"][ueldo_shortcode_gap class_name="ueldo_vc_element_54854839505259"][ueldo_shortcode_heading class_name="ueldo_vc_element_15040127537094" heading_subtitle_text="'. esc_html( __( 'Our Services', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1504012766038912" heading_text="'. esc_html( __( 'Esthetic Dentistry', 'ueldo' ) ) .'" font_family="headings-slim-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_card class_name="ueldo_vc_element_1504074519808" border_width="0" custom_colors_enabled="custom_settings" box_shadow_blur_radius_hover="0" box_shadow_color_hover="rgba(255,255,255,0.01)" background_color="#f3f1ef" background_color_hover="#f3f1ef"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15040133918724"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_18540283784161" extra_small_custom_sizes="yes"][ueldo_shortcode_info_box class_name="ueldo_vc_element_19394427925072" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( 'High precision and reliability', 'ueldo' ) ) .'" info_box_subtitle="'. esc_html( __( '18 years of experience', 'ueldo' ) ) .'" info_element_width="50" info_element_height="50" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-molar,flaticon-medical|url:https://www.flaticon.com/free-icon/molar_139408|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#f3f1ef" info_element_background_color_hover="#f3f1ef" info_element_icon_color="#cec4b9" info_element_icon_color_hover="#cec4b9" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_65389125054354" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15041757778862" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_info_box class_name="ueldo_vc_element_22160611080399" content_alignment="left" content_position="inline" info_box_title="1-800-123-4567" info_box_subtitle="24/7 emergency call" info_element_width="50" info_element_height="50" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-call-center,flaticon-technology|url:https://www.flaticon.com/free-icon/call-center_270999|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#f3f1ef" info_element_background_color_hover="#f3f1ef" info_element_icon_color="#cec4b9" info_element_icon_color_hover="#cec4b9" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_79517243894391"][vc_column_text]<p>Nullam porta arcu a efficitur ultricies. Curabitur mattis metus aliquam, tristique erat eget, ultricies odio. Aliquam lacinia placerat leo quis pretium. Vestibulum vulputate nisl mauris, non congue leo maximus sit amet. Maecenas sit amet mauris sed mi efficitur efficitur. Aenean molestie felis id nunc ultrices congue. Nullam pellentesque nec erat ut luctus. Aenean aliquam risus ac consequat dapibus. In eleifend pellentesque semper.</p>[/vc_column_text][vc_row_inner el_class="ueldo-vc-row-overflow-visible"][vc_column_inner width="1/2"][vc_column_text]<h6>Vitae wisi eget nibh condimentum:</h6><ul><li>Pharetra sem, rutrum sit amet, tincidunt,</li><li>Diam ut malesuada id, luctus augue imperdiet,</li><li>Convallis praesent blandit justo, condimentum,</li><li>Sagittis lacus iaculis et.</li></ul>[/vc_column_text][/vc_column_inner][vc_column_inner width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15041755886893" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_two_images_difference class_name="ueldo_vc_element_15040792466446" margin_bottom="0" custom_sizes_enabled="custom_settings" large_width_type="percentage"][/vc_column_inner][/vc_row_inner][ueldo_shortcode_gap class_name="ueldo_vc_element_52580014852672" large_height="25"][ueldo_shortcode_heading class_name="ueldo_vc_element_15040772171522" heading_tag="h4" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15040772314207" heading_text="'. esc_html( __( 'Pricing details', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_price_single class_name="ueldo_vc_element_66664320077467" title="'. esc_html( __( 'Teeth Whitening', 'ueldo' ) ) .'" description="'. esc_html( __( 'Cosmetic Dentistry', 'ueldo' ) ) .'" price="$500 - $600"][ueldo_shortcode_gap class_name="ueldo_vc_element_90050411550572" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_57562256331450" title="'. esc_html( __( 'Dental Bonding', 'ueldo' ) ) .'" description="'. esc_html( __( 'Cosmetic Dentistry', 'ueldo' ) ) .'" price="$150 - $1,500"][ueldo_shortcode_gap class_name="ueldo_vc_element_71028547523491" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_96086175638423" title="'. esc_html( __( 'Dental implants', 'ueldo' ) ) .'" description="'. esc_html( __( 'Cosmetic Dentistry', 'ueldo' ) ) .'" price="'. esc_html( __( '$1200 - $2,500 per tooth', 'ueldo' ) ) .'"][ueldo_shortcode_gap class_name="ueldo_vc_element_46586822649067" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_62259467277126" title="'. esc_html( __( 'Dental bridges', 'ueldo' ) ) .'" description="'. esc_html( __( 'Cosmetic Dentistry', 'ueldo' ) ) .'" price="'. esc_html( __( '$250 - $800 per unit', 'ueldo' ) ) .'"][ueldo_shortcode_gap class_name="ueldo_vc_element_71841910869451" small_custom_sizes="yes" small_height="0"][/vc_column][vc_column width="1/4" el_class="ueldo-row-with-sidebar-sidebar-column"][ueldo_shortcode_gap class_name="ueldo_vc_element_79561403264621"][vc_widget_sidebar {ueldopredefinedsections:sidebar|context:dentist}][ueldo_shortcode_gap class_name="ueldo_vc_element_88472555514686" large_height="25"][/vc_column][/vc_row][/vc_section]',

                'general-dentistry' => '[vc_section css=".vc_custom_1504176479803{margin-top: -38px !important;}"][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15040758825526" large_height="400"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15040758974187" layer_type="image"][/vc_column][/vc_row][/vc_section][vc_section][vc_row el_class="ueldo-row-with-sidebar-on-right"][vc_column width="3/4" el_class="ueldo-row-with-sidebar-content-column"][ueldo_shortcode_gap class_name="ueldo_vc_element_54854839505259"][ueldo_shortcode_heading class_name="ueldo_vc_element_15040127537094" heading_subtitle_text="'. esc_html( __( 'Our Services', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1504012766038912" heading_text="'. esc_html( __( 'General Dentistry', 'ueldo' ) ) .'" font_family="headings-slim-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_card class_name="ueldo_vc_element_1504074519808" border_width="0" custom_colors_enabled="custom_settings" box_shadow_blur_radius_hover="0" box_shadow_color_hover="rgba(255,255,255,0.01)" background_color="#f3f1ef" background_color_hover="#f3f1ef"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15040133918724"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_18540283784161" extra_small_custom_sizes="yes"][ueldo_shortcode_info_box class_name="ueldo_vc_element_19394427925072" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( 'High precision and reliability', 'ueldo' ) ) .'" info_box_subtitle="'. esc_html( __( '18 years of experience', 'ueldo' ) ) .'" info_element_width="50" info_element_height="50" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-molar,flaticon-medical|url:https://www.flaticon.com/free-icon/molar_139408|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#f3f1ef" info_element_background_color_hover="#f3f1ef" info_element_icon_color="#cec4b9" info_element_icon_color_hover="#cec4b9" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_65389125054354" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15041757778862" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_info_box class_name="ueldo_vc_element_22160611080399" content_alignment="left" content_position="inline" info_box_title="1-800-123-4567" info_box_subtitle="24/7 emergency call" info_element_width="50" info_element_height="50" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-call-center,flaticon-technology|url:https://www.flaticon.com/free-icon/call-center_270999|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#f3f1ef" info_element_background_color_hover="#f3f1ef" info_element_icon_color="#cec4b9" info_element_icon_color_hover="#cec4b9" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_79517243894391"][vc_column_text]<p>Nullam porta arcu a efficitur ultricies. Curabitur mattis metus aliquam, tristique erat eget, ultricies odio. Aliquam lacinia placerat leo quis pretium. Vestibulum vulputate nisl mauris, non congue leo maximus sit amet. Maecenas sit amet mauris sed mi efficitur efficitur. Aenean molestie felis id nunc ultrices congue. Nullam pellentesque nec erat ut luctus. Aenean aliquam risus ac consequat dapibus. In eleifend pellentesque semper.</p>[/vc_column_text][vc_row_inner el_class="ueldo-vc-row-overflow-visible"][vc_column_inner width="1/2"][vc_column_text]<h6>Vitae wisi eget nibh condimentum:</h6><ul><li>Pharetra sem, rutrum sit amet, tincidunt,</li><li>Diam ut malesuada id, luctus augue imperdiet,</li><li>Convallis praesent blandit justo, condimentum,</li><li>Sagittis lacus iaculis et.</li></ul>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_215040758825526" large_height="25"][/vc_column_inner][vc_column_inner width="1/2"][/vc_column_inner][/vc_row_inner][ueldo_shortcode_heading class_name="ueldo_vc_element_15040772171522" heading_tag="h4" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15040772314207" heading_text="'. esc_html( __( 'Pricing details', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_price_single class_name="ueldo_vc_element_66664320077467" title="'. esc_html( __( 'Teeth Cleaning', 'ueldo' ) ) .'" description="'. esc_html( __( 'General Dentistry', 'ueldo' ) ) .'" price="$127"][ueldo_shortcode_gap class_name="ueldo_vc_element_90050411550572" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_57562256331450" title="'. esc_html( __( 'Cavity filling (composite)', 'ueldo' ) ) .'" description="'. esc_html( __( 'General Dentistry', 'ueldo' ) ) .'" price="$204"][ueldo_shortcode_gap class_name="ueldo_vc_element_71028547523491" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_96086175638423" title="'. esc_html( __( 'Wisdom tooth removal (per tooth)', 'ueldo' ) ) .'" description="'. esc_html( __( 'General Dentistry', 'ueldo' ) ) .'" price="$250 - $750"][ueldo_shortcode_gap class_name="ueldo_vc_element_46586822649067" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_62259467277126" title="'. esc_html( __( 'Root Canal', 'ueldo' ) ) .'" description="'. esc_html( __( 'General Dentistry', 'ueldo' ) ) .'" price="$1,150"][ueldo_shortcode_gap class_name="ueldo_vc_element_71841910869451" small_custom_sizes="yes" small_height="0"][/vc_column][vc_column width="1/4" el_class="ueldo-row-with-sidebar-sidebar-column"][ueldo_shortcode_gap class_name="ueldo_vc_element_79561403264621"][vc_widget_sidebar {ueldopredefinedsections:sidebar|context:dentist}][ueldo_shortcode_gap class_name="ueldo_vc_element_88472555514686" large_height="25"][/vc_column][/vc_row][/vc_section]',

                '404-page' => '[vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_27816494044293123"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-3 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-8"][ueldo_shortcode_icon class_name="ueldo_vc_element_15040044386905" icon_alignment="center" {ueldopredefinedsections:icon|key:flaticon-tooth,flaticon-medical|url:https://www.flaticon.com/free-icon/tooth_139366|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="130" margin_bottom="60" custom_colors_enabled="custom_settings" icon_color="rgba(56,43,35,0.05)"][ueldo_shortcode_heading class_name="ueldo_vc_element_34384176156800" heading_tag="h1" text_align="center" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( '404 page', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_5847134406963" heading_text="'. esc_html( __( 'Nothing found here!', 'ueldo' ) ) .'" font_family="headings-slim-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Integer sollicitudin sapien eget molestie laoreet. Integer quis est quis orci convallis commodo in vel elit. Ut efficitur auctor bibendum. In quam elit, ornare eu augue sit amet, ultricies congue est. Pellentesque rutrum.</p>[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_1504001139184" button_text="'. esc_html( __( 'Go back to home page', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'|title:'. rawurlencode( esc_html( __( 'Home', 'ueldo' ) ) ) .'||" button_alignment="center" show_button_icon="yes"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_15040015598753"][/vc_column][vc_column offset="vc_col-lg-3 vc_col-md-2 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][/vc_section]',

                'blog-responsive-margin-top' => '[vc_section css=".vc_custom_1504177022358{margin-top: -30px !important;}"][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15041770376886" large_height="30" small_custom_sizes="yes" small_height="0"][/vc_column][/vc_row][/vc_section]',

                'header' => '[vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible"][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_67809159459639" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" color="#ffffff" large_height_type="calc" large_height_calc_operator="+" large_height_calc_px="36" small_layer_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_59381882441422" large_height="30"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_1503651120899"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15036511247754" large_width_type="px" large_width_px="147"][ueldo_shortcode_website_logo class_name="ueldo_vc_element_15036511477264" large_width_type="px" large_width_px="147" {ueldopredefinedsections:image|context:dentist-logo}][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15036511320366" large_width_type="calc" large_width_calc_px="147" large_content_alignment="right"][ueldo_shortcode_button class_name="ueldo_vc_element_921495124393821" button_visible_on_devices="large,medium" button_text="'. esc_html( __( 'contact@example.com', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( esc_url( __( 'mailto:contact@example.com', 'ueldo' ) ) ) .'|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" button_alignment="inline" custom_sizes_enabled="custom_settings" standard_button_font_size="13" standard_button_padding_top="11" standard_button_padding_right="20" standard_button_padding_bottom="11" standard_button_padding_left="20" standard_button_use_static_height="no"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_630534624161055" button_visible_on_devices="large,medium" button_text="'. esc_html( __( 'Call now: 1-800-123-4567', 'ueldo' ) ) .'" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" button_alignment="inline" custom_sizes_enabled="custom_settings" additional_margin_before="15" standard_button_font_size="13" standard_button_padding_top="11" standard_button_padding_right="20" standard_button_padding_bottom="11" standard_button_padding_left="20" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="#44806b" standard_button_background_color_hover="#3f7764" standard_button_border_color="#44806b" standard_button_border_color_hover="#3f7764" standard_button_box_shadow_vertical_length="10" standard_button_box_shadow_blur_radius="35" standard_button_box_shadow_color="rgba(68,128,107,0.25)" standard_button_box_shadow_color_hover="rgba(63,119,100,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_973961852729491" button_visible_on_devices="small" button_text="'. esc_html( __( 'Open Menu', 'ueldo' ) ) .'" action_after_click="show_hide_side_menu" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-bars" custom_sizes_enabled="custom_settings" additional_margin_before="15" standard_button_font_size="13" standard_button_padding_top="11" standard_button_padding_right="20" standard_button_padding_bottom="11" standard_button_padding_left="20" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="#44806b" standard_button_background_color_hover="#3f7764" standard_button_border_color="#44806b" standard_button_border_color_hover="#3f7764" standard_button_box_shadow_vertical_length="10" standard_button_box_shadow_blur_radius="35" standard_button_box_shadow_color="rgba(68,128,107,0.25)" standard_button_box_shadow_color_hover="rgba(63,119,100,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_684329059494224" button_visible_on_devices="extra-small" button_text="" action_after_click="show_hide_side_menu" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-bars" custom_sizes_enabled="custom_settings" additional_margin_before="15" standard_button_font_size="13" standard_button_padding_top="11" standard_button_padding_right="20" standard_button_padding_bottom="11" standard_button_padding_left="20" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="#44806b" standard_button_background_color_hover="#3f7764" standard_button_border_color="#44806b" standard_button_border_color_hover="#3f7764" standard_button_box_shadow_vertical_length="10" standard_button_box_shadow_blur_radius="35" standard_button_box_shadow_color="rgba(68,128,107,0.25)" standard_button_box_shadow_color_hover="rgba(63,119,100,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_90908677231919" large_height="30"][/vc_column][/vc_row][/vc_section][vc_section el_class="ueldo-vc-section-overflow-visible"][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_hidden-sm vc_hidden-xs"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_54892457863855" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" color="#382b23" color_add_box_shadow="yes-outset" color_outset_box_shadow_vertical_length="15" color_outset_box_shadow_blur_radius="50" color_outset_box_shadow_spread_radius="-20" color_outset_box_shadow_color="rgba(30,41,37,0.3)" large_width_type="calc" large_width_calc_px="30" large_margin_left="15" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="2"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15036547791839"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_51366394220483" large_width_percentage="80%"][ueldo_shortcode_header_menu class_name="ueldo_vc_element_74804952568809" custom_sizes_enabled="custom_settings" margin_left="15" custom_colors_enabled="custom_settings" menu_element_background_color="#382b23" menu_element_color="rgba(255,255,255,0.5)" active_menu_element_color="#ffffff" active_menu_element_with_child_elements_color="#ffffff" box_shadow_color="rgba(0,0,0,0.1)" submenu_element_bottom_border_color="rgba(0,0,0,0.05)" submenu_element_link_color="rgba(255,255,255,0.6)" submenu_element_link_color_hover="#ffffff"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_26910649059157" large_width_percentage="20%" large_content_alignment="right"][ueldo_shortcode_header_menu class_name="ueldo_vc_element_64418276725924" {ueldopredefinedsections:menu|context:dentist-social-menu} menu_links_alignment="right" custom_sizes_enabled="custom_settings" margin_right="15" custom_colors_enabled="custom_settings" menu_element_background_color="#382b23" menu_element_color="rgba(255,255,255,0.5)" active_menu_element_color="#ffffff" active_menu_element_with_child_elements_color="#ffffff" box_shadow_color="rgba(0,0,0,0.1)" submenu_element_bottom_border_color="rgba(0,0,0,0.05)" submenu_element_link_color="rgba(255,255,255,0.6)" submenu_element_link_color_hover="#ffffff"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][/vc_section]',

                'sticky-header' => '[vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible"][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_41853498504585" layer_for_row_or_section="section" color="#ffffff" color_add_box_shadow="yes-outset" color_outset_box_shadow_blur_radius="35" color_outset_box_shadow_color="rgba(0,0,0,0.1)"][ueldo_shortcode_gap class_name="ueldo_vc_element_66555569291993" large_height="0" small_custom_sizes="yes" small_height="15"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15035660115581"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15035660165914" large_width_type="px" large_width_px="147"][ueldo_shortcode_website_logo class_name="ueldo_vc_element_1503569106865" large_width_type="px" large_width_px="147" {ueldopredefinedsections:image|context:dentist-logo}][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15035660252287" large_width_type="calc" large_width_calc_px="147" large_content_alignment="right"][ueldo_shortcode_header_menu class_name="ueldo_vc_element_15035660396884" menu_links_alignment="right" custom_sizes_enabled="custom_settings" margin_right="-15"][ueldo_shortcode_button class_name="ueldo_vc_element_993274567496" button_visible_on_devices="small" button_text="'. esc_html( __( 'Open Menu', 'ueldo' ) ) .'" action_after_click="show_hide_side_menu" button_alignment="right" show_button_icon="yes" button_icon_fontawesome="fa fa-bars" custom_sizes_enabled="custom_settings" standard_button_padding_top="12" standard_button_padding_right="22" standard_button_padding_bottom="12" standard_button_padding_left="22" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="#44806b" standard_button_border_color="#44806b" standard_button_box_shadow_vertical_length="10" standard_button_box_shadow_blur_radius="35" standard_button_box_shadow_color="rgba(68,128,107,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_499576284521" button_visible_on_devices="extra-small" button_text="" action_after_click="show_hide_side_menu" button_alignment="right" show_button_icon="yes" button_icon_fontawesome="fa fa-bars" custom_sizes_enabled="custom_settings" standard_button_padding_top="12" standard_button_padding_right="22" standard_button_padding_bottom="12" standard_button_padding_left="22" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="#44806b" standard_button_border_color="#44806b" standard_button_box_shadow_vertical_length="10" standard_button_box_shadow_blur_radius="35" standard_button_box_shadow_color="rgba(68,128,107,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_16950982044231" large_height="0" small_custom_sizes="yes" small_height="15"][/vc_column][/vc_row][/vc_section]',

                'footer' => '[vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_151179684425" layer_for_row_or_section="section" layer_z_index="0" color="#f3f1ef"][ueldo_shortcode_gap class_name="ueldo_vc_element_25461227470587"][/vc_column][/vc_row][vc_row content_placement="middle"][vc_column offset="vc_col-lg-5 vc_col-md-5 vc_col-xs-12"][ueldo_shortcode_icon class_name="ueldo_vc_element_84417338421635" icon_alignment="center" {ueldopredefinedsections:icon|key:flaticon-call-center,flaticon-technology|url:https://www.flaticon.com/free-icon/call-center_270999|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="48" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#44806b"][ueldo_shortcode_heading class_name="ueldo_vc_element_49859713046493" text_align="center" heading_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" heading_subtitle_text="'. esc_html( __( 'Emergency call', 'ueldo' ) ) .'" custom_heading_subtitle_font_color_enabled="custom_settings" heading_subtitle_font_color="#44806b" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_70452871883596" heading_text="1-800-123-4567" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" letter_spacing="-2"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Curabitur vitae libero interdum, tincidunt ante at, tincidunt nibh. Nam molestie tincidunt eros in convallis. Morbi scelerisque consequat nunc eu sagittis. Morbi tristique mattis nibh, non consectetur nibh ultrices et.</p>[/vc_column_text][/vc_column][vc_column width="1/12" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6"][ueldo_shortcode_gap class_name="ueldo_vc_element_15041691482638" large_height="0" small_custom_sizes="yes"][vc_row_inner content_placement="top"][vc_column_inner width="1/2" offset="vc_col-xs-12"][vc_column_text]<strong>'. esc_html( __( 'E-mail:', 'ueldo' ) ) .'</strong><br /> <a href="'. esc_url( __( 'mailto:contact@example.com', 'ueldo' ) ) .'">'. esc_html( __( 'contact@example.com', 'ueldo' ) ) .'</a><br /><br /> <strong>'. esc_html( __( 'Location:', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( '5000 Example Street,', 'ueldo' ) ) .'<br /> '. esc_html( __( 'Los Angeles, CA', 'ueldo' ) ) .'<br /><br /> <strong>'. esc_html( __( 'Licence ID:', 'ueldo' ) ) .'</strong><br /> 1234567890[/vc_column_text][/vc_column_inner][vc_column_inner width="1/2" offset="vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15041689586063" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][vc_column_text]<strong>'. esc_html( __( 'Payment methods:', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Cash, Credit Cards, PayPal', 'ueldo' ) ) .'<br /><br /> <strong>'. esc_html( __( 'Respected insurers:', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Insurance Company,', 'ueldo' ) ) .'<br /> '. esc_html( __( 'Another Insurance Company,', 'ueldo' ) ) .'<br /> '. esc_html( __( 'Insurance Example,', 'ueldo' ) ) .'<br /> '. esc_html( __( 'ExampleIns & Co', 'ueldo' ) ) .'[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_31338872696000"][ueldo_shortcode_delimiter class_name="ueldo_vc_element_15036727799476" large_height="1" custom_colors_enabled="custom_settings" background_color="#eae6e2"][/vc_column][/vc_row][vc_row][vc_column offset="vc_hidden-xs"][vc_column_text]<p style="text-align: center;"><strong>2017 - '. date( 'Y' ) .' &copy; '. sprintf( wp_kses( __( 'UeldoDent - demo version of <a href="%s" target="_blank">Ueldo WordPress theme</a>', 'ueldo' ), array( 'a' => array( 'href' => array(), 'target' => array() ) ) ), esc_url( ueldo_get_external_url( 'ueldo-com' ) ) ) .'</strong><br /> '. sprintf( wp_kses( __( 'Created with love by <a href="%s" target="_blank">Martanian</a>', 'ueldo' ), array( 'a' => array( 'href' => array(), 'target' => array() ) ) ), esc_url( ueldo_get_external_url( 'martanian-com' ) ) ) .'</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_34410427638213" large_height="25"][/vc_column][/vc_row][vc_row][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][vc_column_text]<strong>2017 - '. date( 'Y' ) .' &copy; '. sprintf( wp_kses( __( 'UeldoDent - demo version of <a href="%s" target="_blank">Ueldo WordPress theme</a>', 'ueldo' ), array( 'a' => array( 'href' => array(), 'target' => array() ) ) ), esc_url( ueldo_get_external_url( 'ueldo-com' ) ) ) .'</strong><br /><br /> '. sprintf( wp_kses( __( 'Created with love by <a href="%s" target="_blank">Martanian</a>', 'ueldo' ), array( 'a' => array( 'href' => array(), 'target' => array() ) ) ), esc_url( ueldo_get_external_url( 'martanian-com' ) ) ) .'[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_49224327788735" large_height="25"][/vc_column][/vc_row][/vc_section]',

                'additional-before-side-menu' => '[vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_button class_name="ueldo_vc_element_9921495124393821" button_text="'. esc_html( __( 'contact@example.com', 'ueldo' ) ) .'" button_text_alignment="center" button_url="url:'. rawurlencode( esc_url( __( 'mailto:contact@example.com', 'ueldo' ) ) ) .'|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" custom_sizes_enabled="custom_settings" standard_button_font_size="13" standard_button_padding_top="11" standard_button_padding_right="20" standard_button_padding_bottom="11" standard_button_padding_left="20" standard_button_use_static_height="no" standard_button_use_static_width="yes-full-width" custom_colors_enabled="custom_settings" standard_button_background_color="#382b23" standard_button_border_color="#4a3d34" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_15041813966785" large_height="15"][ueldo_shortcode_button class_name="ueldo_vc_element_9630534624161055" button_text="'. esc_html( __( 'Call now: 1-800-123-4567', 'ueldo' ) ) .'" button_text_alignment="center" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" custom_sizes_enabled="custom_settings" standard_button_font_size="13" standard_button_padding_top="11" standard_button_padding_right="20" standard_button_padding_bottom="11" standard_button_padding_left="20" standard_button_use_static_height="no" standard_button_use_static_width="yes-full-width" custom_colors_enabled="custom_settings" standard_button_background_color="#44806b" standard_button_background_color_hover="#3f7764" standard_button_border_color="#44806b" standard_button_border_color_hover="#3f7764" standard_button_box_shadow_vertical_length="10" standard_button_box_shadow_blur_radius="35" standard_button_box_shadow_color="rgba(68,128,107,0.25)" standard_button_box_shadow_color_hover="rgba(63,119,100,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][/vc_column][/vc_row]',

                'additional-after-side-menu' => '2017 - '. date( 'Y' ) .' &copy; <a href="'. esc_url( ueldo_get_external_url( 'ueldo-com' ) ) .'" target="_blank">'. esc_html( __( 'Ueldo WordPress Theme', 'ueldo' ) ) .'</a>'
            );

            # return result
            return( $page_slug == false ? $contents : ( isset( $contents[esc_attr( $page_slug )] ) ? $contents[esc_attr( $page_slug )] : false ) );
        }

       /**
        *
        * end of class methods.
        *
        */
    }

   /**
    *
    * end of file.
    *
    */

?>