<?php

   /**
    *
    * installation class for "runners club" demo template
    *
    */

    class ueldo_demo_contents_loader_base extends ueldo_demo_contents_loader_installation_helper {

       /**
        *
        * install template or its parts
        *
        */

        public static function install( $parts, $icons ) {

           /**
            *
            * install revolution slider
            *
            */

            if( $parts == 'all' || in_array( 'revolution-slider-sliders', $parts, true ) ) {

                # upload revolution slider and get its id
                if( ( $slider_id = ueldo_add_demo_assets::upload_revslider( 'runners-club' ) ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:revslider|context:runners-club}', 'alias="'. esc_attr( $slider_id ) .'"' );

                    # remove temporary variables
                    unset( $slider_id );
                }
            }

           /**
            *
            * install forms
            *
            */

            if( $parts == 'all' || in_array( 'forms', $parts, true ) ) {

                # add form in contact form 7 plugin and get its id
                if( ( $form_id = ueldo_add_demo_assets::add_contact_form() ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:contactform7|context:runners-club|inside:false}', 'id="'. esc_attr( $form_id ) .'"' );

                    # remove temporary variables
                    unset( $form_id );
                }
            }

           /**
            *
            * add pages, but not fill it with contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # add pages and get its ids
                $pages_ids = ueldo_add_demo_assets::add_empty_pages( 'page', array(
                    '404-page' => esc_html( __( '404 page', 'ueldo' ) ),
                    'home' => esc_html( __( 'Home', 'ueldo' ) )
                ));

                # add headers, footers and extras
                $hefos_ids = ueldo_add_demo_assets::add_empty_pages( 'ueldohefo', array(
                    'footer' => esc_html( __( 'Footer', 'ueldo' ) ),
                    'header' => esc_html( __( 'Header', 'ueldo' ) )
                ));

                # add solution
                self::add_solution( 'pages-ids', array_merge( $pages_ids, $hefos_ids ) );

                # show page on front
                update_option( 'show_on_front', 'page' );

                # update home page ID
                if( $pages_ids['home'] != null && $pages_ids['home'] != false ) update_option( 'page_on_front', $pages_ids['home'] );

                # remove temporary variables
                unset( $pages_ids );
            }

           /**
            *
            * install menus
            *
            */

            if( $parts == 'all' || in_array( 'menus', $parts, true ) ) {

                # add new menu
                if( is_int( $menu_id = ueldo_add_demo_assets::add_menu( 'runners-club-main-menu', self::get_solution( 'pages-ids' ), true ) ) ) {

                    # add solution
                    self::add_solution( 'main-menu-id', esc_attr( $menu_id ) );
                }
            }

           /**
            *
            * get dynamic elements replacements
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) || in_array( 'pages', $parts, true ) ) {

                # get dynamic elements replacements
                $replacements = self::get_dynamic_elements_replacements( self::find_dynamic_elements( self::get_vc_contents() ), $icons, self::get_default_replacements() );
            }

           /**
            *
            * install theme options
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) ) {

                # update theme options
                update_option( 'ueldo_theme_options', self::get_theme_options_array() );

                # set additional content before side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_before_all', self::do_content_replacements( self::get_vc_contents( 'additional-before-side-menu' ), $replacements ) );

                # set additional content after side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_after_all', self::do_content_replacements( self::get_vc_contents( 'additional-after-side-menu' ), $replacements ) );

                # clear theme mods - background color and image
                remove_theme_mod( 'background_color' );
                remove_theme_mod( 'background_position_x' );
                remove_theme_mod( 'background_position_y' );
                remove_theme_mod( 'background_repeat' );
                remove_theme_mod( 'background_attachment' );
                remove_theme_mod( 'background_size' );
                remove_theme_mod( 'background_image' );
            }

           /**
            *
            * fill pages contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # walk for each pages
                foreach( self::get_solution( 'pages-ids' ) as $page_slug => $page_id ) {

                    # update page content
                    $result = wp_update_post( array(
                        'ID' => esc_attr( $page_id ),
                        'post_content' => self::do_content_replacements( self::get_vc_contents( esc_attr( $page_slug ) ), $replacements )
                    ));
                }

                # remove temporary variables
                unset( $replacements );
            }

           /**
            *
            * update permalinks structure
            *
            */

            if( $parts == 'all' || in_array( 'permalinks-structure', $parts, true ) ) {

                # global variable
                global $wp_rewrite;

                # write the rule
                $wp_rewrite -> set_permalink_structure( '/%postname%/' );

                # set the option
                update_option( 'rewrite_rules', false );

                # flush the rules and tell it to write htaccess
                $wp_rewrite -> flush_rules( true );
            }

           /**
            *
            * demo data installed
            *
            */

            exit( '{ "status": "ok" }' );
        }

       /**
        *
        * get possible data parts
        *
        */

        public static function get_possible_data_parts() {

            # return result
            return( array(
                'menus' => esc_html( __( 'Menus', 'ueldo' ) ),
                'pages' => esc_html( __( 'Pages', 'ueldo' ) ),
                'theme-options' => esc_html( __( 'Theme options', 'ueldo' ) ),
                'forms' => esc_html( __( 'Forms', 'ueldo' ) ),
                'revolution-slider-sliders' => esc_html( __( 'Revolution Slider sliders', 'ueldo' ) ),
                'permalinks-structure' => esc_html( __( 'Permalinks structure', 'ueldo' ) )
            ));
        }

       /**
        *
        * get list of required plugins
        *
        */

        public static function get_required_plugins( $parts ) {

            # all data
            if( !is_array( $parts ) && $parts == 'all' ) {

                # return list of required plugins
                return( array(
                    'ueldo',
                    'visual-composer',
                    'revolution-slider',
                    'contact-form-7'
                ));
            }

            # selected parts
            else {

                # prepare array of required plugins
                $result = array( 'ueldo' );

                # do we have to add pages?
                if( in_array( 'pages', $parts, true ) ) {

                    # return list of required plugins
                    return( array(
                        'visual-composer',
                        'revolution-slider',
                        'contact-form-7'
                    ));
                }

                # do we have to add theme options?
                if( in_array( 'theme-options', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'visual-composer' ) );
                }

                # do we have to add forms?
                if( in_array( 'forms', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'contact-form-7' ) );
                }

                # do we have to add revolution slider sliders?
                if( in_array( 'revolution-slider-sliders', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'revolution-slider' ) );
                }

                # return result
                return( $result );
            }
        }

       /**
        *
        * get default replacements
        *
        */

        public static function get_default_replacements() {

            # add logo image
            $logo_image_id = ueldo_add_demo_assets::add_image( 'runners-club-logo' );

            # return result
            return( array(
                '{ueldopredefinedsections:image|context:runners-club-logo}' => ( $logo_image_id == false ? '' : 'image="'. esc_attr( $logo_image_id ) .'"' )
            ));
        }

       /**
        *
        * get trusted solution
        *
        */

        public static function get_trusted_solution( $type, $solution ) {

            # do we have solution found?
            if( !empty( $solution ) ) return( $solution );

            # switch by solution type
            switch( $type ) {

                # get most similar elements
                case 'main-menu-slug': return( self::get_most_similar_element( 'menu_slug', esc_html( __( 'Main menu - Runners Club template', 'ueldo' ) ) ) );
                case '404-page-id': return( self::get_most_similar_element( 'page', esc_html( __( '404 page', 'ueldo' ) ) ) );
                case 'footer-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Footer', 'ueldo' ) ) ) );
                case 'header-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Header', 'ueldo' ) ) ) );
            }

            # nothing found
            return( false );
        }

       /**
        *
        * get theme options array
        *
        */

        public static function get_theme_options_array() {

            # return result
            return( array(
                '404-page-id' => array( 'all' => self::get_trusted_solution( '404-page-id', self::get_solution( 'pages-ids', '404-page' ) ) ),
                'blog-posts-list-style' => array(
                    'posts-list-style' => 'default',
                    'display-post-data-under-title' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'yes'
                ),
                'blog-sidebar' => array(
                    'posts-list' => 'yes-right',
                    'single-post' => 'yes-right',
                    'responsive-style' => 'static'
                ),
                'boxed-website' => array(
                    'enabled' => 'no',
                    'large-content-width' => '1100',
                    'large-content-space' => '50',
                    'medium-content-width' => '890',
                    'medium-content-space' => '50',
                    'small-content-width' => '665',
                    'small-content-space' => '50'
                ),
                'comment-textarea-at-top' => 'yes',
                'dynamic-theme-styles-cache' => array(
                    'enabled' => 'no',
                    'clear-cache' => 'all-the-time-when-logged-in'
                ),
                'facebook-fanpage-url' => array( 'all' => 'https://www.facebook.com/envato' ),
                'featured-image-on-lists-only' => 'no',
                'fonts' => array(
                    'general-font-family' => array( 'all' => 'Roboto' ),
                    'general-font-weight' => array( 'all' => '300' ),
                    'general-font-subset' => array( 'all' => 'latin' ),
                    'general-font-smoothing' => array( 'all' => 'yes' ),
                    'general-bold-font-family' => array( 'all' => 'Roboto' ),
                    'general-bold-font-weight' => array( 'all' => '600' ),
                    'general-bold-font-subset' => array( 'all' => 'latin' ),
                    'general-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-font-family' => array( 'all' => 'Roboto' ),
                    'menu-font-weight' => array( 'all' => '500' ),
                    'menu-font-subset' => array( 'all' => 'latin' ),
                    'menu-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-font-family' => array( 'all' => 'Fira Sans' ),
                    'headings-font-weight' => array( 'all' => '500' ),
                    'headings-font-subset' => array( 'all' => 'latin' ),
                    'headings-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-slim-font-family' => array( 'all' => 'Roboto' ),
                    'headings-slim-font-weight' => array( 'all' => '300' ),
                    'headings-slim-font-subset' => array( 'all' => 'latin' ),
                    'headings-slim-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-bold-font-family' => array( 'all' => 'Fira Sans' ),
                    'headings-bold-font-weight' => array( 'all' => '900' ),
                    'headings-bold-font-subset' => array( 'all' => 'latin' ),
                    'headings-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-subtitle-font-family' => array( 'all' => 'Roboto' ),
                    'headings-subtitle-font-weight' => array( 'all' => '700' ),
                    'headings-subtitle-font-subset' => array( 'all' => 'latin' ),
                    'headings-subtitle-font-smoothing' => array( 'all' => 'yes' ),
                    'buttons-font-family' => array( 'all' => 'Roboto' ),
                    'buttons-font-weight' => array( 'all' => '700' ),
                    'buttons-font-subset' => array( 'all' => 'latin' ),
                    'buttons-font-smoothing' => array( 'all' => 'yes' ),
                    'form-fields-font-family' => array( 'all' => 'Roboto' ),
                    'form-fields-font-weight' => array( 'all' => '400' ),
                    'form-fields-font-subset' => array( 'all' => 'latin' ),
                    'form-fields-font-smoothing' => array( 'all' => 'yes' ),
                    'blockquote-font-family' => array( 'all' => 'Roboto' ),
                    'blockquote-font-weight' => array( 'all' => '500' ),
                    'blockquote-font-subset' => array( 'all' => 'latin' ),
                    'blockquote-font-smoothing' => array( 'all' => 'yes' ),
                    'alert-messages-font-family' => array( 'all' => 'Roboto' ),
                    'alert-messages-font-weight' => array( 'all' => '400' ),
                    'alert-messages-font-subset' => array( 'all' => 'latin' ),
                    'alert-messages-font-smoothing' => array( 'all' => 'yes' )
                ),
                'footer-content' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'footer-page-id', self::get_solution( 'pages-ids', 'footer' ) ) ),
                    'position' => array( 'all' => 'static' )
                ),
                'google-maps' => array(
                    'api-key' => '',
                    'next-map-id' => '1'
                ),
                'header' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'header-page-id', self::get_solution( 'pages-ids', 'header' ) ) ),
                    'position' => array( 'all' => 'flying' ),
                    'use-second-header' => array( 'all' => 'no' ),
                    'get-second-content-from' => array( 'all' => 'default' ),
                    'second-header-visible-from' => array( 'all' => '400' ),
                    'default-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'second-header-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) )
                ),
                'lazy-load-images' => array(
                    'enabled' => 'no',
                    'threshold' => '0'
                ),
                'loader-animation' => array(
                    'enabled' => 'yes',
                    'style' => '01',
                    'add-logo' => 'no',
                    'space-between-logo-and-spinner' => '30',
                    'logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'custom-colors-enabled' => 'no',
                    'custom-colors-background' => '#fff',
                    'custom-colors-spinner' => '#b9d014'
                ),
                'local-scrolling-links-animation' => array(
                    'enabled' => 'yes',
                    'animation-speed' => '1000'
                ),
                'opening-hours-status' => array( 'next-status-id' => '1' ),
                'rtl' => array(
                    'is-rtl' => array( 'all' => 'no' ),
                    'load-rtl-admin-styles' => array( 'all' => 'auto' )
                ),
                'side-menu' => array(
                    'style' => 'flying-default-hidden',
                    'menu-key' => array( 'all' => self::get_trusted_solution( 'main-menu-slug', self::get_main_menu_slug() ) ),
                    'menu-link-font-family' => array( 'all' => 'Fira Sans' ),
                    'menu-link-font-weight' => array( 'all' => '500' ),
                    'menu-link-font-subset' => array( 'all' => 'latin' ),
                    'menu-link-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-position' => 'left',
                    'menu-links-alignment' => 'center',
                    'opacity-animation-enabled' => 'yes',
                    'submenu-links' => 'visible-always',
                    'menu-vertical-alignment' => 'middle',
                    'custom-sizes-enabled' => 'yes',
                    'custom-sizes-container-width' => '300',
                    'custom-sizes-menu-link-font-size' => '16',
                    'custom-sizes-menu-link-font-line-height' => '1.0',
                    'custom-sizes-menu-link-font-letter-spacing' => '0',
                    'custom-sizes-menu-link-padding-top-bottom' => '20',
                    'custom-sizes-menu-link-padding-left-right' => '25',
                    'custom-sizes-menu-link-margin-top-bottom' => '0',
                    'custom-sizes-menu-link-margin-left-right' => '0',
                    'custom-sizes-menu-link-bottom-border-width' => '1',
                    'custom-sizes-display-bottom-border-for-last-menu-link' => 'display',
                    'custom-sizes-menu-icon-font-size' => '10',
                    'custom-sizes-menu-icon-margin-top' => '0',
                    'custom-sizes-menu-margin-between-icon-and-title' => '10',
                    'custom-sizes-padding-top-bottom-additional-element-before-menu' => '20',
                    'custom-sizes-padding-left-right-additional-element-before-menu' => '30',
                    'custom-sizes-margin-top-additional-element-before-menu' => '0',
                    'custom-sizes-margin-right-additional-element-before-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-before-menu' => '0',
                    'custom-sizes-margin-left-additional-element-before-menu' => '0',
                    'custom-sizes-padding-top-bottom-additional-element-after-menu' => '20',
                    'custom-sizes-padding-left-right-additional-element-after-menu' => '30',
                    'custom-sizes-margin-top-additional-element-after-menu' => '0',
                    'custom-sizes-margin-right-additional-element-after-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-after-menu' => '0',
                    'custom-sizes-margin-left-additional-element-after-menu' => '0'
                ),
                'single-blog-post-style' => array(
                    'display-post-data-under-title' => 'yes',
                    'blog-post-data-and-title-centered' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'yes'
                ),
                'submit-button-position-in-comment-reply-form' => array( 'all' => 'left' ),
                'translate-publication-dates' => 'yes',
                'twitter-api' => array(
                    'oauth-key' => '',
                    'oauth-secret-key' => ''
                ),
                'under-single-blog-post-content-elements' => array(
                    'elements-count' => '3',
                    'element-1-type' => 'tags-and-categories-with-facebook',
                    'element-1-similar-posts-style' => '02',
                    'element-2-type' => 'author-box',
                    'element-2-similar-posts-style' => '02',
                    'element-3-type' => 'next-previous-posts-navigation',
                    'element-3-similar-posts-style' => '02',
                    'element-4-type' => '',
                    'element-4-similar-posts-style' => '02',
                    'element-5-type' => '',
                    'element-5-similar-posts-style' => '02',
                    'element-6-type' => '',
                    'element-6-similar-posts-style' => '02'
                ),
                'vc-sections-on-blog-pages' => array(
                    'posts-list-above' => array( 'all' => 'none' ),
                    'posts-list-under' => array( 'all' => 'none' ),
                    'single-post-above' => array( 'all' => 'none' ),
                    'single-post-under' => array( 'all' => 'none' ),
                    'archive-above' => array( 'all' => 'none' ),
                    'archive-under' => array( 'all' => 'none' ),
                    'search-above' => array( 'all' => 'none' ),
                    'search-under' => array( 'all' => 'none' )
                ),
                'visual-composer-custom-fonts' => array( 'next-font-id' => '3' ),
                'styles' => array(
                    'line-height-headings' => '1.6',
                    'font-size-h1' => '46',
                    'general-colors-main-color' => '#b9d014',
                    'general-colors-google-map-marker-icon-color' => '#b9d014',
                    'info-box-element-background-color' => '#f8fbe9',
                    'info-box-element-border-color' => '#f8fbe9',
                    'general-colors-headings-subtitle-color' => '#b8cf16',
                    'general-colors-blog-post-data-color' => '#b8cf16',
                    'general-colors-elements-hover-border-color' => '#e5e9d1',
                    'point-of-interest-pulse-color' => '#a6bd02',
                    'general-colors-image-box-shadow' => '0px 0px 0px 0px rgba(255,255,255,0.01)',
                    'buttons-global-button-background-color' => '#b7ce17',
                    'buttons-global-button-border-color' => '#b7ce17',
                    'buttons-global-button-border-radius' => '25',
                    'buttons-global-button-background-color-hover' => '#a4bb07',
                    'buttons-global-button-border-color-hover' => '#a4bb07',
                    'buttons-global-button-box-shadow-hover' => '0px 10px 35px 0px rgba(164,187,7,0.25)',
                    'general-colors-elements-box-shadow' => '0px 10px 35px 0px rgba(0,0,0,0.03)',
                    'general-colors-elements-hover-box-shadow' => '0px 10px 35px 0px rgba(0,0,0,0.03)',
                    'header-bar-and-menu-background-color' => '#463429',
                    'header-bar-and-menu-link-color' => '#bdada3',
                    'header-bar-and-menu-active-or-hover-link-color' => '#b9d014',
                    'header-bar-and-menu-submenu-background-color' => '#b9d014',
                    'forms-checkbox-radio-main-color' => '#b9d014',
                    'side-menu-box-shadow' => '-5px 0px 20px 0px rgba(182,205,23,0.15)',
                    'side-menu-background-color' => '#b6cd17',
                    'side-menu-link-color' => '#eaf5a0',
                    'side-menu-link-color-hover' => '#ffffff',
                    'side-menu-active-link-color' => '#ffffff'
                )
            ));
        }

       /**
        *
        * get default contents
        *
        */

        public static function get_vc_contents( $page_slug = false ) {

            # array of pages contents
            $contents = array(

                'home' => '[vc_section full_width="stretch_row_content"][vc_row full_width="stretch_row_content_no_spaces"][vc_column][rev_slider {ueldopredefinedsections:revslider|context:runners-club}][/vc_column][/vc_row][/vc_section][vc_section el_class="ueldo-vc-section-overflow-visible"][vc_row el_class="ueldo-vc-row-overflow-visible" css=".vc_custom_1512466281691{margin-top: -60px !important;}"][vc_column][ueldo_shortcode_card class_name="ueldo_vc_element_15077964726749" border_width="0" padding_top="35" padding_right="45" padding_bottom="60" padding_left="45"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_83427640534156" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-runner,flaticon-interface|url:https://www.flaticon.com/free-icon/runner_182603|slug:icon_} icon_size="148" icon_rotate="10deg" icon_color="rgba(0,0,0,0.03)" large_width_type="px" large_width_px="148" large_height_type="px" large_height_px="148" large_layer_position="top_right" large_margin_top="-18" large_margin_right="-18"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_91301356831247" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-sports,flaticon-podium|url:https://www.flaticon.com/free-icon/podium_342460|slug:icon_} icon_size="148" icon_rotate="345deg" icon_color="rgba(0,0,0,0.03)" large_width_type="px" large_width_px="148" large_height_type="px" large_height_px="148" large_margin_top="-18" large_margin_left="-18"][ueldo_shortcode_heading class_name="ueldo_vc_element_76607552366066" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1936005164785" heading_text="'. esc_html( __( 'Want to run a Marathon?', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" font_size="28" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_gap class_name="ueldo_vc_element_15082308175401" large_height="20"][ueldo_shortcode_heading class_name="ueldo_vc_element_13080886485293" heading_tag="h1" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_top="-15" custom_margin_bottom="60"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_7797548971372" heading_text="'. esc_html( __( 'Let\'s train together!', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" line_height="1" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15077979035754"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_77554003956771" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" small_custom_sizes="yes"][ueldo_shortcode_info_box class_name="ueldo_vc_element_79378729664971" content_alignment="left" content_position="inline" display_additional_info_box_element="yes" info_box_title="'. esc_html( __( 'Marathons finished together', 'ueldo' ) ) .'" info_box_subtitle="Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos." {ueldopredefinedsections:icon|key:flaticon-medal|url:https://www.flaticon.com/free-icon/medal_341464|slug:info_element_icon_} additional_info_element_width="48" additional_info_element_height="48" additional_info_element_margin_right="12" additional_info_element_margin_bottom="12" additional_info_element_type="counter" additional_info_element_counter_value="42" additional_info_element_counter_custom_font_enabled="custom_settings" additional_info_element_counter_font_size="24" additional_info_element_counter_font_family="headings-bold-font"][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_15081620117405" large_height="0" small_custom_sizes="yes" small_height="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_72410282451473" large_width_type="px" large_width_px="30" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_31706857788512" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" small_custom_sizes="yes"][ueldo_shortcode_info_box class_name="ueldo_vc_element_20464272605876" content_alignment="left" content_position="inline" display_additional_info_box_element="yes" info_box_title="'. esc_html( __( 'Experienced trainers', 'ueldo' ) ) .'" info_box_subtitle="Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos." {ueldopredefinedsections:icon|key:flaticon-running-shoes,flaticon-sports|url:https://www.flaticon.com/free-icon/running-shoes_418281|slug:info_element_icon_} additional_info_element_width="48" additional_info_element_height="48" additional_info_element_margin_right="12" additional_info_element_margin_bottom="12" additional_info_element_type="counter" additional_info_element_counter_value="6" additional_info_element_counter_custom_font_enabled="custom_settings" additional_info_element_counter_font_size="24" additional_info_element_counter_font_family="headings-bold-font"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible"][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_89190836013752" large_height="75" small_custom_sizes="yes" small_height="440"][ueldo_shortcode_heading class_name="ueldo_vc_element_4174573318487" text_align="center" heading_subtitle_text="'. esc_html( __( 'Good plan is a half of the success', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_68123201912105" heading_text="'. esc_html( __( 'How do we prepare for a Marathon?', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text][ueldo_next_prev_loop_icons loop_id="81075938462200"][/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15078868912156" large_height="25"][ueldo_shortcode_card class_name="ueldo_vc_element_52460958689290" border_width="0" padding_top="0" padding_right="0" padding_bottom="0" padding_left="0" custom_colors_enabled="custom_settings" box_shadow_color="rgba(255,255,255,0.01)" box_shadow_blur_radius_hover="0" box_shadow_color_hover="rgba(255,255,255,0.01)" background_color="#fafbf7" background_color_hover="#fafbf7"][ueldo_shortcode_loop class_name="ueldo_vc_element_81075938462200" columns="1" use_separate_next_prev_arrows="separated" custom_next_prev_arrows_settings="custom_settings" arrow_border_radius="4" arrow_border_width="1" custom_colors_enabled="custom_settings" loop_background_color="rgba(255,255,255,0)" next_prev_arrow_color="#eeeeee" next_prev_arrow_container_background="#ffffff" next_prev_arrow_container_background_hover="#ffffff" next_prev_arrow_container_border_color="#f1f1f1" next_prev_arrow_container_border_color_hover="#e5e9d1" next_prev_arrow_container_box_shadow_color="rgba(255,255,255,0.01)" next_prev_arrow_container_box_shadow_color_hover="rgba(255,255,255,0.01)"][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_9279784849086"][ueldo_shortcode_gap class_name="ueldo_vc_element_88774439750863" large_height="45" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_91853766070332"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_57966492003388" large_width_type="px" large_width_px="60" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_56651863706488" large_width_type="px" large_width_px="150" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="30"][ueldo_shortcode_icon class_name="ueldo_vc_element_4838352222539" {ueldopredefinedsections:icon|key:flaticon-calendar,flaticon-time|url:https://www.flaticon.com/free-icon/calendar_149375|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="90" custom_colors_enabled="custom_settings" icon_color="#b8cf16"][ueldo_shortcode_gap class_name="ueldo_vc_element_15082299772255" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_12633333215725" large_width_percentage="0%" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_65517035464533" large_width_type="calc" large_width_calc_px="270" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="60"][ueldo_shortcode_heading class_name="ueldo_vc_element_5414487111293" heading_subtitle_text="'. esc_html( __( 'Step 1.', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_43662492294239" heading_text="'. esc_html( __( 'Following a Training Schedule', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Integer non nisl rutrum, pretium dui at, aliquet sapien. Donec eget nisi a mauris ultricies ornare eu non mauris. Nulla molestie metus in facilisis interdum. Pellentesque facilisis elit.[/vc_column_text][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_71712671411186" large_width_type="px" large_width_px="60" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="30"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_90962823159426" large_height="45" extra_small_custom_sizes="yes" extra_small_height="30"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_36543842313388"][ueldo_shortcode_gap class_name="ueldo_vc_element_26861488396706" large_height="45" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_55576963289444"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_72660414132422" large_width_type="px" large_width_px="60" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_60480843079081" large_width_type="px" large_width_px="150" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="30"][ueldo_shortcode_icon class_name="ueldo_vc_element_1497023452985" {ueldopredefinedsections:icon|key:flaticon-sleep,flaticon-clock|url:https://www.flaticon.com/free-icon/sleep_563442|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="90" custom_colors_enabled="custom_settings" icon_color="#b8cf16"][ueldo_shortcode_gap class_name="ueldo_vc_element_15082300432857" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_98608173915601" large_width_percentage="0%" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_28857326648947" large_width_type="calc" large_width_calc_px="260" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="60"][ueldo_shortcode_heading class_name="ueldo_vc_element_7214766924165" heading_subtitle_text="'. esc_html( __( 'Step 2.', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_94251738884579" heading_text="'. esc_html( __( 'Recovering From Your Workouts', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Integer non nisl rutrum, pretium dui at, aliquet sapien. Donec eget nisi a mauris ultricies ornare eu non mauris. Nulla molestie metus in facilisis interdum. Pellentesque facilisis elit nec lacus.[/vc_column_text][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_1345434157623" large_width_type="px" large_width_px="60" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="30"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_19486288611482" large_height="45" extra_small_custom_sizes="yes" extra_small_height="30"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_72141467022213"][ueldo_shortcode_gap class_name="ueldo_vc_element_37072631265442" large_height="45" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_93391267668627"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_71318578190379" large_width_type="px" large_width_px="60" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_71952242756859" large_width_type="px" large_width_px="150" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="30"][ueldo_shortcode_icon class_name="ueldo_vc_element_2439103805692" {ueldopredefinedsections:icon|key:flaticon-vegetable,flaticon-food|url:https://www.flaticon.com/free-icon/vegetable_497190|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="90" custom_colors_enabled="custom_settings" icon_color="#b8cf16"][ueldo_shortcode_gap class_name="ueldo_vc_element_15082300888667" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_88510160363029" large_width_percentage="0%" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_64356870806399" large_width_type="calc" large_width_calc_px="260" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="60"][ueldo_shortcode_heading class_name="ueldo_vc_element_9386151191275" heading_subtitle_text="'. esc_html( __( 'Step 3.', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_23754504951693" heading_text="'. esc_html( __( 'Getting the Right Nutrition', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Integer non nisl rutrum, pretium dui at, aliquet sapien. Donec eget nisi a mauris ultricies ornare eu non mauris. Nulla molestie metus in facilisis interdum. Pellentesque facilisis elit nec lacus.[/vc_column_text][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_27209869775635" large_width_type="px" large_width_px="60" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="30"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_61197880766302" large_height="45" extra_small_custom_sizes="yes" extra_small_height="30"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_95265870396065"][ueldo_shortcode_gap class_name="ueldo_vc_element_30447250554988" large_height="45" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_90756288389750"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_46231727420940" large_width_type="px" large_width_px="60" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_85874185799713" large_width_type="px" large_width_px="150" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="30"][ueldo_shortcode_icon class_name="ueldo_vc_element_2376124826412" {ueldopredefinedsections:icon|key:flaticon-runner,flaticon-interface|url:https://www.flaticon.com/free-icon/runner_182603|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="90" custom_colors_enabled="custom_settings" icon_color="#b8cf16"][ueldo_shortcode_gap class_name="ueldo_vc_element_15082301409366" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_37016934886670" large_width_percentage="0%" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_34831286334063" large_width_type="calc" large_width_calc_px="260" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="60"][ueldo_shortcode_heading class_name="ueldo_vc_element_1146622812570" heading_subtitle_text="'. esc_html( __( 'Step 4.', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_10871252459477" heading_text="'. esc_html( __( 'Getting the Right Gear', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Integer non nisl rutrum, pretium dui at, aliquet sapien. Donec eget nisi a mauris ultricies ornare eu non mauris. Nulla molestie metus in facilisis interdum. Pellentesque facilisis elit nec lacus.[/vc_column_text][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_6632120934167" large_width_type="px" large_width_px="60" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="30"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_67043295885235" large_height="45" extra_small_custom_sizes="yes" extra_small_height="30"][/ueldo_shortcode_loop_cell][/ueldo_shortcode_loop][/ueldo_shortcode_card][/vc_column][vc_column width="1/3" offset="vc_hidden-sm vc_hidden-xs"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_1437326295951" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" layer_type="image" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="233" large_height_type="calc" large_height_calc_operator="+" large_height_calc_px="60" large_layer_position="top_right" large_margin_top="-60" large_custom_row_border_radius="yes-unique-for-corners" large_row_border_radius_top_left_corner="4" large_row_border_radius_bottom_left_corner="4" medium_layer_custom_sizes="yes" medium_width_type="calc" medium_width_calc_base="50%" medium_width_calc_px="198" medium_height_type="calc" medium_height_calc_operator="+" medium_height_calc_px="60" medium_layer_position="top_right" medium_margin_top="-60" medium_custom_row_border_radius="yes-copy-from-large" small_layer_custom_sizes="yes" small_width_type="calc" small_width_calc_base="50%" small_width_calc_operator="+" small_width_calc_px="332" small_height_type="px" small_height_px="350" small_layer_position="top_right" small_margin_top="30" small_custom_row_border_radius="yes-copy-from-large" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="30" extra_small_height_type="px" extra_small_height_px="350" extra_small_layer_position="top_right" extra_small_margin_top="30" extra_small_custom_row_border_radius="yes-copy-from-large"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible" el_id="why-to-train-with-us"][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/3" offset="vc_hidden-sm vc_hidden-xs"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_3203256522075" layer_for_row_or_section="section" layer_z_index="0" custom_layer_sizes="custom_settings" layer_type="image" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="233" large_height_type="calc" large_height_calc_operator="+" large_height_calc_px="60" large_margin_top="-60" large_custom_row_border_radius="yes-unique-for-corners" large_row_border_radius_top_right_corner="4" large_row_border_radius_bottom_right_corner="4" medium_layer_custom_sizes="yes" medium_width_type="calc" medium_width_calc_base="50%" medium_width_calc_px="198" medium_height_type="calc" medium_height_calc_operator="+" medium_height_calc_px="60" medium_margin_top="-60" medium_custom_row_border_radius="yes-copy-from-large" small_layer_custom_sizes="yes" small_width_type="calc" small_width_calc_base="50%" small_width_calc_operator="+" small_width_calc_px="332" small_height_type="px" small_height_px="350" small_margin_top="30" small_custom_row_border_radius="yes-copy-from-large" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="30" extra_small_height_type="px" extra_small_height_px="350" extra_small_margin_top="30" extra_small_custom_row_border_radius="yes-copy-from-large"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_46788426908410" large_height="75" small_custom_sizes="yes" small_height="440"][ueldo_shortcode_heading class_name="ueldo_vc_element_4722794177546" text_align="center" heading_subtitle_text="'. esc_html( __( 'Together we\'re stronger', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_78993558261066" heading_text="'. esc_html( __( 'Why you will love to run with us?', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Maecenas quis justo ipsum. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Donec ut condimentum nunc. Duis consectetur, lacus vel interdum tempus, nisi ante volutpat magna, in aliquam ipsum massa nec risus. Vestibulum aliquet, ante blandit egestas tincidunt.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15078896167713" large_height="24"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15078881987649"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_60141653214921" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" extra_small_custom_sizes="yes"][ueldo_shortcode_heading class_name="ueldo_vc_element_19338084915859" heading_tag="h5" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_36845080312293" heading_text="Donec mi velit, pharetra id turpis:"][/ueldo_shortcode_heading][ueldo_shortcode_icon_list class_name="ueldo_vc_element_15078889051996" icon_fontawesome="fa fa-check" margin_bottom="0"]Integer eget dui eleifend massa,<br /><br /> Euismod consectetur sed nec arcu,<br /><br /> Ut non sem aliquet turpis auctor,<br /><br /> Morbi molestie arcu ante eget,<br /><br /> Turpis euismod in, vestibulum ante,<br /><br /> Primis in faucibus orci luctus et[/ueldo_shortcode_icon_list][ueldo_shortcode_gap class_name="ueldo_vc_element_15082303201755" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_79042807125061" large_width_type="px" large_width_px="30" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_25578182164775" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" extra_small_custom_sizes="yes"][ueldo_shortcode_card class_name="ueldo_vc_element_15078906007002" border_width="0" padding_top="0" padding_bottom="0"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_46060063121366" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-shoe,flaticon-fashion|url:https://www.flaticon.com/free-icon/shoe_250333|slug:icon_} icon_size="98" icon_rotate="15deg" icon_color="rgba(0,0,0,0.03)" large_width_type="px" large_width_px="98" large_height_type="px" large_height_px="98" large_layer_position="top_right" large_margin_top="-33" large_margin_right="-8"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_89163799739844" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-speed,flaticon-people|url:https://www.flaticon.com/free-icon/speed_249167|slug:icon_} icon_size="98" icon_rotate="345deg" icon_color="rgba(0,0,0,0.03)" large_width_type="px" large_width_px="98" large_height_type="px" large_height_px="98" large_layer_position="bottom_left" large_margin_bottom="-8" large_margin_left="-8"][ueldo_shortcode_gap class_name="ueldo_vc_element_18802470780024" large_height="40"][ueldo_shortcode_heading class_name="ueldo_vc_element_99330867847053" heading_tag="h5" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_56825829290289" heading_text="'. esc_html( __( 'We\'ll help you to increase your strength and endurance!', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_button class_name="ueldo_vc_element_15078901325575" button_text="'. esc_html( __( 'Call us now!', 'ueldo' ) ) .'" button_alignment="center" show_button_icon="yes" button_icon_fontawesome="fa fa-phone-square" hover_transform_enabled="yes"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_15078912235516" large_height="40"][/ueldo_shortcode_card][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][/vc_section][vc_section el_id="upcoming-marathons"][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_47664541306122" large_height="75"][ueldo_shortcode_heading class_name="ueldo_vc_element_22567316500952" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_13393484780394" heading_text="'. esc_html( __( 'What we are prepairing for?', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_gap class_name="ueldo_vc_element_59803094120832" large_height="20"][ueldo_shortcode_heading class_name="ueldo_vc_element_61809656594908" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_top="-15" custom_margin_bottom="60"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_58248259779596" heading_text="'. esc_html( __( 'Upcoming Marathons we\'ll run', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" line_height="1" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][/vc_column][/vc_row][vc_row][vc_column width="1/3"][ueldo_shortcode_icon class_name="ueldo_vc_element_38285518605778" {ueldopredefinedsections:icon|key:flaticon-statue-of-liberty,flaticon-monument|url:https://www.flaticon.com/free-icon/statue-of-liberty_181442|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="75" margin_bottom="15" custom_colors_enabled="custom_settings" icon_color="#b9d014"][ueldo_shortcode_heading class_name="ueldo_vc_element_23667410130676" heading_tag="h5" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_38660285997959" heading_text="'. esc_html( __( 'New York Marathon', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Aenean magna tortor, interdum eu urna in, auctor facilisis mi. Integer sit amet auctor justo, ac pellentesque ipsum vestibulum.<br /><br /> <strong>'. esc_html( __( 'Date:', 'ueldo' ) ) .'</strong> '. esc_html( __( 'November 4, 2018', 'ueldo' ) ) .'<br /> <strong>'. esc_html( __( 'Time-Qualifying Standards:', 'ueldo' ) ) .'</strong> <a href="#">'. esc_html( __( 'Check here', 'ueldo' ) ) .'</a>[/vc_column_text][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_67774173070556" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_icon class_name="ueldo_vc_element_76152889161728" {ueldopredefinedsections:icon|key:flaticon-london-bridge,flaticon-monuments|url:https://www.flaticon.com/free-icon/london-bridge_181430|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="75" margin_bottom="15" custom_colors_enabled="custom_settings" icon_color="#b9d014"][ueldo_shortcode_heading class_name="ueldo_vc_element_70957375949255" heading_tag="h5" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_67718499240054" heading_text="'. esc_html( __( 'London Marathon', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Aenean magna tortor, interdum eu urna in, auctor facilisis mi. Integer sit amet auctor justo, ac pellentesque ipsum vestibulum.<br /><br /> <strong>'. esc_html( __( 'Date:', 'ueldo' ) ) .'</strong> '. esc_html( __( 'April 22, 2018', 'ueldo' ) ) .'<br /> <strong>'. esc_html( __( 'Time-Qualifying Standards:', 'ueldo' ) ) .'</strong> <a href="#">'. esc_html( __( 'Check here', 'ueldo' ) ) .'</a>[/vc_column_text][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_24457202879983" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_icon class_name="ueldo_vc_element_14164639962952" {ueldopredefinedsections:icon|key:flaticon-eiffel-tower,flaticon-travel|url:https://www.flaticon.com/free-icon/eiffel-tower_244463|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="75" margin_bottom="15" custom_colors_enabled="custom_settings" icon_color="#b9d014"][ueldo_shortcode_heading class_name="ueldo_vc_element_91563899134886" heading_tag="h5" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_56253143989030" heading_text="'. esc_html( __( 'Paris Marathon', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Aenean magna tortor, interdum eu urna in, auctor facilisis mi. Integer sit amet auctor justo, ac pellentesque ipsum vestibulum.<br /><br /> <strong>'. esc_html( __( 'Date:', 'ueldo' ) ) .'</strong> '. esc_html( __( 'April 8, 2018', 'ueldo' ) ) .'<br /> <strong>'. esc_html( __( 'Time-Qualifying Standards:', 'ueldo' ) ) .'</strong> <a href="#">'. esc_html( __( 'Check here', 'ueldo' ) ) .'</a>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15078964543181" large_height="15" small_custom_sizes="yes"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row" el_id="our-trainers"][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15123827272724"][/vc_column][/vc_row][vc_row content_placement="bottom" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15079060212185" heading_subtitle_text="'. esc_html( __( 'About us', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15079060508588" heading_text="'. esc_html( __( 'Meet our trainers!', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]Nam orci lorem, congue nec lectus et, maximus dignissim eros. Lorem ipsum dolor sit amet, consectetur adipiscing.[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_15079065012643" button_text="'. esc_html( __( 'Call us now!', 'ueldo' ) ) .'" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_fontawesome="fa fa-phone-square" hover_transform_enabled="yes"][/ueldo_shortcode_button][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15082281968993" large_height="0" small_custom_sizes="yes"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_1507898676132" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" color="#f8f5f2" large_height_type="calc" large_height_calc_px="120" large_layer_position="bottom_left" medium_layer_custom_sizes="yes" medium_height_type="calc" medium_height_calc_px="90" medium_layer_position="bottom_left" small_layer_custom_sizes="yes"][ueldo_shortcode_presentation class_name="ueldo_vc_element_15078985606081"][ueldo_shortcode_presentation_element class_name="ueldo_vc_element_1507898572516"][ueldo_shortcode_presentation_point_of_interest class_name="ueldo_vc_element_51376045415637" position_y="30%" position_x="23.70%" modal_position="bottom" title="'. esc_html( __( 'Susane Smith', 'ueldo' ) ) .'"]<strong>'. esc_html( __( 'Susane Smith', 'ueldo' ) ) .'</strong><br /><br /> Phasellus euismod arcu sit amet orci dictum aliquam. Fusce ac nunc dolor. Aliquam erat volutpat. Praesent ultricies molestie tortor, sit amet bibendum justo pellentesque nec. Quisque pulvinar dolor nisl, non convallis tellus cursus ac. Suspendisse ut justo odio. Nulla facilisis nulla ac dictum aliquam.[/ueldo_shortcode_presentation_point_of_interest][ueldo_shortcode_presentation_point_of_interest class_name="ueldo_vc_element_10244190757499" position_y="37%" position_x="32.40%" modal_position="bottom" title="'. esc_html( __( 'Monica Wayne', 'ueldo' ) ) .'"]<strong>'. esc_html( __( 'Monica Wayne', 'ueldo' ) ) .'</strong><br /><br /> Phasellus euismod arcu sit amet orci dictum aliquam. Fusce ac nunc dolor. Aliquam erat volutpat. Praesent ultricies molestie tortor, sit amet bibendum justo pellentesque nec. Quisque pulvinar dolor nisl, non convallis tellus cursus ac. Suspendisse ut justo odio. Nulla facilisis nulla ac dictum aliquam.[/ueldo_shortcode_presentation_point_of_interest][ueldo_shortcode_presentation_point_of_interest class_name="ueldo_vc_element_65401387120895" position_y="29.50%" position_x="41%" modal_position="bottom" title="'. esc_html( __( 'Tom Jones', 'ueldo' ) ) .'"]<strong>'. esc_html( __( 'Tom Jones', 'ueldo' ) ) .'</strong><br /><br /> Phasellus euismod arcu sit amet orci dictum aliquam. Fusce ac nunc dolor. Aliquam erat volutpat. Praesent ultricies molestie tortor, sit amet bibendum justo pellentesque nec. Quisque pulvinar dolor nisl, non convallis tellus cursus ac. Suspendisse ut justo odio. Nulla facilisis nulla ac dictum aliquam.[/ueldo_shortcode_presentation_point_of_interest][ueldo_shortcode_presentation_point_of_interest class_name="ueldo_vc_element_42032565488486" position_y="38%" position_x="52%" modal_position="bottom" title="'. esc_html( __( 'Anne Johnes', 'ueldo' ) ) .'"]<strong>'. esc_html( __( 'Anne Johnes', 'ueldo' ) ) .'</strong><br /><br /> Phasellus euismod arcu sit amet orci dictum aliquam. Fusce ac nunc dolor. Aliquam erat volutpat. Praesent ultricies molestie tortor, sit amet bibendum justo pellentesque nec. Quisque pulvinar dolor nisl, non convallis tellus cursus ac. Suspendisse ut justo odio. Nulla facilisis nulla ac dictum aliquam.[/ueldo_shortcode_presentation_point_of_interest][ueldo_shortcode_presentation_point_of_interest class_name="ueldo_vc_element_17492400281621" position_y="41%" position_x="60%" modal_position="bottom" title="'. esc_html( __( 'Rachel Rayne', 'ueldo' ) ) .'"]<strong>'. esc_html( __( 'Rachel Rayne', 'ueldo' ) ) .'</strong><br /><br /> Phasellus euismod arcu sit amet orci dictum aliquam. Fusce ac nunc dolor. Aliquam erat volutpat. Praesent ultricies molestie tortor, sit amet bibendum justo pellentesque nec. Quisque pulvinar dolor nisl, non convallis tellus cursus ac. Suspendisse ut justo odio. Nulla facilisis nulla ac dictum aliquam.[/ueldo_shortcode_presentation_point_of_interest][ueldo_shortcode_presentation_point_of_interest class_name="ueldo_vc_element_37940806982149" position_y="34%" position_x="67.50%" modal_position="bottom" title="'. esc_html( __( 'Mike McDonovan', 'ueldo' ) ) .'"]<strong>'. esc_html( __( 'Mike McDonovan', 'ueldo' ) ) .'</strong><br /><br /> Phasellus euismod arcu sit amet orci dictum aliquam. Fusce ac nunc dolor. Aliquam erat volutpat. Praesent ultricies molestie tortor, sit amet bibendum justo pellentesque nec. Quisque pulvinar dolor nisl, non convallis tellus cursus ac. Suspendisse ut justo odio. Nulla facilisis nulla ac dictum aliquam.[/ueldo_shortcode_presentation_point_of_interest][/ueldo_shortcode_presentation_element][/ueldo_shortcode_presentation][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_59342804642797" large_height="75"][/vc_column][/vc_row][vc_row][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_progress_bar class_name="ueldo_vc_element_63031463059448" progress_bar_duration="2000" progress_bar_value="85%" progress_bar_title="'. esc_html( __( 'Marathons finished together', 'ueldo' ) ) .'" progress_bar_title_position="above-progress-bar" custom_colors_enabled="custom_settings" inactive_background_color="#ece5e0"][vc_column_text]Interdum et malesuada fames ac ante ipsum primis in faucibus. Mauris vulputate, dui ac placerat laoreet, augue mi mollis odio, id dictum.[/vc_column_text][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_65128894620776" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_progress_bar class_name="ueldo_vc_element_35236340094619" progress_bar_duration="2000" progress_bar_value="72%" progress_bar_title="'. esc_html( __( 'Strength improvement', 'ueldo' ) ) .'" progress_bar_title_position="above-progress-bar" custom_colors_enabled="custom_settings" inactive_background_color="#ece5e0"][vc_column_text]Interdum et malesuada fames ac ante ipsum primis in faucibus. Mauris vulputate, dui ac placerat laoreet, augue mi mollis odio, id dictum.[/vc_column_text][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_24545744132923" large_height="0" small_custom_sizes="yes" small_height="45"][ueldo_shortcode_progress_bar class_name="ueldo_vc_element_16722083510638" progress_bar_duration="2000" progress_bar_value="100%" progress_bar_title="'. esc_html( __( 'New friendships', 'ueldo' ) ) .'" progress_bar_title_position="above-progress-bar" custom_colors_enabled="custom_settings" inactive_background_color="#ece5e0"][vc_column_text]Interdum et malesuada fames ac ante ipsum primis in faucibus. Mauris vulputate, dui ac placerat laoreet, augue mi mollis odio, id dictum.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_54112995970352" large_height="75"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15079140366547" large_height="75"][ueldo_shortcode_heading class_name="ueldo_vc_element_15079138585324" text_align="center" heading_subtitle_text="'. esc_html( __( 'Let\'s do it together!', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15079138825565" heading_text="'. esc_html( __( 'The successes achieved by our runners', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][/vc_column][/vc_row][vc_row][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][vc_column_text]<p style="text-align: center;">Nullam leo nulla, suscipit at luctus non, mattis ut enim. Orci varius natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Nunc sagittis mi quis posuere vulputate. Etiam in dolor a urna placerat consectetur, donec molestie.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_1507971735321" large_height="25"][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_73764629813023"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_35838843871000" large_width_type="px" large_width_px="45" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="20" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_65720652455618" large_width_type="calc" large_width_calc_px="90" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_px="40" small_custom_sizes="yes"][ueldo_shortcode_icon class_name="ueldo_vc_element_42229352805346" icon_alignment="center" {ueldopredefinedsections:icon|key:flaticon-sports,flaticon-podium|url:https://www.flaticon.com/free-icon/podium_342460|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="60" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#b9d014"][ueldo_shortcode_heading class_name="ueldo_vc_element_30449906279843" heading_tag="h5" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1611294690689" heading_text="'. esc_html( __( 'Top 50 place in New York Marathon', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_76448706321377" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_23725311055892"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_25570745678829" large_width_type="px" large_width_px="45" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="20" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_97758300622370" large_width_type="calc" large_width_calc_px="90" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_px="40" small_custom_sizes="yes"][ueldo_shortcode_icon class_name="ueldo_vc_element_16745467747563" icon_alignment="center" {ueldopredefinedsections:icon|key:flaticon-trophy,flaticon-cup|url:https://www.flaticon.com/free-icon/trophy_420105|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="60" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#b9d014"][ueldo_shortcode_heading class_name="ueldo_vc_element_61186663449432" heading_tag="h5" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_2524412154797" heading_text="'. esc_html( __( 'Together we finished 42 marathons', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_46715493280191" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_84079909371116"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_63906268792317" large_width_type="px" large_width_px="45" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="20" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_90913700141351" large_width_type="calc" large_width_calc_px="90" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_px="40" small_custom_sizes="yes"][ueldo_shortcode_icon class_name="ueldo_vc_element_79335703010286" icon_alignment="center" {ueldopredefinedsections:icon|key:flaticon-teamwork,flaticon-people|url:https://www.flaticon.com/free-icon/teamwork_160128|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="60" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#b9d014"][ueldo_shortcode_heading class_name="ueldo_vc_element_65330663830024" heading_tag="h5" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_8725296210530" heading_text="'. esc_html( __( '7 Ultramarathons finished in last three years', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_150797187758" large_height="75"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible"][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/3" offset="vc_hidden-sm vc_hidden-xs"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_93203256522075" layer_for_row_or_section="section" layer_z_index="0" custom_layer_sizes="custom_settings" layer_type="image" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="233" large_height_type="calc" large_height_calc_px="30" large_custom_row_border_radius="yes-unique-for-corners" large_row_border_radius_top_right_corner="4" large_row_border_radius_bottom_right_corner="4" medium_layer_custom_sizes="yes" medium_width_type="calc" medium_width_calc_base="50%" medium_width_calc_px="198" medium_height_type="calc" medium_height_calc_px="30" medium_custom_row_border_radius="yes-copy-from-large" small_layer_custom_sizes="yes" small_width_type="calc" small_width_calc_base="50%" small_width_calc_operator="+" small_width_calc_px="332" small_height_type="px" small_height_px="350" small_custom_row_border_radius="yes-copy-from-large" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="30" extra_small_height_type="px" extra_small_height_px="350" extra_small_custom_row_border_radius="yes-copy-from-large"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15079728531203" small_custom_sizes="yes" small_height="410"][ueldo_shortcode_heading class_name="ueldo_vc_element_15079728586184" text_align="center" heading_subtitle_text="'. esc_html( __( 'Our runners opinions', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15079728706236" heading_text="'. esc_html( __( 'What does the others says about us?', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text][ueldo_next_prev_loop_icons loop_id="15079743168805"][/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_915079720214605" large_height="25"][ueldo_shortcode_loop class_name="ueldo_vc_element_15079743168805" columns="2" use_separate_next_prev_arrows="separated" custom_next_prev_arrows_settings="custom_settings" arrow_border_radius="4" arrow_border_width="1"][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_49304715252750"][ueldo_shortcode_card class_name="ueldo_vc_element_63079518258499" border_width="0" padding_top="30" padding_bottom="30"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_16206038482561" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-right-quote,flaticon-interface|url:https://www.flaticon.com/free-icon/right-quote_157248|slug:icon_} icon_size="78" icon_color="rgba(0,0,0,0.03)" large_width_type="px" large_width_px="78" large_height_type="px" large_height_px="78" large_layer_position="top_right" large_margin_top="-20" large_margin_right="-8"][ueldo_shortcode_icon class_name="ueldo_vc_element_55519321012754" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_81155281111424" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_50932724902183" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_64884740008307" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_27380242540888" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_gap class_name="ueldo_vc_element_63969443911796" large_height="30"][vc_column_text]Nulla volutpat finibus euismod. Vestibulum et porta diam. Phasellus fringilla lorem a elementum gravida. Aliquam eu euismod risus.[/vc_column_text][ueldo_shortcode_inline_container class_name="ueldo_vc_element_33090646696145"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_61254379511535" large_width_type="px" large_width_px="80"][ueldo_shortcode_image class_name="ueldo_vc_element_18360860501555" border_radius="25" large_width_type="px" large_width_px="50" large_height_px="50" margin_bottom="0"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_57045199714674" large_width_type="calc" large_width_calc_px="80"][vc_column_text]<strong>'. esc_html( __( 'Anne Wayne', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Important Company, LLC', 'ueldo' ) ) .'[/vc_column_text][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_64403305908341" large_height="30"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_16957295797803"][ueldo_shortcode_card class_name="ueldo_vc_element_79327885741751" border_width="0" padding_top="30" padding_bottom="30"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_24981969554162" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-right-quote,flaticon-interface|url:https://www.flaticon.com/free-icon/right-quote_157248|slug:icon_} icon_size="78" icon_color="rgba(0,0,0,0.03)" large_width_type="px" large_width_px="78" large_height_type="px" large_height_px="78" large_layer_position="top_right" large_margin_top="-20" large_margin_right="-8"][ueldo_shortcode_icon class_name="ueldo_vc_element_58456252972610" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_41842058706250" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_80092245534744" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_14155237992850" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_24554468600038" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_gap class_name="ueldo_vc_element_27311063642721" large_height="30"][vc_column_text]Nulla volutpat finibus euismod. Vestibulum et porta diam. Phasellus fringilla lorem a elementum gravida. Aliquam eu euismod risus.[/vc_column_text][ueldo_shortcode_inline_container class_name="ueldo_vc_element_13943043041121"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_38161527064845" large_width_type="px" large_width_px="80"][ueldo_shortcode_image class_name="ueldo_vc_element_82110284355001" border_radius="25" large_width_type="px" large_width_px="50" large_height_px="50" margin_bottom="0"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_66398071132355" large_width_type="calc" large_width_calc_px="80"][vc_column_text]<strong>'. esc_html( __( 'Tom Smith', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Important Company, LLC', 'ueldo' ) ) .'[/vc_column_text][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_80689136864014" large_height="30"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_22070610180471"][ueldo_shortcode_card class_name="ueldo_vc_element_99214520065594" border_width="0" padding_top="30" padding_bottom="30"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_47414835115694" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-right-quote,flaticon-interface|url:https://www.flaticon.com/free-icon/right-quote_157248|slug:icon_} icon_size="78" icon_color="rgba(0,0,0,0.03)" large_width_type="px" large_width_px="78" large_height_type="px" large_height_px="78" large_layer_position="top_right" large_margin_top="-20" large_margin_right="-8"][ueldo_shortcode_icon class_name="ueldo_vc_element_51873175258943" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_84891521693527" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_62043366857272" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_24550427899982" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_76243423918153" icon_alignment="inline" icon_fontawesome="fa fa-star-half-o" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_gap class_name="ueldo_vc_element_23719509849462" large_height="30"][vc_column_text]Nulla volutpat finibus euismod. Vestibulum et porta diam. Phasellus fringilla lorem a elementum gravida. Aliquam eu euismod risus.[/vc_column_text][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15156202997526"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_86290729255651" large_width_type="px" large_width_px="80"][ueldo_shortcode_image class_name="ueldo_vc_element_76815238773058" border_radius="25" large_width_type="px" large_width_px="50" large_height_px="50" margin_bottom="0"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_82298799091681" large_width_type="calc" large_width_calc_px="80"][vc_column_text]<strong>'. esc_html( __( 'Susane Smith', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Important Company, LLC', 'ueldo' ) ) .'[/vc_column_text][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_61834584050834" large_height="30"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_58025954835209"][ueldo_shortcode_card class_name="ueldo_vc_element_23619089492816" border_width="0" padding_top="30" padding_bottom="30"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_54693014174071" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-right-quote,flaticon-interface|url:https://www.flaticon.com/free-icon/right-quote_157248|slug:icon_} icon_size="78" icon_color="rgba(0,0,0,0.03)" large_width_type="px" large_width_px="78" large_height_type="px" large_height_px="78" large_layer_position="top_right" large_margin_top="-20" large_margin_right="-8"][ueldo_shortcode_icon class_name="ueldo_vc_element_13845767983949" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_85661354277628" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_49389825066102" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_65920497791008" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_icon class_name="ueldo_vc_element_82590473600257" icon_alignment="inline" icon_fontawesome="fa fa-star" custom_sizes_enabled="custom_settings" icon_size="15" margin_right="3" custom_colors_enabled="custom_settings" icon_color="#fbd60b"][ueldo_shortcode_gap class_name="ueldo_vc_element_98725256369302" large_height="30"][vc_column_text]Nulla volutpat finibus euismod. Vestibulum et porta diam. Phasellus fringilla lorem a elementum gravida. Aliquam eu euismod risus.[/vc_column_text][ueldo_shortcode_inline_container class_name="ueldo_vc_element_43527173266146"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_93487030853620" large_width_type="px" large_width_px="80"][ueldo_shortcode_image class_name="ueldo_vc_element_11497835650740" border_radius="25" large_width_type="px" large_width_px="50" large_height_px="50" margin_bottom="0"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_58168308992912" large_width_type="calc" large_width_calc_px="80"][vc_column_text]<strong>'. esc_html( __( 'Mike McDonovan', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Important Company, LLC', 'ueldo' ) ) .'[/vc_column_text][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_17922715745334" large_height="30"][/ueldo_shortcode_loop_cell][/ueldo_shortcode_loop][/vc_column][/vc_row][/vc_section]',

                '404-page' => '[vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_69851771433029" layer_for_row_or_section="section" color="#f8f5f2"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_75501378284945" layer_title="'. esc_html( __( 'Left icon', 'ueldo' ) ) .'" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-speed,flaticon-people|url:https://www.flaticon.com/free-icon/speed_249167|slug:icon_} icon_size="148" icon_rotate="345deg" icon_color="#efece8" extra_class_name="ueldo-vc-row-layer-overflow-visible" large_width_type="px" large_width_px="148" large_height_type="px" large_height_px="148" large_layer_position="bottom_left" large_margin_bottom="-25" large_margin_left="-25"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_55042640931364" layer_title="'. esc_html( __( 'Right icon', 'ueldo' ) ) .'" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-trophy,flaticon-cup|url:https://www.flaticon.com/free-icon/trophy_420105|slug:icon_} icon_size="148" icon_rotate="15deg" icon_color="#efece8" extra_class_name="ueldo-vc-row-layer-overflow-visible" large_width_type="px" large_width_px="148" large_height_type="px" large_height_px="148" large_layer_position="top_right" large_margin_top="-25" large_margin_right="-25"][ueldo_shortcode_gap class_name="ueldo_vc_element_7671715611844"][/vc_column][/vc_row][vc_row content_placement="middle"][vc_column width="1/2"][ueldo_shortcode_image class_name="ueldo_vc_element_42654540775431" large_height_px="400" extra_small_custom_sizes="yes" margin_bottom="0"][/vc_column][vc_column width="1/2"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15081545562341"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_1508154559605" large_width_type="px" large_width_px="30" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15081545661704" large_width_type="calc" large_width_calc_px="30" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15082312244295" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_heading class_name="ueldo_vc_element_15081541981534" heading_subtitle_text="'. esc_html( __( '404 page', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15081542127106" heading_text="'. esc_html( __( 'Nothing found here...', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]Duis lacinia tincidunt odio at dictum. Fusce justo elit, molestie id iaculis volutpat, tempor sit amet ante. Duis fermentum ante enim, ut sollicitudin ex consequat eu. Nullam sem est, tincidunt quis tincidunt.[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_1508154610363" button_text="'. esc_html( __( 'Back to home page', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'runners-club%2F|title:'. rawurlencode( esc_html( __( 'Home page', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_fontawesome="fa fa-home" hover_transform_enabled="yes"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15081545502242"][/vc_column][/vc_row][/vc_section]',

                'footer' => '[vc_section el_id="contact"][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15079880975954" large_height="45" small_custom_sizes="yes" small_height="30"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_icon class_name="ueldo_vc_element_15081446380422" icon_alignment="center" {ueldopredefinedsections:icon|key:flaticon-runner,flaticon-interface|url:https://www.flaticon.com/free-icon/runner_182603|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="60" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#b8cf16"][ueldo_shortcode_heading class_name="ueldo_vc_element_15079880553418" text_align="center" heading_subtitle_text="'. esc_html( __( 'Do you have any questions?', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15079880759966" heading_text="'. esc_html( __( 'Feel free to contact us!', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][contact-form-7 {ueldopredefinedsections:contactform7|context:runners-club|inside:false}][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_1508145024286"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15081450273673" large_width_type="px" large_width_px="30" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15081450331504" large_width_type="calc" large_width_calc_px="30" small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15081454209228" large_height="54" small_custom_sizes="yes" small_height="45"][vc_column_text]<strong>'. esc_html( __( 'When do we train?', 'ueldo' ) ) .'</strong><br /> Praesent vehicula, est sed tristique efficitur, velit est blandit risus, nec dapibus ipsum dolor sit amet lacus. Ut nec magna elementum.<br /><br /> <strong>'. esc_html( __( 'How long does the training take?', 'ueldo' ) ) .'</strong><br /> Proin eleifend felis leo, sit amet mattis augue luctus nec. Curabitur efficitur vulputate arcu, sed ullamcorper ligula. Morbi feugiat lacus a enim consectetur pulvinar. Fusce tincidunt est at arcu dictum.<br /><br /> <strong>'. esc_html( __( 'What should you take on training?', 'ueldo' ) ) .'</strong><br /> Non ultrices metus laoreet. Suspendisse risus metus, ultricies ut lorem non, porttitor dapibus nunc. Nulla ornare tincidunt convallis.[/vc_column_text][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15079882959264" large_height="75" extra_small_custom_sizes="yes" extra_small_height="45"][/vc_column][/vc_row][/vc_section][vc_section][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_delimiter class_name="ueldo_vc_element_15081462209329" large_height="1" margin_bottom="45"][/vc_column][/vc_row][vc_row][vc_column][vc_column_text]<p style="text-align: center;">2017 - '. date( 'Y' ) .' &copy; <strong><a href="'. esc_url( ueldo_get_external_url( 'ueldo-com' ) ) .'" target="_blank">'. esc_html( __( 'Ueldo', 'ueldo' ) ) .'</a></strong> '. esc_html( __( 'WordPress theme by', 'ueldo' ) ) .' <strong><a href="'. esc_url( ueldo_get_external_url( 'martanian-com' ) ) .'" target="_blank">Martanian</a></strong></p>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15081463218307" large_height="45"][/vc_column][/vc_row][/vc_section]',

                'header' => '[vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible"][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15081476377136" layer_for_row_or_section="section" color="#463429" color_add_box_shadow="yes-outset" color_outset_box_shadow_vertical_length="10" color_outset_box_shadow_blur_radius="35" color_outset_box_shadow_color="rgba(70,52,41,0.18)"][ueldo_shortcode_gap class_name="ueldo_vc_element_8956258473365" large_height="0" small_custom_sizes="yes" small_height="28"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15081487841488"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15081487878015" large_width_percentage="30%" small_custom_sizes="yes" small_width_type="calc" small_width_calc_px="40"][ueldo_shortcode_website_logo class_name="ueldo_vc_element_15081493619387" large_width_type="px" large_width_px="168" {ueldopredefinedsections:image|context:runners-club-logo}][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15081487959041" large_width_percentage="70%" large_content_alignment="right" small_custom_sizes="yes" small_width_type="px" small_width_px="40" small_content_alignment="right"][ueldo_shortcode_header_menu class_name="ueldo_vc_element_15081484347542" menu_links_alignment="right" custom_sizes_enabled="custom_settings" margin_right="-15"][ueldo_shortcode_button class_name="ueldo_vc_element_15081607526555" button_visible_on_devices="small,extra-small" button_text="" action_after_click="show_hide_side_menu" button_alignment="right" show_button_icon="yes" button_icon_fontawesome="fa fa-bars" custom_sizes_enabled="custom_settings" standard_button_icon_size="16" standard_button_padding_top="0" standard_button_padding_right="0" standard_button_padding_bottom="0" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_border_radius="0" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="#463429" standard_button_background_color_hover="#463429" standard_button_border_color="#463429" standard_button_border_color_hover="#463429" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="0" standard_button_box_shadow_blur_radius_hover="0" standard_button_box_shadow_color_hover="rgba(255,255,255,0.01)" standard_button_icon_color="#a9998f" standard_button_icon_color_hover="#a9998f"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_2976526756693" large_height="0" small_custom_sizes="yes" small_height="29"][/vc_column][/vc_row][/vc_section]',

                'additional-before-side-menu' => '',

                'additional-after-side-menu' => ''
            );

            # return result
            return( $page_slug == false ? $contents : ( isset( $contents[esc_attr( $page_slug )] ) ? $contents[esc_attr( $page_slug )] : false ) );
        }

       /**
        *
        * end of class methods.
        *
        */
    }

   /**
    *
    * end of file.
    *
    */

?>