<?php

   /**
    *
    * installation class for "stud" demo template
    *
    */

    class ueldo_demo_contents_loader_base extends ueldo_demo_contents_loader_installation_helper {

       /**
        *
        * install template or its parts
        *
        */

        public static function install( $parts, $icons ) {

           /**
            *
            * install revolution slider
            *
            */

            if( $parts == 'all' || in_array( 'revolution-slider-sliders', $parts, true ) ) {

                # upload revolution slider and get its id
                if( ( $slider_id = ueldo_add_demo_assets::upload_revslider( 'stud-home-page' ) ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:revslider|context:stud-home-page}', 'alias="'. esc_attr( $slider_id ) .'"' );

                    # remove temporary variables
                    unset( $slider_id );
                }
            }

           /**
            *
            * install forms
            *
            */

            if( $parts == 'all' || in_array( 'forms', $parts, true ) ) {

                # add form in contact form 7 plugin and get its id
                if( ( $form_id = ueldo_add_demo_assets::add_contact_form() ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:contactform7|context:stud|inside:true}', 'id=``'. esc_attr( $form_id ) .'``' );

                    # remove temporary variables
                    unset( $form_id );
                }
            }

           /**
            *
            * install blog posts
            *
            */

            if( $parts == 'all' || in_array( 'posts', $parts, true ) ) {

                # do we have default image ID?
                if( self::get_solution( 'default-image-id' ) == false ) {

                    # add solution with default image ID
                    self::add_solution( 'default-image-id', ueldo_add_demo_assets::add_image( 'default-image' ) );
                }

                # get current user data
                $current_user = wp_get_current_user();

                # add blog post
                $new_post_id = ueldo_add_demo_assets::add_blog_post( array(
                    'title' => esc_html( __( 'Only three rooms left for winter season!', 'ueldo' ) ),
                    'content' => self::get_vc_contents( 'blog-post' ),
                    'excerpt' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas vulputate ante purus, sit amet scelerisque ipsum venenatis sed.',
                    'thumbnail' => self::get_solution( 'default-image-id' ),
                    'category' => array( wp_create_category( esc_html( __( 'Stays', 'ueldo' ) ) ) ),
                    'tags' => array(
                        esc_html( __( 'Stays', 'ueldo' ) ),
                        esc_html( __( 'Winter Season', 'ueldo' ) )
                    ),
                    'comments' => array(
                        array(
                            'author' => esc_html( __( 'Mike', 'ueldo' ) ),
                            'author-email' => esc_html( __( 'mike@example.com', 'ueldo' ) ),
                         			'content' => 'Quisque tempor ut justo sed consequat. Sed egestas placerat eros in molestie. Praesent sollicitudin, odio ut malesuada cursus, nulla mauris dignissim dolor, a luctus massa massa semper nibh. Phasellus vitae ornare dolor. Aenean blandit porttitor dapibus. Nunc ac metus urna. Vivamus placerat porta magna, vitae porttitor justo efficitur non.'
                        )
                    )
                ));

                # wait until previous post is added
                if( $new_post_id !== false ) {

                    # clear temporary variable
                    unset( $new_post_id );

                    # add blog post
                    $new_post_id = ueldo_add_demo_assets::add_blog_post( array(
                        'title' => esc_html( __( 'Great reviews about our Horse Pension', 'ueldo' ) ),
                        'content' => self::get_vc_contents( 'blog-post' ),
                        'excerpt' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas vulputate ante purus, sit amet scelerisque ipsum venenatis sed.',
                        'thumbnail' => self::get_solution( 'default-image-id' ),
                        'category' => array( wp_create_category( esc_html( __( 'Horse Pension', 'ueldo' ) ) ) ),
                        'tags' => array(
                            esc_html( __( 'Horse Pension', 'ueldo' ) ),
                            esc_html( __( 'Horses', 'ueldo' ) ),
                            esc_html( __( 'Reviews', 'ueldo' ) )
                        ),
                        'comments' => array(
                            array(
                             			'author' => esc_html( __( 'Susane', 'ueldo' ) ),
                             			'author-email' => esc_html( __( 'susane@example.com', 'ueldo' ) ),
                             			'content' => 'Integer ac blandit ipsum. Sed nunc ante, bibendum id eros eu, pellentesque malesuada augue. Duis nunc tellus, facilisis et justo eget, suscipit tincidunt mi. Praesent vel nibh luctus, semper velit facilisis, bibendum elit. Donec varius, elit id interdum molestie, purus lorem sollicitudin purus, ut dictum nulla felis quis lacus. Ut quis velit neque.',
                                'replies' => array(
                                    array(
                                        'author' => esc_html( __( 'John', 'ueldo' ) ),
                                        'author-email' => esc_html( __( 'john@example.com', 'ueldo' ) ),
                                        'content' => 'Donec tortor purus, cursus fermentum leo vel, finibus faucibus mi. Fusce nec turpis vitae massa malesuada molestie vitae vel turpis. Mauris ultrices lacinia lacus, in porta velit imperdiet sed. Interdum et malesuada fames ac ante ipsum primis in faucibus. Donec dignissim eleifend sapien, nec facilisis arcu mattis nec.'
                                    ),
                                    array(
                                        'author' => esc_html( $current_user -> display_name ),
                                        'author-email' => esc_html( $current_user -> user_email ),
                                        'content' => 'Fusce nec turpis vitae massa malesuada molestie vitae vel turpis. Mauris ultrices lacinia lacus, in porta velit imperdiet sed. Interdum et malesuada fames ac ante ipsum primis in faucibus. Donec dignissim eleifend sapien, nec facilisis arcu mattis nec. Quisque interdum feugiat ex ut posuere. Sed rutrum purus ipsum, eget feugiat dolor elementum vitae.',
                                        'user_id' => esc_attr( $current_user -> ID )
                                    )
                                )
                            )
                        )
                    ));

                    # wait until previous post is added
                    if( $new_post_id !== false ) {

                        # clear temporary variable
                        unset( $new_post_id );

                        # add blog post
                        ueldo_add_demo_assets::add_blog_post( array(
                            'title' => esc_html( __( 'New beautiful horse reside in our stud!', 'ueldo' ) ),
                            'content' => self::get_vc_contents( 'blog-post' ),
                            'excerpt' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas vulputate ante purus, sit amet scelerisque ipsum venenatis sed.',
                            'thumbnail' => self::get_solution( 'default-image-id' ),
                            'category' => array( wp_create_category( esc_html( __( 'Horse Pension', 'ueldo' ) ) ) ),
                            'tags' => array(
                                esc_html( __( 'Horse Pension', 'ueldo' ) ),
                                esc_html( __( 'Horses', 'ueldo' ) )
                            ),
                            'comments' => array(
                                array(
                                    'author' => esc_html( __( 'John', 'ueldo' ) ),
                                    'author-email' => esc_html( __( 'john@example.com', 'ueldo' ) ),
                                    'content' => 'Aliquam erat volutpat. Nam ac odio in erat lobortis tempus a id urna. Vestibulum varius, ligula convallis ultrices volutpat, arcu elit pellentesque turpis, sit amet laoreet odio odio et risus. Nullam vehicula justo sit amet mauris molestie faucibus. Ut luctus sodales mauris, nec sagittis lorem congue a. In eget tincidunt nulla.'
                                ),
                                array(
                                    'author' => esc_html( __( 'Monica', 'ueldo' ) ),
                                    'author-email' => esc_html( __( 'monica@example.com', 'ueldo' ) ),
                                    'content' => 'Nullam vehicula justo sit amet mauris molestie faucibus. Ut luctus sodales mauris, nec sagittis lorem congue a. In eget tincidunt nulla. Interdum et malesuada fames ac ante ipsum primis in faucibus. Vestibulum nunc massa, blandit id urna non, facilisis ultrices ligula. Nullam at nibh vel leo placerat gravida. Sed sit amet mi neque.'
                                )
                            )
                        ));
                    }
                }

                # remove temporary variables
                unset( $current_user );

                # posts per page
                update_option( 'posts_per_page', '10' );
            }

           /**
            *
            * add pages, but not fill it with contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # add pages and get its ids
                $pages_ids = ueldo_add_demo_assets::add_empty_pages( 'page', array(
                    '404-page' => esc_html( __( '404 page', 'ueldo' ) ),
                    'about-us' => esc_html( __( 'About us', 'ueldo' ) ),
                    'blog' => esc_html( __( 'Blog', 'ueldo' ) ),
                    'contact' => esc_html( __( 'Contact', 'ueldo' ) ),
                    'home' => esc_html( __( 'Home', 'ueldo' ) ),
                    'offer-and-prices' => esc_html( __( 'Offer & prices', 'ueldo' ) ),
                    'stays' => esc_html( __( 'Stays', 'ueldo' ) )
                ));

                # add headers, footers and extras
                $hefos_ids = ueldo_add_demo_assets::add_empty_pages( 'ueldohefo', array(
                    'footer' => esc_html( __( 'Footer', 'ueldo' ) ),
                    'header' => esc_html( __( 'Header', 'ueldo' ) )
                ));

                # add solution
                self::add_solution( 'pages-ids', array_merge( $pages_ids, $hefos_ids ) );

                # show page on front
                update_option( 'show_on_front', 'page' );

                # update blog posts page ID
                if( $pages_ids['blog'] != null && $pages_ids['blog'] != false ) update_option( 'page_for_posts', $pages_ids['blog'] );

                # update home page ID
                if( $pages_ids['home'] != null && $pages_ids['home'] != false ) update_option( 'page_on_front', $pages_ids['home'] );

                # remove temporary variables
                unset( $pages_ids );
            }

           /**
            *
            * install menus
            *
            */

            if( $parts == 'all' || in_array( 'menus', $parts, true ) ) {

                # add new menu
                if( is_int( $menu_id = ueldo_add_demo_assets::add_menu( 'stud-main-menu', self::get_solution( 'pages-ids' ), true ) ) ) {

                    # add solution
                    self::add_solution( 'main-menu-id', esc_attr( $menu_id ) );
                }
            }

           /**
            *
            * configure sidebars & widgets
            *
            */

            if( $parts == 'all' || in_array( 'sidebars-and-widgets', $parts, true ) ) {

                # sidebars and widgets data array
                $sw_data = array(
                    'widget_categories' => array(
                        '1' => array(
                            'title' => '',
                            'count' => 0,
                            'hierarchical' => 0,
                            'dropdown' => 0
                        ),
                        '_multiwidget' => true
                    ),
                    'widget_text' => array( '_multiwidget' => true ),
                    'widget_rss' => array( '_multiwidget' => true ),
                    'widget_search' => array(
                        '1' => array( 'title' => '' ),
                        '_multiwidget' => true
                    ),
                    'widget_recent-posts' => array(
                        '1' =>  array(
                            'title' => '',
                            'number' => 5
                        ),
                        '_multiwidget' => true
                    ),
                    'widget_recent-comments' => array( '_multiwidget' => true ),
                    'widget_archives' => array( '_multiwidget' => true ),
                    'widget_meta' => array( '_multiwidget' => true ),
                    'widget_pages' => array( '_multiwidget' => true ),
                    'widget_calendar' => array( '_multiwidget' => true ),
                    'widget_media_audio' => array( '_multiwidget' => true ),
                    'widget_media_image' => array( '_multiwidget' => true ),
                    'widget_media_video' => array( '_multiwidget' => true ),
                    'widget_tag_cloud' => array( '_multiwidget' => true ),
                    'widget_nav_menu' => array( '_multiwidget' => true ),
                    'widget_custom_html' => array( '_multiwidget' => true ),
                    'widget_rev-slider-widget' => array( '_multiwidget' => true ),
                    'widget_ueldo_popular_posts_widget' => array(
                        '1' =>  array(
                            'posts_number' => '3',
                            'posts_from_last' => 'all',
                            'title' => esc_html( __( 'Popular posts', 'ueldo' ) )
                        ),
                        '_multiwidget' => true
                    ),
                    'widget_ueldo_call_to_action_widget' => array( '_multiwidget' => true ),
                    'widget_media_gallery' => array( '_multiwidget' => true ),
                    'sidebars_widgets' => array(
                        'wp_inactive_widgets' => array(),
                        'blog-sidebar' => array(
                            '0' => 'search-1',
                            '1' => 'recent-posts-1',
                            '2' => 'categories-1',
                            '3' => 'ueldo_popular_posts_widget-1'
                        ),
                        'array_version' => 3
                    )
                );

                # remove temporary variables
                unset( $temp );

                # walk for each options
                foreach( $sw_data as $option_key => $option_data ) {

                    # update option
                    update_option( $option_key, $option_data );
                }
            }

           /**
            *
            * get dynamic elements replacements
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) || in_array( 'pages', $parts, true ) ) {

                # get dynamic elements replacements
                $replacements = self::get_dynamic_elements_replacements( self::find_dynamic_elements( self::get_vc_contents() ), $icons, self::get_default_replacements() );
            }

           /**
            *
            * install theme options
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) ) {

                # update theme options
                update_option( 'ueldo_theme_options', self::get_theme_options_array() );

                # set additional content before side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_before_all', self::do_content_replacements( self::get_vc_contents( 'additional-before-side-menu' ), $replacements ) );

                # set additional content after side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_after_all', self::do_content_replacements( self::get_vc_contents( 'additional-after-side-menu' ), $replacements ) );

                # clear theme mods - background color and image
                remove_theme_mod( 'background_color' );
                remove_theme_mod( 'background_position_x' );
                remove_theme_mod( 'background_position_y' );
                remove_theme_mod( 'background_repeat' );
                remove_theme_mod( 'background_attachment' );
                remove_theme_mod( 'background_size' );
                remove_theme_mod( 'background_image' );
            }

           /**
            *
            * fill pages contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # walk for each pages
                foreach( self::get_solution( 'pages-ids' ) as $page_slug => $page_id ) {

                    # not for blog page
                    if( $page_slug == 'blog' ) continue;

                    # update page content
                    $result = wp_update_post( array(
                        'ID' => esc_attr( $page_id ),
                        'post_content' => self::do_content_replacements( self::get_vc_contents( esc_attr( $page_slug ) ), $replacements )
                    ));
                }

                # remove temporary variables
                unset( $replacements );
            }

           /**
            *
            * update permalinks structure
            *
            */

            if( $parts == 'all' || in_array( 'permalinks-structure', $parts, true ) ) {

                # global variable
                global $wp_rewrite;

                # write the rule
                $wp_rewrite -> set_permalink_structure( '/%postname%/' );

                # set the option
                update_option( 'rewrite_rules', false );

                # flush the rules and tell it to write htaccess
                $wp_rewrite -> flush_rules( true );
            }

           /**
            *
            * demo data installed
            *
            */

            exit( '{ "status": "ok" }' );
        }

       /**
        *
        * get possible data parts
        *
        */

        public static function get_possible_data_parts() {

            # return result
            return( array(
                'menus' => esc_html( __( 'Menus', 'ueldo' ) ),
                'posts' => esc_html( __( 'Posts', 'ueldo' ) ),
                'pages' => esc_html( __( 'Pages', 'ueldo' ) ),
                'theme-options' => esc_html( __( 'Theme options', 'ueldo' ) ),
                'forms' => esc_html( __( 'Forms', 'ueldo' ) ),
                'sidebars-and-widgets' => esc_html( __( 'Sidebars & widgets', 'ueldo' ) ),
                'revolution-slider-sliders' => esc_html( __( 'Revolution Slider sliders', 'ueldo' ) ),
                'permalinks-structure' => esc_html( __( 'Permalinks structure', 'ueldo' ) )
            ));
        }

       /**
        *
        * get list of required plugins
        *
        */

        public static function get_required_plugins( $parts ) {

            # all data
            if( !is_array( $parts ) && $parts == 'all' ) {

                # return list of required plugins
                return( array(
                    'ueldo',
                    'visual-composer',
                    'revolution-slider',
                    'contact-form-7'
                ));
            }

            # selected parts
            else {

                # prepare array of required plugins
                $result = array( 'ueldo' );

                # do we have to add pages?
                if( in_array( 'pages', $parts, true ) ) {

                    # return list of required plugins
                    return( array(
                        'visual-composer',
                        'revolution-slider',
                        'contact-form-7'
                    ));
                }

                # do we have to add theme options?
                if( in_array( 'theme-options', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'visual-composer' ) );
                }

                # do we have to add forms?
                if( in_array( 'forms', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'contact-form-7' ) );
                }

                # do we have to add revolution slider sliders?
                if( in_array( 'revolution-slider-sliders', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'revolution-slider' ) );
                }

                # return result
                return( $result );
            }
        }

       /**
        *
        * get default replacements
        *
        */

        public static function get_default_replacements() {

            # add pattern image
            $pattern_image_id = ueldo_add_demo_assets::add_image( 'stud-pattern' );

            # add grass isolated image
            $grass_isolated_image_id = ueldo_add_demo_assets::add_image( 'stud-grass-isolated' );

            # add logo image
            $logo_image_id = ueldo_add_demo_assets::add_image( 'stud-logo-demo-like' );

            # add side-menu logo image
            $side_menu_logo_image_id = ueldo_add_demo_assets::add_image( 'stud-logo-side-menu' );

            # return result
            return( array(
                '{ueldopredefinedsections:googlemap|context:stud-demo-like}' => 'google_map_id="1"',
                '{ueldopredefinedsections:image|context:stud-logo-demo-like}' => ( $logo_image_id == false ? '' : 'image="'. esc_attr( $logo_image_id ) .'"' ),
                '{ueldopredefinedsections:image|context:stud-logo-side-menu}' => ( $side_menu_logo_image_id == false ? '' : 'image="'. esc_attr( $side_menu_logo_image_id ) .'"' ),
                '{ueldopredefinedsections:image|context:stud-pattern}' => ( $pattern_image_id == false ? '' : 'image="'. esc_attr( $pattern_image_id ) .'"' ),
                '{ueldopredefinedsections:image|context:stud-grass-isolated}' => ( $grass_isolated_image_id == false ? '' : 'image="'. esc_attr( $grass_isolated_image_id ) .'"' ),
            ));
        }

       /**
        *
        * get trusted solution
        *
        */

        public static function get_trusted_solution( $type, $solution ) {

            # do we have solution found?
            if( !empty( $solution ) ) return( $solution );

            # switch by solution type
            switch( $type ) {

                # get most similar elements
                case 'main-menu-slug': return( self::get_most_similar_element( 'menu_slug', esc_html( __( 'Main menu - Stud template', 'ueldo' ) ) ) );
                case '404-page-id': return( self::get_most_similar_element( 'page', esc_html( __( '404 page', 'ueldo' ) ) ) );
                case 'footer-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Footer', 'ueldo' ) ) ) );
                case 'header-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Header', 'ueldo' ) ) ) );
            }

            # nothing found
            return( false );
        }

       /**
        *
        * get theme options array
        *
        */

        public static function get_theme_options_array() {

            # return result
            return( array(
                '404-page-id' => array( 'all' => self::get_trusted_solution( '404-page-id', self::get_solution( 'pages-ids', '404-page' ) ) ),
                'blog-posts-list-style' => array(
                    'posts-list-style' => 'default',
                    'display-post-data-under-title' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'yes'
                ),
                'blog-sidebar' => array(
                    'posts-list' => 'yes-right',
                    'single-post' => 'yes-right',
                    'responsive-style' => 'static'
                ),
                'boxed-website' => array(
                    'enabled' => 'no',
                    'large-content-width' => '1100',
                    'large-content-space' => '50',
                    'medium-content-width' => '890',
                    'medium-content-space' => '50',
                    'small-content-width' => '665',
                    'small-content-space' => '50'
                ),
                'comment-textarea-at-top' => 'yes',
                'dynamic-theme-styles-cache' => array(
                    'enabled' => 'no',
                    'clear-cache' => 'all-the-time-when-logged-in'
                ),
                'facebook-fanpage-url' => array( 'all' => 'https://www.facebook.com/envato' ),
                'featured-image-on-lists-only' => 'no',
                'fonts' => array(
                    'general-font-family' => array( 'all' => 'Roboto' ),
                    'general-font-weight' => array( 'all' => '300' ),
                    'general-font-subset' => array( 'all' => 'latin' ),
                    'general-font-smoothing' => array( 'all' => 'yes' ),
                    'general-bold-font-family' => array( 'all' => 'Roboto' ),
                    'general-bold-font-weight' => array( 'all' => '500' ),
                    'general-bold-font-subset' => array( 'all' => 'latin' ),
                    'general-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-font-family' => array( 'all' => 'Roboto' ),
                    'menu-font-weight' => array( 'all' => '500' ),
                    'menu-font-subset' => array( 'all' => 'latin' ),
                    'menu-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-font-family' => array( 'all' => 'Libre Baskerville' ),
                    'headings-font-weight' => array( 'all' => '700' ),
                    'headings-font-subset' => array( 'all' => 'latin' ),
                    'headings-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-slim-font-family' => array( 'all' => 'Roboto' ),
                    'headings-slim-font-weight' => array( 'all' => '300' ),
                    'headings-slim-font-subset' => array( 'all' => 'latin' ),
                    'headings-slim-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-bold-font-family' => array( 'all' => 'Libre Baskerville' ),
                    'headings-bold-font-weight' => array( 'all' => '700' ),
                    'headings-bold-font-subset' => array( 'all' => 'latin' ),
                    'headings-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-subtitle-font-family' => array( 'all' => 'Francois One' ),
                    'headings-subtitle-font-weight' => array( 'all' => 'regular' ),
                    'headings-subtitle-font-subset' => array( 'all' => 'latin' ),
                    'headings-subtitle-font-smoothing' => array( 'all' => 'yes' ),
                    'buttons-font-family' => array( 'all' => 'Roboto' ),
                    'buttons-font-weight' => array( 'all' => '700' ),
                    'buttons-font-subset' => array( 'all' => 'latin' ),
                    'buttons-font-smoothing' => array( 'all' => 'yes' ),
                    'form-fields-font-family' => array( 'all' => 'Roboto' ),
                    'form-fields-font-weight' => array( 'all' => 'regular' ),
                    'form-fields-font-subset' => array( 'all' => 'latin' ),
                    'form-fields-font-smoothing' => array( 'all' => 'yes' ),
                    'blockquote-font-family' => array( 'all' => 'Roboto' ),
                    'blockquote-font-weight' => array( 'all' => '500' ),
                    'blockquote-font-subset' => array( 'all' => 'latin' ),
                    'blockquote-font-smoothing' => array( 'all' => 'yes' ),
                    'alert-messages-font-family' => array( 'all' => 'Roboto' ),
                    'alert-messages-font-weight' => array( 'all' => '400' ),
                    'alert-messages-font-subset' => array( 'all' => 'latin' ),
                    'alert-messages-font-smoothing' => array( 'all' => 'yes' )
                ),
                'footer-content' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'footer-page-id', self::get_solution( 'pages-ids', 'footer' ) ) ),
                    'position' => array( 'all' => 'fixed-to-bottom' )
                ),
                'google-maps' => array(
                    'api-key' => '',
                    'next-map-id' => '2',
                    'google-map-1-title' => esc_html( __( 'Map', 'ueldo' ) ),
                    'google-map-1-center-lat' => '40.770113',
                    'google-map-1-center-lng' => '-73.975072',
                    'google-map-1-zoom' => '11',
                    'google-map-1-markers-next-marker-id' => '3',
                    'google-map-1-markers-marker-1-title' => esc_html( __( 'Marker', 'ueldo' ) ),
                    'google-map-1-markers-marker-1-lat' => '40.770113',
                    'google-map-1-markers-marker-1-lng' => '-73.975072',
                    'google-map-1-markers-marker-1-use-custom-marker' => 'no',
                    'google-map-1-markers-marker-1-custom-icon-library' => 'fontawesome',
                    'google-map-1-markers-marker-1-custom-icon' => 'fa fa-address-book',
                    'google-map-1-markers-marker-1-custom-icon-size' => '18',
                    'google-map-1-markers-marker-1-custom-icon-width' => '36',
                    'google-map-1-markers-marker-1-custom-icon-height' => '36',
                    'google-map-1-markers-marker-1-custom-icon-border-radius' => 'circle',
                    'google-map-1-markers-marker-1-custom-icon-border-radius-px' => '4',
                    'google-map-1-markers-marker-1-custom-icon-color' => '#798d20',
                    'google-map-1-markers-marker-1-custom-icon-background-color' => '#fff',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-horizontal-length' => '0',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-vertical-length' => '5',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-blur-radius' => '20',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-spread-radius' => '0',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-color' => 'rgba( 0, 0, 0, 0.1 )',
                    'google-map-1-markers-marker-1-custom-marker-image' => '',
                    'google-map-1-custom-style' => '[{"featureType":"administrative","stylers":[{"saturation":-100},{"lightness":20},{"visibility":"on"}]},{"featureType":"landscape.man_made","stylers":[{"color":"#f5eae4"},{"saturation":-60},{"lightness":10},{"visibility":"simplified"}]},{"featureType":"landscape.natural","stylers":[{"saturation":-60},{"lightness":60},{"visibility":"simplified"}]},{"featureType":"poi","stylers":[{"saturation":-100},{"lightness":60},{"visibility":"off"}]},{"featureType":"road","stylers":[{"saturation":-100},{"lightness":40},{"visibility":"on"}]},{"featureType":"transit","stylers":[{"saturation":-100},{"lightness":60},{"visibility":"off"}]},{"featureType":"water","stylers":[{"color":"#878979"},{"visibility":"on"}]}]'
                ),
                'header' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'header-page-id', self::get_solution( 'pages-ids', 'header' ) ) ),
                    'position' => array( 'all' => 'flying' ),
                    'use-second-header' => array( 'all' => 'no' ),
                    'get-second-content-from' => array( 'all' => 'default' ),
                    'second-header-visible-from' => array( 'all' => '400' ),
                    'default-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'second-header-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) )
                ),
                'lazy-load-images' => array(
                    'enabled' => 'no',
                    'threshold' => '0'
                ),
                'loader-animation' => array(
                    'enabled' => 'yes',
                    'style' => '01',
                    'add-logo' => 'no',
                    'space-between-logo-and-spinner' => '30',
                    'logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'custom-colors-enabled' => 'no',
                    'custom-colors-background' => '#fff',
                    'custom-colors-spinner' => '#798d20'
                ),
                'local-scrolling-links-animation' => array(
                    'enabled' => 'yes',
                    'animation-speed' => '1000'
                ),
                'opening-hours-status' => array( 'next-status-id' => '1' ),
                'rtl' => array(
                    'is-rtl' => array( 'all' => 'no' ),
                    'load-rtl-admin-styles' => array( 'all' => 'auto' )
                ),
                'side-menu' => array(
                    'style' => 'flying-default-hidden',
                    'menu-key' => array( 'all' => self::get_trusted_solution( 'main-menu-slug', self::get_main_menu_slug() ) ),
                    'menu-link-font-family' => array( 'all' => 'Roboto' ),
                    'menu-link-font-weight' => array( 'all' => '500' ),
                    'menu-link-font-subset' => array( 'all' => 'latin' ),
                    'menu-link-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-position' => 'left',
                    'menu-links-alignment' => 'center',
                    'opacity-animation-enabled' => 'no',
                    'submenu-links' => 'visible-always',
                    'menu-vertical-alignment' => 'top',
                    'custom-sizes-enabled' => 'yes',
                    'custom-sizes-container-width' => '250',
                    'custom-sizes-menu-link-font-size' => '14',
                    'custom-sizes-menu-link-font-line-height' => '1.0',
                    'custom-sizes-menu-link-font-letter-spacing' => '0',
                    'custom-sizes-menu-link-padding-top-bottom' => '15',
                    'custom-sizes-menu-link-padding-left-right' => '25',
                    'custom-sizes-menu-link-margin-top-bottom' => '0',
                    'custom-sizes-menu-link-margin-left-right' => '0',
                    'custom-sizes-menu-link-bottom-border-width' => '1',
                    'custom-sizes-display-bottom-border-for-last-menu-link' => 'display',
                    'custom-sizes-menu-icon-font-size' => '10',
                    'custom-sizes-menu-icon-margin-top' => '0',
                    'custom-sizes-menu-margin-between-icon-and-title' => '10',
                    'custom-sizes-padding-top-bottom-additional-element-before-menu' => '30',
                    'custom-sizes-padding-left-right-additional-element-before-menu' => '30',
                    'custom-sizes-margin-top-additional-element-before-menu' => '0',
                    'custom-sizes-margin-right-additional-element-before-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-before-menu' => '0',
                    'custom-sizes-margin-left-additional-element-before-menu' => '0',
                    'custom-sizes-padding-top-bottom-additional-element-after-menu' => '30',
                    'custom-sizes-padding-left-right-additional-element-after-menu' => '30',
                    'custom-sizes-margin-top-additional-element-after-menu' => '0',
                    'custom-sizes-margin-right-additional-element-after-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-after-menu' => '0',
                    'custom-sizes-margin-left-additional-element-after-menu' => '0'
                ),
                'single-blog-post-style' => array(
                    'display-post-data-under-title' => 'yes',
                    'blog-post-data-and-title-centered' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'yes'
                ),
                'submit-button-position-in-comment-reply-form' => array( 'all' => 'center' ),
                'translate-publication-dates' => 'yes',
                'twitter-api' => array(
                    'oauth-key' => '',
                    'oauth-secret-key' => ''
                ),
                'under-single-blog-post-content-elements' => array(
                    'elements-count' => '1',
                    'element-1-type' => 'tags-and-categories-with-facebook',
                    'element-1-similar-posts-style' => '02',
                    'element-2-type' => 'author-box',
                    'element-2-similar-posts-style' => '02',
                    'element-3-type' => 'next-previous-posts-navigation',
                    'element-3-similar-posts-style' => '02',
                    'element-4-type' => '',
                    'element-4-similar-posts-style' => '02',
                    'element-5-type' => '',
                    'element-5-similar-posts-style' => '02',
                    'element-6-type' => '',
                    'element-6-similar-posts-style' => '02'
                ),
                'vc-sections-on-blog-pages' => array(
                    'posts-list-above' => array( 'all' => 'none' ),
                    'posts-list-under' => array( 'all' => 'none' ),
                    'single-post-above' => array( 'all' => 'none' ),
                    'single-post-under' => array( 'all' => 'none' ),
                    'archive-above' => array( 'all' => 'none' ),
                    'archive-under' => array( 'all' => 'none' ),
                    'search-above' => array( 'all' => 'none' ),
                    'search-under' => array( 'all' => 'none' )
                ),
                'visual-composer-custom-fonts' => array( 'next-font-id' => '1' ),
                'styles' => array(
                    'general-colors-website-background' => '#fff5ed',
                    'general-colors-main-color' => '#798d20',
                    'info-box-element-background-color' => '#f5eae3',
                    'general-colors-content-color' => '#65605d',
                    'general-colors-elements-border-color' => '#efe4db',
                    'buttons-global-button-background-color' => '#798d20',
                    'buttons-global-button-border-color' => '#798d20',
                    'buttons-global-button-box-shadow' => '0px 10px 25px -5px rgba(96,113,20,0.25)',
                    'buttons-global-button-background-color-hover' => '#617a16',
                    'buttons-global-button-border-color-hover' => '#617a16',
                    'buttons-global-button-box-shadow-hover' => '0px 10px 35px 0px rgba(97,122,22,0.25)',
                    'buttons-global-button-border-radius' => '30',
                    'buttons-global-button-border-width' => '1',
                    'general-colors-elements-hover-border-color' => '#efe4db',
                    'general-colors-headings-subtitle-color' => '#798d20',
                    'general-colors-blog-post-data-color' => '#798d20',
                    'general-colors-elements-inset-border-color' => '#f3e8df',
                    'header-bar-and-menu-background-color' => '#2f2b20',
                    'header-bar-and-menu-link-color' => '#948f80',
                    'header-bar-and-menu-active-or-hover-link-color' => '#ded8c7',
                    'header-bar-and-menu-submenu-background-color' => '#948f80',
                    'general-colors-icon-color' => '#e5dbd3',
                    'font-size-h6' => '16',
                    'font-size-smallest-content' => '14',
                    'font-size-h5' => '18',
                    'forms-field-border-color' => '#e6ddd5',
                    'forms-field-background-color' => '#fbf2eb',
                    'forms-field-inset-box-shadow' => '0px 0px 0px 0px rgba(255,255,255,0)',
                    'forms-field-border-color-on-hover' => '#d1cac2',
                    'forms-checkbox-radio-main-color' => '#798d20',
                    'forms-field-border-color-for-invalid-values' => '#ecbbbd',
                    'forms-select-and-date-field-icon-color' => '#dbd4cb',
                    'forms-select-and-date-field-icon-border-color' => '#ede2dc',
                    'forms-select-and-date-field-icon-background-color' => '#fbf2eb',
                    'flying-sidebar-border-color' => '#e4d8ce',
                    'sidebar-background-color' => '#f5eae3',
                    'announcement-warning-background-color' => '#ffeebf',
                    'announcement-warning-border-color' => '#efe1bf',
                    'announcement-warning-content-color' => '#d6a735',
                    'announcement-warning-box-shadow' => '0px 0px 15px 0px rgba(255,246,221,0.75)',
                    'general-colors-blockquote-color' => '#798d20',
                    'side-menu-box-shadow' => '5px 0px 20px 0px rgba(10,0,0,0.2)',
                    'side-menu-background-color' => '#fff5ed',
                    'side-menu-link-color' => '#65605d',
                    'side-menu-link-border-bottom-color' => '#fbeee4',
                    'side-menu-link-color-hover' => '#798d20',
                    'side-menu-link-border-bottom-color-hover' => '#fbeee4',
                    'side-menu-active-link-color' => '#798d20',
                    'side-menu-active-link-border-bottom-color' => '#fbeee4'
                )
            ));
        }

       /**
        *
        * get default contents
        *
        */

        public static function get_vc_contents( $page_slug = false ) {

            # array of pages contents
            $contents = array(

                'home' => '[vc_section full_width="stretch_row_content"][vc_row full_width="stretch_row_content_no_spaces"][vc_column][rev_slider {ueldopredefinedsections:revslider|context:stud-home-page}][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_341927929830"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_150151363278" layer_z_index="0" custom_layer_sizes="custom_settings" color="#f5eae3" large_width_type="px" large_width_px="800" large_height_type="px" large_height_px="300" large_margin_top="90" large_margin_left="15" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="4" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="600" medium_height_type="px" medium_height_px="300" medium_margin_top="90" medium_margin_left="15" medium_custom_row_border_radius="yes-copy-from-large" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="450" small_height_type="px" small_height_px="362" small_margin_top="90" small_margin_left="15" small_custom_row_border_radius="yes-copy-from-large" extra_small_layer_custom_sizes="yes" extra_small_height_percentage="42%" extra_small_margin_top="90" extra_small_margin_left="15" extra_small_custom_row_border_radius="yes-copy-from-large"][ueldo_shortcode_heading class_name="ueldo_vc_element_179223040898" heading_tag="h6" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="45"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_546756819928" heading_text="'. esc_html( __( 'ABOUT OUR HORSE STUD', 'ueldo' ) ) .'" font_family="headings-subtitle-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_846549632610" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="45" custom_margin_left="45"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_802449622460" heading_text="'. esc_html( __( 'For beginners and advanced riders.', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings" line_height="1" letter_spacing="-1"][/ueldo_shortcode_heading][ueldo_shortcode_inline_container class_name="ueldo_vc_element_150235114264"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_150235123237" large_width_type="px" large_width_px="45"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_150235114648" large_width_type="px" large_width_px="335" small_custom_sizes="yes" small_width_type="px" small_width_px="265" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="90"][vc_column_text]Curabitur scelerisque justo et massa aliquam bibendum. Nam ut odio egestas, ullamcorper eros eu, aliquet dolor. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_150235129065" large_height="11"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_delimiter class_name="ueldo_vc_element_150151324944" large_width_type="px" large_width_px="60" large_height="4" margin_bottom="0" margin_left="45" custom_colors_enabled="custom_settings" background_color="#798d20"][ueldo_shortcode_gap class_name="ueldo_vc_element_15023634609" large_height="85" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_button class_name="ueldo_vc_element_788538532677" button_type="two-line-button" button_visible_on_devices="large,medium" button_text="'. esc_html( __( 'Call us now!', 'ueldo' ) ) .'" second_line_text_font_family="headings-font" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" button_alignment="inline" custom_sizes_enabled="custom_settings" additional_margin_before="25" two_line_button_title_font_size="18" two_line_button_padding_top="0" two_line_button_padding_bottom="0" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_second_line_color_hover="#798d20"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_127356307599" button_type="two-line-button" button_visible_on_devices="large,medium" button_text="'. esc_html( __( 'Send us an email!', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'contact@example.com', 'ueldo' ) ) .'" second_line_text_font_family="headings-font" button_url="url:'. rawurlencode( esc_url( __( 'mailto:contact@example.com', 'ueldo' ) ) ) .'|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" button_alignment="inline" custom_sizes_enabled="custom_settings" additional_margin_before="15" two_line_button_title_font_size="18" two_line_button_padding_top="0" two_line_button_padding_right="0" two_line_button_padding_bottom="0" two_line_button_padding_left="0" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_second_line_color_hover="#798d20"][/ueldo_shortcode_button][/vc_column][vc_column width="1/2"][ueldo_shortcode_button class_name="ueldo_vc_element_923468151250" button_text="'. esc_html( __( 'Find out more', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'about-us%2F|title:'. rawurlencode( esc_html( __( 'About us', 'ueldo' ) ) ) .'||" button_alignment="right" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_150236378666" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_image class_name="ueldo_vc_element_150151333129" large_height_px="365" margin_bottom="0"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_button class_name="ueldo_vc_element_135357482227" button_type="two-line-button" button_visible_on_devices="small" button_text="'. esc_html( __( 'Call us now!', 'ueldo' ) ) .'" second_line_text_font_family="headings-font" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" button_alignment="inline" custom_sizes_enabled="custom_settings" additional_margin_before="25" two_line_button_title_font_size="18" two_line_button_padding_top="0" two_line_button_padding_bottom="2" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_background_color="rgba(255,245,237,0.01)" two_line_button_background_color_hover="rgba(255,245,237,0.01)" two_line_button_border_color="rgba(239,228,219,0.01)" two_line_button_border_color_hover="rgba(239,228,219,0.01)" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_second_line_color_hover="#798d20"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_382805070773" button_type="two-line-button" button_visible_on_devices="small" button_text="'. esc_html( __( 'Send us an email!', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'contact@example.com', 'ueldo' ) ) .'" second_line_text_font_family="headings-font" button_url="url:'. rawurlencode( esc_url( __( 'mailto:contact@example.com', 'ueldo' ) ) ) .'|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" button_alignment="inline" custom_sizes_enabled="custom_settings" additional_margin_before="15" two_line_button_title_font_size="18" two_line_button_padding_top="0" two_line_button_padding_right="0" two_line_button_padding_bottom="2" two_line_button_padding_left="0" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_background_color="rgba(255,245,237,0.01)" two_line_button_background_color_hover="rgba(255,245,237,0.01)" two_line_button_border_color="rgba(239,228,219,0.01)" two_line_button_border_color_hover="rgba(239,228,219,0.01)" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_second_line_color_hover="#798d20"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row][vc_column el_class="ueldo-vc-row-overflow-visible"][ueldo_shortcode_gap class_name="ueldo_vc_element_833246150449" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_button class_name="ueldo_vc_element_542941559036" button_type="two-line-button" button_visible_on_devices="extra-small" button_text="'. esc_html( __( 'Call us now!', 'ueldo' ) ) .'" second_line_text_font_family="headings-font" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" custom_sizes_enabled="custom_settings" additional_margin_before="25" two_line_button_title_font_size="18" two_line_button_padding_top="0" two_line_button_padding_bottom="2" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_background_color="rgba(255,245,237,0.01)" two_line_button_background_color_hover="rgba(255,245,237,0.01)" two_line_button_border_color="rgba(239,228,219,0.01)" two_line_button_border_color_hover="rgba(239,228,219,0.01)" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_second_line_color_hover="#798d20"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_951722308259" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_button class_name="ueldo_vc_element_577141389553" button_type="two-line-button" button_visible_on_devices="extra-small" button_text="'. esc_html( __( 'Send us an email!', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'contact@example.com', 'ueldo' ) ) .'" second_line_text_font_family="headings-font" button_url="url:'. rawurlencode( esc_url( __( 'mailto:contact@example.com', 'ueldo' ) ) ) .'|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" custom_sizes_enabled="custom_settings" additional_margin_before="25" two_line_button_title_font_size="18" two_line_button_padding_top="0" two_line_button_padding_bottom="2" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_background_color="rgba(255,245,237,0.01)" two_line_button_background_color_hover="rgba(255,245,237,0.01)" two_line_button_border_color="rgba(239,228,219,0.01)" two_line_button_border_color_hover="rgba(239,228,219,0.01)" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_second_line_color_hover="#798d20"][/ueldo_shortcode_button][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_274792030684" large_height="45"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/3"][ueldo_shortcode_card class_name="ueldo_vc_element_2050267823"][ueldo_shortcode_info_box class_name="ueldo_vc_element_319947327738" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Professional care', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" {ueldopredefinedsections:icon|key:flaticon-horseshoe,flaticon-horse|url:https://www.flaticon.com/free-icon/horseshoe_259782|slug:info_element_icon_}][ueldo_shortcode_gap class_name="ueldo_vc_element_496366896712" large_height="30"][vc_column_text]Nulla sit amet efficitur nisl, vel vehicula erat. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][/ueldo_shortcode_info_box][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_249667670419" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/3"][ueldo_shortcode_card class_name="ueldo_vc_element_7321339510"][ueldo_shortcode_info_box class_name="ueldo_vc_element_383115227733" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Fenced paddock', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" {ueldopredefinedsections:icon|key:flaticon-fence|url:https://www.flaticon.com/free-icon/fence_459709|slug:info_element_icon_}][ueldo_shortcode_gap class_name="ueldo_vc_element_496162589380" large_height="30"][vc_column_text]Nulla sit amet efficitur nisl, vel vehicula erat. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][/ueldo_shortcode_info_box][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_630120118412" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/3"][ueldo_shortcode_card class_name="ueldo_vc_element_7814304797"][ueldo_shortcode_info_box class_name="ueldo_vc_element_923177703566" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Pension for Horses', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" {ueldopredefinedsections:icon|key:flaticon-barn,flaticon-buildings|url:https://www.flaticon.com/free-icon/barn_119301|slug:info_element_icon_}][ueldo_shortcode_gap class_name="ueldo_vc_element_416017297859" large_height="30"][vc_column_text]Nulla sit amet efficitur nisl, vel vehicula erat. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][/ueldo_shortcode_info_box][/ueldo_shortcode_card][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_407392822660"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_642524623264"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_892087863746" layer_for_row_or_section="section" layer_z_index="0" color="#3e4226"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_132572403890" layer_for_row_or_section="section" layer_z_index="0" layer_type="image" image_size="auto" image_repeat="repeat" {ueldopredefinedsections:image|context:stud-pattern}][/vc_column][/vc_row][vc_row full_width="stretch_row" content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_image class_name="ueldo_vc_element_617612375883" large_height_px="450" margin_bottom="0"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_427516645060" layer_z_index="0" custom_layer_sizes="custom_settings" color="#484c31" large_width_percentage="50%" large_height_type="px" large_height_px="400" large_layer_position="center_left" large_margin_top="-200" large_custom_row_border_radius="yes-unique-for-corners" large_row_border_radius_top_right_corner="4" large_row_border_radius_bottom_right_corner="4" extra_small_layer_custom_sizes="yes" extra_small_width_percentage="50%" extra_small_height_type="px" extra_small_height_px="400" extra_small_margin_top="25"][/vc_column][vc_column width="1/2"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_150236627151"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_150236627599" large_width_type="px" large_width_px="30" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_150236629106" large_width_type="calc" large_width_calc_px="30" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_150236538944" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_heading class_name="ueldo_vc_element_621139400917" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_903603646497" heading_text="'. esc_html( __( 'Experience an', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings" custom_font_color_enabled="custom_settings" font_color="#ffffff" font_color_hover="#ffffff"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_110239227312" heading_text="'. esc_html( __( 'wonderful', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings" custom_font_color_enabled="custom_settings" font_color="#ffffff" font_color_hover="#ffffff" add_highlights="yes-underline" underline_height="8" underline_margin_bottom="9"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_63007537219" heading_text="'. esc_html( __( 'adventure', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings" custom_font_color_enabled="custom_settings" font_color="#ffffff" font_color_hover="#ffffff"][/ueldo_shortcode_heading][vc_column_text]<p style="color: #8b9074;">Mauris laoreet est vitae ultrices eleifend. Phasellus sed interdum odio. Proin nec finibus dui. Quisque tincidunt tellus ut dignissim congue. Praesent nisl ligula, rhoncus in mollis a, tempus in purus.</p>[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_197359504784" button_text="'. esc_html( __( 'Check Stays', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'stays%2F|title:'. rawurlencode( esc_html( __( 'Stays', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_917267158233"][/vc_column][/vc_row][vc_row full_width="stretch_row" content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_150236641407"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_150236641779" large_width_type="calc" large_width_calc_px="30" extra_small_custom_sizes="yes"][ueldo_shortcode_heading class_name="ueldo_vc_element_169773578010" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_828475265039" heading_text="'. esc_html( __( 'Active rest for the', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings" custom_font_color_enabled="custom_settings" font_color="#ffffff" font_color_hover="#ffffff"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_768580543650" heading_text="'. esc_html( __( 'whole', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings" custom_font_color_enabled="custom_settings" font_color="#ffffff" font_color_hover="#ffffff" additional_margin_after="-4" additional_padding_right="4" add_highlights="yes-underline" underline_height="8" underline_margin_bottom="9"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_501021766467" heading_text="'. esc_html( __( 'family', 'ueldo' ) ) .'" custom_font_size_and_line_height_enabled="custom_settings" custom_font_color_enabled="custom_settings" font_color="#ffffff" font_color_hover="#ffffff" additional_margin_before="-4" additional_padding_left="4" add_highlights="yes-underline" underline_height="8" underline_margin_bottom="9"][/ueldo_shortcode_heading][vc_column_text]<p style="color: #8b9074;">Mauris laoreet est vitae ultrices eleifend. Phasellus sed interdum odio. Proin nec finibus dui. Quisque tincidunt tellus ut dignissim congue. Praesent nisl ligula, rhoncus in mollis a, tempus in purus.</p>[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_116781402611" button_text="'. esc_html( __( 'Check our Offer', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_150236540296" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15023664293" large_width_type="px" large_width_px="30" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][vc_column width="1/2"][ueldo_shortcode_image class_name="ueldo_vc_element_552297518654" large_height_px="450" margin_bottom="0"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_455434525980" layer_z_index="0" custom_layer_sizes="custom_settings" color="#484c31" large_width_percentage="50%" large_height_type="px" large_height_px="400" large_layer_position="center_right" large_margin_top="-200" large_custom_row_border_radius="yes-unique-for-corners" large_row_border_radius_top_left_corner="4" large_row_border_radius_bottom_left_corner="4" extra_small_layer_custom_sizes="yes" extra_small_width_percentage="50%" extra_small_height_type="px" extra_small_height_px="400" extra_small_layer_position="bottom_right" extra_small_margin_bottom="25"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_121140519371"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_151124843709361"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_812328365861" large_height="30"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/3" offset="vc_col-lg-3 vc_col-md-4"][ueldo_shortcode_card class_name="ueldo_vc_element_150158281034" margin_bottom="30"][ueldo_shortcode_heading class_name="ueldo_vc_element_504644651483" heading_tag="h4" text_align="center" display_heading_subtitle="no" heading_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" custom_margins_enabled="custom_margins" custom_margin_bottom="29"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_739866753185" heading_text="'. esc_html( __( 'Call for reservation', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_info_box class_name="ueldo_vc_element_150158343707" whole_box_link="yes" box_link_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" info_box_title="" info_box_subtitle="" {ueldopredefinedsections:icon|key:flaticon-cellphone,flaticon-smartphone|url:https://www.flaticon.com/free-icon/smartphone_480978|slug:info_element_icon_}][/ueldo_shortcode_info_box][ueldo_shortcode_heading class_name="ueldo_vc_element_643229887309" heading_tag="h4" text_align="center" display_heading_subtitle="no" heading_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" custom_margins_enabled="custom_margins" custom_margin_top="28" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_842340975667" heading_text="1-800-123-4567" custom_font_size_and_line_height_enabled="custom_settings" font_size="22" letter_spacing="-1" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][/ueldo_shortcode_card][/vc_column][vc_column width="2/3" offset="vc_col-lg-9 vc_col-md-8"][ueldo_shortcode_accordion class_name="ueldo_vc_element_150158199226" single_element_title_heading_type="h5" custom_colors_enabled="custom_settings" box_shadow_color="rgba(255,255,255,0.01)" box_shadow_color_hover="rgba(0,0,0,0.05)" element_title_color_hover="#313131" info_box_title_heading_type="h5"][ueldo_shortcode_accordion_single_element class_name="ueldo_vc_element_485590344601" title="'. esc_html( __( 'How many horses are in the stud?', 'ueldo' ) ) .'"]Ut ligula nunc, facilisis vitae libero sed, facilisis ultricies sem. Sed auctor aliquet ligula a vehicula. Vivamus arcu lorem, fringilla et varius vitae, ullamcorper a nulla. Sed euismod lorem ex. Mauris eu turpis non tortor fringilla faucibus. Ut enim massa, pharetra ac ipsum eu, porta tincidunt magna.[/ueldo_shortcode_accordion_single_element][ueldo_shortcode_accordion_single_element class_name="ueldo_vc_element_905471115841" title="'. esc_html( __( 'How old is the stud?', 'ueldo' ) ) .'"]Morbi vestibulum ipsum felis, sed scelerisque mi lobortis bibendum. Fusce semper mauris eu dignissim mollis. Nulla tincidunt urna vel massa gravida accumsan. Suspendisse in velit ac neque sodales faucibus id et dolor. Pellentesque risus sapien, hendrerit ac lorem vel, imperdiet vulputate.[/ueldo_shortcode_accordion_single_element][ueldo_shortcode_accordion_single_element class_name="ueldo_vc_element_868517339803" title="'. esc_html( __( 'How much does a horse ride cost?', 'ueldo' ) ) .'"]Sed scelerisque nibh tortor, in ultricies dolor condimentum a. In scelerisque lobortis turpis, in vulputate lacus tincidunt sed. Nulla rhoncus bibendum diam, a pellentesque purus egestas tincidunt. Nullam feugiat quam in tellus ornare, sed pharetra lorem semper. Sed auctor aliquet ligula a vehicula. Vivamus arcu lorem.[/ueldo_shortcode_accordion_single_element][/ueldo_shortcode_accordion][ueldo_shortcode_row_layer class_name="ueldo_vc_element_150158412399" layer_z_index="0" custom_layer_sizes="custom_settings" color="#f5eae3" large_width_type="px" large_width_px="400" large_height_type="calc" large_height_calc_operator="+" large_height_calc_px="30" large_margin_top="-30" large_margin_left="75" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="4" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="400" medium_height_type="calc" medium_height_calc_operator="+" medium_height_calc_px="30" medium_margin_top="-30" medium_margin_left="75" medium_custom_row_border_radius="yes-copy-from-large" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="400" small_height_type="calc" small_height_calc_operator="+" small_height_calc_px="30" small_margin_top="-30" small_margin_left="75" small_custom_row_border_radius="yes-copy-from-large" extra_small_layer_custom_sizes="yes" extra_small_margin_top="-15" extra_small_custom_row_border_radius="yes-same-for-corners" extra_small_row_border_radius="4"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_717891729833"][/vc_column][/vc_row][/vc_section][vc_section][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_heading class_name="ueldo_vc_element_150158090255" text_align="center" heading_subtitle_text="'. esc_html( __( 'Blog notes', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_150158093058" heading_text="'. esc_html( __( 'Recent news & articles', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_gap class_name="ueldo_vc_element_355325585903" large_height="30"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/3"][ueldo_shortcode_post_page_box class_name="ueldo_vc_element_440141122333" heading_type="h6" box_style="03"][ueldo_shortcode_gap class_name="ueldo_vc_element_811214875360" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/3"][ueldo_shortcode_post_page_box class_name="ueldo_vc_element_691833370891" post_no="latest_minus_1" heading_type="h6" box_style="03"][ueldo_shortcode_gap class_name="ueldo_vc_element_122447496226" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/3"][ueldo_shortcode_post_page_box class_name="ueldo_vc_element_611402972811" post_no="latest_minus_2" heading_type="h6" box_style="03"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_841547713594"][/vc_column][/vc_row][/vc_section]',

                'about-us' => '[vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_339187100045"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2" offset="vc_col-lg-3 vc_col-md-3"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_150175249932" layer_z_index="0" custom_layer_sizes="custom_settings" color="#f5eae3" large_width_type="px" large_width_px="500" large_height_type="px" large_height_px="450" large_margin_top="-20" large_margin_left="-5" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="4" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="420" medium_height_type="px" medium_height_px="420" medium_margin_top="-20" medium_margin_left="-5" medium_custom_row_border_radius="yes-copy-from-large" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="665" small_height_type="px" small_height_px="530" small_margin_top="-20" small_margin_left="-5" small_custom_row_border_radius="yes-copy-from-large" extra_small_layer_custom_sizes="yes" extra_small_width_percentage="90%" extra_small_height_type="px" extra_small_height_px="1090" extra_small_margin_top="-20" extra_small_margin_left="-5" extra_small_custom_row_border_radius="yes-copy-from-large"][ueldo_shortcode_image class_name="ueldo_vc_element_335315250787" additional="gallery_image" gallery_slug="about-us" large_height_px="220" medium_custom_sizes="yes" medium_height_px="200" small_custom_sizes="yes" small_height_px="250"][ueldo_shortcode_image class_name="ueldo_vc_element_900207296970" additional="gallery_image" gallery_slug="about-us" large_height_px="220" medium_custom_sizes="yes" medium_height_px="200" small_custom_sizes="yes" small_height_px="250" margin_bottom="0"][ueldo_shortcode_gap class_name="ueldo_vc_element_150237086583" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/2" offset="vc_col-lg-3 vc_col-md-3"][ueldo_shortcode_image class_name="ueldo_vc_element_167909837112" additional="gallery_image" gallery_slug="about-us" large_height_px="220" medium_custom_sizes="yes" medium_height_px="200" small_custom_sizes="yes" small_height_px="250"][ueldo_shortcode_image class_name="ueldo_vc_element_504223899410" additional="gallery_image" gallery_slug="about-us" large_height_px="220" medium_custom_sizes="yes" medium_height_px="200" small_custom_sizes="yes" small_height_px="250" margin_bottom="0"][/vc_column][vc_column css=".vc_custom_1503397103298{margin-left: 30px !important;}" offset="vc_col-lg-6 vc_col-md-6 vc_hidden-xs"][ueldo_shortcode_gap class_name="ueldo_vc_element_260479385626" large_height="0" small_custom_sizes="yes" small_height="45"][ueldo_shortcode_heading class_name="ueldo_vc_element_858480478851" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'About us', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_61010828053" heading_text="'. esc_html( __( 'Meet our Horse Stud', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum eu nibh in nisl sagittis pharetra id sed nulla. Sed vulputate ullamcorper ante eu euismod. Sed est dui, tempor tincidunt erat in, ultrices vehicula felis. Praesent id molestie massa, vel consectetur quam.[/vc_column_text][ueldo_shortcode_inline_container class_name="ueldo_vc_element_526407438414"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_488281242812" large_width_type="calc" large_width_calc_base="33%" large_width_calc_px="15" large_content_alignment="center"][ueldo_shortcode_info_box class_name="ueldo_vc_element_48451984314" info_box_title="'. esc_html( __( '54 Well Arranged Horses', 'ueldo' ) ) .'" info_box_subtitle="" info_element_title_margin_top="15" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-transport,flaticon-horse|url:https://www.flaticon.com/free-icon/horse_101694|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#fff5ed" info_element_background_color_hover="#fff5ed" info_element_icon_color="#2f2b20" info_element_icon_color_hover="#2f2b20" info_element_box_shadow_color="rgba(255,245,237,0.01)" info_element_box_shadow_color_hover="rgba(255,245,237,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_545590806409" large_width_type="px" large_width_px="15"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_507782398892" large_width_type="calc" large_width_calc_base="33%" large_width_calc_px="15" large_content_alignment="center"][ueldo_shortcode_info_box class_name="ueldo_vc_element_49144874869" info_box_title="'. esc_html( __( 'Organic food from own Farm', 'ueldo' ) ) .'" info_box_subtitle="" info_element_title_margin_top="15" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-food,flaticon-vegetables|url:https://www.flaticon.com/free-icon/vegetables_424307|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#fff5ed" info_element_background_color_hover="#fff5ed" info_element_icon_color="#2f2b20" info_element_icon_color_hover="#2f2b20" info_element_box_shadow_color="rgba(255,245,237,0.01)" info_element_box_shadow_color_hover="rgba(255,245,237,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_261119168131" large_width_type="px" large_width_px="15"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_308562259949" large_width_percentage="33%" large_content_alignment="center"][ueldo_shortcode_info_box class_name="ueldo_vc_element_29758945677" info_box_title="'. esc_html( __( 'Area for cross-country jumping', 'ueldo' ) ) .'" info_box_subtitle="" info_element_title_margin_top="15" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-sport,flaticon-gymnastics|url:https://www.flaticon.com/free-icon/gymnastics_250365|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#fff5ed" info_element_background_color_hover="#fff5ed" info_element_icon_color="#2f2b20" info_element_icon_color_hover="#2f2b20" info_element_box_shadow_color="rgba(255,245,237,0.01)" info_element_box_shadow_color_hover="rgba(255,245,237,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_gap class_name="ueldo_vc_element_400206106032" large_height="0" small_custom_sizes="yes" small_height="45"][ueldo_shortcode_heading class_name="ueldo_vc_element_655975905276" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'About us', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_46164489997" heading_text="'. esc_html( __( 'Meet our Horse Stud', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum eu nibh in nisl sagittis pharetra id sed nulla. Sed vulputate ullamcorper ante eu euismod. Sed est dui, tempor tincidunt erat in, ultrices vehicula felis. Praesent id molestie massa, vel consectetur quam.[/vc_column_text][ueldo_shortcode_info_box class_name="ueldo_vc_element_44867293665" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( '54 Well Arranged Horses', 'ueldo' ) ) .'" info_box_subtitle="" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-transport,flaticon-horse|url:https://www.flaticon.com/free-icon/horse_101694|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#fff5ed" info_element_background_color_hover="#fff5ed" info_element_icon_color="#2f2b20" info_element_icon_color_hover="#2f2b20" info_element_box_shadow_color="rgba(255,245,237,0.01)" info_element_box_shadow_color_hover="rgba(255,245,237,0.01)"][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_87945631078" large_height="15"][ueldo_shortcode_info_box class_name="ueldo_vc_element_41656057204" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( 'Organic food from own Farm', 'ueldo' ) ) .'" info_box_subtitle="" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-food,flaticon-vegetables|url:https://www.flaticon.com/free-icon/vegetables_424307|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#fff5ed" info_element_background_color_hover="#fff5ed" info_element_icon_color="#2f2b20" info_element_icon_color_hover="#2f2b20" info_element_box_shadow_color="rgba(255,245,237,0.01)" info_element_box_shadow_color_hover="rgba(255,245,237,0.01)"][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_34569799842" large_height="15"][ueldo_shortcode_info_box class_name="ueldo_vc_element_25470838133" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( 'Area for cross-country jumping', 'ueldo' ) ) .'" info_box_subtitle="" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-sport,flaticon-gymnastics|url:https://www.flaticon.com/free-icon/gymnastics_250365|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color="#fff5ed" info_element_background_color_hover="#fff5ed" info_element_icon_color="#2f2b20" info_element_icon_color_hover="#2f2b20" info_element_box_shadow_color="rgba(255,245,237,0.01)" info_element_box_shadow_color_hover="rgba(255,245,237,0.01)"][/ueldo_shortcode_info_box][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_289026872451"][/vc_column][/vc_row][/vc_section][vc_section][vc_row full_width="stretch_row" content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_heading class_name="ueldo_vc_element_582569088981" heading_subtitle_text="'. esc_html( __( 'Great experience', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_13391188899" heading_text="'. esc_html( __( '60 years of history', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum eu nibh in nisl sagittis pharetra id sed nulla. Sed vulputate ullamcorper ante eu euismod. Sed est dui, tempor tincidunt erat in, ultrices vehicula felis. Praesent id molestie massa, vel consectetur quam.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_480628280410" large_height="0" extra_small_custom_sizes="yes" extra_small_height="10"][/vc_column][/vc_row][vc_row full_width="stretch_row" content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2" offset="vc_hidden-xs"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15112704623413"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15112704666239" large_width_type="calc" large_width_calc_px="30"][ueldo_shortcode_heading class_name="ueldo_vc_element_130749671838" heading_subtitle_text="'. esc_html( __( 'Great experience', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_11800053029" heading_text="'. esc_html( __( '60 years of history', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum eu nibh in nisl sagittis pharetra id sed nulla. Sed vulputate ullamcorper ante eu euismod. Sed est dui, tempor tincidunt erat in, ultrices vehicula felis. Praesent id molestie massa, vel consectetur quam.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_691457808140" large_height="0" extra_small_custom_sizes="yes" extra_small_height="10"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][vc_column width="1/2"][ueldo_shortcode_timeline class_name="ueldo_vc_element_150175197829" custom_colors_enabled="custom_settings" card_box_shadow_blur_radius="35" card_box_shadow_color="rgba(0,0,0,0.05)" card_box_shadow_color_hover="rgba(0,0,0,0.05)" date_text_color="#ffffff" date_box_shadow_color="rgba(255,245,237,0.01)" timeline_line_box_shadow_color="rgba(255,245,237,0.01)" timeline_circle_box_shadow_color="rgba(255,245,237,0.01)" next_prev_arrow_container_box_shadow_color="rgba(255,245,237,0.01)" next_prev_arrow_container_box_shadow_color_hover="rgba(255,245,237,0.01)"][ueldo_shortcode_timeline_element class_name="ueldo_vc_element_517153227491" date="1956"]Nunc sollicitudin tortor id elit lobortis, et volutpat sem dictum. Morbi sed semper est. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae.[/ueldo_shortcode_timeline_element][ueldo_shortcode_timeline_element class_name="ueldo_vc_element_170625936177" date="1984"]Nunc sollicitudin tortor id elit lobortis, et volutpat sem dictum. Morbi sed semper est. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae.[/ueldo_shortcode_timeline_element][ueldo_shortcode_timeline_element class_name="ueldo_vc_element_811434664509" date="2002"]Nunc sollicitudin tortor id elit lobortis, et volutpat sem dictum. Morbi sed semper est. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae.[/ueldo_shortcode_timeline_element][ueldo_shortcode_timeline_element class_name="ueldo_vc_element_340249256699"]Nunc sollicitudin tortor id elit lobortis, et volutpat sem dictum. Morbi sed semper est. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae.[/ueldo_shortcode_timeline_element][/ueldo_shortcode_timeline][ueldo_shortcode_row_layer class_name="ueldo_vc_element_39221099552" layer_z_index="0" custom_layer_sizes="custom_settings" large_width_percentage="50%" large_height_percentage="90%" large_layer_position="top_right" large_margin_top="22" large_custom_row_border_radius="yes-unique-for-corners" large_row_border_radius_top_left_corner="4" large_row_border_radius_bottom_left_corner="4" extra_small_layer_custom_sizes="yes" extra_small_width_percentage="50%" extra_small_height_type="calc" extra_small_height_calc_px="60" extra_small_layer_position="bottom_right" extra_small_margin_bottom="30"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_36320846606" layer_z_index="0" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat" large_width_percentage="50%" large_height_percentage="90%" large_layer_position="top_right" large_margin_top="22" large_custom_row_border_radius="yes-unique-for-corners" large_row_border_radius_top_left_corner="4" large_row_border_radius_bottom_left_corner="4" extra_small_layer_custom_sizes="yes" extra_small_width_percentage="50%" extra_small_height_type="calc" extra_small_height_calc_px="60" extra_small_layer_position="bottom_right" extra_small_margin_bottom="30" {ueldopredefinedsections:image|context:stud-pattern}][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_860537067923"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15113451630066" layer_for_row_or_section="section" layer_z_index="0" color="#f5eae3"][ueldo_shortcode_gap class_name="ueldo_vc_element_535283821852" extra_small_custom_sizes="yes" extra_small_height="25"][ueldo_shortcode_heading class_name="ueldo_vc_element_944810655477" text_align="center" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'References', 'ueldo' ) ) .'" custom_margin_bottom="60"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_21111226182" heading_text="'. esc_html( __( 'They said about us...', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_full_width_testimonials class_name="ueldo_vc_element_150175858403" type="persons" content_position="above" custom_next_prev_arrows_settings="custom_settings" arrow_border_radius="20" arrow_border_width="1" custom_colors_enabled="custom_settings" background_color="#f5eae3" persons_images_box_shadow_color="rgba(255,245,237,0.01)" persons_images_box_shadow_color_hover="rgba(255,245,237,0.01)" active_person_image_box_shadow_color="rgba(0,0,0,0.2)" active_person_image_box_shadow_color_hover="rgba(0,0,0,0.2)" next_prev_arrow_color="#798d20" next_prev_arrow_container_background="#efe4db" next_prev_arrow_container_background_hover="#e8ddd4" next_prev_arrow_container_border_color="#efe4db" next_prev_arrow_container_border_color_hover="#e8ddd4" next_prev_arrow_container_box_shadow_color="rgba(255,245,237,0.01)" next_prev_arrow_container_box_shadow_color_hover="rgba(255,245,237,0.01)"][ueldo_shortcode_full_width_testimonials_single_testimonial class_name="ueldo_vc_element_604732235002"][vc_column_text]Suspendisse accumsan tellus vel tortor mattis, id aliquet enim vehicula. Nulla fringilla tempor dolor, at ultrices nisl rhoncus id. Fusce dapibus blandit nunc quis semper. Duis libero magna, fringilla ut ipsum faucibus, mollis fermentum ex. Pellentesque interdum turpis lacus, ut congue diam scelerisque ac. Maecenas vitae tempor sapien.[/vc_column_text][/ueldo_shortcode_full_width_testimonials_single_testimonial][ueldo_shortcode_full_width_testimonials_single_testimonial class_name="ueldo_vc_element_327814233406"][vc_column_text]Suspendisse accumsan tellus vel tortor mattis, id aliquet enim vehicula. Nulla fringilla tempor dolor, at ultrices nisl rhoncus id. Fusce dapibus blandit nunc quis semper. Duis libero magna, fringilla ut ipsum faucibus, mollis fermentum ex. Pellentesque interdum turpis lacus, ut congue diam scelerisque ac. Maecenas vitae tempor sapien.[/vc_column_text][/ueldo_shortcode_full_width_testimonials_single_testimonial][ueldo_shortcode_full_width_testimonials_single_testimonial class_name="ueldo_vc_element_431763208721"][vc_column_text]Suspendisse accumsan tellus vel tortor mattis, id aliquet enim vehicula. Nulla fringilla tempor dolor, at ultrices nisl rhoncus id. Fusce dapibus blandit nunc quis semper. Duis libero magna, fringilla ut ipsum faucibus, mollis fermentum ex. Pellentesque interdum turpis lacus, ut congue diam scelerisque ac. Maecenas vitae tempor sapien.[/vc_column_text][/ueldo_shortcode_full_width_testimonials_single_testimonial][/ueldo_shortcode_full_width_testimonials][ueldo_shortcode_gap class_name="ueldo_vc_element_150176458929" large_height="30"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_150184369967" layer_for_row_or_section="section" layer_z_index="0" custom_layer_sizes="custom_settings" layer_type="image" large_width_type="px" large_width_px="228" large_height_type="px" large_height_px="284" large_layer_position="bottom_left" large_margin_bottom="0" large_margin_left="0" {ueldopredefinedsections:image|context:stud-grass-isolated}][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_274792030684"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/3"][ueldo_shortcode_card class_name="ueldo_vc_element_2050267823"][ueldo_shortcode_info_box class_name="ueldo_vc_element_319947327738" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Professional care', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" {ueldopredefinedsections:icon|key:flaticon-horseshoe,flaticon-horse|url:https://www.flaticon.com/free-icon/horseshoe_259782|slug:info_element_icon_}][ueldo_shortcode_gap class_name="ueldo_vc_element_496366896712" large_height="30"][vc_column_text]Nulla sit amet efficitur nisl, vel vehicula erat. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][/ueldo_shortcode_info_box][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_418228885933" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/3"][ueldo_shortcode_card class_name="ueldo_vc_element_7321339510"][ueldo_shortcode_info_box class_name="ueldo_vc_element_383115227733" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Fenced paddock', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" {ueldopredefinedsections:icon|key:flaticon-fence|url:https://www.flaticon.com/free-icon/fence_459709|slug:info_element_icon_}][ueldo_shortcode_gap class_name="ueldo_vc_element_496162589380" large_height="30"][vc_column_text]Nulla sit amet efficitur nisl, vel vehicula erat. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][/ueldo_shortcode_info_box][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_285632504439" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/3"][ueldo_shortcode_card class_name="ueldo_vc_element_7814304797"][ueldo_shortcode_info_box class_name="ueldo_vc_element_923177703566" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Pension for Horses', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" {ueldopredefinedsections:icon|key:flaticon-barn,flaticon-buildings|url:https://www.flaticon.com/free-icon/barn_119301|slug:info_element_icon_}][ueldo_shortcode_gap class_name="ueldo_vc_element_416017297859" large_height="30"][vc_column_text]Nulla sit amet efficitur nisl, vel vehicula erat. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][/ueldo_shortcode_info_box][/ueldo_shortcode_card][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_643446289064"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="2/3" offset="vc_hidden-xs"][ueldo_shortcode_heading class_name="ueldo_vc_element_169188038949" heading_tag="h3" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Visit us for adventure', 'ueldo' ) ) .'" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_89978733453" heading_text="'. esc_html( __( 'Check our offer and prices', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/3" offset="vc_hidden-xs"][ueldo_shortcode_button class_name="ueldo_vc_element_307908657921" button_text="'. esc_html( __( 'Go to Offer page', 'ueldo' ) ) .'" button_text_alignment="center" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" button_alignment="right" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_heading class_name="ueldo_vc_element_324984541916" heading_tag="h3" text_align="center" heading_subtitle_text="'. esc_html( __( 'Visit us for adventure', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_49624884929" heading_text="'. esc_html( __( 'Check our offer and prices', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_button class_name="ueldo_vc_element_494463605640" button_text="'. esc_html( __( 'Go to Offer page', 'ueldo' ) ) .'" button_text_alignment="center" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" button_alignment="center" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_945207672373"][/vc_column][/vc_row][/vc_section]',

                'contact' => '[vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_771456817541234" layer_for_row_or_section="section" layer_z_index="0" custom_layer_sizes="custom_settings" layer_type="image" image_position_y="45%" large_height_type="px" large_height_px="400"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_240590238533" layer_for_row_or_section="section" layer_opacity="60%" layer_z_index="0" custom_layer_sizes="custom_settings" color="#3e4226" large_height_type="px" large_height_px="400"][ueldo_shortcode_gap class_name="ueldo_vc_element_833788756364" large_height="120"][ueldo_shortcode_heading class_name="ueldo_vc_element_150183355941" text_align="center" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Contact us!', 'ueldo' ) ) .'" custom_heading_subtitle_font_color_enabled="custom_settings" heading_subtitle_font_color="#c0d07d" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_150183358828" heading_text="'. esc_html( __( 'We\'re glad you\'re here!', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings" font_color="#ffffff" font_color_hover="#ffffff"][/ueldo_shortcode_heading][ueldo_shortcode_gap class_name="ueldo_vc_element_749935463221" large_height="120"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="2/3"][ueldo_shortcode_card class_name="ueldo_vc_element_150209361963" padding_top="30" padding_bottom="30" custom_colors_enabled="custom_settings" box_shadow_blur_radius="35" box_shadow_color="rgba(0,0,0,0.05)" box_shadow_color_hover="rgba(0,0,0,0.05)"][ueldo_shortcode_form class_name="ueldo_vc_element_150209363118" form_shortcode="`{`contact-form-7 {ueldopredefinedsections:contactform7|context:stud|inside:true}`}`"][/ueldo_shortcode_card][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_150210027494" large_height="90" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_150243450136"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_150243450698" large_width_type="px" large_width_px="30" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="15" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_150243451638" large_width_type="calc" large_width_calc_px="30" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_px="15" extra_small_custom_sizes="yes"][ueldo_shortcode_heading class_name="ueldo_vc_element_300349773963" heading_tag="h3" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Address', 'ueldo' ) ) .'" custom_margin_bottom="0"][/ueldo_shortcode_heading][vc_column_text]'. esc_html( __( '1234 Example,', 'ueldo' ) ) .'<br /> '. esc_html( __( 'Los Angeles, CA 98765', 'ueldo' ) ) .'[/vc_column_text][ueldo_shortcode_heading class_name="ueldo_vc_element_413562807905" heading_tag="h3" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Tax ID', 'ueldo' ) ) .'" custom_margin_bottom="0"][/ueldo_shortcode_heading][vc_column_text]123456789[/vc_column_text][ueldo_shortcode_heading class_name="ueldo_vc_element_178885079661" heading_tag="h3" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Bank Account Number', 'ueldo' ) ) .'" custom_margin_bottom="0"][/ueldo_shortcode_heading][vc_column_text]00 0000 0000 0000 0000 0000 0000[/vc_column_text][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15020985173" large_height="45"][/vc_column][/vc_row][vc_row full_width="stretch_row" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_150243549913"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_150243556437" large_width_type="px" large_width_px="45" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15024355078" large_width_type="calc" large_width_calc_px="90" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_px="60" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_150243581534" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_button class_name="ueldo_vc_element_611152659039" button_type="two-line-button" button_visible_on_devices="large,medium" button_text="'. esc_html( __( 'Call us now!', 'ueldo' ) ) .'" second_line_text_font_family="headings-font" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" button_alignment="inline" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="18" two_line_button_padding_top="0" two_line_button_padding_bottom="0" two_line_button_padding_left="0" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_second_line_color_hover="#798d20"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_713596596500" button_type="two-line-button" button_visible_on_devices="large,medium" button_text="'. esc_html( __( 'Send us an email!', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'contact@example.com', 'ueldo' ) ) .'" second_line_text_font_family="headings-font" button_url="url:'. rawurlencode( esc_url( __( 'mailto:contact@example.com', 'ueldo' ) ) ) .'|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" button_alignment="inline" custom_sizes_enabled="custom_settings" additional_margin_before="15" two_line_button_title_font_size="18" two_line_button_padding_top="0" two_line_button_padding_right="0" two_line_button_padding_bottom="0" two_line_button_padding_left="0" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_second_line_color_hover="#798d20"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_349592402793" button_type="two-line-button" button_visible_on_devices="small,extra-small" button_text="'. esc_html( __( 'Call us now!', 'ueldo' ) ) .'" second_line_text_font_family="headings-font" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="18" two_line_button_padding_top="0" two_line_button_padding_bottom="0" two_line_button_padding_left="0" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_background_color="rgba(255,245,237,0.01)" two_line_button_background_color_hover="rgba(255,245,237,0.01)" two_line_button_border_color="rgba(239,228,219,0.01)" two_line_button_border_color_hover="rgba(239,228,219,0.01)" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_second_line_color_hover="#798d20"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_150243512164" large_height="0" small_custom_sizes="yes" small_height="30"][ueldo_shortcode_button class_name="ueldo_vc_element_760762410053" button_type="two-line-button" button_visible_on_devices="small,extra-small" button_text="'. esc_html( __( 'Send us an email!', 'ueldo' ) ) .'" second_line_text="'. esc_html( __( 'contact@example.com', 'ueldo' ) ) .'" second_line_text_font_family="headings-font" button_url="url:'. rawurlencode( esc_url( __( 'mailto:contact@example.com', 'ueldo' ) ) ) .'|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" custom_sizes_enabled="custom_settings" two_line_button_title_font_size="18" two_line_button_padding_top="0" two_line_button_padding_right="0" two_line_button_padding_bottom="0" two_line_button_padding_left="0" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_background_color="rgba(255,245,237,0.01)" two_line_button_background_color_hover="rgba(255,245,237,0.01)" two_line_button_border_color="rgba(239,228,219,0.01)" two_line_button_border_color_hover="rgba(239,228,219,0.01)" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_second_line_color_hover="#798d20"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_150210466786" large_height="120" medium_custom_sizes="yes" medium_height="100" small_custom_sizes="yes" small_height="45"][ueldo_shortcode_heading class_name="ueldo_vc_element_777431596852" heading_tag="h3" heading_subtitle_text="'. esc_html( __( 'We\'re not so far away', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Mauris quis sem blandit, ultricies metus et, tristique lorem. Cras at quam nulla. Suspendisse tincidunt metus at blandit consequat. Curabitur lacinia in sapien non bibendum. Vestibulum luctus tempor ante, quis vulputate ante porttitor vel. Etiam vel tristique leo.[/vc_column_text][ueldo_shortcode_social_media_feed class_name="ueldo_vc_element_150210680988" type="facebook_like_button"][/ueldo_shortcode_social_media_feed][ueldo_shortcode_gap class_name="ueldo_vc_element_1502435825" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_150243557259" large_width_type="px" large_width_px="45" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="15" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][vc_column width="1/2"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_731163280424" layer_z_index="0" custom_layer_sizes="custom_settings" color="#f5eae3" large_width_type="px" large_width_px="500" large_height_type="px" large_height_px="450" large_layer_position="bottom_right" large_margin_right="-10" large_margin_bottom="53" large_custom_row_border_radius="yes-unique-for-corners" large_row_border_radius_top_left_corner="4" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="300" medium_height_type="px" medium_height_px="450" medium_layer_position="bottom_right" medium_margin_right="-10" medium_margin_bottom="53" medium_custom_row_border_radius="yes-copy-from-large" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="240" small_height_type="px" small_height_px="450" small_layer_position="bottom_right" small_margin_right="-10" small_margin_bottom="53" small_custom_row_border_radius="yes-copy-from-large" extra_small_layer_custom_sizes="yes"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_165672603000" layer_z_index="0" custom_layer_sizes="custom_settings" color="#f5eae3" large_width_type="px" large_width_px="200" large_height_type="px" large_height_px="200" large_layer_position="bottom_center" large_margin_bottom="5" large_margin_left="-10" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="4" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="140" medium_height_type="px" medium_height_px="140" medium_layer_position="bottom_center" medium_margin_bottom="5" medium_margin_left="-10" medium_custom_row_border_radius="yes-copy-from-large" extra_small_layer_visibility="no"][ueldo_shortcode_google_map class_name="ueldo_vc_element_150211474891" large_height_px="450" {ueldopredefinedsections:googlemap|context:stud-demo-like}][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_993244845259"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible"][vc_row][vc_column][ueldo_shortcode_heading class_name="ueldo_vc_element_150211880692" heading_tag="h3" text_align="center" heading_subtitle_text="'. esc_html( __( 'Follow us', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_150211881824" heading_text="'. esc_html( __( 'We are on social media', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15021179886"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_150211799279" large_width_percentage="100%" large_content_alignment="center"][ueldo_shortcode_button class_name="ueldo_vc_element_989857005047" button_text="" button_text_alignment="center" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-facebook" custom_sizes_enabled="custom_settings" standard_button_icon_size="18" standard_button_padding_top="14" standard_button_padding_right="0" standard_button_padding_bottom="14" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_use_static_width="yes-pixels" standard_button_static_width="46" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_icon_color="#ffffff" standard_button_icon_color_hover="#ffffff"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_571818569342" button_text="" button_text_alignment="center" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-twitter" custom_sizes_enabled="custom_settings" additional_margin_before="15" standard_button_icon_size="18" standard_button_padding_top="14" standard_button_padding_right="0" standard_button_padding_bottom="14" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_use_static_width="yes-pixels" standard_button_static_width="46" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_icon_color="#ffffff" standard_button_icon_color_hover="#ffffff"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_619672196812" button_text="" button_text_alignment="center" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-google-plus" custom_sizes_enabled="custom_settings" additional_margin_before="15" standard_button_icon_size="18" standard_button_padding_top="14" standard_button_padding_right="0" standard_button_padding_bottom="14" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_use_static_width="yes-pixels" standard_button_static_width="46" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_icon_color="#ffffff" standard_button_icon_color_hover="#ffffff"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_963500294592" button_text="" button_text_alignment="center" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-tripadvisor" custom_sizes_enabled="custom_settings" additional_margin_before="15" standard_button_icon_size="18" standard_button_padding_top="14" standard_button_padding_right="0" standard_button_padding_bottom="14" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_use_static_width="yes-pixels" standard_button_static_width="46" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_icon_color="#ffffff" standard_button_icon_color_hover="#ffffff"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][vc_row_inner][vc_column_inner width="1/6"][/vc_column_inner][vc_column_inner width="2/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_150211904723" large_height="30"][vc_column_text]<p style="text-align: center;">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras vestibulum mauris vel dignissim placerat. Sed turpis odio, rutrum nec pulvinar eget, varius malesuada diam. Aliquam faucibus tristique enim at porttitor.</p>[/vc_column_text][/vc_column_inner][vc_column_inner width="1/6"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_993244845259"][/vc_column][/vc_row][/vc_section]',

                'offer-and-prices' => '[vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_77145681754" layer_for_row_or_section="section" layer_z_index="0" custom_layer_sizes="custom_settings" layer_type="image" image_position_y="45%" large_height_type="px" large_height_px="400"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_240590238533" layer_for_row_or_section="section" layer_opacity="60%" layer_z_index="0" custom_layer_sizes="custom_settings" color="#3e4226" large_height_type="px" large_height_px="400"][ueldo_shortcode_gap class_name="ueldo_vc_element_833788756364" large_height="120"][ueldo_shortcode_heading class_name="ueldo_vc_element_150183355941" text_align="center" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Offer & Prices', 'ueldo' ) ) .'" custom_heading_subtitle_font_color_enabled="custom_settings" heading_subtitle_font_color="#c0d07d" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_150183358828" heading_text="'. esc_html( __( 'Horse Riding lessons for everyone', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings" font_color="#ffffff" font_color_hover="#ffffff"][/ueldo_shortcode_heading][ueldo_shortcode_gap class_name="ueldo_vc_element_749935463221" large_height="120"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_1502174384" custom_layer_sizes="custom_settings" color="#f5eae3" large_width_type="px" large_height_type="px" large_layer_position="bottom_left" large_margin_bottom="-15" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="4"][ueldo_shortcode_pricing_list class_name="ueldo_vc_element_150217258969123456789" custom_colors_enabled="custom_settings" box_shadow_blur_radius="35" box_shadow_color="rgba(0,0,0,0.05)" box_shadow_color_hover="rgba(0,0,0,0.05)" icon_color="rgba(0,0,0,0.03)" inset_box_shadow_color="rgba(0,0,0,0.15)" select_field_inset_box_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_pricing_list_group class_name="ueldo_vc_element_490850298161" title="'. esc_html( __( 'Group Lessons', 'ueldo' ) ) .'" description="'. esc_html( __( 'Single lesson time: at least 30 minutes', 'ueldo' ) ) .'" display_group_icon="no"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_951286246189" title="'. esc_html( __( 'Children - Beginners (1 lesson)', 'ueldo' ) ) .'"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_751181328069" title="'. esc_html( __( 'Children - Beginners (4 lessons)', 'ueldo' ) ) .'" price="$60"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_552953498512" title="'. esc_html( __( 'Children - Beginners (12 lessons)', 'ueldo' ) ) .'" price="$199"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_371885058900" title="'. esc_html( __( 'Semi-Advanced (1 lesson)', 'ueldo' ) ) .'" price="$25"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_724509359292" title="'. esc_html( __( 'Semi-Advanced (4 lessons)', 'ueldo' ) ) .'" price="$90"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_731811987882" title="'. esc_html( __( 'Semi-Advanced (12 lessons)', 'ueldo' ) ) .'" price="$340"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_306217393076" title="'. esc_html( __( 'Advanced (1 lesson)', 'ueldo' ) ) .'" price="$30"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_793244662989" title="'. esc_html( __( 'Advanced (4 lessons)', 'ueldo' ) ) .'" price="$100"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_946300134882" title="'. esc_html( __( 'Advanced (12 lessons)', 'ueldo' ) ) .'" price="$380"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_327221279136" title="'. esc_html( __( 'Seniors (30 minutes)', 'ueldo' ) ) .'" price="$28"][/ueldo_shortcode_pricing_list_group][ueldo_shortcode_pricing_list_group class_name="ueldo_vc_element_343139610053" title="'. esc_html( __( 'Private / Semi-Private Lessons', 'ueldo' ) ) .'" description="'. esc_html( __( 'Single lesson time: at least 45 minutes. Private lessons 1 to 1, Semi-Private 1 to 3.', 'ueldo' ) ) .'" display_group_icon="no"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_807741315949" title="'. esc_html( __( 'Children - Beginners (1 lesson)', 'ueldo' ) ) .'" price="$29"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_609153652292" title="'. esc_html( __( 'Children - Beginners (4 lessons)', 'ueldo' ) ) .'" price="$70"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_950877096773" title="'. esc_html( __( 'Children - Beginners (12 lessons)', 'ueldo' ) ) .'" price="$219"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_576707175992" title="'. esc_html( __( 'Semi-Advanced (1 lesson)', 'ueldo' ) ) .'" price="$35"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_414287726107" title="'. esc_html( __( 'Semi-Advanced (4 lessons)', 'ueldo' ) ) .'" price="$100"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_253350770431" title="'. esc_html( __( 'Semi-Advanced (12 lessons)', 'ueldo' ) ) .'" price="$370"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_915163698123" title="'. esc_html( __( 'Advanced (1 lesson)', 'ueldo' ) ) .'" price="$40"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_346011388055" title="'. esc_html( __( 'Advanced (4 lessons)', 'ueldo' ) ) .'" price="$110"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_901981088218" title="'. esc_html( __( 'Advanced (12 lessons)', 'ueldo' ) ) .'" price="$390"][ueldo_shortcode_pricing_list_attribute class_name="ueldo_vc_element_151207799229" title="'. esc_html( __( 'Seniors (30 minutes)', 'ueldo' ) ) .'" price="$38"][/ueldo_shortcode_pricing_list_group][/ueldo_shortcode_pricing_list][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_62526714103"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_heading class_name="ueldo_vc_element_957224906812" heading_tag="h4" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_536921450254" heading_text="'. esc_html( __( 'Daytime Lessons', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed dictum, nisl non mattis semper, tortor sem cursus tellus.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_150243149825" large_height="0" extra_small_custom_sizes="yes" extra_small_height="10"][/vc_column][vc_column width="1/2"][ueldo_shortcode_heading class_name="ueldo_vc_element_227255073313" heading_tag="h4" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_449303002614" heading_text="'. esc_html( __( 'Jumping Lessons', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Nunc lobortis magna placerat est cursus mattis. Fusce sagittis orci in metus dapibus feugiat. Pellentesque maximus purus.</p>[/vc_column_text][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_56440795885" large_height="25" extra_small_custom_sizes="yes"][ueldo_shortcode_button class_name="ueldo_vc_element_150217517984" button_type="two-line-button" button_text="'. esc_html( __( 'Call for Reservation!', 'ueldo' ) ) .'" button_text_alignment="center" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" button_alignment="center" custom_sizes_enabled="custom_settings" two_line_button_padding_right="40" two_line_button_padding_left="40" two_line_button_border_radius="50" custom_colors_enabled="custom_settings" two_line_button_background_color="#798d20" two_line_button_background_color_hover="#617a16" two_line_button_border_color="#798d20" two_line_button_border_color_hover="#617a16" two_line_button_box_shadow_vertical_length="10" two_line_button_box_shadow_blur_radius="35" two_line_button_box_shadow_spread_radius="-5" two_line_button_box_shadow_color="rgba(121,141,32,0.35)" two_line_button_box_shadow_vertical_length_hover="10" two_line_button_box_shadow_color_hover="rgba(97,122,22,0.25)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_text_shadow_color="rgba(255,245,237,0.01)" standard_button_text_shadow_color_hover="rgba(255,245,237,0.01)" two_line_button_first_line_color="rgba(255,255,255,0.6)" two_line_button_first_line_color_hover="rgba(255,255,255,0.6)" two_line_button_first_line_text_shadow_color="rgba(255,245,237,0.01)" two_line_button_first_line_text_shadow_color_hover="rgba(255,245,237,0.01)" two_line_button_second_line_color="#ffffff" two_line_button_second_line_color_hover="#ffffff" two_line_button_second_line_text_shadow_color="rgba(255,245,237,0.01)" two_line_button_second_line_text_shadow_color_hover="rgba(255,245,237,0.01)" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)" standard_button_icon_text_shadow_color="rgba(255,245,237,0.01)" standard_button_icon_text_shadow_color_hover="rgba(255,245,237,0.01)" two_line_button_icon_text_shadow_color="rgba(255,245,237,0.01)" two_line_button_icon_text_shadow_color_hover="rgba(255,245,237,0.01)"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_54342206826"][/vc_column][/vc_row][/vc_section][vc_section][vc_row full_width="stretch_row" content_placement="middle" css_animation="none" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_150217780985" layer_z_index="0" custom_layer_sizes="custom_settings" color="#f5eae3" large_width_percentage="50%" large_height_percentage="90%" large_margin_top="24" large_custom_row_border_radius="yes-unique-for-corners" large_row_border_radius_top_right_corner="4" large_row_border_radius_bottom_right_corner="4" extra_small_layer_custom_sizes="yes" extra_small_width_percentage="25%" extra_small_height_type="px" extra_small_height_px="400" extra_small_margin_top="25"][ueldo_shortcode_image class_name="ueldo_vc_element_150217745253" large_height_px="450" margin_bottom="0"][/vc_column][vc_column width="1/2" css=".vc_custom_1503397956610{margin-left: 30px !important;}" offset="vc_hidden-xs"][ueldo_shortcode_heading class_name="ueldo_vc_element_838404356498" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_308289879757" heading_text="'. esc_html( __( 'Horse Pension', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_849112676624" heading_tag="h6" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_438583746878" heading_text="'. esc_html( __( 'Starting at', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_974260063876" heading_text="$499" custom_font_color_enabled="custom_settings"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_934790681238" heading_text="'. esc_html( __( '/ mo', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Quisque vel sapien viverra, viverra augue eu, ullamcorper quam. Vivamus rhoncus leo lectus, sit amet ullamcorper libero malesuada sit amet. Praesent lectus mauris, consequat eu pellentesque in, cursus vel metus. Sed porttitor est vel iaculis faucibus. Quisque semper maximus lacus.[/vc_column_text][ueldo_shortcode_inline_container class_name="ueldo_vc_element_168277953121"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_900429533109" large_width_percentage="75%" small_custom_sizes="yes"][ueldo_shortcode_info_box class_name="ueldo_vc_element_86705373483" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( 'We feed horses with organic food from own Farm', 'ueldo' ) ) .'" info_box_subtitle="" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" custom_colors_enabled="custom_settings" info_element_background_color="#fff5ed" info_element_background_color_hover="#fff5ed" info_element_icon_color="#2f2b20" info_element_icon_color_hover="#2f2b20" info_element_box_shadow_color="rgba(255,245,237,0.01)" info_element_box_shadow_color_hover="rgba(255,245,237,0.01)" {ueldopredefinedsections:icon|key:flaticon-food,flaticon-vegetables|url:https://www.flaticon.com/free-icon/vegetables_424307|slug:info_element_icon_}][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row full_width="stretch_row" content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_gap class_name="ueldo_vc_element_15024315506" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_heading class_name="ueldo_vc_element_824927587002" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="5"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_841093084354" heading_text="'. esc_html( __( 'Horse Pension', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_788929022046" heading_tag="h6" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_270780994311" heading_text="'. esc_html( __( 'Starting at', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_425051882390" heading_text="$499" custom_font_color_enabled="custom_settings"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_476007779036" heading_text="'. esc_html( __( '/ mo', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]Quisque vel sapien viverra, viverra augue eu, ullamcorper quam. Vivamus rhoncus leo lectus, sit amet ullamcorper libero malesuada sit amet. Praesent lectus mauris, consequat eu pellentesque in, cursus vel metus. Sed porttitor est vel iaculis faucibus. Quisque semper maximus lacus.[/vc_column_text][ueldo_shortcode_inline_container class_name="ueldo_vc_element_252289609961"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_110008111517" large_width_percentage="75%" small_custom_sizes="yes"][ueldo_shortcode_info_box class_name="ueldo_vc_element_82831900724" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( 'We feed horses with organic food from own Farm', 'ueldo' ) ) .'" info_box_subtitle="" info_element_width="48" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" custom_colors_enabled="custom_settings" info_element_background_color="#fff5ed" info_element_background_color_hover="#fff5ed" info_element_icon_color="#2f2b20" info_element_icon_color_hover="#2f2b20" info_element_box_shadow_color="rgba(255,245,237,0.01)" info_element_box_shadow_color_hover="rgba(255,245,237,0.01)" {ueldopredefinedsections:icon|key:flaticon-food,flaticon-vegetables|url:https://www.flaticon.com/free-icon/vegetables_424307|slug:info_element_icon_}][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_47629609996524"][/vc_column][/vc_row][/vc_section][vc_section][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/3"][ueldo_shortcode_card class_name="ueldo_vc_element_2050267823"][ueldo_shortcode_info_box class_name="ueldo_vc_element_319947327738" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Professional care', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" {ueldopredefinedsections:icon|key:flaticon-horseshoe,flaticon-horse|url:https://www.flaticon.com/free-icon/horseshoe_259782|slug:info_element_icon_}][ueldo_shortcode_gap class_name="ueldo_vc_element_496366896712" large_height="30"][vc_column_text]Nulla sit amet efficitur nisl, vel vehicula erat. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][/ueldo_shortcode_info_box][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_418228885933" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/3"][ueldo_shortcode_card class_name="ueldo_vc_element_7321339510"][ueldo_shortcode_info_box class_name="ueldo_vc_element_383115227733" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Fenced paddock', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" {ueldopredefinedsections:icon|key:flaticon-fence|url:https://www.flaticon.com/free-icon/fence_459709|slug:info_element_icon_}][ueldo_shortcode_gap class_name="ueldo_vc_element_496162589380" large_height="30"][vc_column_text]Nulla sit amet efficitur nisl, vel vehicula erat. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][/ueldo_shortcode_info_box][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_285632504439" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/3"][ueldo_shortcode_card class_name="ueldo_vc_element_7814304797"][ueldo_shortcode_info_box class_name="ueldo_vc_element_923177703566" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Pension for Horses', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" {ueldopredefinedsections:icon|key:flaticon-barn,flaticon-buildings|url:https://www.flaticon.com/free-icon/barn_119301|slug:info_element_icon_}][ueldo_shortcode_gap class_name="ueldo_vc_element_416017297859" large_height="30"][vc_column_text]Nulla sit amet efficitur nisl, vel vehicula erat. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][/ueldo_shortcode_info_box][/ueldo_shortcode_card][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_643446289064"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="2/3" offset="vc_hidden-xs"][ueldo_shortcode_heading class_name="ueldo_vc_element_169188038949" heading_tag="h3" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Unforgettable holidays', 'ueldo' ) ) .'" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_89978733453" heading_text="'. esc_html( __( 'Check our Stays', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/3" offset="vc_hidden-xs"][ueldo_shortcode_button class_name="ueldo_vc_element_307908657921" button_text="'. esc_html( __( 'Go to Stays', 'ueldo' ) ) .'" button_text_alignment="center" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'stays%2F|title:'. rawurlencode( esc_html( __( 'Stays', 'ueldo' ) ) ) .'||" button_alignment="right" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_heading class_name="ueldo_vc_element_324984541916" heading_tag="h3" text_align="center" heading_subtitle_text="'. esc_html( __( 'Unforgettable holidays', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_49624884929" heading_text="'. esc_html( __( 'Check our Stays', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_button class_name="ueldo_vc_element_494463605640" button_text="'. esc_html( __( 'Go to Stays', 'ueldo' ) ) .'" button_text_alignment="center" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'stays%2F|title:'. rawurlencode( esc_html( __( 'Stays', 'ueldo' ) ) ) .'||" button_alignment="center" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_945207672373"][/vc_column][/vc_row][/vc_section]',

                'stays' => '[vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_77145681754" layer_for_row_or_section="section" layer_z_index="0" custom_layer_sizes="custom_settings" layer_type="image" image_position_y="45%" large_height_type="px" large_height_px="400"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_240590238533" layer_for_row_or_section="section" layer_opacity="60%" layer_z_index="0" custom_layer_sizes="custom_settings" color="#3e4226" large_height_type="px" large_height_px="400"][ueldo_shortcode_gap class_name="ueldo_vc_element_833788756364" large_height="120"][ueldo_shortcode_heading class_name="ueldo_vc_element_150183355941" text_align="center" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Farm resting', 'ueldo' ) ) .'" custom_heading_subtitle_font_color_enabled="custom_settings" heading_subtitle_font_color="#c0d07d" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_150183358828" heading_text="'. esc_html( __( 'Spend your holidays with us', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings" font_color="#ffffff" font_color_hover="#ffffff"][/ueldo_shortcode_heading][ueldo_shortcode_gap class_name="ueldo_vc_element_749935463221" large_height="120"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-4 vc_col-md-4"][ueldo_shortcode_pricing_table class_name="ueldo_vc_element_897347862182" pricing_table_style="03" content_alignment="center" title="'. esc_html( __( 'Weekend Stay', 'ueldo' ) ) .'" price_value="345" price_additional_element_text="'. esc_html( __( '/ person', 'ueldo' ) ) .'" margin_bottom="0"][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_602343051351"]'. esc_html( __( 'Full board', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_931521094156"]'. esc_html( __( 'Free bike rental', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_296449883551"]'. esc_html( __( 'Room with bathroom', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_162203389372"]'. esc_html( __( 'TV & WiFi access', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_681769858140"]'. esc_html( __( '5h horse ride included', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_button class_name="ueldo_vc_element_732330907484" button_text="'. esc_html( __( 'Reservation', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" button_alignment="center" show_button_icon="yes" button_icon_visibility="on_hover_only" custom_colors_enabled="custom_settings" standard_button_background_color="#efe4db" standard_button_background_color_hover="#798d20" standard_button_border_color="#efe4db" standard_button_border_color_hover="#798d20" standard_button_box_shadow_color="rgba(239,228,219,0.25)" standard_button_text_color="#313131" standard_button_text_color_hover="#ffffff" standard_button_text_shadow_color="rgba(255,245,237,0.01)" standard_button_text_shadow_color_hover="rgba(255,245,237,0.01)" standard_button_icon_color="rgba(49,49,49,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)" standard_button_icon_text_shadow_color="rgba(255,245,237,0.01)" standard_button_icon_text_shadow_color_hover="rgba(255,245,237,0.01)"][/ueldo_shortcode_button][/ueldo_shortcode_pricing_table][ueldo_shortcode_gap class_name="ueldo_vc_element_853395949344" large_height="0" small_custom_sizes="yes" small_height="45"][/vc_column][vc_column offset="vc_col-lg-4 vc_col-md-4"][ueldo_shortcode_pricing_table class_name="ueldo_vc_element_224906058088" pricing_table_style="03" content_alignment="center" title="'. esc_html( __( '1-week Stay', 'ueldo' ) ) .'" price_value="715" price_additional_element_text="'. esc_html( __( '/ person', 'ueldo' ) ) .'" show_ribbon="yes" ribbon_text="'. esc_html( __( 'Recommended', 'ueldo' ) ) .'" margin_top="-15" margin_bottom="0" custom_colors_enabled="custom_settings" box_shadow_blur_radius="35" box_shadow_color="rgba(0,0,0,0.05)"][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_246652011438"]'. esc_html( __( 'Full board', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_512027459685"]'. esc_html( __( 'Free bike rental', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_573576700657"]'. esc_html( __( 'Room with bathroom', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_424950591669"]'. esc_html( __( 'Access to the sauna', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_166876028644"]'. esc_html( __( 'TV & WiFi access', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_590073492668"]'. esc_html( __( '24h horse ride included', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_button class_name="ueldo_vc_element_414474078875" button_text="'. esc_html( __( 'Reservation', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" button_alignment="center" show_button_icon="yes" button_icon_visibility="on_hover_only"][/ueldo_shortcode_button][/ueldo_shortcode_pricing_table][ueldo_shortcode_gap class_name="ueldo_vc_element_524609306097" large_height="0" small_custom_sizes="yes" small_height="30"][/vc_column][vc_column offset="vc_col-lg-4 vc_col-md-4"][ueldo_shortcode_pricing_table class_name="ueldo_vc_element_280934962868" pricing_table_style="03" content_alignment="center" title="'. esc_html( __( '2-weeks Stay', 'ueldo' ) ) .'" price_value="1400" price_additional_element_text="'. esc_html( __( '/ person', 'ueldo' ) ) .'" margin_bottom="0"][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_332200442315"]'. esc_html( __( 'Full board', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_737077256536"]'. esc_html( __( 'Free bike rental', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_489488212406"]'. esc_html( __( 'Room with bathroom', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_960707985230"]'. esc_html( __( 'TV & WiFi access', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_pricing_table_attribute class_name="ueldo_vc_element_732693338578"]'. esc_html( __( '60h horse ride included', 'ueldo' ) ) .'[/ueldo_shortcode_pricing_table_attribute][ueldo_shortcode_button class_name="ueldo_vc_element_604245809223" button_text="'. esc_html( __( 'Reservation', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" button_alignment="center" show_button_icon="yes" button_icon_visibility="on_hover_only" custom_colors_enabled="custom_settings" standard_button_background_color="#efe4db" standard_button_background_color_hover="#798d20" standard_button_border_color="#efe4db" standard_button_border_color_hover="#798d20" standard_button_box_shadow_color="rgba(239,228,219,0.25)" standard_button_text_color="#313131" standard_button_text_color_hover="#ffffff" standard_button_text_shadow_color="rgba(255,245,237,0.01)" standard_button_text_shadow_color_hover="rgba(255,245,237,0.01)" standard_button_icon_color="rgba(49,49,49,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)" standard_button_icon_text_shadow_color="rgba(255,245,237,0.01)" standard_button_icon_text_shadow_color_hover="rgba(255,245,237,0.01)"][/ueldo_shortcode_button][/ueldo_shortcode_pricing_table][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_150183823205" large_height="30"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_150183825349" large_height="30"][ueldo_shortcode_heading class_name="ueldo_vc_element_150183826277" text_align="center" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Well-equipped', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_150183829193" heading_text="'. esc_html( __( '12 Comfortable Rooms', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/vc_column][/vc_row][vc_row][vc_column width="1/6"][/vc_column][vc_column width="2/3"][vc_column_text]<p style="text-align: center;">Maecenas dui neque, fringilla sed venenatis quis, mollis vitae neque. Sed sit amet semper lacus. Maecenas et massa magna. Aenean at ipsum erat. Donec euismod rutrum mauris, vel finibus elit. Vestibulum tellus magna, faucibus ac hendrerit at, lobortis sed mi. Aliquam id vestibulum metus.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_150183861855"][/vc_column][vc_column width="1/6"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_846784833556" custom_layer_sizes="custom_settings" color="#f5eae3" large_width_type="px" large_width_px="650" large_height_type="px" large_height_px="400" large_layer_position="top_right" large_margin_top="-30" large_margin_right="-15" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="4"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_390351354945" custom_layer_sizes="custom_settings" large_width_type="px" large_height_type="px" large_layer_position="bottom_left" large_margin_bottom="15" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="4"][ueldo_shortcode_loop class_name="ueldo_vc_element_150183864376" columns="4" rows="2" masonry_enabled="yes" custom_colors_enabled="custom_settings" loop_background_color="rgba(255,245,237,0.01)" next_prev_arrow_container_box_shadow_color="rgba(255,245,237,0.01)" next_prev_arrow_container_box_shadow_color_hover="rgba(255,245,237,0.01)"][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_642572410715" width="double"][ueldo_shortcode_image class_name="ueldo_vc_element_346422680817" additional="gallery_image" gallery_slug="gallery" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_558522404372"][ueldo_shortcode_image class_name="ueldo_vc_element_801033779176" additional="gallery_image" gallery_slug="gallery" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_423080047940" large_static_height="yes" large_static_height_px="630" small_custom_sizes="yes" small_static_height="yes"][ueldo_shortcode_image class_name="ueldo_vc_element_556754490088" additional="gallery_image" gallery_slug="gallery" large_height_px="630" small_custom_sizes="yes" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_363917572782"][ueldo_shortcode_image class_name="ueldo_vc_element_327285705535" additional="gallery_image" gallery_slug="gallery" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_911489549322" width="double"][ueldo_shortcode_image class_name="ueldo_vc_element_584628997829" additional="gallery_image" gallery_slug="gallery" custom_colors_enabled="custom_settings" images_container_box_shadow_horizontal_length="0" images_container_box_shadow_vertical_length="0" images_container_box_shadow_blur_radius="0" images_container_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_loop_cell][/ueldo_shortcode_loop][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15112499720028" large_height="45"][/vc_column][/vc_row][/vc_section][vc_section][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/3"][ueldo_shortcode_card class_name="ueldo_vc_element_2050267823"][ueldo_shortcode_info_box class_name="ueldo_vc_element_319947327738" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Professional care', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" {ueldopredefinedsections:icon|key:flaticon-horseshoe,flaticon-horse|url:https://www.flaticon.com/free-icon/horseshoe_259782|slug:info_element_icon_}][ueldo_shortcode_gap class_name="ueldo_vc_element_496366896712" large_height="30"][vc_column_text]Nulla sit amet efficitur nisl, vel vehicula erat. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][/ueldo_shortcode_info_box][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_418228885933" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/3"][ueldo_shortcode_card class_name="ueldo_vc_element_7321339510"][ueldo_shortcode_info_box class_name="ueldo_vc_element_383115227733" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Fenced paddock', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" {ueldopredefinedsections:icon|key:flaticon-fence|url:https://www.flaticon.com/free-icon/fence_459709|slug:info_element_icon_}][ueldo_shortcode_gap class_name="ueldo_vc_element_496162589380" large_height="30"][vc_column_text]Nulla sit amet efficitur nisl, vel vehicula erat. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][/ueldo_shortcode_info_box][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_285632504439" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/3"][ueldo_shortcode_card class_name="ueldo_vc_element_7814304797"][ueldo_shortcode_info_box class_name="ueldo_vc_element_923177703566" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Pension for Horses', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" {ueldopredefinedsections:icon|key:flaticon-barn,flaticon-buildings|url:https://www.flaticon.com/free-icon/barn_119301|slug:info_element_icon_}][ueldo_shortcode_gap class_name="ueldo_vc_element_416017297859" large_height="30"][vc_column_text]Nulla sit amet efficitur nisl, vel vehicula erat. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][/ueldo_shortcode_info_box][/ueldo_shortcode_card][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_643446289064"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="2/3" offset="vc_hidden-xs"][ueldo_shortcode_heading class_name="ueldo_vc_element_169188038949" heading_tag="h3" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Visit us for adventure', 'ueldo' ) ) .'" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_89978733453" heading_text="'. esc_html( __( 'Check our offer and prices', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/3" offset="vc_hidden-xs"][ueldo_shortcode_button class_name="ueldo_vc_element_307908657921" button_text="'. esc_html( __( 'Go to Offer page', 'ueldo' ) ) .'" button_text_alignment="center" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" button_alignment="right" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_heading class_name="ueldo_vc_element_324984541916" heading_tag="h3" text_align="center" heading_subtitle_text="'. esc_html( __( 'Visit us for adventure', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_49624884929" heading_text="'. esc_html( __( 'Check our offer and prices', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_button class_name="ueldo_vc_element_494463605640" button_text="'. esc_html( __( 'Go to Offer page', 'ueldo' ) ) .'" button_text_alignment="center" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" button_alignment="center" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_945207672373"][/vc_column][/vc_row][/vc_section]',

                '404-page' => '[vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15113748595675" layer_for_row_or_section="section" layer_z_index="0" color="#f5eae3"][ueldo_shortcode_gap class_name="ueldo_vc_element_150226943749"][ueldo_shortcode_heading class_name="ueldo_vc_element_150226944972" heading_tag="h1" text_align="center" heading_subtitle_text="'. esc_html( __( 'Ooops...', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_150226946042" heading_text="'. esc_html( __( 'Nothing found here...', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_row_layer class_name="ueldo_vc_element_150184369967" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" layer_type="image" large_width_type="px" large_width_px="228" large_height_type="px" large_height_px="284" large_layer_position="bottom_left" large_margin_bottom="0" large_margin_left="0" {ueldopredefinedsections:image|context:stud-grass-isolated}][/vc_column][/vc_row][vc_row][vc_column width="1/6" offset="vc_col-lg-3 vc_col-md-3"][/vc_column][vc_column width="2/3" offset="vc_col-lg-6 vc_col-md-6"][vc_column_text]<p style="text-align: center;">'. sprintf( wp_kses( __( 'We could not find the results you are looking for - it may be removed, or temporary hidden. Please try to use the search form, or <a href="%s">go back to home page</a>.', 'ueldo' ), array( 'a' => array( 'href' => array(), 'target' => array() ) ) ), esc_url( home_url( '/' ) ) ) .'</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_150226952342" large_height="30"][/vc_column][vc_column width="1/6" offset="vc_col-lg-3 vc_col-md-3"][/vc_column][/vc_row][vc_row][vc_column width="1/3" offset="vc_col-xs-2"][/vc_column][vc_column width="1/3" offset="vc_col-xs-8"][ueldo_shortcode_search_field class_name="ueldo_vc_element_150226953049"][/vc_column][vc_column width="1/3" offset="vc_col-xs-2"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_1502269590"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_274792030684"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/3"][ueldo_shortcode_card class_name="ueldo_vc_element_2050267823"][ueldo_shortcode_info_box class_name="ueldo_vc_element_319947327738" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Professional care', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" {ueldopredefinedsections:icon|key:flaticon-horseshoe,flaticon-horse|url:https://www.flaticon.com/free-icon/horseshoe_259782|slug:info_element_icon_}][ueldo_shortcode_gap class_name="ueldo_vc_element_496366896712" large_height="30"][vc_column_text]Nulla sit amet efficitur nisl, vel vehicula erat. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][/ueldo_shortcode_info_box][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_418228885933" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/3"][ueldo_shortcode_card class_name="ueldo_vc_element_7321339510"][ueldo_shortcode_info_box class_name="ueldo_vc_element_383115227733" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Fenced paddock', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" {ueldopredefinedsections:icon|key:flaticon-fence|url:https://www.flaticon.com/free-icon/fence_459709|slug:info_element_icon_}][ueldo_shortcode_gap class_name="ueldo_vc_element_496162589380" large_height="30"][vc_column_text]Nulla sit amet efficitur nisl, vel vehicula erat. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][/ueldo_shortcode_info_box][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_285632504439" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][/vc_column][vc_column width="1/3"][ueldo_shortcode_card class_name="ueldo_vc_element_7814304797"][ueldo_shortcode_info_box class_name="ueldo_vc_element_923177703566" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'offer-and-prices%2F|title:'. rawurlencode( esc_html( __( 'Offer & Prices', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Pension for Horses', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" {ueldopredefinedsections:icon|key:flaticon-barn,flaticon-buildings|url:https://www.flaticon.com/free-icon/barn_119301|slug:info_element_icon_}][ueldo_shortcode_gap class_name="ueldo_vc_element_416017297859" large_height="30"][vc_column_text]Nulla sit amet efficitur nisl, vel vehicula erat. Quisque feugiat mi ac faucibus gravida. Duis ultrices, nisi.[/vc_column_text][/ueldo_shortcode_info_box][/ueldo_shortcode_card][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_643446289064"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="2/3" offset="vc_hidden-xs"][ueldo_shortcode_heading class_name="ueldo_vc_element_169188038949" heading_tag="h3" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Visit us for adventure', 'ueldo' ) ) .'" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_89978733453" heading_text="'. esc_html( __( 'Check our Stays offer', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/3" offset="vc_hidden-xs"][ueldo_shortcode_button class_name="ueldo_vc_element_307908657921" button_text="'. esc_html( __( 'Go to Stays page', 'ueldo' ) ) .'" button_text_alignment="center" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'stays%2F|title:'. rawurlencode( esc_html( __( 'Stays', 'ueldo' ) ) ) .'||" button_alignment="right" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_heading class_name="ueldo_vc_element_324984541916" heading_tag="h3" text_align="center" heading_subtitle_text="'. esc_html( __( 'Visit us for adventure', 'ueldo' ) ) .'"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_49624884929" heading_text="'. esc_html( __( 'Check our Stays offer', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_button class_name="ueldo_vc_element_494463605640" button_text="'. esc_html( __( 'Go to Stays page', 'ueldo' ) ) .'" button_text_alignment="center" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'stays%2F|title:'. rawurlencode( esc_html( __( 'Stays', 'ueldo' ) ) ) .'||" button_alignment="center" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_945207672373"][/vc_column][/vc_row][/vc_section]',

                'footer' => '[vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_150227854798" layer_for_row_or_section="section" layer_type="image" image_add_box_shadow="yes-inset-on-top" image_inset_top_box_shadow_blur_radius="30" image_inset_top_box_shadow_spread_radius="-10" image_inset_top_box_shadow_color="rgba(47,43,32,0.5)"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_150227858051" layer_for_row_or_section="section" layer_opacity="60%" color="#3e4226"][ueldo_shortcode_gap class_name="ueldo_vc_element_150234936277" large_height="20"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15113768442284" large_height="35"][/vc_column][/vc_row][vc_row][vc_column width="1/2" offset="vc_hidden-xs"][vc_column_text]<p style="color: #948f80">2017 - '. date( 'Y' ) .' &copy; <a href="'. esc_url( ueldo_get_external_url( 'ueldo-com' ) ) .'" target="_blank">'. esc_html( __( 'Ueldo', 'ueldo' ) ) .'</a> '. esc_html( __( 'WordPress theme by', 'ueldo' ) ) .' <a href="'. esc_url( ueldo_get_external_url( 'martanian-com' ) ) .'" target="_blank">Martanian</a></p>[/vc_column_text][/vc_column][vc_column width="1/2" offset="vc_hidden-xs"][vc_column_text]<p style="text-align: right;color: #948f80">'. esc_html( __( 'Follow us on', 'ueldo' ) ) .' <a href="#">'. esc_html( __( 'Facebook', 'ueldo' ) ) .'</a> '. esc_html( __( 'and', 'ueldo' ) ) .' <a href="#">'. esc_html( __( 'Twitter', 'ueldo' ) ) .'</a></p>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][vc_column_text]<p style="color: #948f80">2017 - '. date( 'Y' ) .' &copy; <a href="'. esc_url( ueldo_get_external_url( 'ueldo-com' ) ) .'" target="_blank">'. esc_html( __( 'Ueldo', 'ueldo' ) ) .'</a> '. esc_html( __( 'WordPress theme by', 'ueldo' ) ) .' <a href="'. esc_url( ueldo_get_external_url( 'martanian-com' ) ) .'" target="_blank">Martanian</a><br /> '. esc_html( __( 'Follow us on', 'ueldo' ) ) .' <a href="#">'. esc_html( __( 'Facebook', 'ueldo' ) ) .'</a> '. esc_html( __( 'and', 'ueldo' ) ) .' <a href="#">'. esc_html( __( 'Twitter', 'ueldo' ) ) .'</a></p>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_430650667204" large_height="35"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15113764428597" layer_for_row_or_section="section" layer_z_index="0" color="#2f2b20"][/vc_column][/vc_row][/vc_section]',

                'header' => '[vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible"][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15015897030112" layer_for_row_or_section="section" color="#2f2b20" color_add_box_shadow="yes-outset" color_outset_box_shadow_vertical_length="10" color_outset_box_shadow_blur_radius="35" color_outset_box_shadow_color="rgba(47,43,32,0.25)"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_150159191865"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_150159192288" large_width_percentage="25%"][ueldo_shortcode_website_logo class_name="ueldo_vc_element_150166743069" large_width_type="px" large_width_px="124" {ueldopredefinedsections:image|context:stud-logo-demo-like}][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_150159193569" large_width_percentage="75%" large_content_alignment="right"][ueldo_shortcode_gap class_name="ueldo_vc_element_719126943083" large_height="0" small_custom_sizes="yes" small_height="21"][ueldo_shortcode_header_menu class_name="ueldo_vc_element_150158952183" menu_width_style="inline" custom_sizes_enabled="custom_settings" margin_right="-15" active_menu_element_bottom_line_height="3" custom_colors_enabled="custom_settings" active_menu_element_with_child_elements_color="#ffffff" active_menu_element_bottom_line_color="#798d20" box_shadow_color="rgba(0,0,0,0.1)" submenu_element_bottom_border_color="rgba(0,0,0,0.05)" submenu_element_link_color="rgba(255,255,255,0.6)" submenu_element_link_color_hover="#ffffff"][ueldo_shortcode_button class_name="ueldo_vc_element_114023344908" button_text="" button_text_alignment="center" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-facebook" custom_sizes_enabled="custom_settings" additional_margin_before="30" standard_button_padding_top="9" standard_button_padding_right="0" standard_button_padding_bottom="9" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_use_static_width="yes-pixels" standard_button_static_width="33" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="rgba(255,255,255,0.1)" standard_button_background_color_hover="#798d20" standard_button_box_shadow_vertical_length="0" standard_button_box_shadow_blur_radius="0" standard_button_box_shadow_spread_radius="0" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="0" standard_button_box_shadow_blur_radius_hover="0" standard_button_box_shadow_color_hover="rgba(255,255,255,0.01)" standard_button_icon_color="#948f80" standard_button_icon_color_hover="#ffffff"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_718447917148" button_text="" button_text_alignment="center" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-twitter" custom_sizes_enabled="custom_settings" additional_margin_before="15" standard_button_padding_top="9" standard_button_padding_right="0" standard_button_padding_bottom="9" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_use_static_width="yes-pixels" standard_button_static_width="33" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="rgba(255,255,255,0.1)" standard_button_background_color_hover="#798d20" standard_button_box_shadow_vertical_length="0" standard_button_box_shadow_blur_radius="0" standard_button_box_shadow_spread_radius="0" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="0" standard_button_box_shadow_blur_radius_hover="0" standard_button_box_shadow_color_hover="rgba(255,255,255,0.01)" standard_button_icon_color="#948f80" standard_button_icon_color_hover="#ffffff"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_150219100246" button_visible_on_devices="small,extra-small" button_text="" button_text_alignment="center" action_after_click="show_hide_side_menu" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-bars" custom_sizes_enabled="custom_settings" additional_margin_before="15" standard_button_padding_top="9" standard_button_padding_right="0" standard_button_padding_bottom="9" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_use_static_width="yes-pixels" standard_button_static_width="33" standard_button_border_width="0"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_628778302906" large_height="0" small_custom_sizes="yes" small_height="20"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][/vc_section]',

                'additional-before-side-menu' => '[vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_button class_name="ueldo_vc_element_150236131365" button_text="'. esc_html( __( 'Close menu', 'ueldo' ) ) .'" button_text_alignment="center" action_after_click="show_hide_side_menu" button_alignment="center" show_button_icon="yes" button_icon_fontawesome="fa fa-times" custom_sizes_enabled="custom_settings" standard_button_use_static_width="yes" standard_button_static_width="190" custom_colors_enabled="custom_settings" standard_button_background_color="#efe4db" standard_button_border_color="#efe4db" standard_button_box_shadow_color="rgba(221,210,204,0.25)" standard_button_text_color="#313131" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#d2c6bc" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][/vc_column][/vc_row]',

                'additional-after-side-menu' => '[vc_row][vc_column][ueldo_shortcode_website_logo class_name="ueldo_vc_element_250166743069" horizontal_alignment="center" large_width_type="px" large_width_px="112" {ueldopredefinedsections:image|context:stud-logo-side-menu}][ueldo_shortcode_gap class_name="ueldo_vc_element_150235937496" large_height="15"][/vc_column][/vc_row]',

                'blog-post' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas vulputate ante purus, sit amet scelerisque ipsum venenatis sed. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum ornare est eu sapien sagittis, vitae maximus dui pharetra. Morbi aliquam magna non consectetur tincidunt. Nam sem dui, consectetur et tortor vitae, volutpat mollis nibh. <!--more--> Pellentesque id tempor mauris. Vivamus pulvinar turpis viverra enim condimentum, sed varius justo mattis. Sed viverra eros at sem semper consectetur. Proin eu facilisis justo. Duis vehicula mi id diam faucibus laoreet. Duis nec venenatis libero, sit amet iaculis lacus. Praesent ac feugiat est. Vestibulum commodo ultrices elementum. Nulla nec fringilla felis. <h3>Curabitur congue, odio at tempus lobortis, risus turpis</h3> Condimentum ipsum, sed porta urna nunc commodo lorem. Donec ac massa scelerisque, egestas sapien eget, semper tortor. Fusce vitae tempor est. Phasellus eu lectus faucibus, varius risus at, feugiat quam. Maecenas vestibulum, mauris non vehicula laoreet, turpis felis auctor turpis, vitae hendrerit nibh sem quis ante. Vivamus vel purus vel diam hendrerit finibus sit amet eu metus. <a href="#">Phasellus vitae varius</a> mauris, facilisis sagittis ex. Fusce nec mi non eros efficitur egestas. Quisque at pharetra ligula, non mattis nunc. Ut bibendum sollicitudin mi, ut euismod velit tempor id. Phasellus molestie non neque sed placerat. <blockquote>Etiam nec euismod mauris. Nulla cursus ut leo quis mattis. Maecenas pharetra et turpis nec eleifend. Integer nec sapien neque. Aliquam quis augue at libero imperdiet consequat molestie.</blockquote> Nulla porta sodales sem vel tempus. Vivamus interdum ante ex, ut imperdiet ex vestibulum ut. In pretium diam a viverra lacinia. Fusce cursus, arcu nec pharetra imperdiet, neque lorem malesuada lectus, in egestas elit massa a erat. Donec efficitur sem vitae magna facilisis feugiat. Integer rhoncus augue a sollicitudin semper. Aliquam quis augue at libero imperdiet consequat molestie semper risus. In hac habitasse platea dictumst. <h4>Cum sociis natoque penatibus</h4> Donec purus magna, condimentum at luctus eu, porttitor vel leo. Mauris in massa viverra: <ul><li>Proin eleifend sollicitudin sem,</li><li>A convallis lorem cursus convallis,</li><li>Mauris mattis urna dolor, vel efficitur,</li><li>Mauris faucibus semper aliquam,</li><li>Nullam et justo id velit aliquet venenatis,</li></ul> Donec maximus laoreet risus et fringilla. Fusce vestibulum nisi vel ex efficitur pharetra. Ut sit amet dolor a risus vehicula mollis. Sed at enim quis tortor fermentum ornare sit amet at purus. Sed lobortis viverra sem sed congue. Vivamus et porta arcu. Donec faucibus eget dolor ut pharetra. Mauris et metus vitae dui rhoncus aliquet. Quisque nunc lacus, efficitur id ipsum at, elementum pretium libero.'
            );

            # return result
            return( $page_slug == false ? $contents : ( isset( $contents[esc_attr( $page_slug )] ) ? $contents[esc_attr( $page_slug )] : false ) );
        }

       /**
        *
        * end of class methods.
        *
        */
    }

   /**
    *
    * end of file.
    *
    */

?>