<?php

   /**
    *
    * base functions
    *
    */

    # get path to wordpress core
    function ueldo_load_demo_data_ajax_core_path() {

        # explode the content path
        $exploded = explode( 'wp-content', $_SERVER['SCRIPT_FILENAME'] );

        # path up to themes directory
        return( $exploded[0] );
    }

    # check if connection is legal
    function ueldo_check_load_demo_data_ajax_call_correctness() {

        # is the http referer correct?
        if( strpos( $_SERVER['HTTP_REFERER'], '?page=ueldo_load_demo_data' ) === false ) return( false );

        # is the call made from current domain?
        if( strpos( $_SERVER['HTTP_REFERER'], $_SERVER['HTTP_HOST'] ) === false ) return( false );

        # return result
        return( is_user_logged_in() && current_user_can( 'manage_options' ) );
    }

    # display result as json
    function ueldo_load_demo_data_display_json( $status = 'ok', $data = array() ) {

        # is result an array?
        if( in_array( $status, array( 'ok', 'wrong' ), true ) && is_array( $data ) ) echo json_encode( array( 'status' => $status, 'data' => $data ) );

        # return
        exit;
    }

   /**
    *
    * configurations
    *
    */

    # include wordpress core
    define( 'WP_USE_THEMES', false );
    require( ueldo_load_demo_data_ajax_core_path() .'wp-load.php' );

    # check if user is logged-in
    if( ueldo_check_load_demo_data_ajax_call_correctness() == false ) exit( esc_html( __( 'Permission denied.', 'ueldo' ) ) );

    # do we have required data set?
    if( !isset( $_POST ) || !isset( $_POST['template'] ) || !isset( $_POST['action'] ) || !in_array( $_POST['template'], array_keys( ueldo_load_demo_data_get_demo_templates_array() ), true ) || empty( $_POST['action'] ) ) exit( esc_html( __( 'Permission denied.', 'ueldo' ) ) );

    # load taxonomy functions
    require_once( ABSPATH .'wp-admin/includes/taxonomy.php' );

   /**
    *
    * include class dedicated for selected demo template
    *
    */

    # get path to dedicated class
    $filepath = plugin_dir_path( __FILE__ ) .'_contents/'. esc_attr( $_POST['template'] ) .'.php';

    # does class file exists?
    if( file_exists( $filepath ) ) {

       /**
        *
        * base functions used for installations
        *
        */

        class ueldo_demo_contents_loader_installation_helper {

           /**
            *
            * solutions array
            *
            */

            public static $solutions = array();

           /**
            *
            * cache new solution
            *
            */

            public static function add_solution( $code, $solution ) {

                # add solution
                self::$solutions[esc_attr( $code )] = $solution;
            }

           /**
            *
            * get single solution
            *
            */

            public static function get_solution( $code, $subcode = false ) {

                # do we have subcode?
                if( $subcode != false ) return( isset( self::$solutions[esc_attr( $code )] ) && isset( self::$solutions[esc_attr( $code )][esc_attr( $subcode )] ) ? self::$solutions[esc_attr( $code )][esc_attr( $subcode )] : false );

                # return single solution
                return( isset( self::$solutions[esc_attr( $code )] ) ? self::$solutions[esc_attr( $code )] : false );
            }

           /**
            *
            * get all solutions
            *
            */

            public static function get_solutions() {

                # return result
                return( self::$solutions );
            }

           /**
            *
            * find dynamic elements in content
            *
            */

            public static function find_dynamic_elements( $contents ) {

                # array of unique dynamic elements
                $dynamic_elements = array();

                # walk for each contents
                foreach( $contents as $content ) {

                    # find all dynamic elements inside content
                    $dynamic_elements_positions = ueldo_strpos_all( $content, '{ueldopredefinedsections:' );

                    # do we have any?
                    if( $dynamic_elements_positions !== false ) {

                        # walk for each dynamic element
                        foreach( $dynamic_elements_positions as $dynamic_elements_position ) {

                            # get full dynamic element string
                            $string = substr( $content, $dynamic_elements_position, ( strpos( $content, '}', $dynamic_elements_position ) - $dynamic_elements_position + 1 ) );

                            # only unique dynamic elements
                            if( !in_array( $string, array_keys( $dynamic_elements ), true ) ) {

                                # add to dynamic elements array
                                $dynamic_elements[$string] = '';
                            }
                        }
                    }
                }

                # return result
                return( $dynamic_elements );
            }

           /**
            *
            * get dynamic elements replacements
            *
            */

            public static function get_dynamic_elements_replacements( $dynamic_elements, $icons, $default_replacements ) {

                # prepare results array
                $result = array();

                # walk for each dynamic elements
                foreach( $dynamic_elements as $dynamic_element_key => $dynamic_element_replacement ) {

                    # replace flaticon icon
                    if( strpos( $dynamic_element_key, '{ueldopredefinedsections:icon|' ) !== false ) $result[$dynamic_element_key] = self::find_flaticon_icon_replacement( $dynamic_element_key, $icons );

                    # other elements
                    else {

                        # try to find a solution
                        $solution = self::get_solution( $dynamic_element_key );

                        # do we have correct solution found?
                        if( $solution != false ) $result[$dynamic_element_key] = $solution;
                        else {

                            # check if solution can be found in custom replacements array
                            if( isset( $default_replacements[$dynamic_element_key] ) ) $result[$dynamic_element_key] = $default_replacements[$dynamic_element_key];
                            else $result[$dynamic_element_key] = '';
                        }
                    }
                }

                # return result
                return( $result );
            }

           /**
            *
            * find flaticon icon replacement
            *
            */

            public static function find_flaticon_icon_replacement( $code, $icons ) {

                # walk for each icon
                foreach( $icons as $icon ) {

                    # check icon codes if they are saved as array
                    if( is_array( $icon['code'] ) ) {

                        # walk for each code
                        foreach( $icon['code'] as $icon_code_id => $icon_code ) {

                            # compare and return replacement
                            if( $code == $icon_code ) return( $icon['replacement'][esc_attr( $icon_code_id )] );
                        }
                    }

                    # check icon code if it is saved as string
                    else {

                        # compare and return replacement
                        if( $code == $icon['code'] ) return( $icon['replacement'] );
                    }
                }

                # nothing found?
                return( '' );
            }

           /**
            *
            * do content replacements
            *
            */

            public static function do_content_replacements( $content, $replacements ) {

                # walk for each replacements
                foreach( $replacements as $replacement_key => $replacement_solution ) {

                    # do the replacements
                    $content = str_replace( $replacement_key, $replacement_solution, $content );
                }

                # return result
                return( $content );
            }

           /**
            *
            * get main menu slug
            *
            */

            public static function get_main_menu_slug() {

                # there's no main menu found?
                if( self::get_solution( 'main-menu-id' ) == false ) return( false );

                # get main menu object
                $main_menu_object = wp_get_nav_menu_object( esc_attr( self::get_solution( 'main-menu-id' ) ) );

                # return main menu slug
                return( $main_menu_object != false ? $main_menu_object -> slug : '' );
            }

           /**
            *
            * get most similar element to requested one
            *
            */

            public static function get_most_similar_element( $type, $title ) {

                # switch by element type
                switch( $type ) {

                   /**
                    *
                    * menu slug
                    *
                    */

                    case 'menu_slug':

                        # get all navigation menus
                        $menus = get_terms( 'nav_menu', array( 'hide_empty' => false ) );

                        # nav menu location
                        $locations = get_theme_mod( 'nav_menu_locations' );

                        # possible menu names
                        $possible_names = array();

                        # do we have any menu?
                        if( $menus != false && $menus != null && is_array( $menus ) ) {

                            # walk foreach navigation menus
                            foreach( $menus as $menu ) {

                                # compare the title
                                if( $title == $menu -> name || strpos( $menu -> name, $title ) !== false ) {

                                    # update possible names array
                                    $possible_names[] = array( 'slug' => $menu -> slug, 'same_or_similar' => esc_attr( $title == $menu -> name ? 'same' : 'similar' ) );

                                    # killer
                                    if( $locations['ueldo_main_menu'] == $menu -> term_id ) return( $menu -> slug );
                                }
                            }

                            # still here; do we have any possible names found?
                            if( count( $possible_names ) > 0 ) {

                                # walk for each possible names
                                foreach( $possible_names as $possible_name ) {

                                    # looking for menu with the same name
                                    if( $possible_name['same_or_similar'] == 'same' ) return( $possible_name['slug'] );
                                }

                                # still here; return first one
                                return( $possible_name[0]['slug'] );
                            }
                        }

                        # nothing found
                        return( false );

                    break;

                   /**
                    *
                    * page, header, footer or extras
                    *
                    */

                    case 'page':
                    case 'ueldohefo':

                        # get list of all pages
                        $pages = get_posts( array( 'post_type' => esc_attr( $type ), 'posts_per_page' => -1, 'status' => 'publish' ) );

                        # possible pages names
                        $possible_names = array();

                        # do we have any page?
                        if( $pages != false && $pages != null && is_array( $pages ) ) {

                            # walk for each form
                            foreach( $pages as $page ) {

                                # killer
                                if( $title == $page -> post_title ) return( $page -> ID );

                                # is it similar?
                                if( strpos( $page -> post_title, $title ) !== false ) $possible_names[] = $page -> ID;
                            }

                            # still here; return first possible name
                            return( isset( $possible_names[0] ) ? $possible_names[0] : false );
                        }

                        # nothing found
                        return( false );

                    break;
                }

                # nothing found
                return( false );
            }

           /**
            *
            * end of class methods.
            *
            */
        }

       /**
        *
        * require dedicated class file
        *
        */

        require_once( $filepath );

       /**
        *
        * base class for installation process
        *
        */

        class ueldo_demo_contents_loader extends ueldo_demo_contents_loader_base {

           /**
            *
            * array of all flaticon icons
            *
            */

            public static $flaticon_icons = array();

           /**
            *
            * clarification records
            *
            */

            public static $clarification_records = array(
                'icon_not_found' => array(),
                'other' => array()
            );

           /**
            *
            * get clarification solution
            *
            */

            public static function get_clarification_solution( $element_id, $type, $data = false ) {

                # do we need to find specific data?
                if( $data !== false ) {

                    # find clarification solution
                    if( !isset( $_POST['data'] ) || !isset( $_POST['data']['clarifications'] ) || !isset( $_POST['data']['clarifications'][esc_attr( $type )] ) || !isset( $_POST['data']['clarifications'][esc_attr( $type )][esc_attr( $element_id )] ) || !isset( $_POST['data']['clarifications'][esc_attr( $type )][esc_attr( $element_id )][esc_attr( $data )] ) ) return( false );

                    # all fine
                    return( $_POST['data']['clarifications'][esc_attr( $type )][esc_attr( $element_id )][esc_attr( $data )] );
                }

                # return simple solution
                else {

                    # find clarification solution
                    if( !isset( $_POST['data'] ) || !isset( $_POST['data']['clarifications'] ) || !isset( $_POST['data']['clarifications'][esc_attr( $type )] ) || !isset( $_POST['data']['clarifications'][esc_attr( $type )][esc_attr( $element_id )] ) ) return( false );

                    # all fine
                    return( $_POST['data']['clarifications'][esc_attr( $type )][esc_attr( $element_id )] );
                }
            }

           /**
            *
            * check for clarifications
            *
            */

            public static function check_for_clarifications( $parts ) {

                # do we have to install pages?
                if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                    # find all flaticon icons to replace
                    self::find_all_flaticon_icons();

                    # walk for each flaticon icon
                    foreach( self::get_all_flaticon_icons() as $element_id => $element ) {

                        # array of possible icon replacements
                        $possible_icons = self::find_all_possible_icon_replacements( $element );

                        # there's only one possible icon?
                        if( count( $possible_icons ) === 1 ) {

                            # update dynamic element replacement
                            self::update_flaticon_icon_replacement( $element_id, $element['slug'], $possible_icons[0] );
                        }

                        # clearification required
                        else {

                            # there's no any possible icon found?
                            if( count( $possible_icons ) === 0 ) {

                                # add new clarification record
                                if( !self::are_clarifications_solved() ) self::add_clarification_record( $element_id, 'icon_not_found' );
                                else {

                                    # solutions array
                                    $solutions = array(
                                        'icon_font_unique_key' => self::get_clarification_solution( $element_id, 'icon_not_found', 'font-family' ),
                                        'icon_key' => self::get_clarification_solution( $element_id, 'icon_not_found', 'class' )
                                    );
                                }
                            }

                            # there's more than one possible icon found?
                            else {

                                # add new clarification record
                                if( !self::are_clarifications_solved() ) self::add_clarification_record( $element_id, 'duplicated_icon', $possible_icons );
                                else {

                                    # get id of selected possible icon
                                    $selected_id = self::get_clarification_solution( $element_id, 'other' );

                                    # solutions array
                                    $solutions = array(
                                        'icon_font_unique_key' => $possible_icons[$selected_id]['icon_font_unique_key'],
                                        'icon_key' => $possible_icons[$selected_id]['icon_key']
                                    );
                                }
                            }

                            # update dynamic element replacement
                            if( isset( $solutions ) ) self::update_flaticon_icon_replacement( $element_id, $element['slug'], $solutions );

                            # remove temporary variable
                            unset( $solutions, $selected_id );
                        }

                        # remove temporary variables
                        unset( $possible_icons );
                    }
                }
            }

           /**
            *
            * register new flaticon icon
            *
            */

            public static function register_flaticon_icon( $record ) {

                # flag for prevent dynamic elements duplication
                $already_exists = false;

                # walk for each dynamic element
                foreach( self::$flaticon_icons as $element_id => $element ) {

                    # do we have the same element already added?
                    if( ( !is_array( $element['code'] ) && $element['code'] == $record['code'] ) || ( is_array( $element['code'] ) && in_array( $record['code'], $element['code'], true ) ) ) $already_exists = true;

                    # do we have similar element already added
                    else if( $element['url'] == $record['url'] ) {

                        # replace string to array for code field
                        if( !is_array( $element['code'] ) ) $element['code'] = array( $element['code'] );

                        # replace string to array for slug field
                        if( !is_array( $element['slug'] ) ) $element['slug'] = array( $element['slug'] );

                        # add slug and code to element
                        $element['code'][] = $record['code'];
                        $element['slug'][] = $record['slug'];

                        # update global variable
                        self::$flaticon_icons[esc_attr( $element_id )] = $element;

                        # set exists flag
                        $already_exists = true;
                    }
                }

                # add unique dynamic element
                if( $already_exists == false ) self::$flaticon_icons[] = $record;
            }

           /**
            *
            * find all flaticon icons
            *
            */

            public static function find_all_flaticon_icons() {

                # walk for each page
                foreach( self::get_vc_contents() as $key => $content ) {

                    # find all flaticon icons
                    $icons = ueldo_strpos_all( $content, '{ueldopredefinedsections:icon|' );

                    # do we have any?
                    if( $icons !== false ) {

                        # walk for each flaticon icon
                        foreach( $icons as $icon ) {

                            # get full dynamic element string
                            $string = substr( $content, $icon, ( strpos( $content, '}', $icon ) - $icon + 1 ) );

                            # explode string
                            $string_exploded = explode( '|', $string );

                            # register new flaticon icon
                            self::register_flaticon_icon( array(
                                'code' => $string,
                                'keys' => explode( ',', str_replace( 'key:', '', $string_exploded[1] ) ),
                                'url' => str_replace( 'url:', '', $string_exploded[2] ),
                                'slug' => str_replace( 'slug:', '', str_replace( '}', '', $string_exploded[3] ) ),
                                'replacement' => ''
                            ) );

                            # remove temporary variable
                            unset( $string, $string_exploded );
                        }
                    }

                    # remove temporary variables
                    unset( $icons, $icon );
                }
            }

           /**
            *
            * get all found flaticon icons
            *
            */

            public static function get_all_flaticon_icons() {

                # return result
                return( self::$flaticon_icons );
            }

           /**
            *
            * find all possible icon replacements
            *
            */

            public static function find_all_possible_icon_replacements( $element ) {

                # global variables
                global $ueldo_cache_option;

                # prepare results array
                $result = array();

                # do we have custom icons added?
                if( ueldo_plugin_is_any_custom_icon_added() && $element != false && isset( $element['keys'] ) ) {

                    # get all custom icon fonts
                    $icon_fonts = $ueldo_cache_option -> get_option( 'ueldo_custom_icons' );

                    # do we have custom icons added?
                    if( $icon_fonts != false ) {

                        # walk for each icon fonts
                        foreach( $icon_fonts as $icon_font ) {

                            # walk for each icon inside this icon font
                            foreach( $icon_font['icons'] as $icon ) {

                                # walk for each element key
                                foreach( $element['keys'] as $element_key ) {

                                    # compare
                                    if( strpos( $icon, str_replace( 'flaticon-', '', $element_key ) ) ) {

                                        # update result array
                                        $result[] = array(
                                            'icon_font_unique_key' => $icon_font['unique_key'],
                                            'icon_font_name' => $icon_font['name'],
                                            'icon_key' => $icon
                                        );
                                    }
                                }
                            }
                        }
                    }

                    # remove temporary variable
                    unset( $icon_fonts, $icon_font, $icon, $element_key );
                }

                # remove possible elements duplicates
                if( count( $result ) > 1 ) $result = self::remove_possible_flaticon_icons_duplicates( $result );

                # return result
                return( $result );
            }

           /**
            *
            * remove duplicates from possible flaticon icons array
            *
            */

            public static function remove_possible_flaticon_icons_duplicates( $elements ) {

                # array of unique elements
                $unique = array( $elements[0] );

                # walk for each elements
                foreach( $elements as $element_id => $element_data ) {

                    # skip first element
                    if( $element_id == 0 ) continue;

                    # set flag
                    $is_unique = true;

                    # walk for each unique elements
                    foreach( $unique as $unique_element_id => $unique_element_data ) {

                        # compare
                        if( $element_data == $unique_element_data ) $is_unique = false;
                    }

                    # is element unique?
                    if( $is_unique == true ) $unique[] = $element_data;
                }

                # return result
                return( $unique );
            }

           /**
            *
            * update flaticon icon replacement
            *
            */

            public static function update_flaticon_icon_replacement( $element_id, $slug, $icon ) {

                # do we have this dynamic element added?
                if( !isset( self::$flaticon_icons[esc_attr( $element_id )] ) ) return( false );

                # is there more than one slug?
                if( is_array( $slug ) ) {

                    # add multiple replacements
                    $replacement = array();

                    # walk for each slug
                    foreach( $slug as $single_slug ) {

                        # update replacements array
                        $replacement[] = esc_attr( $single_slug ) .'library="'. esc_attr( $icon['icon_font_unique_key'] ) .'" '. esc_attr( $single_slug ) . esc_attr( $icon['icon_font_unique_key'] ) .'="'. esc_attr( $icon['icon_key'] ) .'"';;
                    }
                }

                # single replacement
                else {

                    # set the replacement
                    $replacement = esc_attr( $slug ) .'library="'. esc_attr( $icon['icon_font_unique_key'] ) .'" '. esc_attr( $slug ) . esc_attr( $icon['icon_font_unique_key'] ) .'="'. esc_attr( $icon['icon_key'] ) .'"';
                }

                # update replacement
                self::$flaticon_icons[esc_attr( $element_id )]['replacement'] = $replacement;
            }

           /**
            *
            * add required clarification record
            *
            */

            public static function add_clarification_record( $element_id, $type, $data = false ) {

                # find flaticon icon related to this clarification record
                $flaticon_icon = self::get_flaticon_icon_by_id( $element_id );

                # couldn't find dynamic element?
                if( $flaticon_icon == false ) exit( esc_html( __( 'Unknown internal error - couldn\'t find flaticon icon with ID: ', 'ueldo' ) ) . esc_attr( $element_id ) );

                # switch by clarification type
                switch( $type ) {

                   /**
                    *
                    * couldn't find flaticon icon
                    *
                    */

                    case 'icon_not_found':

                        # add clarification record
                        self::$clarification_records['icon_not_found'][] = array(
                            'dynamic_element_id' => esc_attr( $element_id ),
                            'icon_key' => $flaticon_icon['keys'],
                            'icon_url' => esc_url( $flaticon_icon['url'] )
                        );

                    break;

                   /**
                    *
                    * duplicated icon
                    *
                    */

                    case 'duplicated_icon':

                        # add clarification record
                        self::$clarification_records['other'][] = array(
                            'type' => 'duplicated_icon',
                            'dynamic_element_id' => esc_attr( $element_id ),
                            'icon_key' => $flaticon_icon['keys'],
                            'icon_url' => esc_url( $flaticon_icon['url'] ),
                            'possible_icons' => $data
                        );

                    break;
                }

                # remove temporary variables
                unset( $flaticon_icon );
            }

           /**
            *
            * get clarification records
            *
            */

            public static function get_clarification_records() {

                # return result
                return( self::$clarification_records );
            }

           /**
            *
            * are clarifications solved?
            *
            */

            public static function are_clarifications_solved() {

                # return result
                return( isset( $_POST['clarified'] ) && $_POST['clarified'] == 'yes' );
            }

           /**
            *
            * get flaticon icon by id
            *
            */

            public static function get_flaticon_icon_by_id( $id ) {

                # return flaticon icon
                return( isset( self::$flaticon_icons[esc_attr( $id )] ) ? self::$flaticon_icons[esc_attr( $id )] : false );
            }

           /**
            *
            * check if any clarification record exists
            *
            */

            public static function any_clarification_record_exists() {

                # walk for each clarification records types
                foreach( self::get_clarification_records() as $type => $value ) {

                    # do we have any record added?
                    if( count( $value ) > 0 ) return( true );
                }

                # there's no any clarification record found
                return( false );
            }

           /**
            *
            * return clarifications json
            *
            */

            public static function return_clarifications_json() {

                # there's no any clarification records found?
                if( !self::any_clarification_record_exists() ) {

                    # clarifications not needed
                    echo json_encode( array( 'needClarification' => 'no' ) );

                    # exit the script
                    exit;
                }

                # return clarifications
                else {

                    # get all clarification records
                    $clarification_records = self::get_clarification_records();

                    # prepare result array
                    $result = array(
                        'needClarification' => 'yes',
                        'clarifications' => array()
                    );

                    # do we have "icon_not_found" clarification records?
                    if( count( $clarification_records['icon_not_found'] ) > 0 ) {

                        # update result array
                        $result['clarifications'][] = array(
                            'type' => 'icon_not_found',
                            'records' => $clarification_records['icon_not_found']
                        );
                    }

                    # do we have other clarification records?
                    if( count( $clarification_records['other'] ) > 0 ) {

                        # walk for each clarification result
                        foreach( $clarification_records['other'] as $record_id => $record_data ) {

                            # update result array
                            $result['clarifications'][] = $record_data;
                        }
                    }

                    # remove temporary variables
                    unset( $clarification_records );

                    # display results array as json
                    echo json_encode( $result );

                    # exit the script
                    exit;
                }
            }

           /**
            *
            * end of class methods
            *
            */
        }

        # switch through requested action
        switch( $_POST['action'] ) {

           /**
            *
            * get possible data parts
            *
            */

            case 'get_possible_data_parts': ueldo_load_demo_data_display_json( 'ok', ueldo_demo_contents_loader::get_possible_data_parts() ); break;

           /**
            *
            * get list or required plugins
            *
            */

            case 'get_required_plugins':

                # do we have data set?
                if( !isset( $_POST['data'] ) ) exit( esc_html( __( 'Couldn\'t get required plugins list.', 'ueldo' ) ) );

                # get list from dedicated class
                $plugins = ueldo_demo_contents_loader::get_required_plugins( $_POST['data'] );

                # do we have any plugin found?
                if( !is_array( $plugins ) || $plugins == array() ) ueldo_load_demo_data_display_json();
                else {

                    # prepare results array
                    $result = array();

                    # walk for each plugin
                    foreach( $plugins as $slug ) {

                        # check plugin activation status
                        $result[] = array(
                            'slug' => esc_attr( $slug ),
                            'name' => esc_html( ueldo_plugins::get_plugin_name( $slug ) ),
                            'status' => ueldo_plugins::is_plugin_installed( $slug ) ? ( ueldo_plugins::is_active_plugin( $slug ) ? 'activated' : 'notactivated' ) : 'notinstalled'
                        );
                    }

                    # return result
                    ueldo_load_demo_data_display_json( 'ok', $result );
                }

            break;

           /**
            *
            * install and activate plugin
            *
            */

            case 'install_and_activate_plugin':

                # do we have data set?
                if( !isset( $_POST['data'] ) || !ueldo_plugins::is_known_plugin( $_POST['data'] ) ) exit( esc_html( __( 'Couldn\'t get plugin slug.', 'ueldo' ) ) );

                # check if plugin is installed
                if( !ueldo_plugins::is_plugin_installed( $_POST['data'] ) ) {

                    # install plugin
                    if( ueldo_plugins::install_plugin( $_POST['data'] ) ) {

                        # activate plugin
                        if( ueldo_plugins::activate_plugin( $_POST['data'] ) ) {

                            # all goes fine!
                            ueldo_load_demo_data_display_json();
                        }

                        # something goes wrong
                        ueldo_load_demo_data_display_json( 'wrong', array( 'type' => 'plugin_installed_but_not_activated', 'message' => esc_html( __( 'Plugin installed but not activated, please try to activate it manually.', 'ueldo' ) ) ) );
                    }
                }

                # plugin installed somehow, try to activate it
                else {

                    # activate plugin
                    if( ueldo_plugins::activate_plugin( $_POST['data'] ) ) {

                        # all goes fine!
                        ueldo_load_demo_data_display_json();
                    }

                    # something goes wrong
                    ueldo_load_demo_data_display_json( 'wrong', array( 'type' => 'plugin_installed_but_not_activated', 'message' => esc_html( __( 'Plugin installed but not activated, please try to activate it manually.', 'ueldo' ) ) ) );
                }

                # something goes wrong
                exit( esc_html( __( 'Couldn\'t install and activate plugin properly.', 'ueldo' ) ) );

            break;

           /**
            *
            * activate plugin
            *
            */

            case 'activate_plugin':

                # do we have data set?
                if( !isset( $_POST['data'] ) || !ueldo_plugins::is_known_plugin( $_POST['data'] ) ) exit( esc_html( __( 'Couldn\'t get plugin slug.', 'ueldo' ) ) );

                # check if plugin is installed
                if( !ueldo_plugins::is_plugin_installed( $_POST['data'] ) ) {

                    # expected that plugin is installed
                    exit( esc_html( __( 'Can not activate plugin which is not installed.', 'ueldo' ) ) );
                }

                # plugin correctly installed
                else {

                    # activate plugin
                    if( ueldo_plugins::activate_plugin( $_POST['data'] ) ) {

                        # all goes fine!
                        ueldo_load_demo_data_display_json();
                    }

                    # something goes wrong
                    exit( esc_html( __( 'Couldn\'t activate this plugin, please try to activate it manually.', 'ueldo' ) ) );
                }

            break;

           /**
            *
            * check for clarifications
            *
            */

            case 'check_for_clarifications':

                # do we have data set?
                if( !isset( $_POST['data'] ) ) exit( esc_html( __( 'Couldn\'t find required data.', 'ueldo' ) ) );

                # check for clarifications
                ueldo_demo_contents_loader::check_for_clarifications( $_POST['data'] );

                # return clarifications json
                ueldo_demo_contents_loader::return_clarifications_json();

            break;

           /**
            *
            * proceed installation
            *
            */

            case 'proceed_installation':

                # do we have data set?
                if( !isset( $_POST['data'] ) || !isset( $_POST['clarified'] ) ) exit( esc_html( __( 'Couldn\'t find required data.', 'ueldo' ) ) );

                # check for clarifications
                ueldo_demo_contents_loader::check_for_clarifications( $_POST['data']['parts'] );

                # somehow there are still clarifications records?
                if( ueldo_demo_contents_loader::any_clarification_record_exists() == true ) exit( esc_html( __( 'Unknown internal error with clarification solutions.', 'ueldo' ) ) );

                # proceed the install
                ueldo_demo_contents_loader::install( $_POST['data']['parts'], ueldo_demo_contents_loader::get_all_flaticon_icons() );

            break;

           /**
            *
            * end of actions.
            *
            */
        }
    }

    # couldn't find dedicated class file?
    else {

        # return error message
        exit( esc_html( __( 'Couldn\'t find class file for this template.', 'ueldo' ) ) );
    }

   /**
    *
    * end of ajax file.
    *
    */

?>