<?php

   /**
    *
    * shortcodes styles cache class action hooks
    *
    */

    add_action( 'wp_enqueue_scripts', array( 'ueldo_static_shortcodes_styles_cache', 'enqueue_head_styles' ) );
    add_action( 'wp_footer', array( 'ueldo_static_shortcodes_styles_cache', 'enqueue_footer_styles' ) );

   /**
    *
    * shortcodes styles cache class definition
    *
    */

    class ueldo_static_shortcodes_styles_cache {

       /**
        *
        * css style container
        *
        */

        public static $css = '';

       /**
        *
        * css styles code already cached before
        *
        */

        public static $cached_css = '';

       /**
        *
        * did we get the cache from database already?
        *
        */

        public static $cached_css_loaded = false;

       /**
        *
        * add new style (generated live) to final result
        *
        */

        public static function add_new_css( $css ) {

            # update css style container
            self::$css .= $css;
        }

       /**
        *
        * get new style (generated live)
        *
        */

        public static function get_all_new_css() {

            # return result
            return( self::$css );
        }

       /**
        *
        * get base cache directory path
        *
        */

        public static function get_cache_dir_path( $url = false ) {

            # get upload directory path
            $upload_dir = wp_upload_dir();

            # get custom directory path
            $custom_dir = '/ueldo-plugin/_static-shortcodes-styles-cache/';

            # check uploads directory
            if( !self::check_uploads_directory( $upload_dir['basedir'], $custom_dir ) ) return( false );

            # return result
            return( $url == false ? esc_attr( $upload_dir['basedir'] . $custom_dir ) : esc_attr( $upload_dir['baseurl'] . $custom_dir ) );
        }

       /**
        *
        * check if custom uploads directory exists - if not, create it
        *
        */

        public static function check_uploads_directory( $basedir, $dir ) {

            # remove first slash from directory path
            $dir = substr( $dir, 1 );

            # remove last slash from directory path and explode directory
            $dir = explode( '/', substr( $dir, 0, ( strlen( $dir ) - 1 ) ) );

            # current path helper
            $current_path = '/';

            # walk for each directory
            for( $i = 0; $i < count( $dir ); $i++ ) {

                # update current path helper
                $current_path .= $dir[$i] .'/';

                # check if directory exists
                if( !file_exists( $basedir . $current_path ) ) {

                    # create directory
                    $result = mkdir( $basedir . $current_path, 0755 );

                    # failed?
                    if( $result == false ) return( false );
                }
            }

            # all goes fine
            return( true );
        }

       /**
        *
        * get filename for cached styles
        *
        */

        public static function get_filename() {

            # theme options cache
            global $ueldo_cache_option;

            # get the language key
            $lang_key = ueldo_get_current_language_key();

            # define page ID
            $page_id = get_the_ID();

            # is it the blog page?
            if( ueldo_is_blog_page() ) {

                # is it not a single post page?
                if( !is_single() ) $page_id = $ueldo_cache_option -> get_option( 'page_for_posts' );
            }

            # is it the 404 page?
            if( is_404() ) $page_id = ueldo_get_theme_options_value( '404-page-id', esc_attr( $lang_key ) );

            # return result
            return( esc_attr( $page_id ) .'_'. esc_attr( $lang_key ) .'.css' );
        }

       /**
        *
        * are styles cached for this page?
        *
        */

        public static function are_styles_cached() {

            # get cache dir path
            $cache_dir = self::get_cache_dir_path();

            # do we have cache dir path?
            if( $cache_dir == false ) return( false );

            # is cache file exists?
            return( file_exists( $cache_dir . self::get_filename() ) );
        }

       /**
        *
        * enqueue styles for "head" section
        *
        */

        public static function enqueue_head_styles() {

            # do we have cached css styles?
            if( self::are_styles_cached() ) {

                # enqueue plugin styles
                wp_enqueue_style( 'ueldo-plugin-static-styles', self::get_cache_dir_path( true ) . esc_attr( self::get_filename() ), false, null );
            }
        }

       /**
        *
        * get cached styles content
        *
        */

        public static function get_cached_styles_content() {

            # get cache dir path
            $cache_dir = self::get_cache_dir_path();

            # do we have cache dir path?
            if( $cache_dir == false ) return( false );

            # filepath
            $filepath = $cache_dir . self::get_filename();

            # return result
            return( file_exists( $filepath ) ? file_get_contents( $filepath ) : false );
        }

       /**
        *
        * update styles cache file
        *
        */

        public static function update_styles_cache() {

            # get cache dir path
            $cache_dir = self::get_cache_dir_path();

            # do we have cache dir path?
            if( $cache_dir == false ) return( false );

            # file name
            $filename = $cache_dir . self::get_filename();

            # create file
            $file = fopen( $filename, 'w+' );

            # is file writable?
            if( $file !== false && is_writable( $filename ) ) {

                # write styles to file
                fwrite( $file, ueldo_minify_css( self::get_all_new_css() ) );

                # close file handle
                fclose( $file );
            }
        }

       /**
        *
        * enqueue styles for "footer" section
        *
        */

        public static function enqueue_footer_styles() {

            # can we update previously cached styles?
            if( self::are_styles_cached() == false || self::get_cached_styles_content() != self::get_all_new_css() ) {

                # update file with styles cache
                self::update_styles_cache();

                # enqueue plugin styles
                wp_enqueue_style( 'ueldo-plugin-static-styles-updated', plugins_url( 'static-shortcodes-styles-cache.css', __FILE__ ), array(), false, null );

                # add inline style with custom css code
                wp_add_inline_style( 'ueldo-plugin-static-styles-updated', self::get_all_new_css() );
            }
        }

       /**
        *
        * end of methods.
        *
        */
    }

   /**
    *
    * end of class.
    *
    */

?>