<?php

   /**
    *
    * map the shortcode settings with visual composer
    *
    */

    vc_map( ueldo_update_custom_vc_shortcode_settings( array(
        'name' => esc_html( __( 'Point of interest', 'ueldo' ) ),
        'description' => esc_html( __( 'Display single point of interest on presentation element', 'ueldo' ) ),
        'base' => 'ueldo_shortcode_presentation_point_of_interest',
        'content_element' => true,
        'category' => esc_html( __( 'Ueldo', 'ueldo' ) ),
        'icon' => esc_url( get_template_directory_uri() .'/_assets/_img/vc-icon.png' ),
        'as_child' => array( 'only' => 'ueldo_shortcode_presentation_element' ),
        'params' => array(

           /**
            *
            * class name
            *
            */

            ueldo_add_custom_vc_shortcode_settings( 'class-name', '', '', array(), esc_html( __( 'General settings', 'ueldo' ) ) ),

           /**
            *
            * group: general settings
            *
            */

            array(
                'type' => 'dropdown',
                'heading' => esc_html( __( 'Vertical position', 'ueldo' ) ),
                'param_name' => 'position_y',
                'value' => ueldo_get_vc_loop_option_percents( true ),
                'std' => '50%',
                'group' => esc_html( __( 'General settings', 'ueldo' ) )
            ),

            array(
                'type' => 'dropdown',
                'heading' => esc_html( __( 'Horizontal position', 'ueldo' ) ),
                'param_name' => 'position_x',
                'value' => ueldo_get_vc_loop_option_percents( true ),
                'std' => '50%',
                'group' => esc_html( __( 'General settings', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_divider',
                'param_name' => 'divider_modal_window_position',
                'std' => '',
                'group' => esc_html( __( 'General settings', 'ueldo' ) )
            ),

            array(
                'type' => 'dropdown',
                'heading' => esc_html( __( 'Modal window position', 'ueldo' ) ),
                'param_name' => 'modal_position',
                'value' => array(
                    esc_html( __( 'Top', 'ueldo' ) ) => 'top',
                    esc_html( __( 'Right', 'ueldo' ) ) => 'right',
                    esc_html( __( 'Bottom', 'ueldo' ) ) => 'bottom',
                    esc_html( __( 'Left', 'ueldo' ) ) => 'left'
                ),
                'std' => 'top',
                'group' => esc_html( __( 'General settings', 'ueldo' ) )
            ),

            array(
                'type' => 'dropdown',
                'heading' => esc_html( __( 'Switch modal window to full-width from', 'ueldo' ) ),
                'param_name' => 'modal_window_to_full_width_from',
                'value' => array(
                    esc_html( __( 'Medium devices', 'ueldo' ) ) => 'medium',
                    esc_html( __( 'Small devices', 'ueldo' ) ) => 'small',
                    esc_html( __( 'Extra small devices', 'ueldo' ) ) => 'extra-small'
                ),
                'std' => 'extra-small',
                'group' => esc_html( __( 'General settings', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_divider',
                'param_name' => 'divider_content',
                'std' => '',
                'group' => esc_html( __( 'General settings', 'ueldo' ) )
            ),

            array(
                'type' => 'textfield',
                'heading' => esc_html( __( 'Title', 'ueldo' ) ),
                'param_name' => 'title',
                'admin_label' => true,
                'std' => esc_html( __( 'High qualified team', 'ueldo' ) ),
                'group' => esc_html( __( 'General settings', 'ueldo' ) )
            ),

            array(
                'type' => 'textarea_html',
                'heading' => esc_html( __( 'Content', 'ueldo' ) ),
                'param_name' => 'content',
                'group' => esc_html( __( 'General settings', 'ueldo' ) )
            ),

           /**
            *
            * group: sizes
            *
            */

            array(
                'type' => 'dropdown',
                'heading' => esc_html( __( 'Custom sizes enabled?', 'ueldo' ) ),
                'param_name' => 'custom_sizes_enabled',
                'value' => array(
                    esc_html( __( 'No, use theme defaults', 'ueldo' ) ) => 'theme_defaults',
                    esc_html( __( 'Yes, use custom settings', 'ueldo' ) ) => 'custom_settings'
                ),
                'std' => 'theme_defaults',
                'group' => esc_html( __( 'Sizes', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_divider',
                'param_name' => 'divider_modal_window_sizes',
                'std' => '',
                'dependency' => array(
                    'element' => 'custom_sizes_enabled',
                    'value' => 'custom_settings'
                ),
                'group' => esc_html( __( 'Sizes', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_px_number',
                'heading' => esc_html( __( 'Modal window width', 'ueldo' ) ),
                'param_name' => 'modal_window_width',
                'std' => '350',
                'ueldo-number-field-minus-allowed' => false,
                'dependency' => array(
                    'element' => 'custom_sizes_enabled',
                    'value' => 'custom_settings'
                ),
                'group' => esc_html( __( 'Sizes', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_px_number',
                'heading' => esc_html( __( 'Modal window content height', 'ueldo' ) ),
                'param_name' => 'modal_window_content_height',
                'std' => '135',
                'ueldo-number-field-minus-allowed' => false,
                'dependency' => array(
                    'element' => 'custom_sizes_enabled',
                    'value' => 'custom_settings'
                ),
                'group' => esc_html( __( 'Sizes', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_divider',
                'param_name' => 'divider_modal_window_padding',
                'std' => '',
                'dependency' => array(
                    'element' => 'custom_sizes_enabled',
                    'value' => 'custom_settings'
                ),
                'group' => esc_html( __( 'Sizes', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_px_number',
                'heading' => esc_html( __( 'Modal window padding top / bottom', 'ueldo' ) ),
                'param_name' => 'modal_window_padding_top_bottom',
                'std' => '30',
                'ueldo-number-field-minus-allowed' => false,
                'dependency' => array(
                    'element' => 'custom_sizes_enabled',
                    'value' => 'custom_settings'
                ),
                'group' => esc_html( __( 'Sizes', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_px_number',
                'heading' => esc_html( __( 'Modal window padding left / right', 'ueldo' ) ),
                'param_name' => 'modal_window_padding_left_right',
                'std' => '30',
                'ueldo-number-field-minus-allowed' => false,
                'dependency' => array(
                    'element' => 'custom_sizes_enabled',
                    'value' => 'custom_settings'
                ),
                'group' => esc_html( __( 'Sizes', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_divider',
                'param_name' => 'divider_modal_window_border',
                'std' => '',
                'dependency' => array(
                    'element' => 'custom_sizes_enabled',
                    'value' => 'custom_settings'
                ),
                'group' => esc_html( __( 'Sizes', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_px_number',
                'heading' => esc_html( __( 'Modal window border width', 'ueldo' ) ),
                'param_name' => 'modal_window_border_width',
                'std' => '0',
                'ueldo-number-field-minus-allowed' => false,
                'dependency' => array(
                    'element' => 'custom_sizes_enabled',
                    'value' => 'custom_settings'
                ),
                'group' => esc_html( __( 'Sizes', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_px_number',
                'heading' => esc_html( __( 'Modal window border radius', 'ueldo' ) ),
                'param_name' => 'modal_window_border_radius',
                'std' => '4',
                'ueldo-number-field-minus-allowed' => false,
                'dependency' => array(
                    'element' => 'custom_sizes_enabled',
                    'value' => 'custom_settings'
                ),
                'group' => esc_html( __( 'Sizes', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_divider',
                'param_name' => 'divider_modal_window_margin_to_point',
                'std' => '',
                'dependency' => array(
                    'element' => 'custom_sizes_enabled',
                    'value' => 'custom_settings'
                ),
                'group' => esc_html( __( 'Sizes', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_px_number',
                'heading' => esc_html( __( 'Modal window margin to point of interest', 'ueldo' ) ),
                'param_name' => 'modal_window_margin_to_point',
                'std' => '15',
                'ueldo-number-field-minus-allowed' => true,
                'dependency' => array(
                    'element' => 'custom_sizes_enabled',
                    'value' => 'custom_settings'
                ),
                'group' => esc_html( __( 'Sizes', 'ueldo' ) )
            ),

           /**
            *
            * group: colors
            *
            */

            array(
                'type' => 'dropdown',
                'heading' => esc_html( __( 'Use custom colors?', 'ueldo' ) ),
                'param_name' => 'custom_colors_enabled',
                'value' => array(
                    esc_html( __( 'No, use theme defaults', 'ueldo' ) ) => 'theme_defaults',
                    esc_html( __( 'Yes, use custom colors', 'ueldo' ) ) => 'custom_settings'
                ),
                'std' => 'theme_defaults',
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
            				'type' => 'colorpicker',
            				'heading' => esc_html( __( 'Point background color', 'ueldo' ) ),
            				'param_name' => 'point_background_color',
            				'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'std' => esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-main-color' ) ),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
         			),

            array(
            				'type' => 'colorpicker',
            				'heading' => esc_html( __( 'Point background color (on hover)', 'ueldo' ) ),
            				'param_name' => 'point_background_color_hover',
            				'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'std' => esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-main-color' ) ),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
         			),

            array(
            				'type' => 'colorpicker',
            				'heading' => esc_html( __( 'Point icon color', 'ueldo' ) ),
            				'param_name' => 'point_icon_color',
            				'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'std' => esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-main-color-contrast-text-color' ) ),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
         			),

            array(
            				'type' => 'colorpicker',
            				'heading' => esc_html( __( 'Point icon color (on hover)', 'ueldo' ) ),
            				'param_name' => 'point_icon_color_hover',
            				'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'std' => esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-main-color-contrast-text-color' ) ),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
         			),

            # point box shadow

            array(
                'type' => 'ueldo_box_shadow_horizontal_length',
                'heading' => esc_html( __( 'Point box shadow', 'ueldo' ) ),
                'param_name' => 'point_box_shadow_horizontal_length',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'horizontal-length' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_vertical_length',
                'heading' => '',
                'param_name' => 'point_box_shadow_vertical_length',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'vertical-length' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_blur_radius',
                'heading' => '',
                'param_name' => 'point_box_shadow_blur_radius',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'blur-radius' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_spread_radius',
                'heading' => '',
                'param_name' => 'point_box_shadow_spread_radius',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'spread-radius' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
            				'type' => 'colorpicker',
            				'heading' => '',
            				'param_name' => 'point_box_shadow_color',
            				'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'std' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'color' ) ),
                'edit_field_class' => 'vc_col-xs-4',
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
         			),

            # point box shadow (on hover)

            array(
                'type' => 'ueldo_box_shadow_horizontal_length',
                'heading' => esc_html( __( 'Point box shadow (on hover)', 'ueldo' ) ),
                'param_name' => 'point_box_shadow_horizontal_length_hover',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'horizontal-length' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_vertical_length',
                'heading' => '',
                'param_name' => 'point_box_shadow_vertical_length_hover',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'vertical-length' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_blur_radius',
                'heading' => '',
                'param_name' => 'point_box_shadow_blur_radius_hover',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'blur-radius' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_spread_radius',
                'heading' => '',
                'param_name' => 'point_box_shadow_spread_radius_hover',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'spread-radius' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
            				'type' => 'colorpicker',
            				'heading' => '',
            				'param_name' => 'point_box_shadow_color_hover',
            				'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'std' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'color' ) ),
                'edit_field_class' => 'vc_col-xs-4',
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
         			),

            # end of point box shadow (on hover)

            array(
            				'type' => 'colorpicker',
            				'heading' => esc_html( __( 'Point animation shadow color', 'ueldo' ) ),
            				'param_name' => 'point_animation_shadow_color',
            				'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'std' => esc_attr( $ueldo_styles_cache -> get_style( 'point-of-interest-pulse-color' ) ),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
         			),

            array(
            				'type' => 'colorpicker',
            				'heading' => esc_html( __( 'Point close background color', 'ueldo' ) ),
            				'param_name' => 'point_close_background_color',
            				'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'std' => esc_attr( $ueldo_styles_cache -> get_style( 'point-of-interest-close-color' ) ),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
         			),

            array(
            				'type' => 'colorpicker',
            				'heading' => esc_html( __( 'Point close background color (on hover)', 'ueldo' ) ),
            				'param_name' => 'point_close_background_color_hover',
            				'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'std' => esc_attr( $ueldo_styles_cache -> get_style( 'point-of-interest-close-color' ) ),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
         			),

            array(
            				'type' => 'colorpicker',
            				'heading' => esc_html( __( 'Point close icon color', 'ueldo' ) ),
            				'param_name' => 'point_close_icon_color',
            				'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'std' => esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-main-color-contrast-text-color' ) ),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
         			),

            array(
            				'type' => 'colorpicker',
            				'heading' => esc_html( __( 'Point close icon color (on hover)', 'ueldo' ) ),
            				'param_name' => 'point_close_icon_color_hover',
            				'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'std' => esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-main-color-contrast-text-color' ) ),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
         			),

            # point close box shadow

            array(
                'type' => 'ueldo_box_shadow_horizontal_length',
                'heading' => esc_html( __( 'Point close box shadow', 'ueldo' ) ),
                'param_name' => 'point_close_box_shadow_horizontal_length',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'horizontal-length' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_vertical_length',
                'heading' => '',
                'param_name' => 'point_close_box_shadow_vertical_length',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'vertical-length' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_blur_radius',
                'heading' => '',
                'param_name' => 'point_close_box_shadow_blur_radius',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'blur-radius' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_spread_radius',
                'heading' => '',
                'param_name' => 'point_close_box_shadow_spread_radius',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'spread-radius' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
            				'type' => 'colorpicker',
            				'heading' => '',
            				'param_name' => 'point_close_box_shadow_color',
            				'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'std' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'color' ) ),
                'edit_field_class' => 'vc_col-xs-4',
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
         			),

            # point close box shadow (on hover)

            array(
                'type' => 'ueldo_box_shadow_horizontal_length',
                'heading' => esc_html( __( 'Point close box shadow (on hover)', 'ueldo' ) ),
                'param_name' => 'point_close_box_shadow_horizontal_length_hover',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'horizontal-length' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_vertical_length',
                'heading' => '',
                'param_name' => 'point_close_box_shadow_vertical_length_hover',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'vertical-length' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_blur_radius',
                'heading' => '',
                'param_name' => 'point_close_box_shadow_blur_radius_hover',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'blur-radius' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_spread_radius',
                'heading' => '',
                'param_name' => 'point_close_box_shadow_spread_radius_hover',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'spread-radius' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
            				'type' => 'colorpicker',
            				'heading' => '',
            				'param_name' => 'point_close_box_shadow_color_hover',
            				'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'std' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'point-of-interest-box-shadow', 'color' ) ),
                'edit_field_class' => 'vc_col-xs-4',
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
         			),

            # end of point close box shadow (on hover)

            array(
                'type' => 'colorpicker',
                'heading' => esc_html( __( 'Modal window background color', 'ueldo' ) ),
                'param_name' => 'modal_window_background_color',
                'dependency' => array(
                    'element' => 'custom_colors_enabled',
                    'value' => 'custom_settings',
                ),
                'std' => esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-website-background' ) ),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'colorpicker',
                'heading' => esc_html( __( 'Modal window background color (on hover)', 'ueldo' ) ),
                'param_name' => 'modal_window_background_color_hover',
                'dependency' => array(
                    'element' => 'custom_colors_enabled',
                    'value' => 'custom_settings',
                ),
                'std' => esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-website-background' ) ),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'colorpicker',
                'heading' => esc_html( __( 'Modal window border color', 'ueldo' ) ),
                'param_name' => 'modal_window_border_color',
                'dependency' => array(
                    'element' => 'custom_colors_enabled',
                    'value' => 'custom_settings',
                ),
                'std' => esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-website-background' ) ),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'colorpicker',
                'heading' => esc_html( __( 'Modal window border color (on hover)', 'ueldo' ) ),
                'param_name' => 'modal_window_border_color_hover',
                'dependency' => array(
                    'element' => 'custom_colors_enabled',
                    'value' => 'custom_settings',
                ),
                'std' => esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-website-background' ) ),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            # modal window box shadow

            array(
                'type' => 'ueldo_box_shadow_horizontal_length',
                'heading' => esc_html( __( 'Modal window box shadow', 'ueldo' ) ),
                'param_name' => 'modal_window_box_shadow_horizontal_length',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-image-box-shadow', 'horizontal-length' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_vertical_length',
                'heading' => '',
                'param_name' => 'modal_window_box_shadow_vertical_length',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-image-box-shadow', 'vertical-length' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_blur_radius',
                'heading' => '',
                'param_name' => 'modal_window_box_shadow_blur_radius',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-image-box-shadow', 'blur-radius' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_spread_radius',
                'heading' => '',
                'param_name' => 'modal_window_box_shadow_spread_radius',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-image-box-shadow', 'spread-radius' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
            				'type' => 'colorpicker',
            				'heading' => '',
            				'param_name' => 'modal_window_box_shadow_color',
            				'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'std' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-image-box-shadow', 'color' ) ),
                'edit_field_class' => 'vc_col-xs-4',
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
         			),

            # modal window box shadow (on hover)

            array(
                'type' => 'ueldo_box_shadow_horizontal_length',
                'heading' => esc_html( __( 'Modal window box shadow (on hover)', 'ueldo' ) ),
                'param_name' => 'modal_window_box_shadow_horizontal_length_hover',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-image-box-shadow', 'horizontal-length' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_vertical_length',
                'heading' => '',
                'param_name' => 'modal_window_box_shadow_vertical_length_hover',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-image-box-shadow', 'vertical-length' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_blur_radius',
                'heading' => '',
                'param_name' => 'modal_window_box_shadow_blur_radius_hover',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-image-box-shadow', 'blur-radius' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
                'type' => 'ueldo_box_shadow_spread_radius',
                'heading' => '',
                'param_name' => 'modal_window_box_shadow_spread_radius_hover',
                'value' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-image-box-shadow', 'spread-radius' ) ),
                'edit_field_class' => 'vc_col-xs-3',
                'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
            ),

            array(
            				'type' => 'colorpicker',
            				'heading' => '',
            				'param_name' => 'modal_window_box_shadow_color_hover',
            				'dependency' => array(
               					'element' => 'custom_colors_enabled',
               					'value' => 'custom_settings',
            				),
                'std' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-image-box-shadow', 'color' ) ),
                'edit_field_class' => 'vc_col-xs-4',
                'group' => esc_html( __( 'Colors', 'ueldo' ) )
         			)

            # end of modal window box shadow (on hover)

           /**
            *
            * end of fields.
            *
            */
        )

       /**
        *
        * end of shortcode settings
        *
        */

    )));

   /**
    *
    * extend WPBakeryShortCode class
    *
    */

    if( class_exists( 'WPBakeryShortCode' ) ) {

        class WPBakeryShortCode_Ueldo_Shortcode_Presentation_Point_Of_Interest extends WPBakeryShortCode {
        }
    }

   /**
    *
    * end of shortcode map.
    *
    */

?>