<?php

   /**
    *
    * base functions
    *
    */

    # get path to wordpress core
    function ueldo_predefined_sections_ajax_core_path() {

        # explode the content path
        $exploded = explode( 'wp-content', $_SERVER['SCRIPT_FILENAME'] );

        # path up to themes directory
        return( $exploded[0] );
    }

    # check if connection is legal
    function ueldo_check_predefined_sections_ajax_call_correctness() {

        # is the call made from current domain?
        if( strpos( $_SERVER['HTTP_REFERER'], $_SERVER['HTTP_HOST'] ) === false ) return( false );

        # return result
        return( is_user_logged_in() );
    }

   /**
    *
    * configurations
    *
    */

    # include wordpress core
    define( 'WP_USE_THEMES', false );
    require( ueldo_predefined_sections_ajax_core_path() .'wp-load.php' );

    # check if user is logged-in
    if( ueldo_check_predefined_sections_ajax_call_correctness() == false ) exit( esc_html( __( 'Permission denied.', 'ueldo' ) ) );

    # do we have clarification status set?
    if( !isset( $_POST['clarified'] ) ) exit( esc_html( __( 'Incorrect input (ErrID: 01).', 'ueldo' ) ) );

    # check if we have section id set
    if( !isset( $_POST['section_id'] ) ) exit( esc_html( __( 'Incorrect input (ErrID: 02).', 'ueldo' ) ) );

    # check if we have section type set
    if( !isset( $_POST['section_type'] ) || !in_array( $_POST['section_type'], array( 'clear', 'demo-like' ), true ) ) exit( esc_html( __( 'Incorrect input (ErrID: 03).', 'ueldo' ) ) );

    # require predefined sections list
    require_once( dirname( __FILE__ ) .'/predefined-sections-list.php' );

   /**
    *
    * predefined section shortcode generator
    *
    */

    class ueldo_predefined_section_shortcode {

       /**
        *
        * shortcode base code
        *
        */

        public static $base_code = false;

       /**
        *
        * array of all shortcode dynamic elements
        *
        */

        public static $dynamic_elements = array();

       /**
        *
        * clarification records
        *
        */

        public static $clarification_records = array(
            'icon_not_found' => array(),
            'other' => array()
        );

       /**
        *
        * add new dynamic element
        *
        */

        public static function add_dynamic_element( $record ) {

            # flag for prevent dynamic elements duplication
            $already_exists = false;

            # walk for each dynamic element
            foreach( self::$dynamic_elements as $element ) {

                # do we have this element already added?
                if( $element['code'] == $record['code'] ) $already_exists = true;
            }

            # add unique dynamic element
            if( $already_exists == false ) self::$dynamic_elements[] = $record;
        }

       /**
        *
        * get all dynamic elements
        *
        */

        public static function get_all_dynamic_elements() {

            # return result
            return( self::$dynamic_elements );
        }

       /**
        *
        * get dynamic element by id
        *
        */

        public static function get_dynamic_element_by_id( $id ) {

            # return dynamic element
            return( isset( self::$dynamic_elements[esc_attr( $id )] ) ? self::$dynamic_elements[esc_attr( $id )] : false );
        }

       /**
        *
        * update dynamic element
        *
        */

        public static function update_dynamic_element_replacement( $id, $replacement ) {

            # do we have this dynamic element added?
            if( !isset( self::$dynamic_elements[esc_attr( $id )] ) ) return( false );

            # update replacement
            self::$dynamic_elements[esc_attr( $id )]['replacement'] = $replacement;
        }

       /**
        *
        * add required clarification record
        *
        */

        public static function add_clarification_record( $element_id, $type, $data = false ) {

            # find dynamic element related to this clarification record
            $dynamic_element = self::get_dynamic_element_by_id( $element_id );

            # couldn't find dynamic element?
            if( $dynamic_element == false ) exit( esc_html( __( 'Unknown internal error - couldn\'t find dynamic element with ID: ', 'ueldo' ) ) . esc_attr( $element_id ) );

            # switch by clarification type
            switch( $type ) {

               /**
                *
                * couldn't find flaticon icon
                *
                */

                case 'icon_not_found':

                    # add clarification record
                    self::$clarification_records['icon_not_found'][] = array(
                        'dynamic_element_id' => esc_attr( $element_id ),
                        'icon_key' => $dynamic_element['keys'],
                        'icon_url' => esc_url( $dynamic_element['url'] )
                    );

                break;

               /**
                *
                * duplicated icon
                *
                */

                case 'duplicated_icon':

                    # add clarification record
                    self::$clarification_records['other'][] = array(
                        'type' => 'duplicated_icon',
                        'dynamic_element_id' => esc_attr( $element_id ),
                        'icon_key' => $dynamic_element['keys'],
                        'icon_url' => esc_url( $dynamic_element['url'] ),
                        'possible_icons' => $data
                    );

                break;

               /**
                *
                * google map
                *
                */

                case 'google_map':

                    # add clarification record
                    self::$clarification_records['other'][] = array(
                        'type' => 'google_map',
                        'dynamic_element_id' => esc_attr( $element_id ),
                        'possible_maps' => $data,
                        'context_string' => self::get_context_string( 'google_map', $dynamic_element['context'] )
                    );

                break;

               /**
                *
                * contact form 7
                *
                */

                case 'contact_form_7':

                    # add clarification record
                    self::$clarification_records['other'][] = array(
                        'type' => 'contact_form_7',
                        'dynamic_element_id' => esc_attr( $element_id ),
                        'possible_forms' => $data
                    );

                break;

               /**
                *
                * image
                *
                */

                case 'image':

                    # add clarification record
                    self::$clarification_records['other'][] = array(
                        'type' => 'image',
                        'dynamic_element_id' => esc_attr( $element_id ),
                        'possible_images' => $data,
                        'context_string' => self::get_context_string( 'image', $dynamic_element['context'] )
                    );

                break;

               /**
                *
                * revslider
                *
                */

                case 'revslider':

                    # add clarification record
                    self::$clarification_records['other'][] = array(
                        'type' => 'revslider',
                        'dynamic_element_id' => esc_attr( $element_id ),
                        'possible_sliders' => $data,
                        'context_string' => self::get_context_string( 'revslider', $dynamic_element['context'] )
                    );

                break;

               /**
                *
                * menu
                *
                */

                case 'menu':

                    # add clarification record
                    self::$clarification_records['other'][] = array(
                        'type' => 'menu',
                        'dynamic_element_id' => esc_attr( $element_id ),
                        'possible_menus' => $data,
                        'context_string' => self::get_context_string( 'menu', $dynamic_element['context'] )
                    );

                break;

               /**
                *
                * mailchimp for wp form
                *
                */

                case 'mc4wp':

                    # add clarification record
                    self::$clarification_records['other'][] = array(
                        'type' => 'mc4wp',
                        'dynamic_element_id' => esc_attr( $element_id ),
                        'possible_forms' => $data
                    );

                break;

               /**
                *
                * opening hours status
                *
                */

                case 'openinghours':

                    # add clarification record
                    self::$clarification_records['other'][] = array(
                        'type' => 'openinghours',
                        'dynamic_element_id' => esc_attr( $element_id ),
                        'possible_statuses' => $data
                    );

                break;

               /**
                *
                * sidebar
                *
                */

                case 'sidebar':

                    # add clarification record
                    self::$clarification_records['other'][] = array(
                        'type' => 'sidebar',
                        'dynamic_element_id' => esc_attr( $element_id ),
                        'possible_sidebars' => $data
                    );

                break;
            }

            # remove temporary variables
            unset( $dynamic_element );
        }

       /**
        *
        * get context string for clarification popup
        *
        */

        public static function get_context_string( $type, $context ) {

            # switch by type
            switch( $type ) {

                # context string for google maps
                case 'google_map':

                    # switch by context
                    switch( $context ) {

                        case 'accountant-new-york': return( esc_html( __( 'New York office', 'ueldo' ) ) );
                        case 'accountant-miami': return( esc_html( __( 'Miami office', 'ueldo' ) ) );
                        case 'accountant-dublin': return( esc_html( __( 'Dublin office', 'ueldo' ) ) );
                    }

                break;

                # context string for image
                case 'image':

                    # switch by context
                    switch( $context ) {

                        case 'accountant-logo-clear': return( esc_html( __( '"Accountant" template logo', 'ueldo' ) ) );
                        case 'accountant-logo-demo-like': return( esc_html( __( '"Accountant" template logo', 'ueldo' ) ) );
                        case 'creative-agency-logo': return( esc_html( __( '"Creative Agency" template logo', 'ueldo' ) ) );
                        case 'stud-pattern': return( esc_html( __( 'Section pattern', 'ueldo' ) ) );
                        case 'stud-grass-isolated': return( esc_html( __( 'Isolated grass image', 'ueldo' ) ) );
                        case 'dentist-logo': return( esc_html( __( '"Dentist" template logo', 'ueldo' ) ) );
                        case 'kayaks-logo': return( esc_html( __( '"Kayaks" template logo', 'ueldo' ) ) );
                        case 'kayaks-wave-white': return( esc_html( __( 'White wave image', 'ueldo' ) ) );
                        case 'kayaks-wave-color-default': return( esc_html( __( 'Wave image with default color', 'ueldo' ) ) );
                        case 'kayaks-wave-color-demo-like': return( esc_html( __( 'Wave image with demo-like color', 'ueldo' ) ) );
                        case 'barber-shop-logo': return( esc_html( __( '"Barbershop" template logo', 'ueldo' ) ) );
                    }

                break;

                # context string for revolution sliders
                case 'revslider':

                    # switch by context
                    switch( $context ) {

                        case 'accountant-home-page': return( esc_html( __( 'Home page slider for "Accountant" template', 'ueldo' ) ) );
                    }

                break;

                # context string for menus
                case 'menu':

                    # switch by context
                    switch( $context ) {

                        case 'accountant-services': return( esc_html( __( 'Services menu (short) for "Accountant" template', 'ueldo' ) ) );
                        case 'accountant-pages': return( esc_html( __( 'Pages menu (short) for "Accountant" template', 'ueldo' ) ) );
                        case 'dentist-social-menu': return( esc_html( __( 'Social icons menu for "Dentist" template', 'ueldo' ) ) );
                        case 'kayaks-pages-menu': return( esc_html( __( 'Pages menu for "Kayaks" template', 'ueldo' ) ) );
                    }

                break;
            }

            # couldn't find context string
            return( false );
        }

       /**
        *
        * get clarification records
        *
        */

        public static function get_clarification_records() {

            # return result
            return( self::$clarification_records );
        }

       /**
        *
        * check if any clarification record exists
        *
        */

        public static function any_clarification_record_exists() {

            # walk for each clarification records types
            foreach( self::get_clarification_records() as $type => $value ) {

                # do we have any record added?
                if( count( $value ) > 0 ) return( true );
            }

            # there's no any clarification record found
            return( false );
        }

       /**
        *
        * are clarifications solved?
        *
        */

        public static function are_clarifications_solved() {

            # return result
            return( isset( $_POST['clarified'] ) && $_POST['clarified'] == 'yes' );
        }

       /**
        *
        * get clarification solution
        *
        */

        public static function get_clarification_solution( $element_id, $type, $data = false ) {

            # do we need to find specific data?
            if( $data !== false ) {

                # find clarification solution
                if( !isset( $_POST['clarifications'] ) || !isset( $_POST['clarifications'][esc_attr( $type )] ) || !isset( $_POST['clarifications'][esc_attr( $type )][esc_attr( $element_id )] ) || !isset( $_POST['clarifications'][esc_attr( $type )][esc_attr( $element_id )][esc_attr( $data )] ) ) return( false );

                # all fine
                return( $_POST['clarifications'][esc_attr( $type )][esc_attr( $element_id )][esc_attr( $data )] );
            }

            # return simple solution
            else {

                # find clarification solution
                if( !isset( $_POST['clarifications'] ) || !isset( $_POST['clarifications'][esc_attr( $type )] ) || !isset( $_POST['clarifications'][esc_attr( $type )][esc_attr( $element_id )] ) ) return( false );

                # all fine
                return( $_POST['clarifications'][esc_attr( $type )][esc_attr( $element_id )] );
            }
        }

       /**
        *
        * get single shortcode base code
        *
        */

        public static function get_base_code() {

            # global variables
            global $_POST;

            # do we need to find the shortcode base code?
            if( self::$base_code == false ) {

                # get all sections shortcodes
                $shortcode = ueldo_predefined_section_code( $_POST['section_id'], $_POST['section_type'] );

                # default base code value
                self::$base_code = !empty( $shortcode ) ? $shortcode : '';

                # remove temporary variables
                unset( $shortcode );
            }

            # return result
            return( self::$base_code );
        }

       /**
        *
        * get all dynamic elements from shortcode base code
        *
        */

        public static function find_all_dynamic_elements() {

           /**
            *
            * check if shortcode contains flaticon icons
            *
            */

            # find flaticon icons
            $icons = ueldo_strpos_all( self::get_base_code(), '{ueldopredefinedsections:icon|' );

            # do we have any?
            if( $icons !== false ) {

                # walk for each flaticon icon
                foreach( $icons as $icon ) {

                    # get full dynamic element string
                    $string = substr( self::get_base_code(), $icon, ( strpos( self::get_base_code(), '}', $icon ) - $icon + 1 ) );

                    # explode string
                    $string_exploded = explode( '|', $string );

                    # add new dynamic element
                    self::add_dynamic_element( array(
                        'code' => $string,
                        'type' => 'icon',
                        'keys' => explode( ',', str_replace( 'key:', '', $string_exploded[1] ) ),
                        'url' => str_replace( 'url:', '', $string_exploded[2] ),
                        'slug' => str_replace( 'slug:', '', str_replace( '}', '', $string_exploded[3] ) ),
                        'replacement' => ''
                    ) );

                    # remove temporary variable
                    unset( $string, $string_exploded );
                }
            }

            # remove temporary variables
            unset( $icons, $icon );

           /**
            *
            * check if shortcode contains google map
            *
            */

            # find google maps
            $maps = ueldo_strpos_all( self::get_base_code(), '{ueldopredefinedsections:googlemap|' );

            # do we have any?
            if( $maps !== false ) {

                # walk for each map
                foreach( $maps as $map ) {

                    # get full dynamic element string
                    $string = substr( self::get_base_code(), $map, ( strpos( self::get_base_code(), '}', $map ) - $map + 1 ) );

                    # explode string
                    $string_exploded = explode( '|', $string );

                    # add new dynamic element
                    self::add_dynamic_element( array(
                        'code' => $string,
                        'type' => 'google_map',
                        'context' => str_replace( 'context:', '', str_replace( '}', '', $string_exploded[1] ) ),
                        'replacement' => ''
                    ) );

                    # remove temporary variable
                    unset( $string, $string_exploded );
                }
            }

            # remove temporary variables
            unset( $maps, $map );

           /**
            *
            * check if shortcode contains contact form
            *
            */

            # find contact forms
            $forms = ueldo_strpos_all( self::get_base_code(), '{ueldopredefinedsections:contactform7|' );

            # do we have any?
            if( $forms !== false ) {

                # walk for each form
                foreach( $forms as $form ) {

                    # get full dynamic element string
                    $string = substr( self::get_base_code(), $form, ( strpos( self::get_base_code(), '}', $form ) - $form + 1 ) );

                    # explode string
                    $string_exploded = explode( '|', $string );

                    # add new dynamic element
                    self::add_dynamic_element( array(
                        'code' => $string,
                        'type' => 'contact_form_7',
                        'context' => str_replace( 'context:', '', $string_exploded[1] ),
                        'inside' => str_replace( 'inside:', '', str_replace( '}', '', $string_exploded[2] ) ),
                        'replacement' => ''
                    ) );

                    # remove temporary variable
                    unset( $string, $string_exploded );
                }
            }

            # remove temporary variables
            unset( $forms, $form );

           /**
            *
            * check if shortcode contains images
            *
            */

            # find images
            $images = ueldo_strpos_all( self::get_base_code(), '{ueldopredefinedsections:image|' );

            # do we have any?
            if( $images !== false ) {

                # walk for each image
                foreach( $images as $image ) {

                    # get full dynamic element string
                    $string = substr( self::get_base_code(), $image, ( strpos( self::get_base_code(), '}', $image ) - $image + 1 ) );

                    # explode string
                    $string_exploded = explode( '|', $string );

                    # add new dynamic element
                    self::add_dynamic_element( array(
                        'code' => $string,
                        'type' => 'image',
                        'context' => str_replace( 'context:', '', str_replace( '}', '', $string_exploded[1] ) ),
                        'replacement' => ''
                    ) );

                    # remove temporary variable
                    unset( $string, $string_exploded );
                }
            }

            # remove temporary variables
            unset( $images, $image );

           /**
            *
            * check if shortcode contains revolution sliders
            *
            */

            # find sliders
            $revsliders = ueldo_strpos_all( self::get_base_code(), '{ueldopredefinedsections:revslider|' );

            # do we have any?
            if( $revsliders !== false ) {

                # walk for each slider
                foreach( $revsliders as $revslider ) {

                    # get full dynamic element string
                    $string = substr( self::get_base_code(), $revslider, ( strpos( self::get_base_code(), '}', $revslider ) - $revslider + 1 ) );

                    # explode string
                    $string_exploded = explode( '|', $string );

                    # add new dynamic element
                    self::add_dynamic_element( array(
                        'code' => $string,
                        'type' => 'revslider',
                        'context' => str_replace( 'context:', '', str_replace( '}', '', $string_exploded[1] ) ),
                        'replacement' => ''
                    ) );

                    # remove temporary variable
                    unset( $string, $string_exploded );
                }
            }

            # remove temporary variables
            unset( $revsliders, $revslider );

           /**
            *
            * check if shortcode contains menus
            *
            */

            # find menus
            $menus = ueldo_strpos_all( self::get_base_code(), '{ueldopredefinedsections:menu|' );

            # do we have any?
            if( $menus !== false ) {

                # walk for each menu
                foreach( $menus as $menu ) {

                    # get full dynamic element string
                    $string = substr( self::get_base_code(), $menu, ( strpos( self::get_base_code(), '}', $menu ) - $menu + 1 ) );

                    # explode string
                    $string_exploded = explode( '|', $string );

                    # add new dynamic element
                    self::add_dynamic_element( array(
                        'code' => $string,
                        'type' => 'menu',
                        'context' => str_replace( 'context:', '', str_replace( '}', '', $string_exploded[1] ) ),
                        'replacement' => ''
                    ) );

                    # remove temporary variable
                    unset( $string, $string_exploded );
                }
            }

            # remove temporary variables
            unset( $menus, $menu );

           /**
            *
            * mailchimp for wordpress form
            *
            */

            # find mc4wp forms
            $forms = ueldo_strpos_all( self::get_base_code(), '{ueldopredefinedsections:mc4wp|' );

            # do we have any form found?
            if( $forms !== false ) {

                # walk for each form
                foreach( $forms as $form ) {

                    # get full dynamic element string
                    $string = substr( self::get_base_code(), $form, ( strpos( self::get_base_code(), '}', $form ) - $form + 1 ) );

                    # explode string
                    $string_exploded = explode( '|', $string );

                    # add new dynamic element
                    self::add_dynamic_element( array(
                        'code' => $string,
                        'type' => 'mc4wp',
                        'context' => str_replace( 'context:', '', $string_exploded[1] ),
                        'inside' => str_replace( 'inside:', '', str_replace( '}', '', $string_exploded[2] ) ),
                        'replacement' => ''
                    ) );

                    # remove temporary variable
                    unset( $string, $string_exploded );
                }
            }

            # remove temporary variables
            unset( $forms, $form );

           /**
            *
            * opening hours status
            *
            */

            # find opening hours status elements
            $opening_hours_statuses = ueldo_strpos_all( self::get_base_code(), '{ueldopredefinedsections:openinghours|' );

            # do we have any status found?
            if( $opening_hours_statuses !== false ) {

                # walk for each status
                foreach( $opening_hours_statuses as $opening_hours_status ) {

                    # get full dynamic element string
                    $string = substr( self::get_base_code(), $opening_hours_status, ( strpos( self::get_base_code(), '}', $opening_hours_status ) - $opening_hours_status + 1 ) );

                    # explode string
                    $string_exploded = explode( '|', $string );

                    # add new dynamic element
                    self::add_dynamic_element( array(
                        'code' => $string,
                        'type' => 'openinghours',
                        'context' => str_replace( 'context:', '', str_replace( '}', '', $string_exploded[1] ) ),
                        'replacement' => ''
                    ) );

                    # remove temporary variable
                    unset( $string, $string_exploded );
                }
            }

            # remove temporary variables
            unset( $opening_hours_statuses, $opening_hours_status );

           /**
            *
            * sidebar
            *
            */

            # find sidebars elements
            $sidebars = ueldo_strpos_all( self::get_base_code(), '{ueldopredefinedsections:sidebar|' );

            # do we have any sidebar found?
            if( $sidebars !== false ) {

                # walk for each sidebar
                foreach( $sidebars as $sidebar ) {

                    # get full dynamic element string
                    $string = substr( self::get_base_code(), $sidebar, ( strpos( self::get_base_code(), '}', $sidebar ) - $sidebar + 1 ) );

                    # explode string
                    $string_exploded = explode( '|', $string );

                    # add new dynamic element
                    self::add_dynamic_element( array(
                        'code' => $string,
                        'type' => 'sidebar',
                        'context' => str_replace( 'context:', '', str_replace( '}', '', $string_exploded[1] ) ),
                        'replacement' => ''
                    ) );

                    # remove temporary variable
                    unset( $string, $string_exploded );
                }
            }

            # remove temporary variables
            unset( $sidebars, $sidebar );

           /**
            *
            * end of possible dynamic elements.
            *
            */
        }

       /**
        *
        * proceed dynamic elements replacement
        *
        */

        public static function replace_dynamic_elements() {

            # walk for each dynamic element record
            foreach( self::get_all_dynamic_elements() as $element_id => $element ) {

                # switch by element type
                switch( $element['type'] ) {

                   /**
                    *
                    * icon
                    *
                    */

                    case 'icon':

                        # array of possible icon replacements
                        $possible_icons = self::find_all_possible_elements( 'icon', $element );

                        # there's only one possible icon?
                        if( count( $possible_icons ) === 1 ) {

                            # update dynamic element replacement
                            self::update_dynamic_element_replacement( $element_id, esc_attr( $element['slug'] ) .'library="'. esc_attr( $possible_icons[0]['icon_font_unique_key'] ) .'" '. esc_attr( $element['slug'] ) . esc_attr( $possible_icons[0]['icon_font_unique_key'] ) .'="'. esc_attr( $possible_icons[0]['icon_key'] ) .'"' );
                        }

                        # clearification required
                        else {

                            # there's no any possible icon found?
                            if( count( $possible_icons ) === 0 ) {

                                # add new clarification record
                                if( !self::are_clarifications_solved() ) self::add_clarification_record( $element_id, 'icon_not_found' );
                                else {

                                    # solutions array
                                    $solutions = array(
                                        'font-family' => self::get_clarification_solution( $element_id, 'icon_not_found', 'font-family' ),
                                        'class' => self::get_clarification_solution( $element_id, 'icon_not_found', 'class' )
                                    );
                                }
                            }

                            # there's more than one possible icon found?
                            else {

                                # add new clarification record
                                if( !self::are_clarifications_solved() ) self::add_clarification_record( $element_id, 'duplicated_icon', $possible_icons );
                                else {

                                    # get id of selected possible icon
                                    $selected_id = self::get_clarification_solution( $element_id, 'other' );

                                    # solutions array
                                    $solutions = array(
                                        'font-family' => $possible_icons[esc_attr( $selected_id )]['icon_font_unique_key'],
                                        'class' => $possible_icons[esc_attr( $selected_id )]['icon_key']
                                    );
                                }
                            }

                            # update dynamic element replacement
                            if( isset( $solutions ) ) self::update_dynamic_element_replacement( $element_id, esc_attr( $element['slug'] ) .'library="'. esc_attr( $solutions['font-family'] ) .'" '. esc_attr( $element['slug'] ) . esc_attr( $solutions['font-family'] ) .'="'. esc_attr( $solutions['class'] ) .'"' );

                            # remove temporary variable
                            unset( $solutions, $selected_id );
                        }

                        # remove temporary variables
                        unset( $possible_icons );

                    break;

                   /**
                    *
                    * google map
                    *
                    */

                    case 'google_map':

                        # array of possible map replacements
                        $possible_maps = self::find_all_possible_elements( 'google_map' );

                        # add new clarification record
                        if( !self::are_clarifications_solved() ) self::add_clarification_record( $element_id, 'google_map', $possible_maps );
                        else {

                            # get id of selected possible map
                            $selected_id = self::get_clarification_solution( $element_id, 'other' );

                            # switch by selected id value
                            switch( $selected_id ) {

                                # add default Google map and assign it to this shortcode
                                case 'default':

                                    # add new google map to theme options and get its ID
                                    $google_map_id = self::add_default_element_for_section( 'google_map', $element['context'] );

                                    # is google map added correctly?
                                    if( $google_map_id === false ) exit( esc_html( __( 'Couldn\'t add default Google map.', 'ueldo' ) ) );
                                    else {

                                        # update dynamic element replacement
                                        self::update_dynamic_element_replacement( $element_id, 'google_map_id="'. esc_attr( $google_map_id ) .'"' );
                                    }

                                    # remove temporary variable
                                    unset( $google_map_id );

                                break;

                                # remove map ID attribute from shortcode
                                case 'later':

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, '' );

                                break;

                                # update shortcode with selected map ID
                                default:

                                    # do we have possible map with this ID found?
                                    if( !isset( $possible_maps[esc_attr( $selected_id )] ) ) exit( esc_html( __( 'Couldn\'t find possible map with ID: ', 'ueldo' ) ) . esc_attr( $selected_id ) );

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, 'google_map_id="'. esc_attr( $possible_maps[esc_attr( $selected_id )]['map_id'] ) .'"' );

                                break;
                            }

                            # remove temporary variables
                            unset( $selected_id );
                        }

                        # remove temporary variables
                        unset( $possible_maps );

                    break;

                   /**
                    *
                    * contact form 7
                    *
                    */

                    case 'contact_form_7':

                        # array of possible form replacements
                        $possible_forms = self::find_all_possible_elements( 'contact_form_7' );

                        # add new clarification record
                        if( !self::are_clarifications_solved() ) self::add_clarification_record( $element_id, 'contact_form_7', $possible_forms );
                        else {

                            # get id of selected form
                            $selected_id = self::get_clarification_solution( $element_id, 'other' );

                            # switch by selected id value
                            switch( $selected_id ) {

                                # add default form and assign it to this shortcode
                                case 'default':

                                    # add new contact form and get its ID
                                    $form_id = self::add_default_element_for_section( 'contact_form_7', $element['context'] );

                                    # is form added correctly?
                                    if( $form_id === false ) exit( esc_html( __( 'Couldn\'t add default contact form.', 'ueldo' ) ) );
                                    else {

                                        # update dynamic element replacement
                                        self::update_dynamic_element_replacement( $element_id, 'id='. ( $element['inside'] == 'true' ? '``' : '"' ) . esc_attr( $form_id ) . ( $element['inside'] == 'true' ? '``' : '"' ) );
                                    }

                                    # remove temporary variable
                                    unset( $form_id );

                                break;

                                # remove form ID attribute from shortcode
                                case 'later':

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, '' );

                                break;

                                # update shortcode with selected form ID
                                default:

                                    # do we have possible form with this ID found?
                                    if( !isset( $possible_forms[esc_attr( $selected_id )] ) ) exit( esc_html( __( 'Couldn\'t find possible form with ID: ', 'ueldo' ) ) . esc_attr( $selected_id ) );

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, 'id='. ( $element['inside'] == 'true' ? '``' : '"' ) . esc_attr( $possible_forms[esc_attr( $selected_id )]['form_id'] ) . ( $element['inside'] == 'true' ? '``' : '"' ) );

                                break;
                            }

                            # remove temporary variables
                            unset( $selected_id );
                        }

                        # remove temporary variables
                        unset( $possible_forms );

                    break;

                   /**
                    *
                    * image
                    *
                    */

                    case 'image':

                        # array of possible image replacements
                        $possible_images = self::find_all_possible_elements( 'image', $element );

                        # add new clarification record
                        if( !self::are_clarifications_solved() ) self::add_clarification_record( $element_id, 'image', $possible_images );
                        else {

                            # get id of selected image
                            $selected_id = self::get_clarification_solution( $element_id, 'other' );

                            # switch by selected id value
                            switch( $selected_id ) {

                                # add default image and assign it to this shortcode
                                case 'default':

                                    # add image to media library and get its id
                                    $image_id = self::add_default_element_for_section( 'image', $element['context'] );

                                    # is image added correctly?
                                    if( $image_id === false ) exit( esc_html( __( 'Couldn\'t add default image.', 'ueldo' ) ) );
                                    else {

                                        # update dynamic element replacement
                                        self::update_dynamic_element_replacement( $element_id, 'image="'. esc_attr( $image_id ) .'"' );
                                    }

                                    # remove temporary variable
                                    unset( $image_id );

                                break;

                                # remove image ID attribute from shortcode
                                case 'later':

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, '' );

                                break;

                                # update shortcode with selected image ID
                                default:

                                    # do we have possible image with this ID found?
                                    if( !isset( $possible_images[esc_attr( $selected_id )] ) ) exit( esc_html( __( 'Couldn\'t find possible image with ID: ', 'ueldo' ) ) . esc_attr( $selected_id ) );

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, 'image="'. esc_attr( $possible_images[esc_attr( $selected_id )]['image_id'] ) .'"' );

                                break;
                            }

                            # remove temporary variables
                            unset( $selected_id );
                        }

                        # remove temporary variables
                        unset( $possible_images );

                    break;

                   /**
                    *
                    * revolution slider
                    *
                    */

                    case 'revslider':

                        # array of possible revolution sliders
                        $possible_sliders = self::find_all_possible_elements( 'revslider', $element );

                        # add new clarification record
                        if( !self::are_clarifications_solved() ) self::add_clarification_record( $element_id, 'revslider', $possible_sliders );
                        else {

                            # get id of selected slider
                            $selected_id = self::get_clarification_solution( $element_id, 'other' );

                            # switch by selected id value
                            switch( $selected_id ) {

                                # add default slider and assign it to this shortcode
                                case 'default':

                                    # add new slider to revolution slider plugin and get its id
                                    $slider_alias = self::add_default_element_for_section( 'revslider', $element['context'] );

                                    # is slider added correctly?
                                    if( $slider_alias === false ) exit( esc_html( __( 'Couldn\'t add default Revolution Slider.', 'ueldo' ) ) );
                                    else {

                                        # update dynamic element replacement
                                        self::update_dynamic_element_replacement( $element_id, 'alias="'. esc_attr( $slider_alias ) .'"' );
                                    }

                                    # remove temporary variable
                                    unset( $slider_alias );

                                break;

                                # remove slider ID attribute from shortcode
                                case 'later':

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, '' );

                                break;

                                # update shortcode with selected slider ID
                                default:

                                    # do we have possible slider with this ID found?
                                    if( !isset( $possible_sliders[esc_attr( $selected_id )] ) ) exit( esc_html( __( 'Couldn\'t find possible Revolution Slider with ID: ', 'ueldo' ) ) . esc_attr( $selected_id ) );

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, 'alias="'. esc_attr( $possible_sliders[esc_attr( $selected_id )]['slider_alias'] ) .'"' );

                                break;
                            }

                            # remove temporary variables
                            unset( $selected_id );
                        }

                        # remove temporary variables
                        unset( $possible_sliders );

                    break;

                   /**
                    *
                    * menu
                    *
                    */

                    case 'menu':

                        # array of possible menus
                        $possible_menus = self::find_all_possible_elements( 'menu', $element );

                        # add new clarification record
                        if( !self::are_clarifications_solved() ) self::add_clarification_record( $element_id, 'menu', $possible_menus );
                        else {

                            # get id of selected menu
                            $selected_id = self::get_clarification_solution( $element_id, 'other' );

                            # switch by selected id value
                            switch( $selected_id ) {

                                # add default menu and assign it to this shortcode
                                case 'default':

                                    # add new menu and get its id
                                    $menu_id = self::add_default_element_for_section( 'menu', $element['context'] );

                                    # is menu added correctly?
                                    if( $menu_id === false ) exit( esc_html( __( 'Couldn\'t add default menu.', 'ueldo' ) ) );
                                    else {

                                        # update dynamic element replacement
                                        self::update_dynamic_element_replacement( $element_id, 'menu_id="'. esc_attr( $menu_id ) .'"' );
                                    }

                                    # remove temporary variable
                                    unset( $menu_id );

                                break;

                                # remove menu ID attribute from shortcode
                                case 'later':

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, 'menu_id=""' );

                                break;

                                # update shortcode with selected menu ID
                                default:

                                    # do we have possible menu with this ID found?
                                    if( !isset( $possible_menus[esc_attr( $selected_id )] ) ) exit( esc_html( __( 'Couldn\'t find possible menu with ID: ', 'ueldo' ) ) . esc_attr( $selected_id ) );

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, 'menu_id="'. esc_attr( $possible_menus[esc_attr( $selected_id )]['menu_slug'] ) .'"' );

                                break;
                            }

                            # remove temporary variables
                            unset( $selected_id );
                        }

                        # remove temporary variables
                        unset( $possible_menus );

                    break;

                   /**
                    *
                    * mailchimp for wordpress form
                    *
                    */

                    case 'mc4wp':

                        # array of possible forms
                        $possible_forms = self::find_all_possible_elements( 'mc4wp', $element );

                        # add new clarification record
                        if( !self::are_clarifications_solved() ) self::add_clarification_record( $element_id, 'mc4wp', $possible_forms );
                        else {

                            # get id of selected form
                            $selected_id = self::get_clarification_solution( $element_id, 'other' );

                            # switch by selected id value
                            switch( $selected_id ) {

                                # add default form and assign it to this shortcode
                                case 'default':

                                    # add new form and get its id
                                    $form_id = self::add_default_element_for_section( 'mc4wp', $element['context'] );

                                    # is form added correctly?
                                    if( $form_id === false ) exit( esc_html( __( 'Couldn\'t add default Mailchimp for WP form.', 'ueldo' ) ) );
                                    else {

                                        # update dynamic element replacement
                                        self::update_dynamic_element_replacement( $element_id, 'id='. ( $element['inside'] == 'true' ? '``' : '"' ) . esc_attr( $form_id ) . ( $element['inside'] == 'true' ? '``' : '"' ) );
                                    }

                                    # remove temporary variable
                                    unset( $menu_id );

                                break;

                                # remove form ID attribute from shortcode
                                case 'later':

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, 'id='. esc_attr( $element['inside'] == 'true' ? '````' : '""' ) );

                                break;

                                # update shortcode with selected form ID
                                default:

                                    # do we have possible form with this ID found?
                                    if( !isset( $possible_forms[esc_attr( $selected_id )] ) ) exit( esc_html( __( 'Couldn\'t find possible Mailchimp For WP form with ID: ', 'ueldo' ) ) . esc_attr( $selected_id ) );

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, 'id='. ( $element['inside'] == 'true' ? '``' : '"' ) . esc_attr( $possible_forms[esc_attr( $selected_id )]['form_id'] ) . ( $element['inside'] == 'true' ? '``' : '"' ) );

                                break;
                            }

                            # remove temporary variables
                            unset( $selected_id );
                        }

                        # remove temporary variables
                        unset( $possible_forms );

                    break;

                   /**
                    *
                    * opening hours
                    *
                    */

                    case 'openinghours':

                        # array of possible opening hours statuses
                        $possible_statuses = self::find_all_possible_elements( 'openinghours', $element );

                        # add new clarification record
                        if( !self::are_clarifications_solved() ) self::add_clarification_record( $element_id, 'openinghours', $possible_statuses );
                        else {

                            # get id of selected opening hours status
                            $selected_id = self::get_clarification_solution( $element_id, 'other' );

                            # switch by selected id value
                            switch( $selected_id ) {

                                # add default opening hours status and assign it to this shortcode
                                case 'default':

                                    # add new opening hours status and get its id
                                    $status_id = self::add_default_element_for_section( 'openinghours', $element['context'] );

                                    # is opening hours status added correctly?
                                    if( $status_id === false ) exit( esc_html( __( 'Couldn\'t add default opening hours status.', 'ueldo' ) ) );
                                    else {

                                        # update dynamic element replacement
                                        self::update_dynamic_element_replacement( $element_id, 'status="'. esc_attr( $status_id ) .'"' );
                                    }

                                    # remove temporary variable
                                    unset( $status_id );

                                break;

                                # remove opening hours status ID attribute from shortcode
                                case 'later':

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, 'status=""' );

                                break;

                                # update shortcode with selected opening hours status ID
                                default:

                                    # do we have possible opening hours status with this ID found?
                                    if( !isset( $possible_statuses[esc_attr( $selected_id )] ) ) exit( esc_html( __( 'Couldn\'t find possible opening hours status with ID: ', 'ueldo' ) ) . esc_attr( $selected_id ) );

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, 'status="'. esc_attr( $possible_statuses[esc_attr( $selected_id )]['status_id'] ) .'"' );

                                break;
                            }

                            # remove temporary variables
                            unset( $selected_id );
                        }

                        # remove temporary variables
                        unset( $possible_statuses );

                    break;

                   /**
                    *
                    * sidebar
                    *
                    */

                    case 'sidebar':

                        # array of possible sidebars
                        $possible_sidebars = self::find_all_possible_elements( 'sidebar', $element );

                        # add new clarification record
                        if( !self::are_clarifications_solved() ) self::add_clarification_record( $element_id, 'sidebar', $possible_sidebars );
                        else {

                            # get id of selected sidebar
                            $selected_id = self::get_clarification_solution( $element_id, 'other' );

                            # switch by selected id value
                            switch( $selected_id ) {

                                # add default sidebar and assign it to this shortcode
                                case 'default':

                                    # add new sidebar and get its id
                                    $sidebar_id = self::add_default_element_for_section( 'sidebar', $element['context'] );

                                    # is sidebar added correctly?
                                    if( $sidebar_id === false ) exit( esc_html( __( 'Couldn\'t add default sidebar.', 'ueldo' ) ) );
                                    else {

                                        # update dynamic element replacement
                                        self::update_dynamic_element_replacement( $element_id, 'sidebar_id="ueldo-custom-sidebar-'. esc_attr( $sidebar_id ) .'"' );
                                    }

                                    # remove temporary variable
                                    unset( $sidebar_id );

                                break;

                                # remove sidebar ID attribute from shortcode
                                case 'later':

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, 'sidebar_id=""' );

                                break;

                                # update shortcode with selected sidebar ID
                                default:

                                    # do we have possible sidebar with this ID found?
                                    if( !isset( $possible_sidebars[esc_attr( $selected_id )] ) ) exit( esc_html( __( 'Couldn\'t find possible sidebar with ID: ', 'ueldo' ) ) . esc_attr( $selected_id ) );

                                    # update dynamic element replacement
                                    self::update_dynamic_element_replacement( $element_id, 'sidebar_id="'. esc_attr( $possible_sidebars[esc_attr( $selected_id )]['sidebar_id'] ) .'"' );

                                break;
                            }

                            # remove temporary variables
                            unset( $selected_id );
                        }

                        # remove temporary variables
                        unset( $possible_sidebars );

                    break;
                }
            }
        }

       /**
        *
        * proceed
        *
        */

        public static function proceed() {

            # couldn't find the shortcode?
            if( self::get_base_code() == '' ) exit( esc_html( __( 'Couldn\'t find shortcode with this ID and type.', 'ueldo' ) ) );

            # find all dynamic elements
            self::find_all_dynamic_elements();

            # there's no any dynamic element found?
            if( self::get_all_dynamic_elements() == array() ) self::return_shortcode( self::get_base_code() );
            else {

                # proceed dynamic elements replacement
                self::replace_dynamic_elements();

                # shortcode is ready to return?
                if( !self::any_clarification_record_exists() ) self::return_shortcode( self::create_result_shortcode() );

                # we have any clarification record found
                else self::return_clarification_requirements();
            }
        }

       /**
        *
        * create result shortcode
        *
        */

        public static function create_result_shortcode() {

            # prepare result
            $shortcode = self::get_base_code();

            # walk for each replacements
            foreach( self::get_all_dynamic_elements() as $element ) {

                # do the replacements
                $shortcode = str_replace( $element['code'], $element['replacement'], $shortcode );

                # remove temporary variables
                unset( $element );
            }

            # return result
            return( $shortcode );
        }

       /**
        *
        * return shortcode
        *
        */

        public static function return_shortcode( $shortcode ) {

            # prepare results array
            $result = array( 'needClarification' => 'no', 'shortcode' => $shortcode );

            # display results array as json
            echo json_encode( $result );

            # exit the script
            exit;
        }

       /**
        *
        * return clarification requirements
        *
        */

        public static function return_clarification_requirements() {

            # get all clarification records
            $clarification_records = self::get_clarification_records();

            # prepare result array
            $result = array(
                'needClarification' => 'yes',
                'clarifications' => array()
            );

            # do we have "icon_not_found" clarification records?
            if( count( $clarification_records['icon_not_found'] ) > 0 ) {

                # update result array
                $result['clarifications'][] = array(
                    'type' => 'icon_not_found',
                    'records' => $clarification_records['icon_not_found']
                );
            }

            # do we have other clarification records?
            if( count( $clarification_records['other'] ) > 0 ) {

                # walk for each clarification result
                foreach( $clarification_records['other'] as $record_id => $record_data ) {

                    # update result array
                    $result['clarifications'][] = $record_data;
                }
            }

            # remove temporary variables
            unset( $clarification_records );

            # display results array as json
            echo json_encode( $result );

            # exit the script
            exit;
        }

       /**
        *
        * find all possible elements for selection
        *
        */

        public static function find_all_possible_elements( $type, $element = false ) {

            # global variables
            global $ueldo_cache_option;

            # prepare results array
            $result = array();

            # switch by elements type
            switch( $type ) {

               /**
                *
                * icon
                *
                */

                case 'icon':

                    # do we have custom icons added?
                    if( ueldo_plugins::is_active_plugin( 'ueldo' ) && ueldo_plugin_is_any_custom_icon_added() && $element != false && isset( $element['keys'] ) ) {

                        # get all custom icon fonts
                        $icon_fonts = $ueldo_cache_option -> get_option( 'ueldo_custom_icons' );

                        # do we have custom icons added?
                        if( $icon_fonts != false ) {

                            # walk for each icon fonts
                            foreach( $icon_fonts as $icon_font ) {

                                # walk for each icon inside this icon font
                                foreach( $icon_font['icons'] as $icon ) {

                                    # walk for each element key
                                    foreach( $element['keys'] as $element_key ) {

                                        # compare
                                        if( strpos( $icon, str_replace( 'flaticon-', '', $element_key ) ) ) {

                                            # update result array
                                            $result[] = array(
                                                'icon_font_unique_key' => $icon_font['unique_key'],
                                                'icon_font_name' => $icon_font['name'],
                                                'icon_key' => $icon
                                            );
                                        }
                                    }
                                }
                            }
                        }

                        # remove temporary variable
                        unset( $icon_fonts, $icon_font, $icon, $element_key );
                    }

                break;

               /**
                *
                * contact form 7 forms
                *
                */

                case 'contact_form_7':

                    # do we have this plugin activated?
                    if( ueldo_plugins::is_active_plugin( 'contact-form-7' ) == true ) {

                        # get list of all contact form 7 forms
                        $forms = get_posts( array( 'post_type' => 'wpcf7_contact_form', 'posts_per_page' => -1, 'status' => 'publish' ) );

                        # do we have any form found?
                        if( $forms !== false ) {

                            # walk for each form
                            foreach( $forms as $form ) {

                                # update result array
                                $result[] = array(
                                    'form_id' => esc_attr( $form -> ID ),
                                    'form_title' => esc_html( $form -> post_title )
                                );
                            }
                        }

                        # remove temporary variables
                        unset( $forms, $form );
                    }

                break;

               /**
                *
                * google map
                *
                */

                case 'google_map':

                    # find all available maps
                    for( $i = 0; $i < ueldo_get_theme_options_value( 'google-maps', false, 'next-map-id' ); $i++ ) {

                        # google map title
                        $title = ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $i ) .'-title' );

                        # do we have map title set?
                        if( $title != false ) {

                            # update result array
                            $result[] = array(
                                'map_id' => esc_attr( $i ),
                                'map_title' => esc_html( $title )
                            );
                        }

                        # remove temporary variables
                        unset( $title );
                    }

                    # remove temporary variables
                    unset( $i );

                break;

               /**
                *
                * image
                *
                */

                case 'image':

                    # get all images from media library
                    $media_images = new WP_Query( array(
                        'post_type' => 'attachment',
                        'post_mime_type' => 'image',
                        'post_status' => 'inherit',
                        'posts_per_page' => - 1,
                    ));

                    # do we have any image found?
                    if( $media_images -> post_count > 0 ) {

                        # walk for each image
                        foreach( $media_images -> posts as $image ) {

                            # compare image title
                            if( strpos( $image -> post_title, $element['context'] ) !== false ) {

                                # update result array
                                $result[] = array(
                                    'image_id' => esc_attr( $image -> ID ),
                                    'image_title' => esc_html( $image -> post_title )
                                );
                            }
                        }
                    }

                    # remove temporary variables
                    unset( $media_images, $image );

                break;

               /**
                *
                * revolution sliders
                *
                */

                case 'revslider':

                    # do we have revolution slider plugin activated?
                    if( ueldo_plugins::is_active_plugin( 'revolution-slider' ) == true ) {

                        # new revolution slider class object
                        $slider = new RevSlider();

                        # get all sliders array
                        $sliders = $slider -> getArrSliders();

                        # do we have any slider found?
                        if( count( $sliders ) > 0 ) {

                            # walk for each slider
                            foreach( $sliders as $slider ) {

                                # update result array
                                $result[] = array(
                                    'slider_id' => esc_attr( $slider -> getID() ),
                                    'slider_title' => esc_html( $slider -> getTitle() ),
                                    'slider_alias' => esc_attr( $slider -> getAlias() )
                                );
                            }
                        }

                        # remove temporary variables
                        unset( $slider, $sliders );
                    }

                break;

               /**
                *
                * menu
                *
                */

                case 'menu':

                    # get all navigation menus
                    $menus = get_terms( 'nav_menu', array( 'hide_empty' => false ) );

                    # do we have any menu?
                    if( $menus != false && $menus != null && is_array( $menus ) ) {

                        # walk foreach navigation menus
                        foreach( $menus as $menu ) {

                            # update result array
                            $result[] = array(
                                'menu_id' => esc_attr( $menu -> term_id ),
                                'menu_title' => esc_html( $menu -> name ),
                                'menu_slug' => esc_attr( $menu -> slug )
                            );
                        }
                    }

                    # remove temporary variables
                    unset( $menus, $menu );

                break;

               /**
                *
                * mailchimp for wordpress form
                *
                */

                case 'mc4wp':

                    # do we have this plugin activated?
                    if( ueldo_plugins::is_active_plugin( 'mailchimp-for-wp' ) == true ) {

                        # get list of all mailchimp for wordpress forms
                        $forms = get_posts( array( 'post_type' => 'mc4wp-form', 'posts_per_page' => -1, 'status' => 'publish' ) );

                        # do we have any form found?
                        if( $forms !== false ) {

                            # walk for each form
                            foreach( $forms as $form ) {

                                # update result array
                                $result[] = array(
                                    'form_id' => esc_attr( $form -> ID ),
                                    'form_title' => esc_html( $form -> post_title )
                                );
                            }
                        }

                        # remove temporary variables
                        unset( $forms, $form );
                    }

                break;

               /**
                *
                * opening hours status
                *
                */

                case 'openinghours':

                    # find all available statuses
                    for( $i = 0; $i < ueldo_get_theme_options_value( 'opening-hours-status', false, 'next-status-id' ); $i++ ) {

                        # status title
                        $title = ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $i ) .'-title' );

                        # do we have status title set?
                        if( $title != false ) {

                            # update result array
                            $result[] = array(
                                'status_id' => esc_attr( $i ),
                                'status_title' => esc_html( $title )
                            );
                        }

                        # remove temporary variables
                        unset( $title );
                    }

                    # remove temporary variables
                    unset( $i );

                break;

               /**
                *
                * sidebar
                *
                */

                case 'sidebar':

                    # add default blog sidebar to results array
                    $result[] = array(
                        'sidebar_id' => 'blog-sidebar',
                        'sidebar_title' => esc_html( __( 'Blog sidebar', 'ueldo' ) )
                    );

                    # get sidebars array
                    $sidebars = get_option( 'ueldo_custom_sidebars' );

                    # do we have custom sidebars?
                    if( $sidebars != false && is_array( $sidebars ) ) {

                        # walk for each sidebar
                        foreach( $sidebars['sidebars'] as $sidebar_id => $sidebar_title ) {

                            # update results array
                            $result[] = array(
                                'sidebar_id' => 'ueldo-custom-sidebar-'. esc_attr( $sidebar_id ),
                                'sidebar_title' => esc_html( $sidebar_title )
                            );
                        }
                    }

                break;
            }

            # remove possible elements duplicates
            if( count( $result ) > 1 ) $result = self::remove_possible_elements_duplicates( $result );

            # return result
            return( $result );
        }

       /**
        *
        * remove duplicates from possible elements array
        *
        */

        public static function remove_possible_elements_duplicates( $elements ) {

            # array of unique elements
            $unique = array( $elements[0] );

            # walk for each elements
            foreach( $elements as $element_id => $element_data ) {

                # skip first element
                if( $element_id == 0 ) continue;

                # set flag
                $is_unique = true;

                # walk for each unique elements
                foreach( $unique as $unique_element_id => $unique_element_data ) {

                    # compare
                    if( $element_data == $unique_element_data ) $is_unique = false;
                }

                # is element unique?
                if( $is_unique == true ) $unique[] = $element_data;
            }

            # return result
            return( $unique );
        }

       /**
        *
        * add default element for selected section
        *
        */

        public static function add_default_element_for_section( $type, $context ) {

            # get cache option class object
            global $ueldo_styles_cache;

            # prepare result variable
            $result = false;

            # switch by element type
            switch( $type ) {

               /**
                *
                * google map
                *
                */

                case 'google_map':

                    # get ueldo theme options
                    $options = get_option( 'ueldo_theme_options' );

                    # base option value
                    $base_option = $options['google-maps'];

                    # get next map ID
                    $next_map_id = isset( $base_option['next-map-id'] ) ? $base_option['next-map-id'] : '1';

                    # array of map styles
                    $map_styles = array(

                        'default' => '[{"featureType":"administrative","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":20}]},{"featureType":"road","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":40}]},{"featureType":"water","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-10},{"lightness":30}]},{"featureType":"landscape.man_made","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":10}]},{"featureType":"landscape.natural","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":60}]},{"featureType":"poi","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]},{"featureType":"transit","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]}]',

                        'stud' => '[{"featureType":"administrative","stylers":[{"saturation":-100},{"lightness":20},{"visibility":"on"}]},{"featureType":"landscape.man_made","stylers":[{"color":"#f5eae4"},{"saturation":-60},{"lightness":10},{"visibility":"simplified"}]},{"featureType":"landscape.natural","stylers":[{"saturation":-60},{"lightness":60},{"visibility":"simplified"}]},{"featureType":"poi","stylers":[{"saturation":-100},{"lightness":60},{"visibility":"off"}]},{"featureType":"road","stylers":[{"saturation":-100},{"lightness":40},{"visibility":"on"}]},{"featureType":"transit","stylers":[{"saturation":-100},{"lightness":60},{"visibility":"off"}]},{"featureType":"water","stylers":[{"color":"#878979"},{"visibility":"on"}]}]'
                    );

                    # define new map data array
                    $new_map_data = array();

                    # switch by google map context
                    switch( $context ) {

                        # default google map for creative agency
                        case 'creative-agency':

                            # prepare new map data array
                            $new_map_data = array(
                                'google-map-'. esc_attr( $next_map_id ) .'-title' => esc_html( __( 'Location map', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lat' => '40.713703',
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lng' => '-74.005325',
                                'google-map-'. esc_attr( $next_map_id ) .'-zoom' => '12',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-next-marker-id' => '2',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-title' => esc_html( __( 'Marker', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lat' => '40.713703',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lng' => '-74.005325',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-use-custom-marker' => 'no',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-library' => 'fontawesome',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon' => 'fa fa-address-book',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-size' => '18',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-width' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-height' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius' => 'circle',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius-px' => '4',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-background-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-container-background-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-horizontal-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'horizontal-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-vertical-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'vertical-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-blur-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'blur-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-spread-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'spread-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-color' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-marker-image' => '',
                                'google-map-'. esc_attr( $next_map_id ) .'-custom-style' => $map_styles['default']
                            );

                        break;

                        # default google map for accountant: new york
                        case 'accountant-new-york':

                            # prepare new map data array
                            $new_map_data = array(
                                'google-map-'. esc_attr( $next_map_id ) .'-title' => esc_html( __( 'New York office', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lat' => '40.713689',
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lng' => '-74.005294',
                                'google-map-'. esc_attr( $next_map_id ) .'-zoom' => '16',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-next-marker-id' => '2',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-title' => esc_html( __( 'Marker', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lat' => '40.713689',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lng' => '-74.005294',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-use-custom-marker' => 'no',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-library' => 'fontawesome',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon' => 'fa fa-address-book',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-size' => '18',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-width' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-height' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius' => 'circle',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius-px' => '4',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-background-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-container-background-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-horizontal-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'horizontal-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-vertical-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'vertical-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-blur-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'blur-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-spread-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'spread-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-color' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-marker-image' => '',
                                'google-map-'. esc_attr( $next_map_id ) .'-custom-style' => $map_styles['default']
                            );

                        break;

                        # default google map for accountant: miami
                        case 'accountant-miami':

                            # prepare new map data array
                            $new_map_data = array(
                                'google-map-'. esc_attr( $next_map_id ) .'-title' => esc_html( __( 'Miami office', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lat' => '25.771694',
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lng' => '-80.190123',
                                'google-map-'. esc_attr( $next_map_id ) .'-zoom' => '16',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-next-marker-id' => '2',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-title' => esc_html( __( 'Marker', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lat' => '25.771694',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lng' => '-80.190123',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-use-custom-marker' => 'no',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-library' => 'fontawesome',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon' => 'fa fa-address-book',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-size' => '18',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-width' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-height' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius' => 'circle',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius-px' => '4',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-background-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-container-background-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-horizontal-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'horizontal-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-vertical-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'vertical-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-blur-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'blur-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-spread-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'spread-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-color' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-marker-image' => '',
                                'google-map-'. esc_attr( $next_map_id ) .'-custom-style' => $map_styles['default']
                            );

                        break;

                        # default google map for accountant: dublin
                        case 'accountant-dublin':

                            # prepare new map data array
                            $new_map_data = array(
                                'google-map-'. esc_attr( $next_map_id ) .'-title' => esc_html( __( 'Dublin office', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lat' => '53.349524',
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lng' => '-6.260238',
                                'google-map-'. esc_attr( $next_map_id ) .'-zoom' => '16',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-next-marker-id' => '2',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-title' => esc_html( __( 'Marker', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lat' => '53.349524',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lng' => '-6.260238',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-use-custom-marker' => 'no',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-library' => 'fontawesome',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon' => 'fa fa-address-book',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-size' => '18',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-width' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-height' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius' => 'circle',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius-px' => '4',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-background-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-container-background-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-horizontal-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'horizontal-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-vertical-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'vertical-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-blur-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'blur-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-spread-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'spread-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-color' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-marker-image' => '',
                                'google-map-'. esc_attr( $next_map_id ) .'-custom-style' => $map_styles['default']
                            );

                        break;

                        # default google map for stud
                        case 'stud-clear':
                        case 'stud-demo-like':

                            # prepare new map data array
                            $new_map_data = array(
                                'google-map-'. esc_attr( $next_map_id ) .'-title' => esc_html( __( 'Map', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lat' => '40.770113',
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lng' => '-73.975072',
                                'google-map-'. esc_attr( $next_map_id ) .'-zoom' => '11',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-next-marker-id' => '2',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-title' => esc_html( __( 'Marker', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lat' => '40.770113',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lng' => '-73.975072',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-use-custom-marker' => 'no',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-library' => 'fontawesome',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon' => 'fa fa-address-book',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-size' => '18',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-width' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-height' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius' => 'circle',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius-px' => '4',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-background-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-container-background-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-horizontal-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'horizontal-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-vertical-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'vertical-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-blur-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'blur-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-spread-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'spread-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-color' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-marker-image' => '',
                                'google-map-'. esc_attr( $next_map_id ) .'-custom-style' => ( $context == 'stud-clear' ? $map_styles['default'] : $map_styles['stud'] )
                            );

                        break;

                        # default google map for dentist
                        case 'dentist':

                            # prepare new map data array
                            $new_map_data = array(
                                'google-map-'. esc_attr( $next_map_id ) .'-title' => esc_html( __( 'Company location', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lat' => '40.713658',
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lng' => '-74.005367',
                                'google-map-'. esc_attr( $next_map_id ) .'-zoom' => '16',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-next-marker-id' => '2',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-title' => esc_html( __( 'Marker', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lat' => '40.713658',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lng' => '-74.005367',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-use-custom-marker' => 'yes-image',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-library' => 'fontawesome',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon' => 'fa fa-address-book',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-size' => '18',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-width' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-height' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius' => 'circle',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius-px' => '4',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-background-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-container-background-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-horizontal-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'horizontal-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-vertical-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'vertical-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-blur-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'blur-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-spread-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'spread-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-color' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-marker-image' => esc_url( get_template_directory_uri() .'/_assets/_img/_templates-images/ueldo-dentist-map-marker.png' ),
                                'google-map-'. esc_attr( $next_map_id ) .'-custom-style' => $map_styles['default']
                            );

                        break;

                        # default google map for kayaks and electrician
                        case 'kayaks':
                        case 'electrician':

                            # prepare new map data array
                            $new_map_data = array(
                                'google-map-'. esc_attr( $next_map_id ) .'-title' => esc_html( __( 'Location map', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lat' => '41.670650',
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lng' => '-87.040978',
                                'google-map-'. esc_attr( $next_map_id ) .'-zoom' => '10',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-next-marker-id' => '2',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-title' => esc_html( __( 'Marker', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lat' => '41.670650',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lng' => '-87.040978',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-use-custom-marker' => 'no',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-library' => 'fontawesome',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon' => 'fa fa-address-book',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-size' => '18',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-width' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-height' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius' => 'circle',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius-px' => '4',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-background-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-container-background-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-horizontal-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'horizontal-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-vertical-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'vertical-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-blur-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'blur-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-spread-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'spread-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-color' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-marker-image' => '',
                                'google-map-'. esc_attr( $next_map_id ) .'-custom-style' => $map_styles['default']
                            );

                        break;

                        # default google map for barber-shop
                        case 'barber-shop':

                            # prepare new map data array
                            $new_map_data = array(
                                'google-map-'. esc_attr( $next_map_id ) .'-title' => esc_html( __( 'Company location', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lat' => '40.713658',
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lng' => '-74.005367',
                                'google-map-'. esc_attr( $next_map_id ) .'-zoom' => '16',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-next-marker-id' => '2',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-title' => esc_html( __( 'Marker', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lat' => '40.713658',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lng' => '-74.005367',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-use-custom-marker' => 'no',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-library' => 'fontawesome',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon' => 'fa fa-address-book',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-size' => '18',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-width' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-height' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius' => 'circle',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius-px' => '4',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-background-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-container-background-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-horizontal-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'horizontal-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-vertical-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'vertical-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-blur-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'blur-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-spread-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'spread-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-color' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-marker-image' => '',
                                'google-map-'. esc_attr( $next_map_id ) .'-custom-style' => $map_styles['default']
                            );

                        break;

                        # default google map for cafe
                        case 'cafe':

                            # prepare new map data array
                            $new_map_data = array(
                                'google-map-'. esc_attr( $next_map_id ) .'-title' => esc_html( __( 'Locations', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lat' => '40.713658',
                                'google-map-'. esc_attr( $next_map_id ) .'-center-lng' => '-74.005767',
                                'google-map-'. esc_attr( $next_map_id ) .'-zoom' => '16',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-next-marker-id' => '4',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-title' => esc_html( __( 'Location 1', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lat' => '40.713658',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-lng' => '-74.005367',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-use-custom-marker' => 'yes-image',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-library' => 'fontawesome',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon' => 'fa fa-address-book',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-size' => '18',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-width' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-height' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius' => 'circle',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-border-radius-px' => '4',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-background-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-container-background-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-horizontal-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'horizontal-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-vertical-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'vertical-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-blur-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'blur-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-spread-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'spread-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-icon-box-shadow-color' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-1-custom-marker-image' => esc_url( get_template_directory_uri() .'/_assets/_img/_templates-images/ueldo-cafe-map-marker.png' ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-title' => esc_html( __( 'Location 2', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-lat' => '40.712637',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-lng' => '-74.009493',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-use-custom-marker' => 'yes-image',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-custom-icon-library' => 'fontawesome',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-custom-icon' => 'fa fa-address-book',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-custom-icon-size' => '18',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-custom-icon-width' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-custom-icon-height' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-custom-icon-border-radius' => 'circle',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-custom-icon-border-radius-px' => '4',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-custom-icon-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-custom-icon-background-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-container-background-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-custom-icon-box-shadow-horizontal-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'horizontal-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-custom-icon-box-shadow-vertical-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'vertical-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-custom-icon-box-shadow-blur-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'blur-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-custom-icon-box-shadow-spread-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'spread-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-custom-icon-box-shadow-color' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-2-custom-marker-image' => esc_url( get_template_directory_uri() .'/_assets/_img/_templates-images/ueldo-cafe-map-marker.png' ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-title' => esc_html( __( 'Location 3', 'ueldo' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-lat' => '40.715431',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-lng' => '-74.002710',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-use-custom-marker' => 'yes-image',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-custom-icon-library' => 'fontawesome',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-custom-icon' => 'fa fa-address-book',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-custom-icon-size' => '18',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-custom-icon-width' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-custom-icon-height' => '36',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-custom-icon-border-radius' => 'circle',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-custom-icon-border-radius-px' => '4',
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-custom-icon-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-custom-icon-background-color' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-google-map-marker-icon-container-background-color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-custom-icon-box-shadow-horizontal-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'horizontal-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-custom-icon-box-shadow-vertical-length' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'vertical-length' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-custom-icon-box-shadow-blur-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'blur-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-custom-icon-box-shadow-spread-radius' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'spread-radius' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-custom-icon-box-shadow-color' => esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'color' ) ),
                                'google-map-'. esc_attr( $next_map_id ) .'-markers-marker-3-custom-marker-image' => esc_url( get_template_directory_uri() .'/_assets/_img/_templates-images/ueldo-cafe-map-marker.png' ),
                                'google-map-'. esc_attr( $next_map_id ) .'-custom-style' => $map_styles['default']
                            );

                        break;
                    }

                    # merge arrays
                    $base_option = array_merge( $base_option, $new_map_data );

                    # update result variable
                    $result = $next_map_id;

                    # update next map ID
                    $base_option['next-map-id'] = esc_attr( $next_map_id + 1 );

                    # update options array
                    $options['google-maps'] = $base_option;

                    # update theme options
                    update_option( 'ueldo_theme_options', $options );

                    # remove temporary variables
                    unset( $base_option, $new_map_data, $next_map_id, $options, $map_styles );

                break;

               /**
                *
                * opening hours status
                *
                */

                case 'openinghours':

                    # get ueldo theme options
                    $options = get_option( 'ueldo_theme_options' );

                    # base option value
                    $base_option = $options['opening-hours-status'];

                    # get next opening hours status ID
                    $next_status_id = isset( $base_option['next-status-id'] ) ? $base_option['next-status-id'] : '1';

                    # define new status array
                    $new_status = array();

                    # switch by opening hours status context
                    switch( $context ) {

                        # default opening hours status for dentist
                        case 'dentist':

                            # prepare new opening hours status data array
                            $new_status = array(
                                'status-'. esc_attr( $next_status_id ) .'-title' => esc_html( __( 'Opening hours', 'ueldo' ) ),
                                'status-'. esc_attr( $next_status_id ) .'-timezone' => 'use-browser',
                                'status-'. esc_attr( $next_status_id ) .'-rules-next-rule-id' => '5',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-title' => esc_html( __( 'Monday', 'ueldo' ) ),
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-apply-for-monday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-all-day-closed' => 'no',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-next-opening-hours-id' => '2',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-opening-hours-1-ignored' => 'no',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-opening-hours-1-from-hour' => '10',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-opening-hours-1-from-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-opening-hours-1-to-hour' => '23',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-opening-hours-1-to-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-title' => esc_html( __( 'Tuesday - Thursday', 'ueldo' ) ),
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-apply-for-tuesday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-apply-for-wednesday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-apply-for-thursday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-all-day-closed' => 'no',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-next-opening-hours-id' => '2',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-opening-hours-1-ignored' => 'no',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-opening-hours-1-from-hour' => '09',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-opening-hours-1-from-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-opening-hours-1-to-hour' => '14',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-opening-hours-1-to-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-title' => esc_html( __( 'Friday - Saturday', 'ueldo' ) ),
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-apply-for-friday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-apply-for-saturday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-all-day-closed' => 'no',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-next-opening-hours-id' => '2',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-opening-hours-1-ignored' => 'no',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-opening-hours-1-from-hour' => '09',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-opening-hours-1-from-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-opening-hours-1-to-hour' => '23',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-opening-hours-1-to-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-4-title' => esc_html( __( 'Sunday', 'ueldo' ) ),
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-4-apply-for-sunday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-4-all-day-closed' => 'yes',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-4-next-opening-hours-id' => '2',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-4-opening-hours-1-ignored' => 'no',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-4-opening-hours-1-from-hour' => '08',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-4-opening-hours-1-from-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-4-opening-hours-1-to-hour' => '16',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-4-opening-hours-1-to-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-exceptions-next-exception-id' => '1'
                            );

                        break;

                        # default opening hours status for barber shop
                        case 'barber-shop':

                            # prepare new opening hours status data array
                            $new_status = array(
                                'status-'. esc_attr( $next_status_id ) .'-title' => esc_html( __( 'Regular opening hours', 'ueldo' ) ),
                                'status-'. esc_attr( $next_status_id ) .'-timezone' => 'use-browser',
                                'status-'. esc_attr( $next_status_id ) .'-rules-next-rule-id' => '4',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-title' => esc_html( __( 'Monday - Friday', 'ueldo' ) ),
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-apply-for-monday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-apply-for-tuesday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-apply-for-wednesday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-apply-for-thursday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-apply-for-friday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-all-day-closed' => 'no',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-next-opening-hours-id' => '2',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-opening-hours-1-ignored' => 'no',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-opening-hours-1-from-hour' => '10',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-opening-hours-1-from-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-opening-hours-1-to-hour' => '23',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-opening-hours-1-to-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-title' => esc_html( __( 'Saturday', 'ueldo' ) ),
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-apply-for-saturday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-all-day-closed' => 'no',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-next-opening-hours-id' => '2',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-opening-hours-1-ignored' => 'no',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-opening-hours-1-from-hour' => '11',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-opening-hours-1-from-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-opening-hours-1-to-hour' => '18',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-2-opening-hours-1-to-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-title' => esc_html( __( 'Sunday', 'ueldo' ) ),
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-apply-for-sunday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-all-day-closed' => 'yes',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-next-opening-hours-id' => '2',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-opening-hours-1-ignored' => 'no',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-opening-hours-1-from-hour' => '08',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-opening-hours-1-from-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-opening-hours-1-to-hour' => '16',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-3-opening-hours-1-to-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-exceptions-next-exception-id' => '1'
                            );

                        break;

                        # default opening hours status for cafe
                        case 'cafe':

                            # prepare new opening hours status data array
                            $new_status = array(
                                'status-'. esc_attr( $next_status_id ) .'-title' => esc_html( __( 'Regular opening hours', 'ueldo' ) ),
                                'status-'. esc_attr( $next_status_id ) .'-timezone' => 'use-browser',
                                'status-'. esc_attr( $next_status_id ) .'-rules-next-rule-id' => '2',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-title' => esc_html( __( 'Everyday', 'ueldo' ) ),
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-apply-for-monday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-apply-for-tuesday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-apply-for-wednesday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-apply-for-thursday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-apply-for-friday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-apply-for-saturday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-apply-for-sunday' => 'on',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-all-day-closed' => 'no',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-next-opening-hours-id' => '2',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-opening-hours-1-ignored' => 'no',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-opening-hours-1-from-hour' => '08',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-opening-hours-1-from-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-opening-hours-1-to-hour' => '22',
                                'status-'. esc_attr( $next_status_id ) .'-rules-rule-1-opening-hours-1-to-minutes' => '00',
                                'status-'. esc_attr( $next_status_id ) .'-exceptions-next-exception-id' => '1'
                            );

                        break;
                    }

                    # merge arrays
                    $base_option = array_merge( $base_option, $new_status );

                    # update result variable
                    $result = $next_status_id;

                    # update next opening hours status ID
                    $base_option['next-status-id'] = esc_attr( $next_status_id + 1 );

                    # update options array
                    $options['opening-hours-status'] = $base_option;

                    # update theme options
                    update_option( 'ueldo_theme_options', $options );

                    # remove temporary variables
                    unset( $base_option, $new_status, $next_status_id, $options );

                break;

               /**
                *
                * sidebar
                *
                */

                case 'sidebar':

                    # is ueldo plugin active?
                    if( ueldo_plugins::is_active_plugin( 'ueldo' ) ) {

                        # switch by sidebar context
                        switch( $context ) {

                            # dentist services sidebar
                            case 'dentist': $title = esc_html( __( 'Service page', 'ueldo' ) ); break;
                        }

                        # get array of all custom sidebars
                        $sidebars = get_option( 'ueldo_custom_sidebars' );

                        # there's no any custom sidebar found?
                        if( $sidebars == false || !is_array( $sidebars ) ) {

                            # default values
                            $sidebars = array(
                                'next-custom-sidebar-id' => '1',
                                'sidebars' => array()
                            );
                        }

                        # assign new sidebar ID to result
                        $result = $sidebars['next-custom-sidebar-id'];

                        # update sidebars array
                        $sidebars['sidebars'][esc_attr( $result )] = esc_html( $title );

                        # update next custom sidebar ID
                        $sidebars['next-custom-sidebar-id'] = esc_attr( $result + 1 );

                        # update option
                        update_option( 'ueldo_custom_sidebars', $sidebars );

                        # remove temporary variables
                        unset( $title, $sidebars );

                        # add default widgets to sidebar
                        self::add_default_widgets_to_sidebar( $result, $context );
                    }

                break;

               /**
                *
                * other elements (action "outsourced")
                *
                */

                case 'contact_form_7': $result = ueldo_add_demo_assets::add_contact_form(); break;
                case 'image': $result = ueldo_add_demo_assets::add_image( esc_attr( $context ) ); break;
                case 'revslider': $result = ueldo_add_demo_assets::upload_revslider( esc_attr( $context ) ); break;
                case 'menu': $result = ueldo_add_demo_assets::add_menu( esc_attr( $context ) ); break;
                case 'mc4wp': $result = ueldo_add_demo_assets::add_mc4wp_form( esc_attr( $context ) ); break;
            }

            # return result
            return( $result );
        }

       /**
        *
        * add default widgets to selected sidebar
        *
        */

        public static function add_default_widgets_to_sidebar( $sidebar_id, $context ) {

            # get sidebar widgets option
            $sidebar_widgets = get_option( 'sidebars_widgets' );

            # copy array version from result array
            $array_version = $sidebar_widgets['array_version'];

            # remove array version from result array
            unset( $sidebar_widgets['array_version'] );

            # update sidebar widgets for selected sidebar
            $sidebar_widgets['ueldo-custom-sidebar-'. esc_attr( $sidebar_id )] = array(
                'ueldo_call_to_action_widget-'. esc_attr( self::add_widget( 'dentist-call-to-action-widget' ) ),
                'nav_menu-'. esc_attr( self::add_widget( 'dentist-nav-menu-widget' ) )
            );

            # bring array version back to result array
            $sidebar_widgets['array_version'] = $array_version;

            # update sidebar widgets array
            update_option( 'sidebars_widgets', $sidebar_widgets );
        }

       /**
        *
        * add new widget
        *
        */

        public static function add_widget( $type ) {

            # switch by widget type
            switch( $type ) {

                # dentist template, call to action widget
                case 'dentist-call-to-action-widget':

                    # option name
                    $option_name = 'widget_ueldo_call_to_action_widget';

                    # update widgets array
                    $new_widget = array(
                        'button_url' => '#',
                        'background_image_url' => '',
                        'button_icon' => '',
                        'button_in_new_tab' => '',
                        'big_title' => esc_html( __( '-30%', 'ueldo' ) ),
                        'title' => esc_html( __( 'Limited offer!', 'ueldo' ) ),
                        'content' => 'Praesent ac feugiat est. Vestibulum commodo ultrices elementum. Nulla nec fringilla felis.',
                        'button_text' => esc_html( __( 'Schedule a Visit', 'ueldo' ) )
                    );

                break;

                # dentist template, nav menu widget
                case 'dentist-nav-menu-widget':

                    # option name
                    $option_name = 'widget_nav_menu';

                    # update widgets array
                    $new_widget = array(
                        'title' => esc_html( __( 'Services', 'ueldo' ) ),
                        'nav_menu' => esc_attr( self::add_default_element_for_section( 'menu', 'dentist-sidebar-services-menu' ) )
                    );

                break;
            }

            # get all "call to action" custom widgets
            $widgets = get_option( $option_name );

            # get next widget ID
            $next_widget_id = self::get_next_widget_id( $widgets );

            # update widgets array
            $widgets[esc_attr( $next_widget_id )] = $new_widget;

            # copy "multiwidget" flag from result array
            $multiwidget = $widgets['_multiwidget'];

            # remove "multiwidget" flag from result array
            unset( $widgets['_multiwidget'] );

            # bring "multiwidget" flag back to result array
            $widgets['_multiwidget'] = $multiwidget;

            # update option
            update_option( $option_name, $widgets );

            # remove temporary variables
            unset( $widgets, $new_widget, $option_name, $multiwidget );

            # return widget id
            return( $next_widget_id );
        }

       /**
        *
        * get next widget ID
        *
        */

        public static function get_next_widget_id( $widgets ) {

            # define last widget ID value
            $last_widget_id = 0;

            # walk for each widget
            foreach( $widgets as $widget_id => $widget_data ) {

                # skip not-numeric values
                if( !is_numeric( $widget_id ) ) continue;

                # update last widget ID
                if( $widget_id > $last_widget_id ) $last_widget_id = $widget_id;
            }

            # update widget ID value
            $last_widget_id++;

            # remove temporary variables
            unset( $widgets, $widget_id, $widget_data );

            # return result
            return( $last_widget_id );
        }

       /**
        *
        * end of class.
        *
        */
    }

   /**
    *
    * proceed the class
    *
    */

    ueldo_predefined_section_shortcode::proceed();

   /**
    *
    * end of file.
    *
    */

?>