<?php

   /**
    *
    * force Visual Composer to initialize as "built into the theme",
    * and register all theme shortcodes for this plugin
    *
    */

    add_action( 'vc_before_init', 'ueldo_vc_set_as_theme' );
    function ueldo_vc_set_as_theme() {

        # styles cache global variable
        global $ueldo_styles_cache;

        # set as theme
        vc_set_as_theme();

        # disable front-end option
        vc_disable_frontend();

        # include each single custom shortcode for visual composer
        foreach( ueldo_get_all_custom_vc_shortcodes_array() as $vc_shortcode ) {

            # include
            require_once( ueldo_plugin_get_path( '_parts/_visual-composer/_shortcodes/'. esc_attr( $vc_shortcode ) .'.php' ) );
        }
    }

   /**
    *
    * add predefined sections loader button before the wordpress editor
    *
    */

    add_action( 'load-post.php', 'ueldo_vc_add_predefined_sections_popup' );
    add_action( 'load-post-new.php', 'ueldo_vc_add_predefined_sections_popup' );

    # include predefined sections popup, only for post / page editors
    function ueldo_vc_add_predefined_sections_popup() {

        # load predefined sections popup
        require_once( ueldo_plugin_get_path( '_parts/_visual-composer/predefined-sections.php' ) );
    }

   /**
    *
    * get an array of all custom theme shortcodes for visual composer
    *
    */

    function ueldo_get_all_custom_vc_shortcodes_array() {

        # return result
        return( array(
            'ueldo_shortcode_accordion_single_element',
            'ueldo_shortcode_accordion',
            'ueldo_shortcode_announcement',
            'ueldo_shortcode_attributes_box_single_attribute',
            'ueldo_shortcode_attributes_box',
            'ueldo_shortcode_button',
            'ueldo_shortcode_card_layer',
            'ueldo_shortcode_card',
            'ueldo_shortcode_delimiter',
            'ueldo_shortcode_filtered_masonry_cell',
            'ueldo_shortcode_filtered_masonry',
            'ueldo_shortcode_form',
            'ueldo_shortcode_full_width_testimonials_single_testimonial',
            'ueldo_shortcode_full_width_testimonials',
            'ueldo_shortcode_gap',
            'ueldo_shortcode_google_map',
            'ueldo_shortcode_header_menu',
            'ueldo_shortcode_heading_text',
            'ueldo_shortcode_heading',
            'ueldo_shortcode_icon_list',
            'ueldo_shortcode_icon',
            'ueldo_shortcode_image',
            'ueldo_shortcode_info_box',
            'ueldo_shortcode_inline_container_element',
            'ueldo_shortcode_inline_container',
            'ueldo_shortcode_languages_switcher',
            'ueldo_shortcode_loop_cell',
            'ueldo_shortcode_loop',
            'ueldo_shortcode_opening_hours_box_element',
            'ueldo_shortcode_opening_hours_box',
            'ueldo_shortcode_opening_hours_status',
            'ueldo_shortcode_post_page_box',
            'ueldo_shortcode_presentation_element',
            'ueldo_shortcode_presentation_point_of_interest',
            'ueldo_shortcode_presentation',
            'ueldo_shortcode_price_single',
            'ueldo_shortcode_pricing_list_attribute',
            'ueldo_shortcode_pricing_list_group',
            'ueldo_shortcode_pricing_list',
            'ueldo_shortcode_pricing_table_attribute',
            'ueldo_shortcode_pricing_table',
            'ueldo_shortcode_progress_bar',
            'ueldo_shortcode_pulsating_circles',
            'ueldo_shortcode_quote',
            'ueldo_shortcode_row_layer',
            'ueldo_shortcode_search_field',
            'ueldo_shortcode_social_media_feed',
            'ueldo_shortcode_tabs_box_single_tab',
            'ueldo_shortcode_tabs_box',
            'ueldo_shortcode_tabs_single_tab',
            'ueldo_shortcode_tabs',
            'ueldo_shortcode_timeline_element',
            'ueldo_shortcode_timeline',
            'ueldo_shortcode_two_images_difference',
            'ueldo_shortcode_website_logo'
        ));
    }

   /**
    *
    * get default button url
    *
    */

    function ueldo_get_default_button_url( $page, $title, $target = false ) {

        # get cache option class object
        global $ueldo_cache_option;

        # get blog page permalink
        if( $page == esc_html( __( 'Blog', 'ueldo' ) ) ) $link = get_permalink( $ueldo_cache_option -> get_option( 'page_for_posts' ) );

        # get home page permalink
        else if( $page == esc_html( __( 'Home', 'ueldo' ) ) ) $link = get_permalink( $ueldo_cache_option -> get_option( 'page_on_front' ) );

        # other pages permalinks
        else {

            $page = get_page_by_title( $page );
            $link = $page != null ? get_permalink( $page -> ID ) : '#';
        }

        # return result
        return( 'url:'. rawurlencode( esc_url( $link ) ) .'|title:'. rawurlencode( esc_attr( $title ) ) .'|'. ( $target != false ? 'target:'. rawurlencode( ' '. esc_attr( $target ) ) : '' ) .'|' );
    }

   /**
    *
    * update custom visual composer shortcode settings
    *
    */

    function ueldo_update_custom_vc_shortcode_settings( $array ) {

        # define array positions result
        $array_positions = array();

        # define required variables
        $pos = 0;
        $last_found = 0;

        # walk for each shortcode param
        foreach( $array['params'] as $key => $value ) {

            # is the additional settings found?
            if( strpos( $key, 'ueldo_custom_vc_shortcode_additional_settings_' ) !== false ) {

                # if positions result array is empty, create one
                if( $array_positions == array() && $pos > 0 ) $array_positions = array( array( 'from' => 0, 'length' => $pos ) );
                else {

                    # if we have some space between searched elements
                    if( $pos - ( $last_found + 1 ) > 0 ) {

                        # update positions array
                        $array_positions[] = array(
                            'from' => ( $last_found + 1 ),
                            'length' => ( $pos - ( $last_found + 1 ) )
                        );
                    }
                }

                # add currently found element to array positions
                $array_positions[] = array(
                    'from' => $pos,
                    'length' => 1
                );

                # update the last found element position
                $last_found = $pos;
            }

            # update position in loop
            $pos++;
        }

        # if last found element was not a last in array
        if( ( $last_found + 1 ) < count( $array['params'] ) ) {

            # add the rest of elements
            $array_positions[] = array(
                'from' => $last_found == 0 ? 0 : ( $last_found + 1 ),
                'length' => count( $array['params'] ) - ( $last_found == 0 ? 0 : ( $last_found + 1 ) )
            );
        }

        # prepare the result
        $result = array();

        # divide params array
        foreach( $array_positions as $array_position ) {

            # set the "found" flag
            $found = false;

            # update divided array
            $divided = array_slice( $array['params'], $array_position['from'], $array_position['length'] );

            # walk for each divided array keys
            foreach( $divided as $key => $value ) {

                # is it the additional params array?
                if( strpos( $key, 'ueldo_custom_vc_shortcode_additional_settings_' ) !== false ) {

                    # update the result
                    $result = array_merge( $result, $value );

                    # update "found" flag
                    $found = true;
                }
            }

            # update divided array
            if( $found == false ) $result = array_merge( $result, $divided );
        }

        # update result array
        $array['params'] = $result;

        # return result
        return( $array );
    }

   /**
    *
    * prepare font family array
    *
    */

    function ueldo_vc_get_heading_text_fonts() {

        # default fonts array
        $default_fonts = array(
            esc_html( __( 'General font', 'ueldo' ) ) .' | '. esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'general-font-family' ) ) .', '. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'general-font-weight' ) ) . ( esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'general-font-subset' ) ) != '' ? ', '. esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'general-font-subset' ) ) : '' ) .', '. esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'general-font-smoothing' ) == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) ) => 'general-font',
            esc_html( __( 'Menu font', 'ueldo' ) ) .' | '. esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'menu-font-family' ) ) .', '. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'menu-font-weight' ) ) . ( esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'menu-font-subset' ) ) != '' ? ', '. esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'menu-font-subset' ) ) : '' ) .', '. esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'menu-font-smoothing' ) == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) ) => 'menu-font',
            esc_html( __( 'Default', 'ueldo' ) ) .' | '. esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-font-family' ) ) .', '. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-font-weight' ) ) . ( esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-font-subset' ) ) != '' ? ', '. esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-font-subset' ) ) : '' ) .', '. esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-font-smoothing' ) == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) ) => 'headings-font',
            esc_html( __( 'Default slim', 'ueldo' ) ) .' | '. esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-slim-font-family' ) ) .', '. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-slim-font-weight' ) ) . ( esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-slim-font-subset' ) ) != '' ? ', '. esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-slim-font-subset' ) ) : '' ) .', '. esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-slim-font-smoothing' ) == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) ) => 'headings-slim-font',
            esc_html( __( 'Default bold', 'ueldo' ) ) .' | '. esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-bold-font-family' ) ) .', '. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-bold-font-weight' ) ) . ( esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-bold-font-subset' ) ) != '' ? ', '. esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-bold-font-subset' ) ) : '' ) .', '. esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-bold-font-smoothing' ) == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) ) => 'headings-bold-font',
            esc_html( __( 'Default for heading subtitles', 'ueldo' ) ) .' | '. esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-subtitle-font-family' ) ) .', '. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-subtitle-font-weight' ) ) . ( esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-subtitle-font-subset' ) ) != '' ? ', '. esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-subtitle-font-subset' ) ) : '' ) .', '. esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'headings-subtitle-font-smoothing' ) == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) ) => 'headings-subtitle-font',
            esc_html( __( 'Default for buttons', 'ueldo' ) ) .' | '. esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'buttons-font-family' ) ) .', '. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'buttons-font-weight' ) ) . ( esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'buttons-font-subset' ) ) != '' ? ', '. esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'buttons-font-subset' ) ) : '' ) .', '. esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', 'all', 'buttons-font-smoothing' ) == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) ) => 'buttons-font'
        );

        # do we have other languages set?
        if( ueldo_is_multilingual() ) {

            # get languages list
            $languages_list = ueldo_get_languages_list();

            # there's no languages added?
            if( $languages_list == array() || $languages_list == false || $languages_list == null || !is_array( $languages_list ) ) {

                # get default fonts array
                $fonts = $default_fonts;
            }

            # we have languages added
            else {

                # define fonts array
                $fonts = array();

                # walk for each language
                foreach( $languages_list as $language ) {

                    # prepare language key
                    $lang_key = strtolower( $language );

                    # update fonts array - default general font
                    $fonts[esc_html( __( 'General font', 'ueldo' ) ) .' ('. esc_html( ueldo_get_language_name( $language ) ) .') | '. esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'general-font-family' ) ) .', '. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'general-font-weight' ) ) . ( esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'general-font-subset' ) ) != '' ? ', '. esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'general-font-subset' ) ) : '' ) .', '. esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'general-font-smoothing' ) == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) )] = 'general-font-'. esc_attr( $lang_key );

                    # update fonts array - default menu font
                    $fonts[esc_html( __( 'Menu font', 'ueldo' ) ) .' ('. esc_html( ueldo_get_language_name( $language ) ) .') | '. esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'menu-font-family' ) ) .', '. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'menu-font-weight' ) ) . ( esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'menu-font-subset' ) ) != '' ? ', '. esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'menu-font-subset' ) ) : '' ) .', '. esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'menu-font-smoothing' ) == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) )] = 'menu-font-'. esc_attr( $lang_key );

                    # update fonts array - default heading font
                    $fonts[esc_html( __( 'Default', 'ueldo' ) ) .' ('. esc_html( ueldo_get_language_name( $language ) ) .') | '. esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-font-family' ) ) .', '. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-font-weight' ) ) . ( esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-font-subset' ) ) != '' ? ', '. esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-font-subset' ) ) : '' ) .', '. esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-font-smoothing' ) == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) )] = 'headings-font-'. esc_attr( $lang_key );

                    # update fonts array - default heading font slim
                    $fonts[esc_html( __( 'Default slim', 'ueldo' ) ) .' ('. esc_html( ueldo_get_language_name( $language ) ) .') | '. esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-slim-font-family' ) ) .', '. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-slim-font-weight' ) ) . ( esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-slim-font-subset' ) ) != '' ? ', '. esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-slim-font-subset' ) ) : '' ) .', '. esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-slim-font-smoothing' ) == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) )] = 'headings-slim-font-'. esc_attr( $lang_key );

                    # update fonts array - default heading font bold
                    $fonts[esc_html( __( 'Default bold', 'ueldo' ) ) .' ('. esc_html( ueldo_get_language_name( $language ) ) .') | '. esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-bold-font-family' ) ) .', '. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-bold-font-weight' ) ) . ( esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-bold-font-subset' ) ) != '' ? ', '. esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-bold-font-subset' ) ) : '' ) .', '. esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-bold-font-smoothing' ) == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) )] = 'headings-bold-font-'. esc_attr( $lang_key );

                    # update fonts array - default heading subtitles font
                    $fonts[esc_html( __( 'Default for heading subtitles', 'ueldo' ) ) .' ('. esc_html( ueldo_get_language_name( $language ) ) .') | '. esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-subtitle-font-family' ) ) .', '. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-subtitle-font-weight' ) ) . ( esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-subtitle-font-subset' ) ) != '' ? ', '. esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-subtitle-font-subset' ) ) : '' ) .', '. esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'headings-subtitle-font-smoothing' ) == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) )] = 'headings-subtitle-font-'. esc_attr( $lang_key );

                    # update fonts array - default buttons font
                    $fonts[esc_html( __( 'Default for buttons', 'ueldo' ) ) .' ('. esc_html( ueldo_get_language_name( $language ) ) .') | '. esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'buttons-font-family' ) ) .', '. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'buttons-font-weight' ) ) . ( esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'buttons-font-subset' ) ) != '' ? ', '. esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'buttons-font-subset' ) ) : '' ) .', '. esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), 'buttons-font-smoothing' ) == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) )] = 'buttons-font-'. esc_attr( $lang_key );
                }
            }
        }

        # website is not multilingual, get default fonts
        else {

            # get default fonts array
            $fonts = $default_fonts;
        }

        # get next font id, configured in theme options for heading vc shortcode
        $next_font_id = ueldo_get_theme_options_value( 'visual-composer-custom-fonts', false, 'next-font-id' );

        # do we have any font added?
        if( $next_font_id !== '1' ) {

            # walk for each custom fonts
            for( $i = 1; $i < $next_font_id; $i++ ) {

                # font data
                $font = array(
                    'family' => ueldo_get_theme_options_value( 'visual-composer-custom-fonts', false, 'font-'. esc_attr( $i ) .'-family' ),
                    'weight' => ueldo_get_theme_options_value( 'visual-composer-custom-fonts', false, 'font-'. esc_attr( $i ) .'-weight' ),
                    'subset' => ueldo_get_theme_options_value( 'visual-composer-custom-fonts', false, 'font-'. esc_attr( $i ) .'-subset' ),
                    'smoothing' => ueldo_get_theme_options_value( 'visual-composer-custom-fonts', false, 'font-'. esc_attr( $i ) .'-smoothing' )
                );

                # do we have the font set?
                if( $font['family'] != false && $font['weight'] != false ) {

                    # update fonts array
                    $fonts[esc_html( __( 'VC Custom font', 'ueldo' ) ) .' | '. esc_html( __( 'Family:', 'ueldo' ) ) .' '. esc_html( $font['family'] ) .', '. esc_html( __( 'Weight:', 'ueldo' ) ) .' '. esc_html( $font['weight'] ) . ( esc_html( $font['subset'] ) != '' ? ', '. esc_html( __( 'Subset:', 'ueldo' ) ) .' '. esc_html( $font['subset'] ) : '' ) .', '. esc_html( __( 'Smoothing:', 'ueldo' ) ) .' '. esc_html( $font['smoothing'] == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) )] = esc_html( $font['family'] ) .','. esc_html( $font['weight'] );
                }
            }
        }

        # return result
        return( $fonts );
    }

   /**
    *
    * is correct icon font?
    *
    */

    function ueldo_is_correct_icon_font( $font ) {

        # global variables
        global $ueldo_cache_option;

        # default icons array
        $icons = array(
            'fontawesome',
            'openiconic',
            'typicons',
            'entypo',
            'linecons',
            'monosocial',
            'material'
        );

        # get custom icons libraries
        if( ueldo_plugin_is_any_custom_icon_added() ) {

            # get all custom icon fonts
            $icon_fonts = $ueldo_cache_option -> get_option( 'ueldo_custom_icons' );

            # do we have custom icons added?
            if( $icon_fonts != false ) {

                # walk for each custom icons
                foreach( $icon_fonts as $icon_font ) {

                    # update icon fonts array
                    $icons[] = $icon_font['unique_key'];
                }
            }
        }

        # return result
        return( in_array( $font, $icons, true ) );
    }

   /**
    *
    * custom visual composer settings which
    * can be used for more than one shortcode
    *
    */

    function ueldo_add_custom_vc_shortcode_settings( $type, $slug = '', $slug_text = '', $dependency = array(), $group = false ) {

        # get cache option global variable
        global $ueldo_cache_option;

        # read the type
        switch( $type ) {

            # class name
            case 'class-name':

                return( array(
                    'type' => 'hidden',
                    'param_name' => 'class_name',
                    'std' => 'ueldo_vc_element_'. str_replace( '.', '', microtime( true ) ),
                    'group' => $group
                ));

            break;

            # icons
            case 'icons':

                # result icons array
                $result = array(
                    array(
                        'type' => 'dropdown',
                        'heading' => esc_html( $slug_text ) .' '. esc_html( __( 'library', 'ueldo' ) ),
                        'param_name' => esc_attr( $slug .'library' ),
                        'value' => array(
                            esc_html( __( 'Font Awesome', 'ueldo' ) ) => 'fontawesome',
                            esc_html( __( 'Open Iconic', 'ueldo' ) ) => 'openiconic',
                            esc_html( __( 'Typicons', 'ueldo' ) ) => 'typicons',
                            esc_html( __( 'Entypo', 'ueldo' ) ) => 'entypo',
                            esc_html( __( 'Linecons', 'ueldo' ) ) => 'linecons',
                            esc_html( __( 'Mono Social', 'ueldo' ) ) => 'monosocial',
                            esc_html( __( 'Material', 'ueldo' ) ) => 'material'
                        ),
                        'dependency' => $dependency,
                        'std' => 'fontawesome',
                        'group' => esc_attr( $group != false ? $group : '' )
                    ),
                    array(
                        'type' => 'iconpicker',
                        'heading' => esc_html( $slug_text ),
                        'param_name' => esc_attr( $slug .'fontawesome' ),
                        'settings' => array(
                            'empty' => false,
                            'type' => 'fontawesome'
                        ),
                        'dependency' => array(
                            'element' => esc_attr( $slug .'library' ),
                            'value' => 'fontawesome'
                        ),
                        'std' => 'fa fa-long-arrow-right',
                        'group' => esc_attr( $group != false ? $group : '' )
                    ),
                    array(
                        'type' => 'iconpicker',
                        'heading' => esc_html( $slug_text ),
                        'param_name' => esc_attr( $slug .'openiconic' ),
                        'settings' => array(
                            'empty' => false,
                            'type' => 'openiconic'
                        ),
                        'dependency' => array(
                            'element' => esc_attr( $slug .'library' ),
                            'value' => 'openiconic'
                        ),
                        'std' => 'vc-oi vc-oi-dial',
                        'group' => esc_attr( $group != false ? $group : '' )
                    ),
                    array(
                        'type' => 'iconpicker',
                        'heading' => esc_html( $slug_text ),
                        'param_name' => esc_attr( $slug .'typicons' ),
                        'settings' => array(
                            'empty' => false,
                            'type' => 'typicons'
                        ),
                        'dependency' => array(
                            'element' => esc_attr( $slug .'library' ),
                            'value' => 'typicons'
                        ),
                        'std' => 'typcn typcn-adjust-brightness',
                        'group' => esc_attr( $group != false ? $group : '' )
                    ),
                    array(
                        'type' => 'iconpicker',
                        'heading' => esc_html( $slug_text ),
                        'param_name' => esc_attr( $slug .'entypo' ),
                        'settings' => array(
                            'empty' => false,
                            'type' => 'entypo'
                        ),
                        'dependency' => array(
                            'element' => esc_attr( $slug .'library' ),
                            'value' => 'entypo'
                        ),
                        'std' => 'entypo-icon entypo-icon-note',
                        'group' => esc_attr( $group != false ? $group : '' )
                    ),
                    array(
                        'type' => 'iconpicker',
                        'heading' => esc_html( $slug_text ),
                        'param_name' => esc_attr( $slug .'linecons' ),
                        'settings' => array(
                            'empty' => false,
                            'type' => 'linecons'
                        ),
                        'dependency' => array(
                            'element' => esc_attr( $slug .'library' ),
                            'value' => 'linecons'
                        ),
                        'std' => 'vc_li vc_li-heart',
                        'group' => esc_attr( $group != false ? $group : '' )
                    ),
                    array(
                        'type' => 'iconpicker',
                        'heading' => esc_html( $slug_text ),
                        'param_name' => esc_attr( $slug .'monosocial' ),
                        'settings' => array(
                            'empty' => false,
                            'type' => 'monosocial'
                        ),
                        'dependency' => array(
                            'element' => esc_attr( $slug .'library' ),
                            'value' => 'monosocial'
                        ),
                        'std' => 'vc-mono vc-mono-fivehundredpx',
                        'group' => esc_attr( $group != false ? $group : '' )
                    ),
                    array(
                        'type' => 'iconpicker',
                        'heading' => esc_html( $slug_text ),
                        'param_name' => esc_attr( $slug .'material' ),
                        'settings' => array(
                            'empty' => false,
                            'type' => 'material'
                        ),
                        'dependency' => array(
                            'element' => esc_attr( $slug .'library' ),
                            'value' => 'material'
                        ),
                        'std' => 'vc-material vc-material-account_balance',
                        'group' => esc_attr( $group != false ? $group : '' )
                    )
                );

                # get custom icons libraries
                if( ueldo_plugin_is_any_custom_icon_added() ) {

                    # get all custom icon fonts
                    $icon_fonts = $ueldo_cache_option -> get_option( 'ueldo_custom_icons' );

                    # do we have custom icons added?
                    if( $icon_fonts != false ) {

                        # walk for each custom icons
                        foreach( $icon_fonts as $icon_font ) {

                            # update result icons array
                            $result[] = array(
                                'type' => 'iconpicker',
                                'heading' => esc_html( $slug_text ),
                                'param_name' => esc_attr( $slug . $icon_font['unique_key'] ),
                                'settings' => array(
                                    'empty' => false,
                                    'type' => $icon_font['unique_key']
                                ),
                                'dependency' => array(
                                    'element' => esc_attr( $slug .'library' ),
                                    'value' => $icon_font['unique_key']
                                ),
                                'std' => $icon_font['icons'][0],
                                'group' => esc_attr( $group != false ? $group : '' )
                            );

                            # update icons list array
                            $result[0]['value'][esc_html( $icon_font['name'] )] = $icon_font['unique_key'];
                        }
                    }
                }

                # return result
                return( $result );

            break;
        }
    }

   /**
    *
    * add custom icons to visual composer iconpicker
    *
    */

    if( ueldo_plugin_is_any_custom_icon_added() ) {

        # get all custom icon fonts
        $icon_fonts = $ueldo_cache_option -> get_option( 'ueldo_custom_icons' );

        # do we have custom icons added?
        if( $icon_fonts != false ) {

            # walk for each custom icons
            foreach( $icon_fonts as $icon_font ) {

                # add filter
                add_filter( 'vc_iconpicker-type-'. esc_attr( $icon_font['unique_key'] ), array( 'ueldo_plugin_add_vc_icon_library', esc_attr( $icon_font['unique_key'] ) ) );
            }
        }

        # remove temporary variables
        unset( $icon_fonts, $icon_font );
    }

   /**
    *
    * array of available intervals
    *
    */

    function ueldo_get_vc_loop_option_intervals( $max = false ) {

        # basement value
        $base = 1;

        # results array
        $result = array();

        # loop
        for( $i = 1; $i < ( $max !== false ? $max : 61 ); $i++ ) {

            # base value
            $base_val = ( $base * $i ) .'000';

            # update results array
            $result[esc_attr( ( $base * $i ) .' ' ) . esc_html( __( 'sec.', 'ueldo' ) )] = esc_attr( $base_val );
        }

        # return result
        return( $result );
    }

   /**
    *
    * array of available image positions
    *
    */

    function ueldo_get_vc_loop_option_percents( $decimals = false ) {

        # results array
        $result = array();

        # loop 0 - 100
        for( $i = 0; $i < 101; $i++ ) {

            # update results array
            $result[] = $i .'%';

            # can we add decimals?
            if( $decimals == true ) {

                # loop 1 - 9
                for( $j = 1; $j < 10; $j++ ) {

                    # update results array
                    $result[] = $i .'.'. $j .'0%';
                }
            }
        }

        # return result
        return( $result );
    }

   /**
    *
    * array of possible z-index values
    *
    */

    function ueldo_get_vc_z_index_options() {

        # results array
        $result = array();

        # default value
        $value = -1;

        # loop for getting all possible values
        while( $value != 310 ) {

            if( $value < 20 ) { $result[] = $value; $value += 1; }
            if( $value >= 20 && $value < 310 ) { $result[] = $value; $value += 10; }
        }

        # return result
        return( $result );
    }

   /**
    *
    * array of possible rotate (deg) values
    *
    */

    function ueldo_get_rotate_deg_options() {

        # results array
        $result = array();

        # loop 0 - 100
        for( $i = 0; $i < 361; $i++ ) {

            # update results array
            $result[] = $i .'deg';
        }

        # return result
        return( $result );
    }

   /**
    *
    * array of available revolution slider sliders
    *
    */

    function ueldo_get_vc_loop_revolution_slider_sliders() {

        # is revolution slider active?
        if( !ueldo_plugins::is_active_plugin( 'revolution-slider' ) ) return( array( esc_html( __( 'Revolution Slider is not activated.', 'ueldo' ) ) => 'none' ) );

        # create new revolution slider object
        $revslider = new RevSlider();

        # get all sliders
        $sliders = $revslider -> getAllSliderForAdminMenu();

        # do we have sliders?
        if( !is_array( $sliders ) || $sliders == array() ) return( array() );

        # prepare the result array
        $result = array();

        # walk for each slider
        foreach( $sliders as $single_slider ) {

            # update result array
            $result[esc_attr($single_slider['title'])] = $single_slider['alias'];
        }

        # return result
        return( $result );
    }

   /**
    *
    * get array of google maps configured in theme options page
    *
    */

    function ueldo_get_vc_loop_google_maps() {

        # prepare results array
        $result = array();

        # get next map id
        $next_map_id = ueldo_get_theme_options_value( 'google-maps', false, 'next-map-id' );

        # do we have maps added?
        if( $next_map_id != '1' ) {

            # walk for each map
            for( $i = 0; $i < $next_map_id; $i++ ) {

                # do we have the map?
                if( ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $i ) .'-title' ) !== false ) {

                    # add option
                    $result[esc_html( ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $i ) .'-title' ) .' ('. esc_html( __( 'ID:', 'ueldo' ) ) .' '. esc_attr( $i ) .')' )] = $i;
                }
            }
        }

        # still empty?
        if( $result == array() ) $result[esc_html( __( 'Not found any Google map - please go to Ueldo Theme Options page and create map first.', 'ueldo' ) )] = 'none';

        # return result
        return( $result );
    }

   /**
    *
    * get filters from all filter masonry cells
    *
    */

    function ueldo_vc_get_filter_masonry_cells_filters( $content ) {

        # get custom shortcodes from content
        $shortcodes = ueldo_vc_find_custom_shortcodes( $content );

        # do we have any shortcode added?
        if( $shortcodes == false ) return( false );

        # filter categories array
        $filter_categories = array();

        # walk for each filtered masonry cell
        foreach( $shortcodes as $shortcode ) {

            # is it filtered masonry cell?
            if( $shortcode['key'] != 'ueldo_shortcode_filtered_masonry_cell' ) continue;

            # do we have filter category set?
            if( !empty( $shortcode['atts']['filter_category'] ) ) {

                # explode filter category
                $filter_categories_exploded = explode( ',', $shortcode['atts']['filter_category'] );

                # do we have one filter category?
                if( count( $filter_categories_exploded ) == 1 ) {

                    # do we have this filter category already added?
                    if( !in_array( trim( sanitize_title( $filter_categories_exploded[0] ) ), $filter_categories, true ) ) {

                        # update filter categories array
                        $filter_categories[trim( sanitize_title( $filter_categories_exploded[0] ) )] = $filter_categories_exploded[0];
                    }
                }

                else {

                    # walk for each exploded filter category
                    foreach( $filter_categories_exploded as $single_filter_category ) {

                        # do we have this filter category already added?
                        if( !in_array( trim( sanitize_title( $single_filter_category ) ), $filter_categories, true ) ) {

                            # update filter categories array
                            $filter_categories[trim( sanitize_title( $single_filter_category ) )] = $single_filter_category;
                        }
                    }
                }
            }

            # default filter category
            else {

                # update filter categories array
                $filter_categories[trim( sanitize_title( esc_html( __( 'Photography', 'ueldo' ) ) ) )] = esc_html( __( 'Photography', 'ueldo' ) );
            }
        }

        # return result
        return( $filter_categories == array() ? false : $filter_categories );
    }

   /**
    *
    * get opening hours statuses array
    *
    */

    function ueldo_get_opening_hours_statuses_array() {

        # prepare results array
        $result = array(
            esc_html( __( 'Do not use any opening hours status.', 'ueldo' ) ) => 'none'
        );

        # get next opening hours status id
        $next_status_id = ueldo_get_theme_options_value( 'opening-hours-status', false, 'next-status-id' );

        # do we have maps added?
        if( $next_status_id > 1 ) {

            # walk for each map
            for( $i = 0; $i < $next_status_id; $i++ ) {

                # status title
                $status_title = ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $i ) .'-title' );

                # do we have the map?
                if( $status_title !== false ) {

                    # update results array
                    $result[esc_html( $status_title ) .' ('. esc_html( __( 'ID:', 'ueldo' ) ) .' '. esc_attr( $i ) .')'] = esc_attr( $i );
                }
            }
        }

        # return result
        return( $result );
    }

   /**
    *
    * get pages array
    *
    */

    function ueldo_vc_get_pages_array() {

        # pages list
        $pages_list = get_pages();

        # prepare result array
        $result = array();

        # walk for each page
        foreach( $pages_list as $page ) {

            # update result with page data
            $result[esc_attr( $page -> post_title )] = esc_attr( $page -> ID );
        }

        # return result
        return( $result );
    }

   /**
    *
    * get posts array
    *
    */

    function ueldo_vc_get_posts_array() {

        # posts list
        $posts_list = get_posts( array( 'posts_per_page' => '-1' ) );

        # prepare result array
        $result = array();

        # walk for each page
        foreach( $posts_list as $post ) {

            # update result with post data
            $result[esc_attr( $post -> post_title )] = esc_attr( $post -> ID );
        }

        # return result
        return( $result );
    }

   /**
    *
    * get posts categories array
    *
    */

    function ueldo_vc_get_posts_categories_array() {

        # get categories
        $categories_list = get_categories();

        # prepare result array
        $result = array();

        # walk for each category
        foreach( $categories_list as $category ) {

            # update result with post data
            $result[esc_attr( $category -> name )] = esc_attr( $category -> term_id );
        }

        # return result
        return( $result );
    }

   /**
    *
    * get posts tags array
    *
    */

    function ueldo_vc_get_posts_tags_array() {

        # get tags
        $tags_list = get_tags();

        # prepare result array
        $result = array();

        # walk for each category
        foreach( $tags_list as $tag ) {

            # update result with post data
            $result[esc_attr( $tag -> name )] = esc_attr( $tag -> term_id );
        }

        # return result
        return( $result );
    }

   /**
    *
    * get visual composer icon fonts array
    *
    */

    function ueldo_get_vc_iconfonts_array() {

        # return result
        return( array(
            array( 'key' => 'vc_openiconic', 'url' => vc_asset_url( 'css/lib/vc-open-iconic/vc_openiconic.min.css' ), 'ver' => WPB_VC_VERSION ),
            array( 'key' => 'vc_typicons', 'url' => vc_asset_url( 'css/lib/typicons/src/font/typicons.min.css' ), 'ver' => WPB_VC_VERSION ),
            array( 'key' => 'vc_entypo', 'url' => vc_asset_url( 'css/lib/vc-entypo/vc_entypo.min.css' ), 'ver' => WPB_VC_VERSION ),
            array( 'key' => 'vc_linecons', 'url' => vc_asset_url( 'css/lib/vc-linecons/vc_linecons_icons.min.css' ), 'ver' => WPB_VC_VERSION ),
            array( 'key' => 'vc_monosocial', 'url' => vc_asset_url( 'css/lib/monosocialiconsfont/monosocialiconsfont.min.css' ), 'ver' => WPB_VC_VERSION ),
            array( 'key' => 'vc_material', 'url' => vc_asset_url( 'css/lib/vc-material/vc_material.min.css' ), 'ver' => WPB_VC_VERSION )
        ));
    }

   /**
    *
    * register icon fonts from visual composer
    *
    */

    add_action( 'vc_base_register_front_css', 'ueldo_register_vc_iconfonts' );
    function ueldo_register_vc_iconfonts() {

        # walk for each vc iconfonts array
        foreach( ueldo_get_vc_iconfonts_array() as $iconfont ) {

            # enqueue style
            wp_enqueue_style( esc_attr( $iconfont['key'] ), esc_attr( $iconfont['url'] ), array(), esc_attr( $iconfont['ver'] ) );
        }
    }

   /**
    *
    * get custom font family attributes
    *
    */

    function ueldo_vc_get_custom_font_family_attributes( $font_family, $default_font_family ) {

        # define default result array
        $result = array(
            'font-family' => ueldo_get_theme_options_value( 'fonts', 'all', esc_attr( $default_font_family .'-family' ) ),
            'font-weight' => ueldo_get_theme_options_value( 'fonts', 'all', esc_attr( $default_font_family .'-weight' ) ),
            '-webkit-font-smoothing' => ueldo_get_theme_options_value( 'fonts', 'all', esc_attr( $default_font_family .'-smoothing' ) ) == 'yes' ? 'antialiased' : 'auto',
            '-moz-osx-font-smoothing' => ueldo_get_theme_options_value( 'fonts', 'all', esc_attr( $default_font_family .'-smoothing' ) ) == 'yes' ? 'grayscale' : 'auto'
        );

        # font family
        if( $font_family !== false && !empty( $font_family ) ) {

            # one of custom fonts
            if( strpos( $font_family, ',' ) !== false ) {

                # divide font family and font weight
                $font_data = explode( ',', $font_family );

                # get next visual composer headings fonts id
                $next_font_id = ueldo_get_theme_options_value( 'visual-composer-custom-fonts', false, 'next-font-id' );

                # is any font added?
                if( $next_font_id !== '1' ) {

                    # check if selected font exists
                    for( $i = 1; $i < $next_font_id; $i++ ) {

                        # compare font family
                        if( ueldo_get_theme_options_value( 'visual-composer-custom-fonts', false, 'font-'. esc_attr( $i ) .'-family' ) == $font_data[0] ) {

                            # compare font weight
                            if( ueldo_get_theme_options_value( 'visual-composer-custom-fonts', false, 'font-'. esc_attr( $i ) .'-weight' ) == $font_data[1] ) {

                                # update font family
                                $result['font-family'] = $font_data[0];

                                # update font weight
                                $result['font-weight'] = $font_data[1];

                                # update font smoothing
                                $result['-webkit-font-smoothing'] = ueldo_get_theme_options_value( 'visual-composer-custom-fonts', false, 'font-'. esc_attr( $i ) .'-smoothing' ) == 'yes' ? 'antialiased' : 'auto';

                                # update font smoothing
                                $result['-moz-osx-font-smoothing'] = ueldo_get_theme_options_value( 'visual-composer-custom-fonts', false, 'font-'. esc_attr( $i ) .'-smoothing' ) == 'yes' ? 'grayscale' : 'auto';

                                # break the loop
                                break;
                            }
                        }
                    }
                }
            }

            # one of default fonts
            else {

                # default fonts keys
                $font_keys = array(
                    'general-font',
                    'menu-font',
                    'headings-font',
                    'headings-slim-font',
                    'headings-bold-font',
                    'headings-subtitle-font',
                    'buttons-font'
                );

                # get defaults
                if( in_array( $font_family, $font_keys ) ) {

                    # update font family
                    $result['font-family'] = ueldo_get_theme_options_value( 'fonts', 'all', esc_attr( $font_family .'-family' ) );

                    # update font weight
                    $result['font-weight'] = ueldo_get_theme_options_value( 'fonts', 'all', esc_attr( $font_family .'-weight' ) );

                    # update smoothing option
                    $result['-webkit-font-smoothing'] = ueldo_get_theme_options_value( 'fonts', 'all', esc_attr( $font_family .'-smoothing' ) ) == 'yes' ? 'antialiased' : 'auto';

                    # update smoothing option
                    $result['-moz-osx-font-smoothing'] = ueldo_get_theme_options_value( 'fonts', 'all', esc_attr( $font_family .'-smoothing' ) ) == 'yes' ? 'grayscale' : 'auto';
                }

                # get multilingual font
                else {

                    # walk for each default fonts keys
                    foreach( $font_keys as $font_key ) {

                        # is font key found?
                        if( strpos( $font_family, $font_key ) !== false ) {

                            # get the language key
                            $lang_key = ueldo_get_origin_language_locale( str_replace( $font_key .'-', '', $font_family ) );

                            # is lang key found?
                            if( $lang_key !== false ) {

                                # update font family
                                $result['font-family'] = ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), esc_attr( $font_key .'-family' ) );

                                # update font weight
                                $result['font-weight'] = ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), esc_attr( $font_key .'-weight' ) );

                                # update font smoothing
                                $result['-webkit-font-smoothing'] = ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), esc_attr( $font_key .'-smoothing' ) ) == 'yes' ? 'antialiased' : 'auto';

                                # update font smoothing
                                $result['-moz-osx-font-smoothing'] = ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), esc_attr( $font_key .'-smoothing' ) ) == 'yes' ? 'grayscale' : 'auto';

                                # break the loop
                                break;
                            }
                        }
                    }
                }
            }
        }

        # add "font-style" data
        $result['font-style'] = strpos( $result['font-weight'], 'italic' ) !== false ? 'italic' : 'normal';

        # replace "regular" or "italic" to "normal"
        if( $result['font-weight'] == 'regular' || $result['font-weight'] == 'italic' ) $result['font-weight'] = 'normal';

        # remove "italic" from number value
        if( strpos( $result['font-weight'], 'italic' ) !== false ) $result['font-weight'] = str_replace( 'italic', '', $result['font-weight'] );

        # return result
        return( $result );
    }

   /**
    *
    * find custom shortcodes from visual composer content
    *
    */

    function ueldo_vc_find_custom_shortcodes( $content ) {

        # define result array
        $result = array();

        # shortcodes without content
        $no_content_shortcodes = array(
            'ueldo_shortcode_card_layer',
            'ueldo_shortcode_delimiter',
            'ueldo_shortcode_form',
            'ueldo_shortcode_gap',
            'ueldo_shortcode_google_map',
            'ueldo_shortcode_header_menu',
            'ueldo_shortcode_heading_text',
            'ueldo_shortcode_icon',
            'ueldo_shortcode_image',
            'ueldo_shortcode_languages_switcher',
            'ueldo_shortcode_opening_hours_box_element',
            'ueldo_shortcode_opening_hours_status',
            'ueldo_shortcode_post_page_box',
            'ueldo_shortcode_price_single',
            'ueldo_shortcode_pricing_list_attribute',
            'ueldo_shortcode_progress_bar',
            'ueldo_shortcode_row_layer',
            'ueldo_shortcode_search_field',
            'ueldo_shortcode_two_images_difference',
            'ueldo_shortcode_website_logo'
        );

        # remove space at the begin of attribute
        $content = str_replace( '=" ', '="', $content );

        # walk for each shortcode key
        foreach( ueldo_get_all_custom_vc_shortcodes_array() as $key ) {

            /**
             *
             * find a shortcode with attributes
             *
             */

             # get key positions
             $positions = ueldo_strpos_all( $content, esc_html( '['. $key .' ' ) );

             # is key found in content?
             if( $positions !== false ) {

                 # walk for each position
                 foreach( $positions as $position ) {

                     # get a content from shortcode
                     $shortcode = substr( $content, $position );

                     # end a shortcode with "]" char
                     $shortcode = substr( $shortcode, 0, ( strpos( $shortcode, ']' ) + 1 ) );

                     # if it is not a content shortcode
                     if( in_array( $key, $no_content_shortcodes ) ) {

                         # full shortcode is as same as shortcode begin
                         $shortcode_full = $shortcode;
                     }

                     # get a full shortcode content
                     else {

                         # get full shortcode content
                         $shortcode_full = ueldo_get_full_shortcode( $content, $key, $position );
                     }

                     # prepare shortcode attributes array
                     $atts = array();

                     # walk for each attribute
                     foreach( explode( '" ', str_replace( '['. $key .' ', '', $shortcode ) ) as $attr ) {

                         # divide attribute key and value
                         $attr = explode( '="', $attr );

                         # update shortcode attributes array
                         if( !empty( $attr[0] ) && $attr[0] != ']' ) $atts[$attr[0]] = str_replace( '"]', '', isset( $attr[1] ) ? $attr[1] : '' );
                     }

                     # update results array
                     $result[] = array(
                         'key' => $key,
                         'shortcode' => $shortcode,
                         'shortcode-full' => $shortcode_full,
                         'atts' => $atts
                     );
                 }
             }

            /**
             *
             * find a shortcode without attributes
             *
             */

             # get key positions
             $positions = ueldo_strpos_all( $content, esc_html( '['. $key .']' ) );

             # is key found in content?
             if( $positions !== false ) {

                 # walk for each position
                 foreach( $positions as $position ) {

                     # get a content from shortcode
                     $shortcode = substr( $content, $position );

                     # end the shortcode
                     $shortcode = substr( $shortcode, 0, strlen( '['. $key .']' ) );

                     # if it is not a content shortcode
                     if( in_array( $key, $no_content_shortcodes ) ) {

                         # full shortcode is as same as shortcode begin
                         $shortcode_full = $shortcode;
                     }

                     # get a full shortcode content
                     else {

                         # get full shortcode content
                         $shortcode_full = ueldo_get_full_shortcode( $content, $key, $position );
                     }

                     # update results array
                     $result[] = array(
                         'key' => $key,
                         'shortcode' => $shortcode,
                         'shortcode-full' => $shortcode_full,
                         'atts' => array()
                     );
                 }
             }

            /**
             *
             * end of loop.
             *
             */
        }

        # return result
        return( $result == array() ? false : $result );
    }

   /**
    *
    * get full shortcode code
    *
    */

    function ueldo_get_full_shortcode( $content, $key, $position ) {

        # get shortcode base
        $base = substr( $content, $position );

        # get all beginnings of selected shortcode
        $begins_with_atts = ueldo_strpos_all( $base, esc_html( '['. $key .' ' ) );
        $begins_without_atts = ueldo_strpos_all( $base, esc_html( '['. $key .']' ) );

        # create one array from all beginnings
        $starts = array_merge( is_array( $begins_with_atts ) ? $begins_with_atts : array(), is_array( $begins_without_atts ) ? $begins_without_atts : array() );

        # create one array of all ends
        $ends = ueldo_strpos_all( $base, esc_html( '[/'. $key .']' ) );

        # walk for each endings
        for( $i = 0; $i < count( $ends ); $i++ ) {

            # if there's no more starts, or end is smaller then next start - we have the result
            if( !isset( $starts[$i + 1] ) || $ends[$i] < $starts[$i + 1] ) {

                # return result
                return( substr( $base, 0, $ends[$i] + ( strlen( esc_html( '['. $key .']' ) ) + 1 ) ) );
            }
        }
    }

   /**
    *
    * display custom visual composer styles on website
    *
    */

    add_action( 'wp_enqueue_scripts', 'ueldo_display_custom_vc_shortcodes_styles' );
    function ueldo_display_custom_vc_shortcodes_styles() {

        # we should get styles from cache?
        if( ueldo_dynamic_theme_styles_cache::can_generate() == false ) {

            # do we have styles for this page?
            if( ueldo_dynamic_theme_styles_cache::are_styles_cached() == true ) {

                # end of the function.
                return( true );
            }
        }

        # get post global variable
        global $post;

        # get the language key
        $lang_key = ueldo_get_current_language_key();

        # 404 page?
        if( is_404() || $post == null ) {

            # get global cache object
            global $ueldo_cache_option;

            # get 404 page id
            $page_404 = ueldo_get_theme_options_value( '404-page-id', esc_attr( $lang_key ) );

            # update post array
            $post = $ueldo_cache_option -> get_post( $page_404 );
        }

        # define temporary variable
        $temp = array(
            'page-content' => false,
            'under-blog-post' => is_single() ? ueldo_find_custom_vc_shortcodes_styles( ueldo_get_custom_code_elements_under_single_blog_post_content() ) : false,
            'header-content' => ueldo_get_header_contents_styles( 'main' ),
            'second-header-content' => ueldo_get_header_contents_styles( 'additional' ),
            'footer-content' => ueldo_get_footer_contents_styles(),
            'extras-contents' => ueldo_get_extras_contents_styles(),
            'side-menu-additional-content-before-menu' => ueldo_find_custom_vc_shortcodes_styles( ueldo_get_theme_options_value( 'side-menu', 'ueldo_theme_options_side_menu_additional_content_before_'. strtolower( esc_attr( $lang_key ) ) ) ),
            'side-menu-additional-content-after-menu' => ueldo_find_custom_vc_shortcodes_styles( ueldo_get_theme_options_value( 'side-menu', 'ueldo_theme_options_side_menu_additional_content_after_'. strtolower( esc_attr( $lang_key ) ) ) ),
            '404-page-custom-vc-css' => false
        );

        # do we have post content?
        if( $post != null ) {

            # update temporary variable
            $temp['page-content'] = ueldo_find_custom_vc_shortcodes_styles( $post -> post_content );

            # find custom vc css code
            $vc_css = ueldo_get_custom_css_code( $post -> post_content );

            # find custom vc css code
            $temp['404-page-custom-vc-css'] = empty( $vc_css ) ? false : $vc_css;

            # remove temporary variable
            unset( $vc_css );
        }

        # do we have any content set?
        if( ueldo_all_false( $temp ) ) {

            # can we save styles in cache?
            if( ueldo_dynamic_theme_styles_cache::can_save() == true ) {

                # save styles in cache
                ueldo_dynamic_theme_styles_cache::save_style_in_cache( 'vc', '' );

                # end of the function
                return( true );
            }
        }

        else {

            # prepare the css
            $css_styles = ueldo_minify_css( join( ' ', $temp ) );

            # can we save styles in cache?
            if( ueldo_dynamic_theme_styles_cache::can_save() == true ) {

                # save styles in cache
                ueldo_dynamic_theme_styles_cache::save_style_in_cache( 'vc', $css_styles );

                # end of the function
                return( true );
            }

            # cache disabled - display inline styles
            wp_add_inline_style( 'ueldo-visual-composer-stylesheet', $css_styles );

            # remove temporary variable
            unset( $temp, $css_styles );

            # return
            return( true );
        }

        # return
        return( true );
    }

   /**
    *
    * get tabs data
    *
    */

    function ueldo_vc_get_tabs_shortcodes_data( $content ) {

        # get tab slug class object
        global $ueldo_vc_shortcode_unique_tabs_slugs;

        # clear tabs slugs array
        $ueldo_vc_shortcode_unique_tabs_slugs -> clear_tabs_slugs_array();

        # get custom shortcodes from content
        $shortcodes = ueldo_vc_find_custom_shortcodes( $content );

        # there's no any shortcodes?
        if( $shortcodes == false ) return( false );

        # default icon values
        $defaults = array(
            'single_tab_title' => esc_html( __( '15 years of experience', 'ueldo' ) ),
            'icon_library' => 'fontawesome',
            'icon_fontawesome' => 'fa fa-long-arrow-right',
            'icon_openiconic' => 'vc_icon_element-icon vc-oi vc-oi-dial',
            'icon_typicons' => 'typcn typcn-adjust-brightness',
            'icon_entypo' => 'entypo-icon entypo-icon-note',
            'icon_linecons' => 'vc_li vc_li-heart',
            'icon_monosocial' => 'vc-mono vc-mono-fivehundredpx',
            'icon_material' => 'vc-material vc-material-account_balance',
        );

        # results array
        $results = array();

        # walk for each shortcodes
        foreach( $shortcodes as $shortcode ) {

            # is it single tab shortcode?
            if( $shortcode['key'] == 'ueldo_shortcode_tabs_single_tab' ) {

                # get icon library
                $icon_library = isset( $shortcode['atts']['icon_library'] ) && !empty( $shortcode['atts']['icon_library'] ) ? $shortcode['atts']['icon_library'] : $defaults['icon_library'];

                # get icon
                $icon = !ueldo_is_correct_icon_font( $icon_library ) ? $defaults['icon_fontawesome'] : ueldo_get_icon_class_from_shortcode_tabs_attributes( $shortcode['atts'], $icon_library, $defaults );

                # get title
                $title = isset( $shortcode['atts']['single_tab_title'] ) ? $shortcode['atts']['single_tab_title'] : $defaults['single_tab_title'];

                # get color
                $color = isset( $shortcode['atts']['custom_icon_color_enabled'] ) && $shortcode['atts']['custom_icon_color_enabled'] == 'custom_settings' ? ( isset( $shortcode['atts']['icon_color'] ) && !empty( $shortcode['atts']['icon_color'] ) ? $shortcode['atts']['icon_color'] : false ) : false;

                # create result array
                $result = array(
                    'icon' => esc_attr( $icon ),
                    'title' => esc_html( $title ),
                    'slug' => esc_attr( $ueldo_vc_shortcode_unique_tabs_slugs -> get_tab_slug( empty( $title ) ? 'single-tab' : $title ) )
                );

                # if we have custom color, add class name to results array
                if( $color !== false ) $result['class'] = isset( $shortcode['atts']['class_name'] ) && !empty( $shortcode['atts']['class_name'] ) ? $shortcode['atts']['class_name'] : '';

                # update results array
                $results[] = $result;

                # remove temporary variables
                unset( $result );
            }

            # remove temporary variables
            unset( $icon_library, $icon, $title, $color );
        }

        # return result
        return( $results == array() ? false : $results );
    }

   /**
    *
    * get icon class from shortcode attributes
    *
    */

    function ueldo_get_icon_class_from_shortcode_tabs_attributes( $atts, $icon_library, $defaults ) {

        # switch the icon library
        switch( $icon_library ) {

            case 'fontawesome': return( $defaults['icon_fontawesome'] );
            case 'openiconic': return( $defaults['icon_openiconic'] );
            case 'typicons': return( $defaults['icon_typicons'] );
            case 'entypo': return( $defaults['icon_entypo'] );
            case 'linecons': return( $defaults['icon_linecons'] );
            case 'monosocial': return( $defaults['icon_monosocial'] );
            case 'material': return( $defaults['icon_material'] );
            default: return( ueldo_get_custom_icon( $atts, 'icon_' ) );
        }
    }

   /**
    *
    * display tabs selector
    *
    */

    function ueldo_shortcode_tabs_display_tabs_selector( $tabs, $selector_style, $selector_position = 'horizontal' ) {

        # only one tab?
        if( count( $tabs ) === 1 ) return;

        # selector style is "03"?
        if( $selector_style == 'style-03' && $selector_position == 'horizontal' ) {

            ?>
            <div class="ueldo-shortcode-tabs-selector-container">
            <?php
        }

        ?>
        <ul class="ueldo-shortcode-tabs-selector ueldo-shortcode-tabs-selector-<?php echo esc_attr( str_replace( 'style-', '', $selector_style ) ); ?>" data-tabs-selector-style="<?php echo esc_attr( $selector_position ); ?>">

            <?php

                # first tab flag
                $is_first = true;

                # tab no.
                $tab_no = 1;

                # walk for each tab
                foreach( $tabs as $tab ) {

                    ?>
                    <li class="<?php echo esc_attr( $is_first == true ? 'ueldo-shortcode-tabs-selector-single-tab-active' : '' ); echo isset( $tab['class'] ) && !empty( $tab['class'] ) ? ' '. esc_attr( $tab['class'] ) : ''; ?>" data-tab-slug="<?php echo esc_attr( $tab['slug'] ); ?>" data-tab-no="<?php echo esc_attr( $tab_no ); ?>">

                        <i class="<?php echo esc_attr( $tab['icon'] ); ?>"></i>
                        <?php if( !empty( $tab['title'] ) ) { ?><span class="ueldo-shortcode-tabs-selector-single-tab-title"><?php echo esc_html( $tab['title'] ); ?></span><?php } ?>

                    </li>
                    <?php

                    # update first tab flag
                    $is_first = false;

                    # update tab no.
                    $tab_no += 1;
                }

            ?>

        </ul>
        <?php

        # selector style is "03"?
        if( $selector_style == 'style-03' && $selector_position == 'horizontal' ) {

            ?>
            </div>
            <?php
        }
    }

   /**
    *
    * display circle navigation
    *
    */

    function ueldo_shortcode_tabs_display_circle_navigation( $tabs, $alignment = 'center' ) {

        # only one tab?
        if( count( $tabs ) === 1 ) return;

        # define element class
        $class = 'ueldo-circle-navigation';

        # update element class by alignment option
        switch( $alignment ) {

            case 'left': $class .= ' ueldo-circle-navigation-alignment-left'; break;
            case 'center': $class .= ' ueldo-circle-navigation-alignment-center'; break;
            case 'right': $class .= ' ueldo-circle-navigation-alignment-right'; break;
        }

        ?>
        <ul class="<?php echo esc_attr( $class ); ?>">

            <?php

                # first tab flag
                $is_first = true;

                # walk for each tab
                foreach( $tabs as $tab ) {

                    ?>
                    <li>

                        <span class="ueldo-circle-navigation-element <?php echo esc_attr( $is_first == true ? 'ueldo-circle-navigation-element-active' : '' ); ?>" data-tab-slug="<?php echo esc_attr( $tab['slug'] ); ?>"></span>

                    </li>
                    <?php

                    # update first tab flag
                    $is_first = false;
                }

            ?>

        </ul>
        <?php
    }

   /**
    *
    * display content inside images container
    *
    */

    function ueldo_shortcode_tabs_display_content_inside_images_container( $atts, $content ) {

        # get tab slug class object
        global $ueldo_vc_shortcode_unique_tabs_slugs;

        # clear tabs slugs array
        $ueldo_vc_shortcode_unique_tabs_slugs -> clear_tabs_slugs_array();

        # custom tab image enabled?
        $custom_tab_image_enabled = isset( $atts['custom_tab_image_enabled'] ) ? $atts['custom_tab_image_enabled'] : 'no';

        ?>
        <div class="ueldo-shortcode-tabs-single-tabs-images-container" data-custom-tab-image="<?php echo esc_attr( $custom_tab_image_enabled ); ?>">

            <?php

                # can single tab have own image?
                if( $custom_tab_image_enabled == 'no' ) ueldo_shortcode_tabs_get_content_inside_image_container( $atts );
                else {

                    # get custom shortcodes
                    $shortcodes = ueldo_vc_find_custom_shortcodes( $content );

                    # "is first" flag
                    $is_first = true;

                    # walk for each found shortcode
                    foreach( $shortcodes as $shortcode ) {

                        # it's not single tab details shortcode?
                        if( $shortcode['key'] != 'ueldo_shortcode_tabs_single_tab' ) continue;

                        # get tab slug
                        $tab_slug = $ueldo_vc_shortcode_unique_tabs_slugs -> get_tab_slug( isset( $shortcode['atts']['single_tab_title'] ) ? $shortcode['atts']['single_tab_title'] : esc_html( __( '15 years of experience', 'ueldo' ) ) );

                        ?>
                        <div class="ueldo-shortcode-tabs-single-tabs-images-single-tab-image-content" data-tab-slug="<?php echo esc_attr( $tab_slug ); ?>" data-visible="<?php echo esc_attr( $is_first == true ? 'yes' : 'no' ); ?>">

                            <?php

                                # display image content
                                ueldo_shortcode_tabs_get_content_inside_image_container( $shortcode['atts'] );

                            ?>

                        </div>
                        <?php

                        # update "is first" flag
                        $is_first = false;
                    }
                }

            ?>

        </div>
        <?php
    }

   /**
    *
    * display image content for tabs
    *
    */

    function ueldo_shortcode_tabs_get_content_inside_image_container( $atts ) {

        # extract shortcode arguments
        extract( shortcode_atts( array(
           'image_content_type' => 'background-image',
           'image' => esc_url( get_template_directory_uri() .'/_assets/_img/image.png' ),
           'image_position_y' => '50%',
           'image_position_x' => '50%',
           'image_alt' => esc_html( __( 'Image', 'ueldo' ) ),
           'video_url' => '',
           'video_title' => esc_html( __( 'Watch the video!', 'ueldo' ) ),
           'revolution_slider_alias' => '',
           'google_map_id' => ''
        ), $atts ));

        # read the content type to display
        switch( $image_content_type ) {

            # background image
            case 'background-image':

                # display image
                ueldo_display_image_for_parent( ueldo_get_image_src( $image ), $image_alt, $image_position_x, $image_position_y );

            break;

            # background image with video button
            case 'background-image-with-video-button':

                # display image
                ueldo_display_image_for_parent( ueldo_get_image_src( $image ), $image_alt, $image_position_x, $image_position_y );

                # do we have a video url?
                if( !empty( $video_url ) ) {

                    ?>
                    <div class="ueldo-play-video-button" data-video-url="<?php echo esc_url( $video_url ); ?>">

                        <div class="ueldo-play-video-button-middle">

                            <div class="ueldo-play-video-button-icon"><i class="fa fa-play"></i></div>
                            <?php if( !empty( $video_title ) ) { ?><div class="ueldo-play-video-button-title"><?php echo esc_attr( $video_title ); ?></div><?php } ?>

                        </div>

                    </div>
                    <?php
                }

            break;

            # revolution slider
            case 'revolution-slider':

                # do we have the slider alias?
                if( !empty( $revolution_slider_alias ) && ueldo_plugins::is_active_plugin( 'revolution-slider' ) ) {

                    # put revolution slider
                    putRevSlider( $revolution_slider_alias );
                }

            break;

            # google map
            case 'google-map':

                # do we have the map?
                if( $google_map_id == 'none' || empty( $google_map_id ) || ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-title' ) == false ) break;

                # get map data
                $map_data = array(
                    'lat' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-center-lat' ),
                    'lng' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-center-lng' ),
                    'zoom' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-zoom' ),
                    'next-marker-id' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-next-marker-id' ),
                    'custom-style' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-custom-style' )
                );

                ?>
                <div class="ueldo-google-map-container">

                    <div class="ueldo-google-map-data" data-lat="<?php echo esc_attr( $map_data['lat'] ); ?>" data-lng="<?php echo esc_attr( $map_data['lng'] ); ?>" data-zoom-level="<?php echo esc_attr( $map_data['zoom'] ); ?>">
                    </div>

                    <?php

                        # do we have map markers added?
                        if( $map_data['next-marker-id'] != '1' ) {

                            # walk for each map marker
                            for( $i = 1; $i < $map_data['next-marker-id']; $i++ ) {

                                # marker exists?
                                if( ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-marker-'. esc_attr( $i ) .'-title' ) == false ) continue;

                                # get marker data
                                $marker_data = array(
                                    'lat' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-marker-'. esc_attr( $i ) .'-lat' ),
                                    'lng' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-marker-'. esc_attr( $i ) .'-lng' ),
                                    'use-custom-marker' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-marker-'. esc_attr( $i ) .'-use-custom-marker' ),
                                    'custom-icon-library' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon-library' ),
                                    'custom-icon' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon' ),
                                    'custom-marker-image' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-marker-image' )
                                );

                                ?>
                                <span class="ueldo-google-map-marker-data" data-lat="<?php echo esc_attr( $marker_data['lat'] ); ?>" data-lng="<?php echo esc_attr( $marker_data['lng'] ); ?>" data-use-custom-marker="<?php echo esc_attr( $marker_data['use-custom-marker'] ); ?>">

                                    <?php

                                        # what do we need to display?
                                        switch( $marker_data['use-custom-marker'] ) {

                                            # can we display custom icon?
                                            case 'yes-icon':

                                                ?>
                                                <span class="ueldo-google-map-marker-content-custom-<?php echo esc_attr( $google_map_id ); ?>-<?php echo esc_attr( esc_attr( $i ) ); ?>">

                                                    <i class="<?php echo esc_attr( $marker_data['custom-icon'] ); ?>"></i>

                                                </span>
                                                <?php

                                            break;

                                            # can we display custom image?
                                            case 'yes-image':

                                                ?>
                                                <span class="ueldo-google-map-marker-content-custom-<?php echo esc_attr( $google_map_id ); ?>-<?php echo esc_attr( esc_attr( $i ) ); ?>">

                                                    <img src="<?php echo esc_attr( $marker_data['custom-marker-image'] ); ?>" />

                                                </span>
                                                <?php

                                            break;
                                        }

                                    ?>

                                </span>
                                <?php

                                # clear marker data
                                $marker_data = false;
                            }
                        }

                        # do we have custom map style added?
                        if( !empty( $map_data['custom-style'] ) && json_decode( html_entity_decode( $map_data['custom-style'] ) ) != null ) {

                            ?>
                            <span class="ueldo-google-map-custom-style-data"><?php echo html_entity_decode( $map_data['custom-style'] ); ?></span>
                            <?php
                        }

                    ?>

                </div>
                <?php

                # clear map data
                $map_data = false;

            break;
        }
    }

   /**
    *
    * display clients logos loop for full-width testimonials shortcode
    *
    */

    function ueldo_shortcode_full_width_testimonials_display_clients_logos_loop( $content, $content_position, $animation_style, $first_after_last ) {

        ?>
        <div class="ueldo-shortcode-full-width-testimonials-clients-logos" data-loop-style="<?php echo esc_attr( $animation_style ); ?>" data-content-position="<?php echo esc_attr( $content_position ); ?>" data-loop-first-after-last="<?php echo esc_attr( $first_after_last ); ?>">

            <div class="ueldo-shortcode-full-width-testimonials-clients-logos-loop">

                <?php

                    # testimonials counter
                    $testimonial_id = 1;

                    # get all single testimonials attributes
                    $shortcodes = ueldo_vc_find_custom_shortcodes( $content );

                    # walk for each found shortcodes
                    foreach( $shortcodes as $shortcode ) {

                        # is it single testimonial content?
                        if( $shortcode['key'] == 'ueldo_shortcode_full_width_testimonials_single_testimonial' ) {

                            ?>
                            <div class="ueldo-shortcode-full-width-testimonials-clients-logos-single-client <?php echo esc_attr( $shortcode['atts']['class_name'] ) ?>" data-active="<?php echo esc_attr( $testimonial_id == 1 ? 'yes' : 'no' ); ?>" data-testimonial-id="<?php echo esc_attr( $testimonial_id ); ?>" data-different-image-on-hover="<?php echo esc_attr( isset( $shortcode['atts']['other_image_on_hover'] ) && $shortcode['atts']['other_image_on_hover'] == 'yes' ? 'yes' : 'no' ); ?>">

                                <?php

                                    # can we display separate image on hover?
                                    if( ( isset( $shortcode['atts']['other_image_on_hover'] ) && $shortcode['atts']['other_image_on_hover'] == 'yes' ) ) {

                                        # get hover image data
                                        $image = array(
                                            'image_src' => isset( $shortcode['atts']['hover_image'] ) ? ueldo_get_image_src( $shortcode['atts']['hover_image'] ) : esc_url( get_template_directory_uri() .'/_assets/_img/image.png' ),
                                            'image_alt' => isset( $shortcode['atts']['hover_image_alt'] ) ? $shortcode['atts']['hover_image_alt'] : esc_html( __( 'Image', 'ueldo' ) )
                                        );

                                        ?>
                                        <div class="ueldo-shortcode-full-width-testimonials-clients-logos-single-client-image-hover">

                                            <div class="ueldo-shortcode-full-width-testimonials-clients-logos-single-client-image-middle-helper">
                                            </div>

                                            <img src="<?php echo esc_url( $image['image_src'] ); ?>" alt="<?php echo esc_html( $image['image_alt'] ); ?>" <?php echo ueldo_retina_ready_attr(); ?> />

                                        </div>
                                        <?php
                                    }

                                    # get image data
                                    $image = array(
                                        'image_src' => isset( $shortcode['atts']['image'] ) ? ueldo_get_image_src( $shortcode['atts']['image'] ) : esc_url( get_template_directory_uri() .'/_assets/_img/image.png' ),
                                        'image_alt' => isset( $shortcode['atts']['image_alt'] ) ? $shortcode['atts']['image_alt'] : esc_html( __( 'Image', 'ueldo' ) )
                                    );

                                ?>

                                <div class="ueldo-shortcode-full-width-testimonials-clients-logos-single-client-image">

                                    <div class="ueldo-shortcode-full-width-testimonials-clients-logos-single-client-image-middle-helper">
                                    </div>

                                    <img src="<?php echo esc_url( $image['image_src'] ); ?>" alt="<?php echo esc_html( $image['image_alt'] ); ?>" <?php echo ueldo_retina_ready_attr(); ?> />

                                </div>

                            </div>
                            <?php

                            # update testimonial id
                            $testimonial_id += 1;
                        }
                    }

                ?>

            </div>

        </div>
        <?php
    }

   /**
    *
    * display clients images loop for full-width testimonials shortcode
    *
    */

    function ueldo_shortcode_full_width_testimonials_display_clients_images_loop( $content, $first_after_last ) {

        ?>
        <div class="ueldo-shortcode-full-width-testimonials-clients-images" data-loop-first-after-last="<?php echo esc_attr( $first_after_last ); ?>">

            <div class="ueldo-shortcode-full-width-testimonials-clients-images-loop">

                <div class="ueldo-shortcode-full-width-testimonials-clients-images-loop-middle-helper">
                </div>

                <?php

                    # testimonials counter
                    $testimonial_id = 1;

                    # get all single testimonials attributes
                    $shortcodes = ueldo_vc_find_custom_shortcodes( $content );

                    # walk for each found shortcodes
                    foreach( $shortcodes as $shortcode ) {

                        # is it single testimonial content?
                        if( $shortcode['key'] == 'ueldo_shortcode_full_width_testimonials_single_testimonial' ) {

                            ?>
                            <div class="ueldo-shortcode-full-width-testimonials-clients-images-single-client-container <?php echo esc_attr( $shortcode['atts']['class_name'] ) ?>">

                                <div class="ueldo-shortcode-full-width-testimonials-clients-images-single-client" data-active="<?php echo esc_attr( $testimonial_id == 1 ? 'yes' : 'no' ); ?>" data-testimonial-id="<?php echo esc_attr( $testimonial_id ); ?>" data-different-image-on-hover="<?php echo esc_attr( isset( $shortcode['atts']['other_image_on_hover'] ) && $shortcode['atts']['other_image_on_hover'] == 'yes' ? 'yes' : 'no' ); ?>">

                                    <?php

                                        # can we display separate image on hover?
                                        if( ( isset( $shortcode['atts']['other_image_on_hover'] ) && $shortcode['atts']['other_image_on_hover'] == 'yes' ) && ( isset( $shortcode['atts']['hover_image'] ) && $shortcode['atts']['hover_image'] != '' ) ) {

                                            # get hover image data
                                            $image = array(
                                                'image_src' => ueldo_get_image_src( $shortcode['atts']['hover_image'] ),
                                                'image_alt' => isset( $shortcode['atts']['hover_image_alt'] ) ? $shortcode['atts']['hover_image_alt'] : esc_html( __( 'Image', 'ueldo' ) ),
                                                'image_position_y' => isset( $shortcode['atts']['hover_image_position_y'] ) ? $shortcode['atts']['hover_image_position_y'] : '50%',
                                                'image_position_x' => isset( $shortcode['atts']['hover_image_position_x'] ) ? $shortcode['atts']['hover_image_position_x'] : '50%'
                                            );

                                            ?>
                                            <div class="ueldo-shortcode-full-width-testimonials-clients-images-single-client-image-hover">

                                                <?php

                                                    # display image
                                                    ueldo_display_image_for_parent( $image['image_src'], $image['image_alt'], $image['image_position_x'], $image['image_position_y'] );

                                                ?>

                                            </div>
                                            <?php
                                        }

                                        # get image data
                                        $image = array(
                                            'image_src' => isset( $shortcode['atts']['image'] ) ? ueldo_get_image_src( $shortcode['atts']['image'] ) : esc_url( get_template_directory_uri() .'/_assets/_img/image.png' ),
                                            'image_alt' => isset( $shortcode['atts']['image_alt'] ) ? $shortcode['atts']['image_alt'] : esc_html( __( 'Image', 'ueldo' ) ),
                                            'image_position_y' => isset( $shortcode['atts']['image_position_y'] ) ? $shortcode['atts']['image_position_y'] : '50%',
                                            'image_position_x' => isset( $shortcode['atts']['image_position_x'] ) ? $shortcode['atts']['image_position_x'] : '50%'
                                        );

                                    ?>

                                    <div class="ueldo-shortcode-full-width-testimonials-clients-images-single-client-image">

                                        <?php

                                            # display image
                                            ueldo_display_image_for_parent( $image['image_src'], $image['image_alt'], $image['image_position_x'], $image['image_position_y'] );

                                        ?>

                                    </div>

                                </div>

                            </div>
                            <?php

                            # update testimonial id
                            $testimonial_id += 1;
                        }
                    }

                ?>

            </div>

        </div>
        <?php
    }

   /**
    *
    * display testimonial authors full-width testimonials shortcode
    *
    */

    function ueldo_shortcode_full_width_testimonials_display_testimonial_authors( $content, $author_name_position, $content_position ) {

        ?>
        <div class="ueldo-shortcode-full-width-testimonials-single-testimonial-authors" data-author-name-position="<?php echo esc_attr( $author_name_position ); ?>" data-content-position="<?php echo esc_attr( $content_position ); ?>">

            <?php

                # testimonials counter
                $testimonial_id = 1;

                # get all single testimonials attributes
                $shortcodes = ueldo_vc_find_custom_shortcodes( $content );

                # walk for each found shortcodes
                foreach( $shortcodes as $shortcode ) {

                    # is it single testimonial content?
                    if( $shortcode['key'] == 'ueldo_shortcode_full_width_testimonials_single_testimonial' ) {

                        ?>
                        <div class="ueldo-shortcode-full-width-testimonials-single-testimonial-author" data-active="<?php echo esc_attr( $testimonial_id == 1 ? 'yes' : 'no' ); ?>" data-testimonial-id="<?php echo esc_attr( $testimonial_id ); ?>">

                            <?php

                                # extract shortcode arguments
                                extract( shortcode_atts( array(
                                   'author_name' => esc_html( __( 'John Doe', 'ueldo' ) ),
                                   'author_description' => esc_html( __( 'Regular customer', 'ueldo' ) )
                                ), $shortcode['atts'] ));

                                # do we have author name?
                                if( !empty( $author_name ) ) {

                                    ?>
                                    <p class="ueldo-shortcode-full-width-testimonials-single-testimonial-author-name"><?php echo esc_html( $author_name ); ?></p>
                                    <?php
                                }

                                # do we have author description?
                                if( !empty( $author_description ) ) {

                                    ?>
                                    <p><?php echo esc_html( $author_description ); ?></p>
                                    <?php
                                }

                                # clear temporary variables
                                unset( $author_name, $author_description );

                            ?>

                        </div>
                        <?php
                    }

                    # update testimonial id
                    $testimonial_id += 1;
                }

            ?>

        </div>
        <?php
    }

   /**
    *
    * check if opening hours status exists
    *
    */

    function ueldo_check_if_opening_hours_status_data_exists( $status_id ) {

        # get status title
        $status_title = ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-title' );

        # return result
        return( $status_title == false ? false : true );
    }

   /**
    *
    * display opening hours status data
    *
    */

    function ueldo_display_opening_hours_status_data( $status_id ) {

        # status title
        $status_data['title'] = ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-title' );

        # do we have the status?
        if( $status_data['title'] !== false ) {

            # update status data array
            $status_data['timezone'] = ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-timezone' );
            $status_data['rules-next-rule-id'] = ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-next-rule-id' );
            $status_data['exceptions-next-exception-id'] = ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-next-exception-id' );

            ?>
            <span class="ueldo-shortcode-opening-hours-status-timezone" data-use-browser-time="<?php echo esc_attr( $status_data['timezone'] == 'use-browser' ? 'yes' : 'no' ); ?>"></span>
            <?php

            # do we have to use timezone time?
            if( $status_data['timezone'] != 'use-browser' ) {

                # get current time with timezone option
                $date = new DateTime( 'now', new DateTimeZone( esc_attr( $status_data['timezone'] ) ) );

                ?>
                <span class="ueldo-shortcode-opening-hours-status-time" data-hour="<?php echo esc_attr( $date -> format( 'H' ) ); ?>" data-minutes="<?php echo esc_attr( $date -> format( 'i' ) ); ?>" data-weekday="<?php echo esc_attr( strtolower( $date -> format( 'l' ) ) ); ?>" data-date="<?php echo esc_attr( $date -> format( 'Y-m-d' ) ); ?>"></span>
                <?php

                # remove temporary variable
                unset( $date );
            }

            # do we have rules added?
            if( $status_data['rules-next-rule-id'] > 1 ) {

                # walk for each rule
                for( $i = 0; $i < $status_data['rules-next-rule-id']; $i++ ) {

                    # do we have rule added?
                    if( ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-title' ) != false ) {

                        # get rule data array
                        $rule_data = array(
                            'all-day-closed' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-all-day-closed' ),
                            'next-opening-hours-id' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-next-opening-hours-id' ),
                            'apply-for-monday' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-apply-for-monday' ) == 'on' ? 'yes' : 'no',
                            'apply-for-tuesday' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-apply-for-tuesday' ) == 'on' ? 'yes' : 'no',
                            'apply-for-wednesday' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-apply-for-wednesday' ) == 'on' ? 'yes' : 'no',
                            'apply-for-thursday' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-apply-for-thursday' ) == 'on' ? 'yes' : 'no',
                            'apply-for-friday' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-apply-for-friday' ) == 'on' ? 'yes' : 'no',
                            'apply-for-saturday' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-apply-for-saturday' ) == 'on' ? 'yes' : 'no',
                            'apply-for-sunday' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-apply-for-sunday' ) == 'on' ? 'yes' : 'no'
                        );

                        # all day closed?
                        if( $rule_data['all-day-closed'] == 'yes' ) {

                            ?>
                            <span class="ueldo-shortcode-opening-hours-status-rule" data-type="closed" data-apply-for-monday="<?php echo esc_attr( $rule_data['apply-for-monday'] ); ?>" data-apply-for-tuesday="<?php echo esc_attr( $rule_data['apply-for-tuesday'] ); ?>" data-apply-for-wednesday="<?php echo esc_attr( $rule_data['apply-for-wednesday'] ); ?>" data-apply-for-thursday="<?php echo esc_attr( $rule_data['apply-for-thursday'] ); ?>" data-apply-for-friday="<?php echo esc_attr( $rule_data['apply-for-friday'] ); ?>" data-apply-for-saturday="<?php echo esc_attr( $rule_data['apply-for-saturday'] ); ?>" data-apply-for-sunday="<?php echo esc_attr( $rule_data['apply-for-sunday'] ); ?>"></span>
                            <?php
                        }

                        # get rules
                        else {

                            ?>
                            <span class="ueldo-shortcode-opening-hours-status-rule" data-type="open" data-apply-for-monday="<?php echo esc_attr( $rule_data['apply-for-monday'] ); ?>" data-apply-for-tuesday="<?php echo esc_attr( $rule_data['apply-for-tuesday'] ); ?>" data-apply-for-wednesday="<?php echo esc_attr( $rule_data['apply-for-wednesday'] ); ?>" data-apply-for-thursday="<?php echo esc_attr( $rule_data['apply-for-thursday'] ); ?>" data-apply-for-friday="<?php echo esc_attr( $rule_data['apply-for-friday'] ); ?>" data-apply-for-saturday="<?php echo esc_attr( $rule_data['apply-for-saturday'] ); ?>" data-apply-for-sunday="<?php echo esc_attr( $rule_data['apply-for-sunday'] ); ?>">
                            <?php

                            # walk for each opening hours
                            for( $j = 0; $j < $rule_data['next-opening-hours-id']; $j++ ) {

                                # ignored?
                                if( ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-ignored' ) == 'no' ) {

                                    # opening hour set data
                                    $opening_hours_set = array(
                                        'from-hour' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-from-hour' ),
                                        'from-minutes' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-from-minutes' ),
                                        'to-hour' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-to-hour' ),
                                        'to-minutes' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-to-minutes' )
                                    );

                                    ?>
                                    <span class="ueldo-shortcode-opening-hours-status-rule-opening-hours-set" data-from-hour="<?php echo esc_attr( $opening_hours_set['from-hour'] ); ?>" data-from-minutes="<?php echo esc_attr( $opening_hours_set['from-minutes'] ); ?>" data-to-hour="<?php echo esc_attr( $opening_hours_set['to-hour'] ); ?>" data-to-minutes="<?php echo esc_attr( $opening_hours_set['to-minutes'] ); ?>"></span>
                                    <?php
                                }
                            }

                            ?>
                            </span>
                            <?php

                        # end of rule opening hours
                        }

                    # end of rule
                    }

                # end of rules loop
                }

            # end of rules
            }

            # do we have exceptions added?
            if( $status_data['exceptions-next-exception-id'] > 1 ) {

                # walk for each rule
                for( $i = 0; $i < $status_data['exceptions-next-exception-id']; $i++ ) {

                    # do we have exception added?
                    if( ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-ignored' ) == 'no' ) {

                        # get exception data array
                        $exception_data = array(
                            'all-day-closed' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-all-day-closed' ),
                            'next-opening-hours-id' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-next-opening-hours-id' ),
                            'apply-from' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-apply-from' ),
                            'apply-to' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-apply-to' )
                        );

                        # all day closed?
                        if( $exception_data['all-day-closed'] == 'yes' ) {

                            ?>
                            <span class="ueldo-shortcode-opening-hours-status-exception" data-type="closed" data-apply-from="<?php echo esc_attr( $exception_data['apply-from'] ); ?>" data-apply-to="<?php echo esc_attr( $exception_data['apply-to'] ); ?>"></span>
                            <?php
                        }

                        # get exception rules
                        else {

                            ?>
                            <span class="ueldo-shortcode-opening-hours-status-exception" data-type="open" data-apply-from="<?php echo esc_attr( $exception_data['apply-from'] ); ?>" data-apply-to="<?php echo esc_attr( $exception_data['apply-to'] ); ?>">
                            <?php

                            # walk for each opening hours
                            for( $j = 0; $j < $exception_data['next-opening-hours-id']; $j++ ) {

                                # opening hour set data
                                $opening_hours_set = array(
                                    'from-hour' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-from-hour' ),
                                    'from-minutes' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-from-minutes' ),
                                    'to-hour' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-to-hour' ),
                                    'to-minutes' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-to-minutes' )
                                );

                                # do we have opening hour set?
                                if( $opening_hours_set['from-hour'] !== false ) {

                                    ?>
                                    <span class="ueldo-shortcode-opening-hours-status-rule-opening-hours-set" data-from-hour="<?php echo esc_attr( $opening_hours_set['from-hour'] ); ?>" data-from-minutes="<?php echo esc_attr( $opening_hours_set['from-minutes'] ); ?>" data-to-hour="<?php echo esc_attr( $opening_hours_set['to-hour'] ); ?>" data-to-minutes="<?php echo esc_attr( $opening_hours_set['to-minutes'] ); ?>"></span>
                                    <?php
                                }
                            }

                            ?>
                            </span>
                            <?php

                        # end of exception rules
                        }

                    # end of exception
                    }

                # end of exceptions loop
                }

            # end of exceptions
            }

        # end of status data
        }
    }

   /**
    *
    * display opening hours box heading
    *
    */

    function ueldo_display_opening_hours_box_heading( $heading_position, $box_title, $display_opening_hours_status, $opening_hours_status_position, $status, $status_dot_position, $text_when_open, $text_when_closed ) {

        # opening hours status visible?
        $opening_hours_status_visible = $display_opening_hours_status == 'yes' && $status != 'none' && ueldo_check_if_opening_hours_status_data_exists( $status ) == true;

        ?>
        <div class="ueldo-shortcode-opening-hours-box-heading ueldo-shortcode-opening-hours-box-heading-position-<?php echo esc_attr( $heading_position ); ?>">

            <?php

                # display heading title on left side
                if( $opening_hours_status_visible == false || ( $opening_hours_status_visible == true && $opening_hours_status_position == 'right' ) ) {

                    ?>
                    <span class="ueldo-shortcode-opening-hours-box-heading-title <?php echo esc_attr( $opening_hours_status_visible == false ? 'ueldo-shortcode-opening-hours-box-heading-title-full-width' : '' ); ?>"><?php echo esc_html( $box_title ); ?></span>
                    <?php
                }

                # can we display opening hours status?
                if( $opening_hours_status_visible == true ) {

                    ?>
                    <div class="ueldo-shortcode-opening-hours-heading-container-for-status ueldo-shortcode-opening-hours-heading-container-for-status-position-<?php echo esc_attr( $opening_hours_status_position ); ?>">

                        <div class="ueldo-shortcode-opening-hours-status ueldo-shortcode-opening-hours-status-dot-position-<?php echo esc_attr( $status_dot_position ); ?>">

                            <div class="ueldo-shortcode-opening-hours-status-content" data-for-status="open">

                                <p><?php echo esc_html( $text_when_open ); ?></p>

                            </div>

                            <div class="ueldo-shortcode-opening-hours-status-content" data-for-status="closed">

                                <p><?php echo esc_html( $text_when_closed ); ?></p>

                            </div>

                            <?php

                                # display opening hours status data
                                ueldo_display_opening_hours_status_data( $status );

                            ?>

                        </div>

                    </div>
                    <?php

                    # display heading title on right side
                    if( $opening_hours_status_position == 'left' ) {

                        ?>
                        <span class="ueldo-shortcode-opening-hours-box-heading-title ueldo-shortcode-opening-hours-box-heading-title-position-right"><?php echo esc_html( $box_title ); ?></span>
                        <?php
                    }
                }

            ?>

        </div>
        <?php
    }

   /**
    *
    * display heading text content
    *
    */

    function ueldo_display_heading_text_content( $type, $text, $counter_value, $counter_duration ) {

        # switch by heading content type
        switch( $type ) {

            case 'custom_text': echo esc_html( $text ); break;
            case 'archive_title': echo get_the_archive_title(); break;
            case 'search_query': echo get_search_query(); break;
            case 'counter': ?><span class="ueldo-shortcode-heading-text-counter" data-counter-duration="<?php echo esc_attr( $counter_duration ); ?>" data-animation-done="no"><?php echo esc_html( $counter_value ); ?></span><?php break;
        }

        # end of the function
        return( true );
    }

   /**
    *
    * remove duplicated class names for custom vc elements
    *
    */

    add_filter( 'wp_insert_post_data', 'ueldo_vc_filter_post_data', '99', 2 );
    function ueldo_vc_filter_post_data( $data, $postarr = array() ) {

        # post content
        $content = $data['post_content'];

        # find duplocated classes
        $classes = ueldo_find_duplicated_class_names_in_vc_shortcodes( $content );

        # do we have duplicated classes?
        if( $classes != false ) {

            # walk for each founded classes
            foreach( $classes['details'] as $class => $class_data ) {

                # is it duplicated class?
                if( $class_data['count'] != '1' ) {

                    # do the content replacement for each duplicate
                    for( $i = 0; $i < $class_data['count']; $i++ ) {

                        # get unique class
                        $unique_class = ueldo_get_unique_class_for_custom_vc_element( $classes['classes'], strlen( str_replace( 'ueldo_vc_element_', '', $class ) ) );

                        # update classes array to avoid unique classes duplications
                        $classes['classes'][] = $unique_class;

                        # replacement
                        $content = substr_replace( $content, $unique_class, $class_data['positions'][$i], strlen( $class ) );
                    }
                }
            }

            # update content in post data
            $data['post_content'] = $content;
        }

        # return updated post data
        return( $data );
    }

   /**
    *
    * find duplicated class names in custom vc shortcodes
    *
    */

    function ueldo_find_duplicated_class_names_in_vc_shortcodes( $content ) {

        # get all class names positions from post content
        $classes_pos = ueldo_strpos_all( $content, 'ueldo_vc_element_' );

        # prepare classes array
        $classes = array();

        # do we have it?
        if( $classes_pos !== false ) {

            # walk for each position
            foreach( $classes_pos as $position ) {

                # start from class begin
                $class = substr( $content, $position );

                # end with class end
                $class = substr( $class, 0, strpos( $class, '"' ) );

                # remove unwanted chars
                $class = str_replace( '\\', '', $class );

                # do we have a duplicate?
                if( isset( $classes['details'][$class] ) ) {

                    # update classes array
                    $classes['details'][$class]['count']++;
                    $classes['details'][$class]['positions'][] = $position;
                }

                # new class
                else {

                    # update classes array
                    $classes['details'][$class] = array(
                        'count' => 1,
                        'positions' => array(
                            $position
                        )
                    );

                    # add class to all classes list
                    $classes['classes'][] = $class;
                }
            }
        }

        # return result
        return( $classes == array() ? false : $classes );
    }

   /**
    *
    * get unique class name
    *
    */

    function ueldo_get_unique_class_for_custom_vc_element( $classes, $length ) {

        # prepare min and max value
        $min = '1';
        $max = '9';

        # loop for the id length
        for( $i = 0; $i < ( $length - 1 ); $i++ ) {

            # update min value
            $min .= '0';

            # update max value
            $max .= '9';
        }

        # too short class id length?
        if( $length === 1 && count( $classes ) >= 10 ) return( 'ueldo_vc_element_x' );
        else if( $length === 2 && count( $classes ) >= 100 ) return( 'ueldo_vc_element_xx' );

        # get unique id
        do { $class = 'ueldo_vc_element_'. mt_rand( ( int ) $min, ( int ) $max ); } while( in_array( $class, $classes, true ) );

        # return result
        return( $class );
    }

   /**
    *
    * custom visual composer param for box-shadow settings
    *
    */

    vc_add_shortcode_param( 'ueldo_box_shadow_horizontal_length', 'ueldo_box_shadow_horizontal_length_field', get_template_directory_uri() .'/_assets/_js/vc-params.js' );
    function ueldo_box_shadow_horizontal_length_field( $settings, $value ) {

        # return field html
        return '<span>'. esc_html( __( 'Horizontal length', 'ueldo' ) ) .'</span><div class="ueldo-box-shadow-field-container"><input name="'. esc_attr( $settings['param_name'] ) .'" class="wpb_vc_param_value wpb-textinput '. esc_attr( $settings['param_name'] ) .' '. esc_attr( $settings['type'] ) .'_field ueldo-validate-number-field" type="text" data-number-field-minus-allowed="yes" value="'. esc_attr( $value ) .'" /></div>';
    }

    vc_add_shortcode_param( 'ueldo_box_shadow_vertical_length', 'ueldo_box_shadow_vertical_length_field', get_template_directory_uri() .'/_assets/_js/vc-params.js' );
    function ueldo_box_shadow_vertical_length_field( $settings, $value ) {

        # return field html
        return '<span>'. esc_html( __( 'Vertical length', 'ueldo' ) ) .'</span><div class="ueldo-box-shadow-field-container"><input name="'. esc_attr( $settings['param_name'] ) .'" class="wpb_vc_param_value wpb-textinput '. esc_attr( $settings['param_name'] ) .' '. esc_attr( $settings['type'] ) .'_field ueldo-validate-number-field" type="text" data-number-field-minus-allowed="yes" value="'. esc_attr( $value ) .'" /></div>';
    }

    vc_add_shortcode_param( 'ueldo_box_shadow_blur_radius', 'ueldo_box_shadow_blur_radius_field', get_template_directory_uri() .'/_assets/_js/vc-params.js' );
    function ueldo_box_shadow_blur_radius_field( $settings, $value ) {

        # return field html
        return '<span>'. esc_html( __( 'Blur radius', 'ueldo' ) ) .'</span><div class="ueldo-box-shadow-field-container"><input name="'. esc_attr( $settings['param_name'] ) .'" class="wpb_vc_param_value wpb-textinput '. esc_attr( $settings['param_name'] ) .' '. esc_attr( $settings['type'] ) .'_field ueldo-validate-number-field" type="text" data-number-field-minus-allowed="yes" value="'. esc_attr( $value ) .'" /></div>';
    }

    vc_add_shortcode_param( 'ueldo_box_shadow_spread_radius', 'ueldo_box_shadow_spread_radius_field', get_template_directory_uri() .'/_assets/_js/vc-params.js' );
    function ueldo_box_shadow_spread_radius_field( $settings, $value ) {

        # return field html
        return '<span>'. esc_html( __( 'Spread radius', 'ueldo' ) ) .'</span><div class="ueldo-box-shadow-field-container"><input name="'. esc_attr( $settings['param_name'] ) .'" class="wpb_vc_param_value wpb-textinput '. esc_attr( $settings['param_name'] ) .' '. esc_attr( $settings['type'] ) .'_field ueldo-validate-number-field" type="text" data-number-field-minus-allowed="yes" value="'. esc_attr( $value ) .'" /></div>';
    }

   /**
    *
    * custom visual composer param for text-shadow settings
    *
    */

    vc_add_shortcode_param( 'ueldo_text_shadow_horizontal_length', 'ueldo_text_shadow_horizontal_length_field', get_template_directory_uri() .'/_assets/_js/vc-params.js' );
    function ueldo_text_shadow_horizontal_length_field( $settings, $value ) {

        # return field html
        return '<span>'. esc_html( __( 'Horizontal length', 'ueldo' ) ) .'</span><div class="ueldo-text-shadow-field-container"><input name="'. esc_attr( $settings['param_name'] ) .'" class="wpb_vc_param_value wpb-textinput '. esc_attr( $settings['param_name'] ) .' '. esc_attr( $settings['type'] ) .'_field ueldo-validate-number-field" type="text" data-number-field-minus-allowed="yes" value="'. esc_attr( $value ) .'" /></div>';
    }

    vc_add_shortcode_param( 'ueldo_text_shadow_vertical_length', 'ueldo_text_shadow_vertical_length_field', get_template_directory_uri() .'/_assets/_js/vc-params.js' );
    function ueldo_text_shadow_vertical_length_field( $settings, $value ) {

        # return field html
        return '<span>'. esc_html( __( 'Vertical length', 'ueldo' ) ) .'</span><div class="ueldo-text-shadow-field-container"><input name="'. esc_attr( $settings['param_name'] ) .'" class="wpb_vc_param_value wpb-textinput '. esc_attr( $settings['param_name'] ) .' '. esc_attr( $settings['type'] ) .'_field ueldo-validate-number-field" type="text" data-number-field-minus-allowed="yes" value="'. esc_attr( $value ) .'" /></div>';
    }

    vc_add_shortcode_param( 'ueldo_text_shadow_blur_radius', 'ueldo_text_shadow_blur_radius_field', get_template_directory_uri() .'/_assets/_js/vc-params.js' );
    function ueldo_text_shadow_blur_radius_field( $settings, $value ) {

        # return field html
        return '<span>'. esc_html( __( 'Blur radius', 'ueldo' ) ) .'</span><div class="ueldo-text-shadow-field-container"><input name="'. esc_attr( $settings['param_name'] ) .'" class="wpb_vc_param_value wpb-textinput '. esc_attr( $settings['param_name'] ) .' '. esc_attr( $settings['type'] ) .'_field ueldo-validate-number-field" type="text" data-number-field-minus-allowed="yes" value="'. esc_attr( $value ) .'" /></div>';
    }

   /**
    *
    * custom visual composer param for pixels value
    *
    */

    vc_add_shortcode_param( 'ueldo_px_number', 'ueldo_px_number_field', get_template_directory_uri() .'/_assets/_js/vc-params.js' );
    function ueldo_px_number_field( $settings, $value ) {

        # is minus allowed?
        $minus_allowed = isset( $settings['ueldo-number-field-minus-allowed'] ) ? $settings['ueldo-number-field-minus-allowed'] : false;

        # are decimals allowed?
        $decimals_allowed = isset( $settings['ueldo-number-field-decimals-allowed'] ) ? $settings['ueldo-number-field-decimals-allowed'] : false;

        # return field html
        return '<div class="ueldo-px-number-field-container"><input name="'. esc_attr( $settings['param_name'] ) .'" class="wpb_vc_param_value wpb-textinput '. esc_attr( $settings['param_name'] ) .' '. esc_attr( $settings['type'] ) .'_field ueldo-validate-number-field" type="text" data-number-field-minus-allowed="'. esc_attr( $minus_allowed == true ? 'yes' : 'no' ) .'" data-number-field-decimals-allowed="'. esc_attr( $decimals_allowed == true ? 'yes' : 'no' ) .'" value="'. esc_attr( $value ) .'" /></div>';
    }

   /**
    *
    * custom visual composer param for em value
    *
    */

    vc_add_shortcode_param( 'ueldo_em_number', 'ueldo_em_number_field', get_template_directory_uri() .'/_assets/_js/vc-params.js' );
    function ueldo_em_number_field( $settings, $value ) {

        # return field html
        return '<div class="ueldo-em-number-field-container"><input name="'. esc_attr( $settings['param_name'] ) .'" class="wpb_vc_param_value wpb-textinput '. esc_attr( $settings['param_name'] ) .' '. esc_attr( $settings['type'] ) .'_field ueldo-validate-number-field" type="text" data-number-field-minus-allowed="no" data-number-field-decimals-allowed="yes" value="'. esc_attr( $value ) .'" /></div>';
    }

   /**
    *
    * custom visual composer param for number value
    *
    */

    vc_add_shortcode_param( 'ueldo_number', 'ueldo_number_field', get_template_directory_uri() .'/_assets/_js/vc-params.js' );
    function ueldo_number_field( $settings, $value ) {

        # is minus allowed?
        $minus_allowed = isset( $settings['ueldo-number-field-minus-allowed'] ) ? $settings['ueldo-number-field-minus-allowed'] : false;

        # decimals allowed?
        $decimals_allowed = isset( $settings['ueldo-number-field-decimals-allowed'] ) ? $settings['ueldo-number-field-decimals-allowed'] : false;

        # return field html
        return '<input name="'. esc_attr( $settings['param_name'] ) .'" class="wpb_vc_param_value wpb-textinput '. esc_attr( $settings['param_name'] ) .' '. esc_attr( $settings['type'] ) .'_field ueldo-validate-number-field" type="text" data-number-field-minus-allowed="'. esc_attr( $minus_allowed == true ? 'yes' : 'no' ) .'" data-number-field-decimals-allowed="'. esc_attr( $decimals_allowed == true ? 'yes' : 'no' ) .'" value="'. esc_attr( $value ) .'" />';
    }

   /**
    *
    * visual composer fields divider
    *
    */

    vc_add_shortcode_param( 'ueldo_divider', 'ueldo_divider_field' );
    function ueldo_divider_field( $settings, $value ) {

        # return field html
        return '<div class="ueldo-vc-fields-divider">

                    <input name="'. esc_attr( $settings['param_name'] ) .'" class="wpb_vc_param_value wpb-textinput '. esc_attr( $settings['param_name'] ) .' '. esc_attr( $settings['type'] ) .'_field" type="hidden" value="'. esc_attr( $value ) .'" />

                </div>';
    }

   /**
    *
    * custom unique shortcode field
    *
    */

    vc_add_shortcode_param( 'ueldo_custom_unique_shortcode', 'ueldo_custom_unique_shortcode_field', get_template_directory_uri() .'/_assets/_js/vc-params.js' );
    function ueldo_custom_unique_shortcode_field( $settings, $value ) {

        # return field html
        return '<div class="ueldo-vc-custom-unique-shortcode">

                    <input name="'. esc_attr( $settings['param_name'] ) .'" class="wpb_vc_param_value wpb-textinput '. esc_attr( $settings['param_name'] ) .' '. esc_attr( $settings['type'] ) .'_field" type="hidden" value="'. esc_attr( $value ) .'" />
                    <pre></pre>

                </div>';
    }

   /**
    *
    * add filter to visual composer animation style list
    *
    */

    add_filter( 'vc_param_animation_style_list', 'ueldo_vc_update_param_animation_style_list' );
    function ueldo_vc_update_param_animation_style_list( $style ) {

        # add custom styles - entrances
        $style[] = array(
        				'label' => esc_attr( __( 'Ueldo theme animations Entrances', 'ueldo' ) ),
        				'values' => array(
           					esc_attr( __( 'ueldoFadeInLeftSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeInLeftSmall',
              						'type' => 'in',
           					),
           					esc_attr( __( 'ueldoFadeInLeftSuperSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeInLeftSuperSmall',
              						'type' => 'in',
           					),
                esc_attr( __( 'ueldoFadeInRightSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeInRightSmall',
              						'type' => 'in',
           					),
           					esc_attr( __( 'ueldoFadeInRightSuperSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeInRightSuperSmall',
              						'type' => 'in',
           					),
                esc_attr( __( 'ueldoFadeInDownSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeInDownSmall',
              						'type' => 'in',
           					),
           					esc_attr( __( 'ueldoFadeInDownSuperSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeInDownSuperSmall',
              						'type' => 'in',
           					),
                esc_attr( __( 'ueldoFadeInUpSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeInUpSmall',
              						'type' => 'in',
           					),
           					esc_attr( __( 'ueldoFadeInUpSuperSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeInUpSuperSmall',
              						'type' => 'in',
           					)
        				)
     			);

        # add custom styles - exits
        $style[] = array(
        				'label' => esc_attr( __( 'Ueldo theme animations Exits', 'ueldo' ) ),
        				'values' => array(
           					esc_attr( __( 'ueldoFadeOutLeftSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeOutLeftSmall',
              						'type' => 'out',
           					),
           					esc_attr( __( 'ueldoFadeOutLeftSuperSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeOutLeftSuperSmall',
              						'type' => 'out',
           					),
           					esc_attr( __( 'ueldoFadeOutRightSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeOutRightSmall',
              						'type' => 'out',
           					),
           					esc_attr( __( 'ueldoFadeOutRightSuperSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeOutRightSuperSmall',
              						'type' => 'out',
           					),
           					esc_attr( __( 'ueldoFadeOutDownSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeOutDownSmall',
              						'type' => 'out',
           					),
           					esc_attr( __( 'ueldoFadeOutDownSuperSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeOutDownSuperSmall',
              						'type' => 'out',
           					),
           					esc_attr( __( 'ueldoFadeOutUpSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeOutUpSmall',
              						'type' => 'out',
           					),
           					esc_attr( __( 'ueldoFadeOutUpSuperSmall', 'ueldo' ) ) => array(
              						'value' => 'ueldoFadeOutUpSuperSmall',
              						'type' => 'out',
           					)
        				)
     			);

        # return result
        return( $style );
    }

   /**
    *
    * class for unique tabs slugs
    *
    */

    class ueldo_vc_shortcode_unique_tabs_slugs {

        # array of tabs slugs
        public $slugs = array();

        # last element identifier
        public $last_id = 0;

        # get tab slug
        public function get_tab_slug( $title ) {

            # unique identifier
            $unique_id = 1;

            # get tab slug
            $tab_slug = sanitize_title( $title );

            # is tab slug unique?
            if( !in_array( $tab_slug, $this -> slugs ) ) $this -> slugs[] = $tab_slug;
            else {

                # do until tab slug will be unique
                do { $new_tab_slug = $tab_slug .'-'. $unique_id; $unique_id++; } while( in_array( $new_tab_slug, $this -> slugs ) );

                # update tab slug
                $tab_slug = $new_tab_slug;

                # update tabs slugs array
                $this -> slugs[] = $tab_slug;

                # remove temporary variables
                unset( $new_tab_slug );
            }

            # return result
            return( $tab_slug );
        }

        # get next element id
        public function get_next_id() {

            # update "last id" variable
            $this -> last_id += 1;

            # return result
            return( $this -> last_id );
        }

        # clear array of tabs slugs
        public function clear_tabs_slugs_array() {

            # do requested action
            $this -> slugs = array();
        }

        # clear "last id" variable
        public function clear_last_id() {

            # do requested action
            $this -> last_id = 0;
        }
    }

    # create object of unique tabs slugs class
    $ueldo_vc_shortcode_unique_tabs_slugs = new ueldo_vc_shortcode_unique_tabs_slugs();

   /**
    *
    * store custom variables in cache
    *
    */

    class ueldo_store_custom_variables {

       /**
        *
        * array with stored variables
        *
        */

        public $variables = array();

       /**
        *
        * set new variable to array
        *
        */

        public function set_variable( $name, $value ) {

            # update variables array
            $this -> variables[$name] = $value;
        }

       /**
        *
        * get value from stored variable
        *
        */

        public function get_variable( $name ) {

            # return result
            return( !isset( $this -> variables[$name] ) ? false : $this -> variables[$name] );
        }

       /**
        *
        * end of class methods.
        *
        */
    }

    # create object of stored custom variables class
    $ueldo_store_custom_variables = new ueldo_store_custom_variables();

   /**
    *
    * require visual composer elements custom styles reader function
    *
    */

    require_once( ueldo_plugin_get_path( '_parts/_visual-composer/vc-styles.php' ) );

   /**
    *
    * end of file.
    *
    */

?>