<?php

   /**
    *
    * add custom post type: headings and footers
    *
    */

    add_action( 'init', 'ueldo_plugin_create_post_type_headers_footers_extras' );
    function ueldo_plugin_create_post_type_headers_footers_extras() {

        # register custom post type
        register_post_type( 'ueldohefo', array(
            'labels' => array(
                'name' => esc_html( __( 'Headers, Footers and Extras', 'ueldo' ) ),
                'singular_name' => esc_html( __( 'Header / Footer / Extras', 'ueldo' ) ),
                'menu_name' => esc_html( __( 'Headers, Footers and Extras', 'ueldo' ) ),
                'name_admin_bar' => esc_html( __( 'Header / Footer / Extras', 'ueldo' ) ),
                'add_new' => esc_html( __( 'Add New', 'ueldo' ) ),
                'add_new_item' => esc_html( __( 'Add New Header / Footer / Extras', 'ueldo' ) ),
                'new_item' => esc_html( __( 'New Header / Footer / Extras', 'ueldo' ) ),
                'edit_item' => esc_html( __( 'Edit Header / Footer / Extras', 'ueldo' ) ),
                'view_item' => esc_html( __( 'View Header / Footer / Extras', 'ueldo' ) ),
                'all_items' => esc_html( __( 'All Headers, Footers and Extras', 'ueldo' ) ),
                'search_items' => esc_html( __( 'Search Headers, Footers and Extras', 'ueldo' ) ),
                'not_found' => esc_html( __( 'No Headers, Footers and Extras found.', 'ueldo' ) ),
                'not_found_in_trash' => esc_html( __( 'No Headers, Footers and Extras found in Trash.', 'ueldo' ) )
            ),
            'public' => true,
            'show_in_menu' => true,
            'show_ui' => true,
            'has_archive' => false,
            'menu_icon' => 'dashicons-layout'
        ));

        # is visual composer plugin activated?
        if( ueldo_plugins::is_active_plugin( 'visual-composer' ) ) {

            # add custom post type to visual composer
            vc_set_default_editor_post_types( array( 'page', 'ueldohefo' ) );
        }
    }

   /**
    *
    * register activation hook - flush cache for new post type
    *
    */

    register_activation_hook( __FILE__, 'ueldo_plugin_rewrite_flush' );
    function ueldo_plugin_rewrite_flush() {

        # register headings and footers custom post type
        ueldo_plugin_create_post_type_headers_footers_extras();

        # flush rewrite rules
        flush_rewrite_rules();
    }

   /**
    *
    * element update messages
    *
    */

    add_filter( 'post_updated_messages', 'ueldo_plugin_hefo_updated_messages' );
    function ueldo_plugin_hefo_updated_messages( $messages ) {

        # get post
        $post = get_post();

        # get post type
        $post_type = get_post_type( $post );

        # get post type object
        $post_type_object = get_post_type_object( $post_type );

        # messages array
        $messages['ueldohefo'] = array(
          		0 => '',
          		1 => esc_html( __( 'Header / Footer / Extras element updated.', 'ueldo' ) ),
          		2 => esc_html( __( 'Custom field updated.', 'ueldo' ) ),
          		3 => esc_html( __( 'Custom field deleted.', 'ueldo' ) ),
          		4 => esc_html( __( 'Header / Footer / Extras element updated.', 'ueldo' ) ),
          		5 => isset( $_GET['revision'] ) ? esc_html( sprintf( __( 'Header / Footer / Extras element restored to revision from %s', 'ueldo' ), wp_post_revision_title( ( int ) $_GET['revision'], false ) ) ) : false,
          		6 => esc_html( __( 'Header / Footer / Extras element published.', 'ueldo' ) ),
          		7 => esc_html( __( 'Header / Footer / Extras element saved.', 'ueldo' ) ),
          		8 => esc_html( __( 'Header / Footer / Extras element submitted.', 'ueldo' ) ),
          		9 => esc_html( sprintf( __( 'Header / Footer / Extras element scheduled for: <strong>%1$s</strong>.', 'ueldo' ), date_i18n( __( 'M j, Y @ G:i', 'ueldo' ), strtotime( $post -> post_date ) ) ) ),
          		10 => esc_html( __( 'Header / Footer / Extras element draft updated.', 'ueldo' ) )
       	);

       	# publicly queried messages
        if( $post_type_object -> publicly_queryable && 'ueldohefo' === $post_type ) {

          		# remove permalinks
          		$messages[$post_type][1] .= '';
          		$messages[$post_type][6] .= '';
          		$messages[$post_type][9] .= '';
          		$messages[$post_type][8] .= '';
          		$messages[$post_type][10] .= '';
       	}

       	# return updated messages array
        return( $messages );
    }

   /**
    *
    * remove "view" action from ueldohefo post type
    *
    */

    add_filter( 'post_row_actions', 'ueldo_plugin_hefo_post_row_actions', 10, 2 );
    function ueldo_plugin_hefo_post_row_actions( $actions, $tag ) {

        # is it ueldohefo post type?
        if( isset( $tag -> post_type ) && $tag -> post_type == 'ueldohefo' ) {

            # remove "view" action
            unset( $actions['view'] );
        }

        # return actions list
        return( $actions );
    }

   /**
    *
    * remove "view header / footer / extras" from admin bar
    *
    */

    add_action( 'admin_bar_menu', 'ueldo_plugin_hefo_remove_from_adminbar', 999 );
    function ueldo_plugin_hefo_remove_from_adminbar( $wp_admin_bar ) {

        # get all toolbar nodes
        $all_toolbar_nodes = $wp_admin_bar -> get_nodes();

        # walk for each toolbar nodes
        foreach( $all_toolbar_nodes as $node_key => $node_data ) {

            # check view node
            if( $node_key == 'view' ) {

                # is it ueldohefo?
                if( strpos( $node_data -> title, esc_html( __( 'View Header / Footer / Extras', 'ueldo' ) ) ) !== false || strpos( $node_data -> href, '/ueldohefo/' ) !== false ) {

                    # remove node
                    $wp_admin_bar -> remove_node( 'view' );
                }
            }
        }
    }

   /**
    *
    * remove ueldohefo pages from wplink popup
    *
    */

    add_filter( 'wp_link_query_args', 'ueldo_plugin_wplink_query_args' );
    function ueldo_plugin_wplink_query_args( $query ) {

        # do we have an array?
        if( isset( $query['post_type'] ) && is_array( $query['post_type'] ) ) {

            # search for the item
            for( $i = 0; $i < count( $query['post_type'] ); $i++ ) {

                # compare
                if( $query['post_type'][$i] == 'ueldohefo' ) {

                    # remove post type from array
                    unset( $query['post_type'][$i] );

                    # break the loop
                    break;
                }
            }

            # refresh array keys
            $query['post_type'] = array_values( $query['post_type'] );
        }

        # return result
        return( $query );
    }

   /**
    *
    * end of hefo post type options.
    *
    */

?>