<?php

   /**
    *
    * filter: retina-ready images for imported sliders
    *
    */

    add_filter( 'revslider_importSliderFromPost_modify_data', 'ueldo_plugin_revslider_import_retina_ready_images' );
    function ueldo_plugin_revslider_import_retina_ready_images( $data ) {

        # do we have slider params array?
        if( isset( $data['sliderParams'] ) && isset( $data['sliderParams']['alias'] ) ) {

            # get slider alias
            $alias = $data['sliderParams']['alias'];

            # is it cafe slider?
            if( ueldo_plugin_is_own_revslider( $alias ) ) {

                # get upload dir path
                $imported = $data['alreadyImported'];

                # do we have any images already imported?
                if( count( $imported ) > 0 ) {

                    # walk for each image
                    foreach( $imported as $imported_image_key => $imported_image_name ) {

                        # extract image name
                        $image_name_exp = explode( '/', $imported_image_name );

                        # get image name
                        $image_name = $image_name_exp[count( $image_name_exp ) - 1];

                        # only for png images
                        if( strpos( $image_name, '.png' ) !== false ) {

                            # remove file extensions
                            $image_name = str_replace( '.png', '', $image_name );

                            # find retina-ready representative path
                            switch( $image_name ) {

                                case 'image': $retina_image = 'image@2x.png'; break;
                                default: $retina_image = '_templates-images/ueldo-'. esc_attr( $image_name ) .'@2x.png'; break;
                            }

                            # upload retina image to revslider
                            ueldo_plugin_upload_retina_ready_image_to_revslider( $retina_image, $image_name_exp );
                        }
                    }
                }
            }
        }

        # return data array
        return( $data );
    }

   /**
    *
    * upload selected image to revolution slider uploads directory
    *
    */

    function ueldo_plugin_upload_retina_ready_image_to_revslider( $image, $orig_image_exp ) {

        # remove last element from original image exploded
        unset( $orig_image_exp[count( $orig_image_exp ) - 1] );

        # general uploads dir
        $uploads_dir = wp_upload_dir();

        # uploads dir for revslider
        $revslider_uploads_dir = $uploads_dir['basedir'] .'/'. implode( '/', $orig_image_exp ) .'/';

        # is revslider uploads directory writable?
        if( !is_writable( $revslider_uploads_dir ) ) return;

        # original retina image path
        $retina_image_path = get_template_directory_uri() .'/_assets/_img/'. esc_attr( $image );

        # copy file to new location
        @copy( $retina_image_path, $revslider_uploads_dir . str_replace( '_templates-images/ueldo-', '', esc_attr( $image ) ) );
    }

   /**
    *
    * check if uploaded slider is from ueldo theme
    *
    */

    function ueldo_plugin_is_own_revslider( $current_alias ) {

        # theme sliders aliases
        $aliases = array(
            'accountant-home-page-slider',
            'barber-shop-slider',
            'cafe-slider',
            'dentist-home-page-slider',
            'kayaks-home-page-slider',
            'runners-club-slider',
            'stud-home-page-slider'
        );

        # walk for each theme slider
        foreach( $aliases as $single_alias ) {

            # do we have a match?
            if( strpos( $current_alias, $single_alias ) !== false ) return true;
        }

        # not a built-in slider
        return( false );
    }

   /**
    *
    * end of file.
    *
    */

?>