<?php

    # prevent direct file access
    if( !defined( 'ABSPATH' ) ) exit;

   /**
    *
    * register custom widgets
    *
    */

    add_action( 'widgets_init', 'ueldo_plugin_register_widgets' );
    function ueldo_plugin_register_widgets() {

        # "popular posts" custom widget
        register_widget( 'ueldo_plugin_popular_posts_widget' );

        # "call to action" custom widget
        register_widget( 'ueldo_plugin_call_to_action_widget' );
    }

   /**
    *
    * "popular posts" custom widget
    *
    */

    class ueldo_plugin_popular_posts_widget extends WP_Widget {

        /**
         *
         * global attribute - posts published time limit
         *
         */

         private $ueldo_plugin_popular_posts_time_limit = '30d';

        /**
         *
         * constructor
         *
         */

         public function __construct() {

             parent::__construct(
                 'ueldo_popular_posts_widget',
                 esc_html( __( 'Ueldo: Popular posts', 'ueldo' ) ),
                 array(
                     'classname' => 'ueldo-popular-posts-widget',
                     'description' => esc_html( __( 'This widget is dedicated to display your most popular posts by comment count.', 'ueldo' ) )
                 )
             );
         }

        /**
         *
         * widget form fields
         *
         */

         public function form( $instance ) {

             # get form fields values
             $instance = wp_parse_args(
                 ( array ) $instance,
                 array(
                     'title' => esc_html( __( 'Popular posts', 'ueldo' ) ),
                     'posts_number' => 3,
                     'posts_from_last' => '30d'
                 )
             );

             ?>
             <div class="ueldo-custom-widget-form">

                 <p>

                     <?php echo esc_html( __( 'Title', 'ueldo' ) ); ?>
                     <input class="widefat" name="<?php echo esc_attr( $this -> get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />

                 </p>

                 <p>

                     <?php echo esc_html( __( 'Posts number', 'ueldo' ) ); ?>
                     <select class="widefat" name="<?php echo esc_attr( $this -> get_field_name( 'posts_number' ) ); ?>">

                         <?php

                             # loop 1 - 10
                             for( $i = 1; $i < 11; $i++ ) {

                                 ?>
                                 <option value="<?php echo esc_attr( $i ); ?>" <?php selected( $instance['posts_number'], $i ); ?>><?php echo esc_html( $i ); ?></option>
                                 <?php
                             }

                         ?>

                     </select>

                 </p>

                 <p>

                     <?php echo esc_html( __( 'Posts published in last:', 'ueldo' ) ); ?>
                     <select class="widefat" name="<?php echo esc_attr( $this -> get_field_name( 'posts_from_last' ) ); ?>">

                         <option value="30d" <?php selected( $instance['posts_from_last'], '30d' ); ?>><?php echo esc_html( __( '30 days', 'ueldo' ) ); ?></option>
                         <option value="3m" <?php selected( $instance['posts_from_last'], '3m' ); ?>><?php echo esc_html( __( '3 months', 'ueldo' ) ); ?></option>
                         <option value="6m" <?php selected( $instance['posts_from_last'], '6m' ); ?>><?php echo esc_html( __( '6 months', 'ueldo' ) ); ?></option>
                         <option value="all" <?php selected( $instance['posts_from_last'], 'all' ); ?>><?php echo esc_html( __( 'Unlimited - all posts', 'ueldo' ) ); ?></option>

                     </select>

                 </p>

             </div>
             <?php
         }

        /**
         *
         * update widget variables
         *
         */

         public function update( $new_instance, $instance ) {

             # all keys array
             $field_keys = array(
                 'url' => array(),
                 'attr' => array(
                     'posts_number',
                     'posts_from_last'
                 ),
                 'text' => array( 'title' )
             );

             # validate each field
             foreach( $field_keys as $field_type => $keys ) {

                 # validate each key
                 foreach( $keys as $key ) {

                     # read field type
                     switch( $field_type ) {

                         # urls
                         case 'url': $instance[$key] = $new_instance[$key] == '' ? '' : esc_url( $new_instance[$key] ); break;

                         # checkbox
                         case 'attr': $instance[$key] = esc_attr( $new_instance[$key] ); break;

                         # texts
                         case 'text': $instance[$key] = esc_html( $new_instance[$key] ); break;
                     }
                 }
             }

             # return result
             return( $instance );
         }

        /**
         *
         * custom filter - limit posts older than 30 days
         *
         */

         public function filter_where( $where = '' ) {

             # choose an action for posts time limit value
             switch( $this -> ueldo_plugin_popular_posts_time_limit ) {

                 case '30d': $time = '-30 days'; break;
                 case '3m': $time = '-3 months'; break;
                 case '6m': $time = '-6 months'; break;
                 case 'all': return( $where );
             }

             # posts in the last 30 days
             $where .= " AND post_date > '". esc_attr( date( 'Y-m-d', strtotime( esc_attr( $time ) ) ) ) ."'";

             # return result
             return( $where );
         }

        /**
         *
         * display widget
         *
         */

         public function widget( $args, $instance ) {

             # get form fields values
             $instance = wp_parse_args(
                 ( array ) $instance,
                 array(
                     'title' => esc_html( __( 'Limited offer', 'ueldo' ) ),
                     'posts_number' => 3,
                     'posts_from_last' => '30d'
                 )
             );

             # update posts time limit
             $this -> ueldo_plugin_popular_posts_time_limit = $instance['posts_from_last'];

             # add filter for posts query - only posts from last 30 days
             add_filter( 'posts_where', array( $this, 'filter_where' ) );

             # get the posts
             query_posts( 'post_type=post&posts_per_page='. esc_attr( $instance['posts_number'] ) .'&orderby=comment_count&ignore_sticky_posts=1&order=DESC' );

             # remove previously added filter
             remove_filter( 'posts_where', array( $this, 'filter_where' ) );

             # before widget
             echo !empty( $args['before_widget'] ) ? $args['before_widget'] : '';

             # do we have title set?
             if( $instance['title'] != '' ) {

                 ?>
                 <h4><?php echo esc_html( $instance['title'] ); ?></h4>
                 <?php
             }

             # there's no any posts?
             if( !have_posts() ) {

                 ?>
                 <p><?php echo esc_html( __( 'Not found any posts', 'ueldo' ) ); ?></p>
                 <?php
             }

             # display popular posts
             else {

                 ?>
                 <ul class="ueldo-posts-list">

                     <?php

                         # posts loop
                         while( have_posts() ) {

                             # get the post object
                             the_post();

                             ?>
                             <li>

                                 <a href="<?php the_permalink(); ?>">

                                     <?php

                                         # get featured image
                                         $ueldo_featured_image = ueldo_get_featured_image( get_the_ID(), get_the_title(), true );

                                         # do we have featured image?
                                         if( $ueldo_featured_image != '' ) {

                                             ?>
                                             <img src="<?php echo esc_url( $ueldo_featured_image['src'] ); ?>" alt="<?php echo esc_attr( $ueldo_featured_image['alt'] ); ?>" />
                                             <?php

                                         # end of featured image
                                         }

                                     ?>

                                     <span class="ueldo-posts-list-single-post-title"><?php echo esc_html( ueldo_limit_the_title( get_the_title() ) ); ?></span>

                                 </a>

                             </li>
                             <?php
                         }

                     ?>

                 </ul>
                 <?php
             }

             # reset the query
             wp_reset_query();

             # after widget
             echo !empty( $args['after_widget'] ) ? $args['after_widget'] : '';
         }

        /**
         *
         * end of widget methods
         *
         */
    }

   /**
    *
    * "call to action" custom widget
    *
    */

    class ueldo_plugin_call_to_action_widget extends WP_Widget {

        /**
         *
         * constructor
         *
         */

         public function __construct() {

             parent::__construct(
                 'ueldo_call_to_action_widget',
                 esc_html( __( 'Ueldo: Call to action', 'ueldo' ) ),
                 array(
                     'classname' => 'ueldo-call-to-action-widget',
                     'description' => esc_html( __( 'This widget is dedicated to display "call to action" box.', 'ueldo' ) )
                 )
             );
         }

        /**
         *
         * widget form fields
         *
         */

         public function form( $instance ) {

             # get form fields values
             $instance = wp_parse_args(
                 ( array ) $instance,
                 array(
                     'big_title' => esc_html( __( '-30%', 'ueldo' ) ),
                     'title' => esc_html( __( 'Limited offer!', 'ueldo' ) ),
                     'content' => 'Praesent ac feugiat est. Vestibulum commodo ultrices elementum. Nulla nec fringilla felis.',
                     'button_text' => esc_html( __( 'Schedule a Visit', 'ueldo' ) ),
                     'button_url' => '#',
                     'button_icon' => '',
                     'button_in_new_tab' => '',
                     'background_image_url' => ''
                 )
             );

             ?>
             <div class="ueldo-custom-widget-form">

                 <p>

                     <?php echo esc_html( __( 'Big title', 'ueldo' ) ); ?>
                     <input class="widefat" name="<?php echo esc_attr( $this -> get_field_name( 'big_title' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['big_title'] ); ?>" />

                 </p>

                 <p>

                     <?php echo esc_html( __( 'Title', 'ueldo' ) ); ?>
                     <input class="widefat" name="<?php echo esc_attr( $this -> get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />

                 </p>

                 <p>

                     <?php echo esc_html( __( 'Content', 'ueldo' ) ); ?>
                     <textarea class="widefat" rows="8" cols="20" name="<?php echo esc_attr( $this -> get_field_name( 'content' ) ); ?>"><?php echo esc_html( $instance['content'] ); ?></textarea>

                 </p>

                 <p>

                     <?php echo esc_html( __( 'Button text', 'ueldo' ) ); ?>
                     <input class="widefat" name="<?php echo esc_attr( $this -> get_field_name( 'button_text' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['button_text'] ); ?>" />

                 </p>

                 <p>

                     <?php echo esc_html( __( 'Button URL', 'ueldo' ) ); ?>
                     <input class="widefat" name="<?php echo esc_attr( $this -> get_field_name( 'button_url' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['button_url'] ); ?>" />

                 </p>

                 <p>

                     <?php echo esc_html( __( 'Button icon', 'ueldo' ) ); ?>
                     <input class="widefat" name="<?php echo esc_attr( $this -> get_field_name( 'button_icon' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['button_icon'] ); ?>" />

                 </p>

                 <p>

                     <?php echo esc_html( __( 'Open button URL in new tab?', 'ueldo' ) ); ?>
                     <br />

                     <input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this -> get_field_id( 'button_in_new_tab' ) ); ?>" <?php checked( $instance[ 'button_in_new_tab' ], 'on' ); ?> name="<?php echo esc_attr( $this -> get_field_name( 'button_in_new_tab' ) ); ?>">
                     <label for="<?php echo esc_attr( $this -> get_field_id( 'button_in_new_tab' ) ); ?>"><?php echo esc_html( __( 'Yes, open button URL in new tab', 'ueldo' ) ); ?></label>

                 </p>

                 <div class="ueldo-custom-widget-form-image-upload">

                     <?php

                         # do we have an image set?
                         if( $instance['background_image_url'] != '' ) {

                             ?>
                             <div class="ueldo-custom-widget-form-image-preview">

                                 <img src="<?php echo esc_url( $instance['background_image_url'] ); ?>" />

                             </div>
                             <?php
                         }

                     ?>

                     <p><?php echo esc_html( __( 'Widget background image', 'ueldo' ) ); ?></p>

                     <input type="text" class="widefat ueldo-media-url" name="<?php echo esc_attr( $this -> get_field_name( 'background_image_url' ) ); ?>" id="<?php echo esc_attr( $this -> get_field_id( 'background_image_url' ) ); ?>" value="<?php echo esc_url( $instance['background_image_url'] ); ?>">
                     <input type="button" class="button ueldo-media-button" value="<?php echo esc_attr( __( 'Select image', 'ueldo' ) ); ?>" />

                 </div>

             </div>
             <?php
         }

        /**
         *
         * update widget variables
         *
         */

         public function update( $new_instance, $instance ) {

             # all keys array
             $field_keys = array(
                 'url' => array(
                     'button_url',
                     'background_image_url'
                 ),
                 'attr' => array(
                     'button_icon',
                     'button_in_new_tab'
                 ),
                 'text' => array(
                     'big_title',
                     'title',
                     'content',
                     'button_text'
                 )
             );

             # validate each field
             foreach( $field_keys as $field_type => $keys ) {

                 # validate each key
                 foreach( $keys as $key ) {

                     # read field type
                     switch( $field_type ) {

                         # urls
                         case 'url': $instance[$key] = $new_instance[$key] == '' ? '' : esc_url( $new_instance[$key] ); break;

                         # checkbox
                         case 'attr': $instance[$key] = esc_attr( $new_instance[$key] ); break;

                         # texts
                         case 'text': $instance[$key] = esc_html( $new_instance[$key] ); break;
                     }
                 }
             }

             # return result
             return( $instance );
         }

        /**
         *
         * display widget
         *
         */

         public function widget( $args, $instance ) {

             # get form fields values
             $instance = wp_parse_args(
                 ( array ) $instance,
                 array(
                     'big_title' => esc_html( __( '-30%', 'ueldo' ) ),
                     'title' => esc_html( __( 'Limited offer!', 'ueldo' ) ),
                     'content' => 'Praesent ac feugiat est. Vestibulum commodo ultrices elementum. Nulla nec fringilla felis.',
                     'button_text' => esc_html( __( 'Schedule a Visit', 'ueldo' ) ),
                     'button_url' => '#',
                     'button_icon' => '',
                     'button_in_new_tab' => '',
                     'background_image_url' => ''
                 )
             );

             # before widget
             echo !empty( $args['before_widget'] ) ? $args['before_widget'] : '';

             ?>
             <div class="ueldo-widget-call-to-action">

                 <?php

                     # background image url
                     if( !empty( $instance['background_image_url'] ) ) {

                         # display image
                         ueldo_display_image_for_parent( $instance['background_image_url'] );
                     }

                 ?>

                 <div class="ueldo-widget-call-to-action-content">

                     <?php

                         # big widget title
                         if( !empty( $instance['big_title'] ) ) {

                             ?>
                             <span class="ueldo-widget-call-to-action-offer"><?php echo do_shortcode( esc_html( $instance['big_title'] ) ); ?></span>
                             <?php
                         }

                         # widget title
                         if( !empty( $instance['title'] ) ) {

                             ?>
                             <h3><?php echo do_shortcode( esc_html( $instance['title'] ) ); ?></h3>
                             <?php
                         }

                         # widget content
                         if( !empty( $instance['content'] ) ) echo wpautop( do_shortcode( esc_html( $instance['content'] ) ) );

                         # button
                         if( !empty( $instance['button_url'] ) && ( !empty( $instance['button_text'] ) || !empty( $instance['button_icon'] ) ) ) {

                             ?>
                             <p>

                                 <a href="<?php echo esc_url( $instance['button_url'] ); ?>" class="ueldo-button ueldo-call-to-action-widget-button" target="<?php echo esc_attr( $instance['button_in_new_tab'] == 'on' ? '_blank' : '_self' ); ?>">

                                     <?php

                                         # button text
                                         if( !empty( $instance['button_text'] ) ) echo esc_html( $instance['button_text'] );

                                         # button icon
                                         if( !empty( $instance['button_icon'] ) ) {

                                             ?>
                                             <i class="<?php echo esc_attr( $instance['button_icon'] ); ?> ueldo-button-icon-after-text"></i>
                                             <?php
                                         }

                                     ?>

                                 </a>

                             </p>
                             <?php
                         }

                     ?>

                 </div>

             </div>
             <?php

             # after widget
             echo !empty( $args['after_widget'] ) ? $args['after_widget'] : '';
         }

        /**
         *
         * end of widget methods
         *
         */
    }

   /**
    *
    * end of file.
    *
    */

?>