<?php

    /*

      Plugin Name: Ueldo Plugin
      Description: Plugin dedicated for Ueldo WordPress theme
      Author: Martanian <support@martanian.com>
      Author URI: http://themeforest.net/user/martanian
      Version: 1.2.7

    */

   /**
    *
    * check theme name
    *
    */

    function ueldo_plugin_check_theme_name() {

        # get theme data
        $theme = wp_get_theme();

        # correct theme name
        $name = 'Ueldo';

        # compare
        return( $theme -> name == $name || $theme -> parent_theme == $name );
    }

   /**
    *
    * plugin dedicated for ueldo theme only
    *
    */

    if( !ueldo_plugin_check_theme_name() ) return;

   /**
    *
    * get plugin url
    *
    */

    function ueldo_plugin_get_url() {

        # return result
        return( plugin_dir_url( __FILE__ ) );
    }

   /**
    *
    * get plugin path
    *
    */

    function ueldo_plugin_get_path( $path ) {

        # return plugin path
        return( plugin_dir_path( __FILE__ ) . esc_attr( $path ) );
    }

   /**
    *
    * get list of plugin parts
    *
    */

    function ueldo_plugin_get_list_of_plugin_parts() {

        # return result
        return( array(
            '_parts/_dynamic-styles-cache/dynamic-styles-cache.php',
            '_parts/helpers.php',
            '_parts/_static-shortcodes-styles-cache/static-shortcodes-styles-cache.php',
            '_parts/shortcodes.php',
            '_parts/twitter-api.php',
            '_parts/hefo-post-type.php',
            '_parts/widgets.php',
            '_parts/_dashboard/dashboard.php',
            '_parts/_icons-uploader/icons-uploader.php',
            '_parts/_languages-sync/languages-sync.php',
            '_parts/_import-export-options/import-export-options.php',
            '_parts/_custom-sidebars/custom-sidebars.php',
            '_parts/_load-demo-data/load-demo-data.php',
            '_parts/revslider-retina-images.php'
        ));
    }

   /**
    *
    * check if openssl libary is available
    *
    */

    function ueldo_plugin_is_openssl_available() {

        # return result
        return( extension_loaded( 'openssl' ) && function_exists( 'openssl_encrypt' ) && function_exists( 'openssl_decrypt' ) );
    }

   /**
    *
    * register plugin parts
    *
    */

    foreach( ueldo_plugin_get_list_of_plugin_parts() as $part ) {

        # require file
        require_once( ueldo_plugin_get_path( $part ) );
    }

   /**
    *
    * enqueue custom icons stylesheet files
    *
    */

    function ueldo_plugin_enqueue_custom_icons_stylesheet() {

        # get global variables
        global $ueldo_cache_option;

        # get icons list
        $icons = $ueldo_cache_option -> get_option( 'ueldo_custom_icons' );

        # there's no custom icons added?
        if( $icons == false ) return;

        # walk for each icon
        foreach( $icons as $icon ) {

            # check for ssl
            if( strpos( $icon['path'], 'http://' ) !== false && is_ssl() ) {

                # replace "http" with "https"
                $icon['path'] = str_replace( 'http://', 'https://', $icon['path'] );
            }

            # enqueue style
            wp_enqueue_style( 'ueldo-plugin-custom-icons-'. esc_attr( $icon['unique_key'] ) .'-stylesheet', esc_url( $icon['path'] ), false, null );
        }
    }

   /**
    *
    * add theme options link to wordpress toolbar
    *
    */

    add_action( 'admin_bar_menu', 'ueldo_plugin_add_theme_options_toolbar_link', 999 );
    function ueldo_plugin_add_theme_options_toolbar_link( $wp_admin_bar ) {

        # custom link attributes
        $args = array(
       		   'id' => 'ueldo-theme-options-toolbar-link',
       		   'title' => esc_html( __( 'Ueldo - Theme Options', 'ueldo' ) ),
       		   'href' => esc_url( admin_url( 'admin.php?page=ueldo_admin' ) ),
       		   'meta' => array(
       			      'class' => 'ueldo-theme-options-toolbar-link',
       			      'title' => esc_html( __( 'Ueldo - Theme Options', 'ueldo' ) )
       			  )
       	);

        # add custom link for wordpress toolbar
        $wp_admin_bar -> add_node( $args );
    }

   /**
    *
    * end of file.
    *
    */

?>