jQuery( document ).ready( function( $ ) {

   /**
    *
    * strict mode
    *
    */

    'use strict';

   /**
    *
    * update theme styles in live preview mode
    *
    */

    $.UeldoCustomizerUpdateThemeStyles = function() {

        var global_styles = [];
        $.each( ueldo_customizer_theme_styles_json, function( theme_style_key, theme_style_default_value ) {

            global_styles[theme_style_key] = wp.customize.value( 'ueldo_theme_options[styles]['+ theme_style_key +']' )();

        });

        var css = '';
        $.each( $.parseJSON( ueldo_customizer_styles_rule_json ), function( index, rule ) {

            var style_enabled = true;
            if( typeof rule.dependency != 'undefined' ) {

                $.each( rule.dependency, function( key, value ) {

                    if( global_styles[key] !== value ) style_enabled = false;

                });
            }

            if( style_enabled == true ) {

                var styles = {};
                $.each( rule.styles, function( key, value ) {

                    if( $.type( value ) != 'object' ) {

                        styles[key] = $.UeldoValidateStyle( global_styles[value], value );
                    }

                    else {

                        if( $.inArray( key, [ '1200_more', '992_1199', '768_991', 'less_767', 'less_991' ] ) !== -1 ) {

                            var substyles = {};
                            $.each( value, function( subkey, subvalue ) { substyles[subkey] = $.UeldoValidateStyle( global_styles[subvalue], subvalue ); });

                            styles[key] = substyles;
                        }

                        else {

                            $.each( value.values, function( pattern_key, pattern_value ) {

                                var color = $.UeldoValidateStyle( global_styles[pattern_value['color']], pattern_value['color'] );
                                if( typeof pattern_value['is_rgba'] != 'undefined' && pattern_value['is_rgba'] == 'yes' ) {

                                    var color_rgb = $.UeldoCustomizerHex2RGB( color );
                                    if( color_rgb !== null ) {

                                        if( typeof pattern_value['opacity'] != 'undefined' && pattern_value['opacity'] != '1' ) {

                                            color_rgb['a'] = ( parseFloat( color_rgb['a'] ) * parseFloat( pattern_value['opacity'] ) ).toFixed( 2 );
                                        }

                                        color = 'rgba( '+ color_rgb['rgb'] +', '+ color_rgb['a'] +' )';
                                    }
                                }

                                value.pattern = value.pattern.split( '{'+ pattern_key +'}' ).join( color );

                            });

                            if( key == 'box-shadow' ) {

                                styles['-webkit-'+ key] = value.pattern;
                                styles['-moz-'+ key] = value.pattern;
                            }

                            if( value.pattern.indexOf( 'math[' ) !== -1 ) value.pattern = $.UeldoReplaceMathInsidePattern( value.pattern );
                            styles[key] = value.pattern;
                        }
                    }

                });

                css += $.UeldoCustomizerCreateCSSCode( rule.elements, styles );
            }

        });

        $.UeldoCustomizerUpdateCSSInlineStyles( css );
    };

   /**
    *
    * create css code
    *
    */

    $.UeldoCustomizerCreateCSSCode = function( elements, styles ) {

        var isCSSResponsive = $.UeldoCustomizerIsCSSRuleResponsive( styles );
        var cssCode = '';

        if( isCSSResponsive == false ) {

            cssCode += elements.join( ', ' ) +' { ';
            $.each( styles, function( key, value ) {

                if( $.inArray( key, [ '-o-background-image', '-moz-background-image', '-webkit-background-image', '-ms-background-image', 'background-image' ] ) !== -1 ) { key = 'background-image'; }
                cssCode += key +': '+ $.UeldoUpdateCSSParam( key, value ) +'; ';

            });

            cssCode += ' } ';
        }

        else {

            switch( isCSSResponsive ) {

                case '1200_more': cssCode += '@media (min-width: 1200px) { '; break;
                case '992_1199': cssCode += '@media (min-width: 992px) and (max-width: 1199px) { '; break;
                case '768_991': cssCode += '@media (min-width: 768px) and (max-width: 991px) { '; break;
                case 'less_767': cssCode += '@media (max-width: 767px) { '; break;
                case 'less_991': cssCode += '@media (max-width: 991px) { '; break;
            }

            cssCode += elements.join( ', ' ) +' { ';
            $.each( styles[isCSSResponsive], function( key, value ) {

                if( $.inArray( key, [ '-o-background-image', '-moz-background-image', '-webkit-background-image', '-ms-background-image', 'background-image' ] ) !== -1 ) { key = 'background-image'; }
                cssCode += key +': '+ $.UeldoUpdateCSSParam( key, value ) +'; ';

            });

            cssCode += ' } } ';
        }

        return( cssCode );
    };

   /**
    *
    * update css code param
    *
    */

    $.UeldoUpdateCSSParam = function( key, value ) {

        var pixel_keys = [
            'font-size',
            'letter-spacing',
            'width',
            'min-width',
            'max-width',
            'height',
            'min-height',
            'max-height',
            'margin-left',
            'margin-right',
            'margin-top',
            'margin-bottom',
            'border-width',
            'border-top-width',
            'border-right-width',
            'border-bottom-width',
            'border-left-width',
            '-webkit-border-radius',
            '-moz-border-radius',
            'border-radius',
            '-webkit-border-bottom-left-radius',
            '-moz-border-bottom-left-radius',
            'border-bottom-left-radius',
            '-webkit-border-bottom-right-radius',
            '-moz-border-bottom-right-radius',
            'border-bottom-right-radius',
            '-webkit-border-top-left-radius',
            '-moz-border-top-left-radius',
            'border-top-left-radius',
            '-webkit-border-top-right-radius',
            '-moz-border-top-right-radius',
            'border-top-right-radius',
            'padding-left',
            'padding-right',
            'padding-top',
            'padding-bottom'
        ];

        if( $.inArray( key, pixel_keys ) !== -1 ) value += 'px';
        else if( key == 'line-height' ) value += 'em';

        if( value == '-0px' || value == 'px' ) value = '0px';

        return( value );
    };

   /**
    *
    * create css style attributes
    *
    */

    $.UeldoCustomizerIsCSSRuleResponsive = function( styles ) {

        var result;
        $.each( styles, function( key, value ) { result = $.type( value ) != 'object' ? false : key; return; });

        return( result );
    }

   /**
    *
    * update inline css styles
    *
    */

    $.UeldoCustomizerUpdateCSSInlineStyles = function( css ) {

        var container = $( '#ueldo-customized-styles-css' );

        if( container.length == 0 ) $( 'body' ).append( '<style type="text/css" id="ueldo-customized-styles-css">'+ css +'</style>' );
        else container.text( css );
    };

   /**
    *
    * change hex color to rgb
    *
    */

    $.UeldoCustomizerHex2RGB = function( hex ) {

        if( hex.indexOf( '#' ) === -1 ) {

            if( hex.indexOf( 'rgba' ) !== -1 || hex.indexOf( 'rgb' ) !== -1 ) {

                hex = hex.replace( 'rgba', '' ).replace( '(', '' ).replace( ')', '' ).split( ',' );

                if( typeof hex[3] == 'undefined' ) return({ 'rgb': $.trim( hex[0] ) +', '+ $.trim( hex[1] ) +', '+ $.trim( hex[2] ), 'a': '1' });
                else {

                    hex[3] = $.trim( hex[3].toString() ).substr( 0, 1 ) == '.' ? '0'+ $.trim( hex[3].toString() ) : $.trim( hex[3].toString() );
                    switch( hex[3] ) {

                        case '': hex[3] = '1'; break;
                        case '.': hex[3] = '1'; break;
                        case '0.': hex[3] = '0'; break;
                        case '1.': hex[3] = '1'; break;
                    }

                    return({ 'rgb': $.trim( hex[0] ) +', '+ $.trim( hex[1] ) +', '+ $.trim( hex[2] ), 'a': hex[3] });
                }
            }

            return( null );
        }

        else {

            var shorthandRegex = /^#?([a-f\d])([a-f\d])([a-f\d])$/i;
            hex = hex.replace( shorthandRegex, function( m, r, g, b ) { return r + r + g + g + b + b; });

            var result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec( hex );
            return result ? { 'rgb': parseInt( result[1], 16 ) +', '+ parseInt( result[2], 16 ) +', '+ parseInt( result[3], 16 ), 'a': '1' } : null;
        }
    };

   /**
    *
    * validate style - if incorrect, return default color
    *
    */

    $.UeldoValidateStyle = function( value, key ) {

        if( key.indexOf( 'color' ) === -1 || key.indexOf( 'box-shadow' ) !== -1 || key.indexOf( 'custom-styles-enabled' ) !== -1 ) return( value );
        else {

            var color_match = new RegExp( /^(\#[\da-f]{3}|\#[\da-f]{6}|rgba\(((\d{1,2}|1\d\d|2([0-4]\d|5[0-5]))\s*,\s*){2}((\d{1,2}|1\d\d|2([0-4]\d|5[0-5]))\s*)(,\s*(0\.\d+|1))\)|hsla\(\s*((\d{1,2}|[1-2]\d{2}|3([0-5]\d|60)))\s*,\s*((\d{1,2}|100)\s*%)\s*,\s*((\d{1,2}|100)\s*%)(,\s*(0\.\d+|1))\)|rgb\(((\d{1,2}|1\d\d|2([0-4]\d|5[0-5]))\s*,\s*){2}((\d{1,2}|1\d\d|2([0-4]\d|5[0-5]))\s*)|hsl\(\s*((\d{1,2}|[1-2]\d{2}|3([0-5]\d|60)))\s*,\s*((\d{1,2}|100)\s*%)\s*,\s*((\d{1,2}|100)\s*%)\))$/ );
            return( color_match.test( value.replace( /\s/g, '' ) ) == false ? ueldo_customizer_theme_styles_json[key] : value );
        }
    };

   /**
    *
    * replace math from pattern
    *
    */

    $.UeldoReplaceMathInsidePattern = function( pattern ) {

        var math = pattern.substr( pattern.indexOf( 'math[' ) );
            math = math.substr( 0, ( math.indexOf( ']' ) + 1 ) );

        pattern = pattern.replace( math, $.UeldoParseMathExpression( $.trim( math.replace( 'math[', '' ).replace( ']', '' ) ) ) );
        return( pattern.indexOf( 'math[' ) !== -1 ? $.UeldoReplaceMathInsidePattern( pattern ) : pattern );
    };

   /**
    *
    * parse math expression
    *
    */

    $.UeldoParseMathExpression = function( expression ) {

        if( expression.indexOf( '(' ) === -1 && expression.indexOf( ')' ) === -1 ) {

            if( expression.indexOf( '+' ) === -1 && expression.indexOf( '-' ) === -1 && expression.indexOf( '*' ) === -1 && expression.indexOf( '/' ) === -1 ) return( $.trim( expression ) );
            var vars = $.trim( expression ).split( ' ' );

            if( vars.length == 3 ) {

                var result = 0;
                switch( vars[1] ) {

                    case '+': result = parseFloat( vars[0] ) + parseFloat( vars[2] ); break;
                    case '-': result = parseFloat( vars[0] ) - parseFloat( vars[2] ); break;
                    case '*': result = parseFloat( vars[0] ) * parseFloat( vars[2] ); break;
                    case '/': result = parseFloat( vars[0] ) / parseFloat( vars[2] ); break;
                }

                return( result.toString() );
            }

            return( '0' );
        }

        else {

            var expression_split = $.trim( expression ).split( '' );
            var is_bracket_opened = false;
            var simple_expression_content = '';

            for( var i = 0; i < expression_split.length; i++ ) {

                if( is_bracket_opened == true && $.inArray( expression[i], [ '(', ')' ] ) === -1 ) simple_expression_content += expression[i];
                if( expression[i] == '(' ) {

                    if( is_bracket_opened == false ) is_bracket_opened = true;
                    else simple_expression_content = '';
                }

                else if( expression[i] == ')' ) {

                    is_bracket_opened = false;
                    expression = expression.replace( '('+ simple_expression_content +')', $.UeldoParseMathExpression( simple_expression_content ) );

                    break;
                }
            }

            return( $.UeldoParseMathExpression( expression ) );
        }
    };

   /**
    *
    * register customizer options observer
    *
    */

    $( window ).load( function() {

        ueldo_customizer_theme_styles_json = $.parseJSON( ueldo_customizer_theme_styles_json );

        $.UeldoCustomizerUpdateThemeStyles();
        $.each( ueldo_customizer_theme_styles_json, function( theme_style_key, theme_style_default_value ) {

            wp.customize( 'ueldo_theme_options[styles]['+ theme_style_key +']', function( value ) {

                value.bind( function() {

                    $.UeldoCustomizerUpdateThemeStyles();

                   /**
                    *
                    * update sidebar border line color in customizer preview
                    *
                    */

                    if( theme_style_key == 'sidebar-border-line-custom-color-enabled' || theme_style_key == 'sidebar-border-line-custom-color' || theme_style_key == 'general-colors-elements-border-color' ) {

                        var custom_enabled = wp.customize.value( 'ueldo_theme_options[styles][sidebar-border-line-custom-color-enabled]' )();
                        var color = custom_enabled == 'yes' ? wp.customize.value( 'ueldo_theme_options[styles][sidebar-border-line-custom-color]' )() : wp.customize.value( 'ueldo_theme_options[styles][general-colors-elements-border-color]' )();
                        var css = ' .ueldo-content-default .ueldo-content-container:before, .vc_row.ueldo-row-with-sidebar-on-left .ueldo-row-with-sidebar-divider-line, .vc_row.ueldo-row-with-sidebar-on-right .ueldo-row-with-sidebar-divider-line { background: '+ color +' !important; }';

                        $( '#ueldo-customized-styles-css' ).append( css );
                    }

                   /**
                    *
                    * end of custom rules.
                    *
                    */

                });

            });

        });

    });

   /**
    *
    * end of jquery functions.
    *
    */

});