<?php

   /**
    *
    * custom field for wordpress customizer
    * - box shadow
    *
    */

    class ueldo_wp_customizer_field_box_shadow extends WP_Customize_Control {

       /**
        *
        * official control name
        *
        */

        public $type = 'ueldo-box-shadow';

       /**
        *
      	 * enqueue scripts and styles
      	 *
      	 */

       	public function enqueue() {

            # enqueue alpha color picker javascript functions
            wp_enqueue_script( 'wp-color-picker-alpha', get_stylesheet_directory_uri() . '/_assets/_libs/alpha-color-picker/wp-color-picker-alpha.js', array( 'jquery', 'wp-color-picker' ), null, true );

            # enqueue box shadow field javascript functions
            wp_enqueue_script( 'box-shadow-field', get_stylesheet_directory_uri() . '/_assets/_js/box-shadow-field.js', array( 'jquery' ), null, true );
       	}

       /**
        *
        * render the control
        *
        */

        public function render_content() {

            # create colors cache object
            $colors_cache = new ueldo_styles_cache();

            # split the box shadow value
            $box_shadow = $colors_cache -> split_box_shadow( $this -> value() );

            # output the label if it was passed in
            if( isset( $this -> label ) && '' !== $this -> label ) {

                ?>
                <span class="customize-control-title"><?php echo sanitize_text_field( $this -> label ); ?></span>
                <?php
            }

            # output the description if it was passed in
            if( isset( $this -> description ) && '' !== $this -> description ) {

                ?>
                <span class="description customize-control-description"><?php echo sanitize_text_field( $this -> description ); ?></span>
                <?php
            }

            ?>
            <div class="ueldo-customizer-box-shadow-field-container">

                <input class="ueldo-customizer-field-box-shadow-value" type="hidden" <?php $this -> link(); ?> />

                <div class="ueldo-customizer-box-shadow-field-container-option">

                    <h5 class="ueldo-customizer-box-shadow-field-heading-without-margin-top"><?php echo esc_html( __( 'Horizontal length:', 'ueldo' ) ); ?></h5>
                    <span class="ueldo-customizer-px-field"><input type="text" class="ueldo-validate-number-field ueldo-customizer-box-shadow-field-container-option-value" data-number-field-minus-allowed="yes" value="<?php echo esc_attr( $box_shadow['horizontal-length'] ); ?>" data-box-shadow-field-option="horizontal-length" /></span>

                </div>

                <div class="ueldo-customizer-box-shadow-field-container-option ueldo-customizer-box-shadow-field-container-option-last">

                    <h5 class="ueldo-customizer-box-shadow-field-heading-without-margin-top"><?php echo esc_html( __( 'Vertical length:', 'ueldo' ) ); ?></h5>
                    <span class="ueldo-customizer-px-field"><input type="text" class="ueldo-validate-number-field ueldo-customizer-box-shadow-field-container-option-value" data-number-field-minus-allowed="yes" value="<?php echo esc_attr( $box_shadow['vertical-length'] ); ?>" data-box-shadow-field-option="vertical-length" /></span>

                </div>

                <div class="ueldo-customizer-box-shadow-field-container-option">

                    <h5><?php echo esc_html( __( 'Blur radius:', 'ueldo' ) ); ?></h5>
                    <span class="ueldo-customizer-px-field"><input type="text" class="ueldo-validate-number-field ueldo-customizer-box-shadow-field-container-option-value" data-number-field-minus-allowed="yes" value="<?php echo esc_attr( $box_shadow['blur-radius'] ); ?>" data-box-shadow-field-option="blur-radius" /></span>

                </div>

                <div class="ueldo-customizer-box-shadow-field-container-option ueldo-customizer-box-shadow-field-container-option-last">

                    <h5><?php echo esc_html( __( 'Spread radius:', 'ueldo' ) ); ?></h5>
                    <span class="ueldo-customizer-px-field"><input type="text" class="ueldo-validate-number-field ueldo-customizer-box-shadow-field-container-option-value" data-number-field-minus-allowed="yes" value="<?php echo esc_attr( $box_shadow['spread-radius'] ); ?>" data-box-shadow-field-option="spread-radius" /></span>

                </div>

                <div class="ueldo-customizer-box-shadow-field-container-option-color">

                    <h5><?php echo esc_html( __( 'Color:', 'ueldo' ) ); ?></h5>
                    <input class="ueldo-customizer-alpha-color-control color-picker" type="text" data-alpha="true" data-default-color="<?php echo esc_attr( $colors_cache -> get_box_shadow_part( $this -> settings['default'] -> default, 'color' ) ); ?>" value="<?php echo esc_attr( $box_shadow['color'] ); ?>" />

                </div>

            </div>
            <?php
        }

       /**
        *
        * end of class methods
        *
        */
    }

   /**
    *
    * end of class.
    *
    */

?>