<?php

   /**
    *
    * styles cache class
    *
    */

    class ueldo_styles_cache {

       /**
        *
        * styles cache object
        *
        */

        public $styles = array();

       /**
        *
        * default styles cache object
        *
        */

        public $default_styles = array();

       /**
        *
        * patterned colors
        *
        */

        public $patterned_colors = array();

       /**
        *
        * patterned styles
        *
        */

        public $patterned_styles = array();

       /**
        *
        * box shadows parts
        *
        */

        public $box_shadows_parts = array();

       /**
        *
        * get the color
        *
        */

        public function __construct() {

            # global variables
            global $ueldo_cache_option;

            # get theme options
            $options = $ueldo_cache_option -> get_option( 'ueldo_theme_options' );

            # do we have styles options?
            if( isset( $options['styles'] ) && is_array( $options['styles'] ) && count( $options['styles'] ) > 0 ) {

                # save styles from theme options
                $this -> styles = $options['styles'];

                # remove temporary variables
                unset( $options );
            }

            # get the default styles
            $this -> default_styles = ueldo_get_default_theme_styles();
        }

       /**
        *
        * refresh cache variables
        *
        */

        public function refresh() {

            # get option, not from cache
            $options = get_option( 'ueldo_theme_options' );

            # clear all variables
            $this -> clear_all_variables();

            # do we have styles options?
            if( isset( $options['styles'] ) && is_array( $options['styles'] ) && count( $options['styles'] ) > 0 ) {

                # save styles from theme options
                $this -> styles = $options['styles'];

                # remove temporary variables
                unset( $options );
            }

            # get the default styles
            $this -> default_styles = ueldo_get_default_theme_styles();
        }

       /**
        *
        * clear all variables
        *
        */

        public function clear_all_variables() {

            # clear styles variable
            $this -> styles = array();

            # clear default styles variable
            $this -> default_styles = array();

            # clear patterned colors variable
            $this -> patterned_colors = array();

            # clear patterned styles variable
            $this -> patterned_styles = array();

            # clear box shadow parts variable
            $this -> box_shadow_parts = array();
        }

       /**
        *
        * get single style value
        *
        */

        public function get_style( $key, $pattern = false ) {

            # do we have the pattern?
            if( $pattern !== false && isset( $pattern['is_rgba'] ) && $pattern['is_rgba'] == 'yes' ) {

                # get the pattern key
                $pattern_key = md5( serialize( $pattern ) );

                # do we have the pattern result already saved?
                if( !isset( $this -> patterned_colors[$pattern_key] ) ) {

                    # get base color
                    $color = isset( $this -> styles[esc_attr( $key )] ) ? $this -> styles[esc_attr( $key )] : false;

                    # do we have the color?
                    if( $color === false || $this -> is_color_correct( $color, $key ) == false ) $color = $this -> default_styles[esc_attr( $key )];

                    # translate color to rgba value
                    $color_rgb = ueldo_hex2rgb( $color );

                    # do we have the color?
                    if( $color_rgb === false ) return( $this -> unknown_style( $key ) );
                    else {

                        # do we have opacity different than 100%?
                        if( isset( $pattern['opacity'] ) && $pattern['opacity'] != '1' ) {

                            # calculation
                            $color_rgb['a'] = ( string ) round( ( float ) $color_rgb['a'] * ( float ) $pattern['opacity'], 2 );
                        }

                        # save pattern result
                        $this -> patterned_colors[$pattern_key] = 'rgba( '. esc_attr( $color_rgb['rgb'] ) .', '. esc_attr( $color_rgb['a'] ) .' )';
                    }
                }

                # return result
                return( $this -> patterned_colors[$pattern_key] );
            }

            # return color
            else {

                # get the color from theme options
                $color = isset( $this -> styles[esc_attr( $key )] ) ? $this -> styles[esc_attr( $key )] : false;

                # return result
                return( $color === false || $this -> is_color_correct( $color, $key ) == false ? $this -> default_styles[esc_attr( $key )] : $color );
            }
        }

       /**
        *
        * get default color value
        *
        */

        public function unknown_style( $key ) {

            # return transparent
            return( 'transparent' );
        }

       /**
        *
        * is color correct?
        *
        */

        public function is_color_correct( $string, $key ) {

            # if the color is a box shadow, return true
            if( strpos( $key, 'color' ) === false || strpos( $key, 'box-shadow' ) !== false || strpos( $key, 'custom-styles-enabled' ) !== false ) return( true );
            else {

                # regular expresion
                $regex = '/^(\#[\da-f]{3}|\#[\da-f]{6}|rgba\(((\d{1,2}|1\d\d|2([0-4]\d|5[0-5]))\s*,\s*){2}((\d{1,2}|1\d\d|2([0-4]\d|5[0-5]))\s*)(,\s*(0\.\d+|1))\)|hsla\(\s*((\d{1,2}|[1-2]\d{2}|3([0-5]\d|60)))\s*,\s*((\d{1,2}|100)\s*%)\s*,\s*((\d{1,2}|100)\s*%)(,\s*(0\.\d+|1))\)|rgb\(((\d{1,2}|1\d\d|2([0-4]\d|5[0-5]))\s*,\s*){2}((\d{1,2}|1\d\d|2([0-4]\d|5[0-5]))\s*)|hsl\(\s*((\d{1,2}|[1-2]\d{2}|3([0-5]\d|60)))\s*,\s*((\d{1,2}|100)\s*%)\s*,\s*((\d{1,2}|100)\s*%)\))$/';

                # return result
                return( preg_match( $regex, str_replace( ' ', '', $string ) ) );
            }
        }

       /**
        *
        * get style from pattern
        *
        */

        public function get_style_from_pattern( $key ) {

            # do we have patterned style already added?
            if( !isset( $this -> patterned_styles[$key] ) ) {

                # get pattern
                $pattern = ueldo_get_color_pattern_options( $key );

                # walk for each pattern values
                foreach( $pattern['values'] as $pattern_key => $pattern_value ) {

                    # update pattern value
                    $pattern['pattern'] = str_replace( '{'. esc_attr( $pattern_key ) .'}', $this -> get_style( $pattern_value['color'], $pattern_value ), $pattern['pattern'] );
                }

                # return result
                $this -> patterned_styles[$key] = $pattern['pattern'];
            }

            # return patterned style
            return( $this -> patterned_styles[$key] );
        }

       /**
        *
        * split the box shadow value
        *
        */

        public function split_box_shadow( $box_shadow ) {

            # split the box shadow value by space
            $box_shadow_exploded = explode( ' ', str_replace( 'inset ', '', $box_shadow ) );

            # prepare results array
            $result = array(
                'horizontal-length' => '0',
                'vertical-length' => '0',
                'blur-radius' => '0',
                'spread-radius' => '0',
                'color' => ''
            );

            # walk for each exploded part
            for( $i = 0; $i < count( $box_shadow_exploded ); $i++ ) {

                # remove "px" string
                $box_shadow_exploded[$i] = str_replace( 'px', '', $box_shadow_exploded[$i] );

                # is color?
                if( !preg_match( '/^[0-9-]+$/', $box_shadow_exploded[$i] ) ) {

                    $result['color'] .= $box_shadow_exploded[$i] .' ';
                }

                # box shadow param
                else {

                    if( $i === 0 ) $result['horizontal-length'] = $box_shadow_exploded[$i];
                    else if( $i === 1 ) $result['vertical-length'] = $box_shadow_exploded[$i];
                    else if( $i === 2 ) $result['blur-radius'] = $box_shadow_exploded[$i];
                    else if( $i === 3 ) $result['spread-radius'] = $box_shadow_exploded[$i];
                }
            }

            # trim the color
            $result['color'] = trim( $result['color'] );

            # return result
            return( $result );
        }

       /**
        *
        * get box shadow part
        *
        */

        public function get_box_shadow_part( $box_shadow, $part ) {

            # do we have box shadow already splited?
            if( !isset( $this -> box_shadows_parts[$box_shadow] ) ) {

                # save splitted box shadow
                $this -> box_shadows_parts[$box_shadow] = $this -> split_box_shadow( $box_shadow );
            }

            # return result
            return( $this -> box_shadows_parts[$box_shadow][$part] );
        }

       /**
        *
        * get box shadow part from pattern
        *
        */

        public function get_box_shadow_part_from_pattern( $pattern, $part ) {

            # return box shadow part
            return( $this -> get_box_shadow_part( $this -> get_style_from_pattern( $pattern ), $part ) );
        }

       /**
        *
        * get box shadow part from color key
        *
        */

        public function get_box_shadow_part_from_color_key( $key, $part ) {

            # return box shadow part
            return( $this -> get_box_shadow_part( $this -> get_style( $key ), $part ) );
        }

       /**
        *
        * get style depended on another
        *
        */

        public function get_style_key_depended( $style, $default, $dependency ) {

            # dependency flag
            $allowed = true;

            # check the dependency
            foreach( $dependency as $key => $value ) {

                # find dependency option
                if( ( isset( $this -> styles[esc_attr( $key )] ) ? $this -> styles[esc_attr( $key )] : $this -> default_styles[esc_attr( $key )] ) != $value ) {

                    # style not allowed
                    $allowed = false;

                    # break the loop
                    break;
                }
            }

            # return result
            return( $allowed ? $style : $default );
        }

       /**
        *
        * destructor
        *
        */

        public function __destruct() {

            # clear the variables
            unset( $this -> styles, $this -> default_styles, $this -> patterned_colors, $this -> patterned_styles );
        }

       /**
        *
        * end of class methods.
        *
        */
    }

   /**
    *
    * define styles cache class object
    *
    */

    $ueldo_styles_cache = new ueldo_styles_cache();

   /**
    *
    * end of class.
    *
    */

?>