<?php

    # prevent direct file access
    if( !defined( 'ABSPATH' ) ) exit;

   /**
    *
    * cache class for "get_option" wordpress function
    *
    */

    class ueldo_cache_option {

       /**
        *
        * loaded options array
        *
        */

        public $options = array();

       /**
        *
        * loaded posts array
        *
        */

        public $posts = array();

       /**
        *
        * clear option value
        *
        */

        public function clear_option( $key ) {

            # do we have the option?
            if( isset( $this -> options[$key] ) ) unset( $this -> options[$key] );
        }

       /**
        *
        * get option value
        *
        */

        public function get_option( $key ) {

            # do we have the option?
            if( !isset( $this -> options[$key] ) ) {

                # get option from database and save to cache array
                $this -> options[$key] = get_option( $key );
            }

            # return option value
            return( $this -> options[$key] );
        }

       /**
        *
        * get post data
        *
        */

        public function get_post( $id ) {

            # do we have the post?
            if( !isset( $this -> posts[$id] ) ) {

                # get option from database and save to cache array
                $this -> posts[$id] = get_post( $id );
            }

            # return option value
            return( $this -> posts[$id] );
        }

       /**
        *
        * destructor
        *
        */

        public function __destruct() {

            # clear the variables
            unset( $this -> options, $this -> posts );
        }

       /**
        *
        * end of class.
        *
        */
    }

    # create object of cache option class
    $ueldo_cache_option = new ueldo_cache_option();

   /**
    *
    * get all default theme options
    *
    */

    function ueldo_get_all_default_theme_options() {

        # default values
        return( array(
            '404-page-id' => array( 'all' => 'default' ),
            'blog-posts-list-style' => array(
                'posts-list-style' => 'default',
                'display-post-data-under-title' => 'yes',
                'featured-image-reverse-indent-allowed' => 'yes'
            ),
            'blog-sidebar' => array(
                'posts-list' => 'yes-right',
                'single-post' => 'yes-right',
                'responsive-style' => 'static'
            ),
            'boxed-website' => array(
                'enabled' => 'no',
                'large-content-width' => '1100',
                'large-content-space' => '50',
                'medium-content-width' => '890',
                'medium-content-space' => '50',
                'small-content-width' => '665',
                'small-content-space' => '50'
            ),
            'comment-textarea-at-top' => 'yes',
            'dynamic-theme-styles-cache' => array(
                'enabled' => 'no',
                'clear-cache' => 'all-the-time-when-logged-in'
            ),
            'facebook-fanpage-url' => array( 'all' => '' ),
            'featured-image-on-lists-only' => 'no',
            'fonts' => array(
                'general-font-family' => array( 'all' => 'Roboto' ),
                'general-font-weight' => array( 'all' => '300' ),
                'general-font-subset' => array( 'all' => 'latin' ),
                'general-font-smoothing' => array( 'all' => 'yes' ),
                'general-bold-font-family' => array( 'all' => 'Roboto' ),
                'general-bold-font-weight' => array( 'all' => '600' ),
                'general-bold-font-subset' => array( 'all' => 'latin' ),
                'general-bold-font-smoothing' => array( 'all' => 'yes' ),
                'menu-font-family' => array( 'all' => 'Roboto' ),
                'menu-font-weight' => array( 'all' => '500' ),
                'menu-font-subset' => array( 'all' => 'latin' ),
                'menu-font-smoothing' => array( 'all' => 'yes' ),
                'headings-font-family' => array( 'all' => 'Roboto' ),
                'headings-font-weight' => array( 'all' => '500' ),
                'headings-font-subset' => array( 'all' => 'latin' ),
                'headings-font-smoothing' => array( 'all' => 'yes' ),
                'headings-slim-font-family' => array( 'all' => 'Roboto' ),
                'headings-slim-font-weight' => array( 'all' => '300' ),
                'headings-slim-font-subset' => array( 'all' => 'latin' ),
                'headings-slim-font-smoothing' => array( 'all' => 'yes' ),
                'headings-bold-font-family' => array( 'all' => 'Roboto' ),
                'headings-bold-font-weight' => array( 'all' => '900' ),
                'headings-bold-font-subset' => array( 'all' => 'latin' ),
                'headings-bold-font-smoothing' => array( 'all' => 'yes' ),
                'headings-subtitle-font-family' => array( 'all' => 'Roboto' ),
                'headings-subtitle-font-weight' => array( 'all' => '700' ),
                'headings-subtitle-font-subset' => array( 'all' => 'latin' ),
                'headings-subtitle-font-smoothing' => array( 'all' => 'yes' ),
                'buttons-font-family' => array( 'all' => 'Roboto' ),
                'buttons-font-weight' => array( 'all' => '700' ),
                'buttons-font-subset' => array( 'all' => 'latin' ),
                'buttons-font-smoothing' => array( 'all' => 'yes' ),
                'form-fields-font-family' => array( 'all' => 'Roboto' ),
                'form-fields-font-weight' => array( 'all' => '400' ),
                'form-fields-font-subset' => array( 'all' => 'latin' ),
                'form-fields-font-smoothing' => array( 'all' => 'yes' ),
                'blockquote-font-family' => array( 'all' => 'Roboto' ),
                'blockquote-font-weight' => array( 'all' => '500' ),
                'blockquote-font-subset' => array( 'all' => 'latin' ),
                'blockquote-font-smoothing' => array( 'all' => 'yes' ),
                'alert-messages-font-family' => array( 'all' => 'Roboto' ),
                'alert-messages-font-weight' => array( 'all' => '400' ),
                'alert-messages-font-subset' => array( 'all' => 'latin' ),
                'alert-messages-font-smoothing' => array( 'all' => 'yes' )
            ),
            'footer-content' => array(
                'get-content-from' => array( 'all' => 'default' ),
                'position' => array( 'all' => 'static' ),
                'ueldo_theme_options_footer_content_all' => date( 'Y' ) .' &copy; <a href="'. esc_url( ueldo_get_external_url( 'ueldo-com' ) ) .'">'. esc_html( __( 'Ueldo WordPress Theme', 'ueldo' ) ) .'</a> '. esc_html( __( 'created with heart by', 'ueldo' ) ) .' <a href="'. esc_url( ueldo_get_external_url( 'martanian-portfolio' ) ) .'" target="_blank">Martanian</a>'
            ),
            'google-maps' => array(
                'api-key' => '',
                'next-map-id' => '1'
            ),
            'header' => array(
                'get-content-from' => array( 'all' => 'default' ),
                'position' => array( 'all' => 'flying' ),
                'use-second-header' => array( 'all' => 'no' ),
                'get-second-content-from' => array( 'all' => 'default' ),
                'second-header-visible-from' => array( 'all' => '400' ),
                'default-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                'second-header-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) )
            ),
            'lazy-load-images' => array(
                'enabled' => 'no',
                'threshold' => '0'
            ),
            'loader-animation' => array(
                'enabled' => 'yes',
                'style' => '01',
                'add-logo' => 'no',
                'space-between-logo-and-spinner' => '30',
                'logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                'custom-colors-enabled' => 'no',
                'custom-colors-background' => '#fff',
                'custom-colors-spinner' => '#145ec1'
            ),
            'local-scrolling-links-animation' => array(
                'enabled' => 'yes',
                'animation-speed' => '1000'
            ),
            'opening-hours-status' => array( 'next-status-id' => '1' ),
            'retina-images-replacement' => array(
                'enabled' => 'no'
            ),
            'rtl' => array(
                'is-rtl' => array( 'all' => 'no' ),
                'load-rtl-admin-styles' => array( 'all' => 'auto' )
            ),
            'side-menu' => array(
                'style' => 'flying-default-hidden',
                'closing-rules-anywhere-outside' => '',
                'closing-rules-any-link-inside' => '',
                'menu-key' => array( 'all' => '' ),
                'menu-link-font-family' => array( 'all' => 'Roboto' ),
                'menu-link-font-weight' => array( 'all' => '300' ),
                'menu-link-font-subset' => array( 'all' => 'latin' ),
                'menu-link-font-smoothing' => array( 'all' => 'yes' ),
                'menu-position' => 'left',
                'menu-links-alignment' => 'left',
                'opacity-animation-enabled' => 'yes',
                'submenu-links' => 'visible-always',
                'menu-vertical-alignment' => 'middle',
                'custom-sizes-enabled' => 'no',
                'custom-sizes-container-width' => '300',
                'custom-sizes-menu-link-font-size' => '14',
                'custom-sizes-menu-link-font-line-height' => '1.0',
                'custom-sizes-menu-link-font-letter-spacing' => '0',
                'custom-sizes-menu-link-padding-top-bottom' => '15',
                'custom-sizes-menu-link-padding-left-right' => '25',
                'custom-sizes-menu-link-margin-top-bottom' => '0',
                'custom-sizes-menu-link-margin-left-right' => '0',
                'custom-sizes-menu-link-bottom-border-width' => '1',
                'custom-sizes-display-bottom-border-for-last-menu-link' => 'hide',
                'custom-sizes-menu-icon-font-size' => '10',
                'custom-sizes-menu-icon-margin-top' => '0',
                'custom-sizes-menu-margin-between-icon-and-title' => '10',
                'custom-sizes-padding-top-bottom-additional-element-before-menu' => '20',
                'custom-sizes-padding-left-right-additional-element-before-menu' => '30',
                'custom-sizes-margin-top-additional-element-before-menu' => '0',
                'custom-sizes-margin-right-additional-element-before-menu' => '0',
                'custom-sizes-margin-bottom-additional-element-before-menu' => '0',
                'custom-sizes-margin-left-additional-element-before-menu' => '0',
                'custom-sizes-padding-top-bottom-additional-element-after-menu' => '20',
                'custom-sizes-padding-left-right-additional-element-after-menu' => '30',
                'custom-sizes-margin-top-additional-element-after-menu' => '0',
                'custom-sizes-margin-right-additional-element-after-menu' => '0',
                'custom-sizes-margin-bottom-additional-element-after-menu' => '0',
                'custom-sizes-margin-left-additional-element-after-menu' => '0',
                'ueldo_theme_options_side_menu_additional_content_before_all' => '',
                'ueldo_theme_options_side_menu_additional_content_after_all' => ''
            ),
            'single-blog-post-style' => array(
                'display-post-data-under-title' => 'yes',
                'blog-post-data-and-title-centered' => 'yes',
                'featured-image-reverse-indent-allowed' => 'yes',
                'featured-image-position' => 'above-post-title-and-data'
            ),
            'styles-default' => array(
                'general-colors-website-background' => '#fff',
                'general-colors-main-color' => '#145ec1',
                'general-colors-main-color-contrast-text-color' => '#fff',
                'general-colors-headings-color' => '#313131',
                'general-colors-headings-subtitle-color' => '#c5c5c5',
                'general-colors-content-color' => '#757575',
                'general-colors-blockquote-color' => '#757575',
                'general-colors-blog-post-data-color' => '#145ec1',
                'general-colors-preformatted-text-color' => '#313131',
                'general-colors-elements-border-color' => '#f1f1f1',
                'general-colors-elements-hover-border-color' => '#dae2ec',
                'general-colors-elements-box-shadow' => '0 0 0 0 rgba( 255, 255, 255, 0.00 )',
                'general-colors-elements-hover-box-shadow' => '0 0 35px rgba( 0, 0, 0, 0.05 )',
                'general-colors-elements-inset-border-color' => '#f2f4f8',
                'general-colors-elements-background-icon-color' => 'rgba( 0, 0, 0, 0.03 )',
                'general-colors-elements-heading-or-active-tab-background-color' => '#fbfbfb',
                'general-colors-icon-color' => '#eee',
                'general-colors-image-box-shadow' => '-8px 8px 50px rgba( 0, 0, 0, 0.1 )',
                'general-colors-circle-navigation-background-color' => '#f1f1f1',
                'general-colors-comment-author-avatar-box-shadow' => '-8px 8px 75px rgba( 0, 0, 0, 0.05 )',
                'general-colors-pulsating-circles-central-circle-box-shadow' => '0 0 15px rgba( 0, 0, 0, 0.05 )',
                'general-colors-pricing-list-inset-box-shadow' => 'inset 5px 0 10px -8px rgba( 0, 0, 0, 0.15 )',
                'general-colors-full-width-elements-inset-box-shadow-top' => 'inset 0 20px 20px rgba( 0, 0, 0, 0.05 )',
                'general-colors-full-width-elements-inset-box-shadow-bottom' => 'inset 0 -20px 20px rgba( 0, 0, 0, 0.05 )',
                'general-colors-google-map-marker-icon-color' => '#145ec1',
                'general-colors-google-map-marker-icon-container-background-color' => '#fff',
                'general-colors-google-map-marker-icon-container-box-shadow' => '0 5px 20px rgba( 0, 0, 0, 0.1 )',
                'header-bar-and-menu-background-color' => '#fff',
                'header-bar-and-menu-box-shadow' => '0 0 35px rgba( 0, 0, 0, 0.1 )',
                'header-bar-and-menu-link-color' => '#a9a9a9',
                'header-bar-and-menu-active-or-hover-link-color' => '#145ec1',
                'header-bar-and-menu-submenu-background-color' => '#145ec1',
                'header-bar-and-menu-submenu-box-shadow' => '0 4px 10px rgba( 0, 0, 0, 0.1 )',
                'header-bar-and-menu-submenu-element-border-bottom-color' => 'rgba( 0, 0, 0, 0.05 )',
                'header-bar-and-menu-submenu-element-link-color' => 'rgba( 255, 255, 255, 0.6 )',
                'header-bar-and-menu-submenu-element-active-or-hover-link-color' => '#fff',
                'image-loader-color' => '#fff',
                'image-loader-background-color' => '#ccc',
                'image-loader-color-for-call-to-action-widget' => '#ccc',
                'point-of-interest-pulse-color' => '#0a3d82',
                'point-of-interest-box-shadow' => '0 0 10px rgba( 0, 0, 0, 0.3 )',
                'point-of-interest-close-color' => '#cc6164',
                'info-box-element-background-color' => '#f4f8fd',
                'info-box-element-border-color' => '#dee8f5',
                'opening-hours-status-color-when-open' => '#6ad201',
                'opening-hours-status-color-when-closed' => '#e73a30',
                'sidebar-background-color' => '#fff',
                'sidebar-border-line-custom-color-enabled' => 'no',
                'sidebar-border-line-custom-color' => '#f1f1f1',
                'flying-sidebar-border-color' => '#ddd',
                'flying-sidebar-box-shadow' => '-8px 0 65px rgba( 0, 0, 0, 0.12 )',
                'play-video-button-color' => '#fff',
                'play-video-button-box-shadow' => '0 0 60px rgba( 0, 0, 0, 0.55 )',
                'play-video-button-title-background-color' => 'rgba( 11, 11, 11, 0.7 )',
                'play-video-button-title-text-color' => '#fff',
                'side-menu-box-shadow' => '-5px 0 20px rgba( 20, 76, 152, 0.15 )',
                'side-menu-background-color' => '#145ec1',
                'side-menu-link-color' => 'rgba( 255, 255, 255, 0.6 )',
                'side-menu-link-border-bottom-color' => 'rgba( 255, 255, 255, 0.05 )',
                'side-menu-link-background-color' => 'rgba( 255, 255, 255, 0.00 )',
                'side-menu-link-color-hover' => '#fff',
                'side-menu-link-border-bottom-color-hover' => 'rgba( 255, 255, 255, 0.05 )',
                'side-menu-link-background-color-hover' => 'rgba( 255, 255, 255, 0.00 )',
                'side-menu-active-link-color' => '#fff',
                'side-menu-active-link-border-bottom-color' => 'rgba( 255, 255, 255, 0.05 )',
                'side-menu-active-link-background-color' => 'rgba( 255, 255, 255, 0.00 )',
                'side-menu-link-icon-color' => 'rgba( 255, 255, 255, 0.6 )',
                'side-menu-link-icon-color-hover' => '#fff',
                'side-menu-active-link-icon-color' => '#fff',
                'boxed-website-box-shadow' => '0 0 25px rgba( 0, 0, 0, 0.1 )',
                'forms-field-border-color' => '#d9dbde',
                'forms-field-border-color-on-hover' => '#ccc',
                'forms-field-border-color-on-focus' => '#aaa',
                'forms-field-border-color-for-invalid-values' => '#f1d5d6',
                'forms-field-text-color' => '#313131',
                'forms-field-background-color' => '#fff',
                'forms-field-box-shadow' => '0 0 0 rgba( 0, 0, 0, 0.00 )',
                'forms-field-inset-box-shadow' => '0 0 3px rgba( 0, 0, 0, 0.05 )',
                'forms-checkbox-radio-main-color' => '#145ec1',
                'forms-placeholder-text-color' => '#888',
                'forms-invalid-field-tip-text-color' => '#cc6164',
                'forms-select-and-date-field-icon-color' => '#ddd',
                'forms-select-and-date-field-icon-border-color' => '#ececec',
                'forms-select-and-date-field-icon-background-color' => '#fbfbfb',
                'datepicker-container-background-color' => '#2a2a2a',
                'datepicker-container-box-shadow' => '0 10px 35px rgba( 0, 0, 0, 0.03 )',
                'datepicker-headings-color' => '#fff',
                'datepicker-next-prev-arrows-color' => 'rgba( 255, 255, 255, 0.5 )',
                'datepicker-next-prev-arrows-color-hover' => '#fff;',
                'datepicker-weekdays-and-buttons-color' => 'rgba( 255, 255, 255, 0.5 )',
                'datepicker-single-day-background-color' => '#313131',
                'datepicker-single-day-text-color' => 'rgba( 255, 255, 255, 0.35 )',
                'datepicker-single-day-background-color-hover' => '#145ec1',
                'datepicker-single-day-text-color-hover' => '#fff',
                'datepicker-single-day-disabled-text-color' => 'rgba( 255, 255, 255, 0.1 )',
                'datepicker-dividers-border-color' => '#313131',
                'datepicker-time-slider-background-color' => 'rgba( 255, 255, 255, 0.15 )',
                'datepicker-time-slider-handle-background-color' => '#fff',
                'two-images-difference-shortcode-handle-color' => '#fff',
                'two-images-difference-shortcode-handle-box-shadow' => '0 0 12px rgba( 51, 51, 51, 0.5 )',
                'two-images-difference-shortcode-overlay-background-color' => 'rgba( 0, 0, 0, 0.5 )',
                'two-images-difference-shortcode-before-and-after-label-background-color' => 'rgba( 255, 255, 255, 0.2 )',
                'two-images-difference-shortcode-before-and-after-label-text-color' => '#fff',
                'gallery-image-overlay-background-color' => 'rgba( 31, 31, 31, 0.45 )',
                'gallery-image-buttons-color' => '#fff',
                'gallery-image-buttons-box-shadow' => '0 0 60px rgba( 0, 0, 0, 0.55 )',
                'announcement-info-content-color' => '#7aa8e8',
                'announcement-info-border-color' => '#dee6f1',
                'announcement-info-background-color' => '#e8f0fa',
                'announcement-info-box-shadow' => '0 0 15px 0 rgba( 232, 240, 250, 0.7 )',
                'announcement-success-content-color' => '#8da662',
                'announcement-success-border-color' => '#e3ead6',
                'announcement-success-background-color' => '#f3f8ec',
                'announcement-success-box-shadow' => '0 0 15px 0 rgba( 243, 248, 236, 0.75 )',
                'announcement-error-content-color' => '#cc6164',
                'announcement-error-border-color' => '#f1d5d6',
                'announcement-error-background-color' => '#f7e6e7',
                'announcement-error-box-shadow' => '0 0 15px 0 rgba( 247, 230, 231, 0.75 )',
                'announcement-warning-content-color' => '#deac31',
                'announcement-warning-border-color' => '#f1e5c8',
                'announcement-warning-background-color' => '#fff6dd',
                'announcement-warning-box-shadow' => '0 0 15px 0 rgba( 255, 246, 221, 0.75 )',
                'buttons-global-button-background-color' => '#145ec1',
                'buttons-global-button-border-color' => '#145ec1',
                'buttons-global-button-text-color' => '#fff',
                'buttons-global-button-icon-color' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-global-button-box-shadow' => '0 0 0 0 rgba( 255, 255, 255, 0.00 )',
                'buttons-global-button-background-color-hover' => '#2470d6',
                'buttons-global-button-border-color-hover' => '#2470d6',
                'buttons-global-button-text-color-hover' => '#fff',
                'buttons-global-button-icon-color-hover' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-global-button-box-shadow-hover' => '0px 10px 35px rgba( 36, 112, 214, 0.25 )',
                'buttons-global-button-font-size' => '14',
                'buttons-global-button-letter-spacing' => '0',
                'buttons-global-button-border-radius' => '2',
                'buttons-global-button-border-width' => '1',
                'buttons-global-button-icon-size' => '14',
                'buttons-global-button-margin-between-text-and-icon' => '15',
                'buttons-global-button-padding-top' => '16.5',
                'buttons-global-button-padding-right' => '28',
                'buttons-global-button-padding-bottom' => '16.5',
                'buttons-global-button-padding-left' => '28',
                'buttons-global-button-use-static-height' => 'yes',
                'buttons-global-button-static-height' => '50',
                'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                'buttons-read-more-button-background-color' => '#145ec1',
                'buttons-read-more-button-border-color' => '#145ec1',
                'buttons-read-more-button-text-color' => '#fff',
                'buttons-read-more-button-icon-color' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-read-more-button-box-shadow' => '0 0 0 0 rgba( 255, 255, 255, 0.00 )',
                'buttons-read-more-button-background-color-hover' => '#2470d6',
                'buttons-read-more-button-border-color-hover' => '#2470d6',
                'buttons-read-more-button-text-color-hover' => '#fff',
                'buttons-read-more-button-icon-color-hover' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-read-more-button-box-shadow-hover' => '0px 10px 35px rgba( 36, 112, 214, 0.25 )',
                'buttons-read-more-button-font-size' => '14',
                'buttons-read-more-button-letter-spacing' => '0',
                'buttons-read-more-button-border-radius' => '2',
                'buttons-read-more-button-border-width' => '1',
                'buttons-read-more-button-icon-size' => '14',
                'buttons-read-more-button-margin-between-text-and-icon' => '15',
                'buttons-read-more-button-padding-top' => '16.5',
                'buttons-read-more-button-padding-right' => '28',
                'buttons-read-more-button-padding-bottom' => '16.5',
                'buttons-read-more-button-padding-left' => '28',
                'buttons-read-more-button-use-static-height' => 'yes',
                'buttons-read-more-button-static-height' => '50',
                'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                'buttons-form-submit-button-background-color' => '#145ec1',
                'buttons-form-submit-button-border-color' => '#145ec1',
                'buttons-form-submit-button-text-color' => '#fff',
                'buttons-form-submit-button-icon-color' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-form-submit-button-box-shadow' => '0 0 0 0 rgba( 255, 255, 255, 0.00 )',
                'buttons-form-submit-button-background-color-hover' => '#2470d6',
                'buttons-form-submit-button-border-color-hover' => '#2470d6',
                'buttons-form-submit-button-text-color-hover' => '#fff',
                'buttons-form-submit-button-icon-color-hover' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-form-submit-button-box-shadow-hover' => '0px 10px 35px rgba( 36, 112, 214, 0.25 )',
                'buttons-form-submit-button-font-size' => '14',
                'buttons-form-submit-button-letter-spacing' => '0',
                'buttons-form-submit-button-border-radius' => '2',
                'buttons-form-submit-button-border-width' => '1',
                'buttons-form-submit-button-icon-size' => '14',
                'buttons-form-submit-button-margin-between-text-and-icon' => '15',
                'buttons-form-submit-button-padding-top' => '16.5',
                'buttons-form-submit-button-padding-right' => '28',
                'buttons-form-submit-button-padding-bottom' => '16.5',
                'buttons-form-submit-button-padding-left' => '28',
                'buttons-form-submit-button-use-static-height' => 'yes',
                'buttons-form-submit-button-static-height' => '50',
                'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles',
                'buttons-call-to-action-widget-button-background-color' => '#145ec1',
                'buttons-call-to-action-widget-button-border-color' => '#145ec1',
                'buttons-call-to-action-widget-button-text-color' => '#fff',
                'buttons-call-to-action-widget-button-icon-color' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-call-to-action-widget-button-box-shadow' => '0 0 0 0 rgba( 255, 255, 255, 0.00 )',
                'buttons-call-to-action-widget-button-background-color-hover' => '#2470d6',
                'buttons-call-to-action-widget-button-border-color-hover' => '#2470d6',
                'buttons-call-to-action-widget-button-text-color-hover' => '#fff',
                'buttons-call-to-action-widget-button-icon-color-hover' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-call-to-action-widget-button-box-shadow-hover' => '0px 10px 35px rgba( 36, 112, 214, 0.25 )',
                'buttons-call-to-action-widget-button-font-size' => '14',
                'buttons-call-to-action-widget-button-letter-spacing' => '0',
                'buttons-call-to-action-widget-button-border-radius' => '2',
                'buttons-call-to-action-widget-button-border-width' => '1',
                'buttons-call-to-action-widget-button-icon-size' => '14',
                'buttons-call-to-action-widget-button-margin-between-text-and-icon' => '15',
                'buttons-call-to-action-widget-button-padding-top' => '16.5',
                'buttons-call-to-action-widget-button-padding-right' => '28',
                'buttons-call-to-action-widget-button-padding-bottom' => '16.5',
                'buttons-call-to-action-widget-button-padding-left' => '28',
                'buttons-call-to-action-widget-button-use-static-height' => 'yes',
                'buttons-call-to-action-widget-button-static-height' => '50',
                'line-height-headings' => '1.4',
                'line-height-general' => '1.8',
                'font-size-h1' => '36',
                'font-size-h2' => '28',
                'font-size-h3' => '24',
                'font-size-h4' => '22',
                'font-size-h5' => '20',
                'font-size-h6' => '18',
                'font-size-content' => '15',
                'font-size-blockquote' => '18',
                'font-size-small-content' => '14',
                'font-size-smallest-content' => '13',
                'font-size-menu-links' => '14',
                'font-size-menu-links-icons' => '10',
                'font-size-call-to-action-widget-offer' => '48',
                'font-size-form-fields' => '13'
            ),
            'styles' => array(
                'general-colors-website-background' => '#fff',
                'general-colors-main-color' => '#145ec1',
                'general-colors-main-color-contrast-text-color' => '#fff',
                'general-colors-headings-color' => '#313131',
                'general-colors-headings-subtitle-color' => '#c5c5c5',
                'general-colors-content-color' => '#757575',
                'general-colors-blockquote-color' => '#757575',
                'general-colors-blog-post-data-color' => '#145ec1',
                'general-colors-preformatted-text-color' => '#313131',
                'general-colors-elements-border-color' => '#f1f1f1',
                'general-colors-elements-hover-border-color' => '#dae2ec',
                'general-colors-elements-box-shadow' => '0 0 0 0 rgba( 255, 255, 255, 0.00 )',
                'general-colors-elements-hover-box-shadow' => '0 0 35px rgba( 0, 0, 0, 0.05 )',
                'general-colors-elements-inset-border-color' => '#f2f4f8',
                'general-colors-elements-background-icon-color' => 'rgba( 0, 0, 0, 0.03 )',
                'general-colors-elements-heading-or-active-tab-background-color' => '#fbfbfb',
                'general-colors-icon-color' => '#eee',
                'general-colors-image-box-shadow' => '-8px 8px 75px rgba( 0, 0, 0, 0.2 )',
                'general-colors-circle-navigation-background-color' => '#f1f1f1',
                'general-colors-comment-author-avatar-box-shadow' => '-8px 8px 75px rgba( 0, 0, 0, 0.05 )',
                'general-colors-pulsating-circles-central-circle-box-shadow' => '0 0 15px rgba( 0, 0, 0, 0.05 )',
                'general-colors-pricing-list-inset-box-shadow' => 'inset 5px 0 10px -8px rgba( 0, 0, 0, 0.15 )',
                'general-colors-full-width-elements-inset-box-shadow-top' => 'inset 0 20px 20px rgba( 0, 0, 0, 0.05 )',
                'general-colors-full-width-elements-inset-box-shadow-bottom' => 'inset 0 -20px 20px rgba( 0, 0, 0, 0.05 )',
                'general-colors-google-map-marker-icon-color' => '#145ec1',
                'general-colors-google-map-marker-icon-container-background-color' => '#fff',
                'general-colors-google-map-marker-icon-container-box-shadow' => '0 5px 20px rgba( 0, 0, 0, 0.1 )',
                'header-bar-and-menu-background-color' => '#fff',
                'header-bar-and-menu-box-shadow' => '0 0 35px rgba( 0, 0, 0, 0.1 )',
                'header-bar-and-menu-link-color' => '#a9a9a9',
                'header-bar-and-menu-active-or-hover-link-color' => '#145ec1',
                'header-bar-and-menu-submenu-background-color' => '#145ec1',
                'header-bar-and-menu-submenu-box-shadow' => '0 4px 10px rgba( 0, 0, 0, 0.1 )',
                'header-bar-and-menu-submenu-element-border-bottom-color' => 'rgba( 0, 0, 0, 0.05 )',
                'header-bar-and-menu-submenu-element-link-color' => 'rgba( 255, 255, 255, 0.6 )',
                'header-bar-and-menu-submenu-element-active-or-hover-link-color' => '#fff',
                'image-loader-color' => '#fff',
                'image-loader-background-color' => '#ccc',
                'image-loader-color-for-call-to-action-widget' => '#ccc',
                'point-of-interest-pulse-color' => '#0a3d82',
                'point-of-interest-box-shadow' => '0 0 10px rgba( 0, 0, 0, 0.3 )',
                'point-of-interest-close-color' => '#cc6164',
                'info-box-element-background-color' => '#f4f8fd',
                'info-box-element-border-color' => '#dee8f5',
                'opening-hours-status-color-when-open' => '#6ad201',
                'opening-hours-status-color-when-closed' => '#e73a30',
                'sidebar-background-color' => '#fff',
                'sidebar-border-line-custom-color-enabled' => 'no',
                'sidebar-border-line-custom-color' => '#f1f1f1',
                'flying-sidebar-border-color' => '#ddd',
                'flying-sidebar-box-shadow' => '-8px 0 65px rgba( 0, 0, 0, 0.12 )',
                'play-video-button-color' => '#fff',
                'play-video-button-box-shadow' => '0 0 60px rgba( 0, 0, 0, 0.55 )',
                'play-video-button-title-background-color' => 'rgba( 11, 11, 11, 0.7 )',
                'play-video-button-title-text-color' => '#fff',
                'side-menu-box-shadow' => '-5px 0 20px rgba( 20, 76, 152, 0.15 )',
                'side-menu-background-color' => '#145ec1',
                'side-menu-link-color' => 'rgba( 255, 255, 255, 0.6 )',
                'side-menu-link-border-bottom-color' => 'rgba( 255, 255, 255, 0.05 )',
                'side-menu-link-background-color' => 'rgba( 255, 255, 255, 0.00 )',
                'side-menu-link-color-hover' => '#fff',
                'side-menu-link-border-bottom-color-hover' => 'rgba( 255, 255, 255, 0.05 )',
                'side-menu-link-background-color-hover' => 'rgba( 255, 255, 255, 0.00 )',
                'side-menu-active-link-color' => '#fff',
                'side-menu-active-link-border-bottom-color' => 'rgba( 255, 255, 255, 0.05 )',
                'side-menu-active-link-background-color' => 'rgba( 255, 255, 255, 0.00 )',
                'side-menu-link-icon-color' => 'rgba( 255, 255, 255, 0.6 )',
                'side-menu-link-icon-color-hover' => '#fff',
                'side-menu-active-link-icon-color' => '#fff',
                'boxed-website-box-shadow' => '0 0 25px rgba( 0, 0, 0, 0.1 )',
                'forms-field-border-color' => '#d9dbde',
                'forms-field-border-color-on-hover' => '#ccc',
                'forms-field-border-color-on-focus' => '#aaa',
                'forms-field-border-color-for-invalid-values' => '#f1d5d6',
                'forms-field-text-color' => '#313131',
                'forms-field-background-color' => '#fff',
                'forms-field-box-shadow' => '0 0 0 rgba( 0, 0, 0, 0.00 )',
                'forms-field-inset-box-shadow' => '0 0 3px rgba( 0, 0, 0, 0.05 )',
                'forms-checkbox-radio-main-color' => '#145ec1',
                'forms-placeholder-text-color' => '#888',
                'forms-invalid-field-tip-text-color' => '#cc6164',
                'forms-select-and-date-field-icon-color' => '#ddd',
                'forms-select-and-date-field-icon-border-color' => '#ececec',
                'forms-select-and-date-field-icon-background-color' => '#fbfbfb',
                'datepicker-container-background-color' => '#2a2a2a',
                'datepicker-container-box-shadow' => '0 10px 35px rgba( 0, 0, 0, 0.03 )',
                'datepicker-headings-color' => '#fff',
                'datepicker-next-prev-arrows-color' => 'rgba( 255, 255, 255, 0.5 )',
                'datepicker-next-prev-arrows-color-hover' => '#fff;',
                'datepicker-weekdays-and-buttons-color' => 'rgba( 255, 255, 255, 0.5 )',
                'datepicker-single-day-background-color' => '#313131',
                'datepicker-single-day-text-color' => 'rgba( 255, 255, 255, 0.35 )',
                'datepicker-single-day-background-color-hover' => '#145ec1',
                'datepicker-single-day-text-color-hover' => '#fff',
                'datepicker-single-day-disabled-text-color' => 'rgba( 255, 255, 255, 0.1 )',
                'datepicker-dividers-border-color' => '#313131',
                'datepicker-time-slider-background-color' => 'rgba( 255, 255, 255, 0.15 )',
                'datepicker-time-slider-handle-background-color' => '#fff',
                'two-images-difference-shortcode-handle-color' => '#fff',
                'two-images-difference-shortcode-handle-box-shadow' => '0 0 12px rgba( 51, 51, 51, 0.5 )',
                'two-images-difference-shortcode-overlay-background-color' => 'rgba( 0, 0, 0, 0.5 )',
                'two-images-difference-shortcode-before-and-after-label-background-color' => 'rgba( 255, 255, 255, 0.2 )',
                'two-images-difference-shortcode-before-and-after-label-text-color' => '#fff',
                'gallery-image-overlay-background-color' => 'rgba( 31, 31, 31, 0.45 )',
                'gallery-image-buttons-color' => '#fff',
                'gallery-image-buttons-box-shadow' => '0 0 60px rgba( 0, 0, 0, 0.55 )',
                'announcement-info-content-color' => '#7aa8e8',
                'announcement-info-border-color' => '#dee6f1',
                'announcement-info-background-color' => '#e8f0fa',
                'announcement-info-box-shadow' => '0 0 15px 0 rgba( 232, 240, 250, 0.7 )',
                'announcement-success-content-color' => '#8da662',
                'announcement-success-border-color' => '#e3ead6',
                'announcement-success-background-color' => '#f3f8ec',
                'announcement-success-box-shadow' => '0 0 15px 0 rgba( 243, 248, 236, 0.75 )',
                'announcement-error-content-color' => '#cc6164',
                'announcement-error-border-color' => '#f1d5d6',
                'announcement-error-background-color' => '#f7e6e7',
                'announcement-error-box-shadow' => '0 0 15px 0 rgba( 247, 230, 231, 0.75 )',
                'announcement-warning-content-color' => '#deac31',
                'announcement-warning-border-color' => '#f1e5c8',
                'announcement-warning-background-color' => '#fff6dd',
                'announcement-warning-box-shadow' => '0 0 15px 0 rgba( 255, 246, 221, 0.75 )',
                'buttons-global-button-background-color' => '#145ec1',
                'buttons-global-button-border-color' => '#145ec1',
                'buttons-global-button-text-color' => '#fff',
                'buttons-global-button-icon-color' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-global-button-box-shadow' => '0 0 0 0 rgba( 255, 255, 255, 0.00 )',
                'buttons-global-button-background-color-hover' => '#2470d6',
                'buttons-global-button-border-color-hover' => '#2470d6',
                'buttons-global-button-text-color-hover' => '#fff',
                'buttons-global-button-icon-color-hover' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-global-button-box-shadow-hover' => '0px 10px 35px rgba( 36, 112, 214, 0.25 )',
                'buttons-global-button-font-size' => '14',
                'buttons-global-button-letter-spacing' => '0',
                'buttons-global-button-border-radius' => '2',
                'buttons-global-button-border-width' => '1',
                'buttons-global-button-icon-size' => '14',
                'buttons-global-button-margin-between-text-and-icon' => '15',
                'buttons-global-button-padding-top' => '16.5',
                'buttons-global-button-padding-right' => '28',
                'buttons-global-button-padding-bottom' => '16.5',
                'buttons-global-button-padding-left' => '28',
                'buttons-global-button-use-static-height' => 'yes',
                'buttons-global-button-static-height' => '50',
                'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                'buttons-read-more-button-background-color' => '#145ec1',
                'buttons-read-more-button-border-color' => '#145ec1',
                'buttons-read-more-button-text-color' => '#fff',
                'buttons-read-more-button-icon-color' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-read-more-button-box-shadow' => '0 0 0 0 rgba( 255, 255, 255, 0.00 )',
                'buttons-read-more-button-background-color-hover' => '#2470d6',
                'buttons-read-more-button-border-color-hover' => '#2470d6',
                'buttons-read-more-button-text-color-hover' => '#fff',
                'buttons-read-more-button-icon-color-hover' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-read-more-button-box-shadow-hover' => '0px 10px 35px rgba( 36, 112, 214, 0.25 )',
                'buttons-read-more-button-font-size' => '14',
                'buttons-read-more-button-letter-spacing' => '0',
                'buttons-read-more-button-border-radius' => '2',
                'buttons-read-more-button-border-width' => '1',
                'buttons-read-more-button-icon-size' => '14',
                'buttons-read-more-button-margin-between-text-and-icon' => '15',
                'buttons-read-more-button-padding-top' => '16.5',
                'buttons-read-more-button-padding-right' => '28',
                'buttons-read-more-button-padding-bottom' => '16.5',
                'buttons-read-more-button-padding-left' => '28',
                'buttons-read-more-button-use-static-height' => 'yes',
                'buttons-read-more-button-static-height' => '50',
                'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                'buttons-form-submit-button-background-color' => '#145ec1',
                'buttons-form-submit-button-border-color' => '#145ec1',
                'buttons-form-submit-button-text-color' => '#fff',
                'buttons-form-submit-button-icon-color' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-form-submit-button-box-shadow' => '0 0 0 0 rgba( 255, 255, 255, 0.00 )',
                'buttons-form-submit-button-background-color-hover' => '#2470d6',
                'buttons-form-submit-button-border-color-hover' => '#2470d6',
                'buttons-form-submit-button-text-color-hover' => '#fff',
                'buttons-form-submit-button-icon-color-hover' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-form-submit-button-box-shadow-hover' => '0px 10px 35px rgba( 36, 112, 214, 0.25 )',
                'buttons-form-submit-button-font-size' => '14',
                'buttons-form-submit-button-letter-spacing' => '0',
                'buttons-form-submit-button-border-radius' => '2',
                'buttons-form-submit-button-border-width' => '1',
                'buttons-form-submit-button-icon-size' => '14',
                'buttons-form-submit-button-margin-between-text-and-icon' => '15',
                'buttons-form-submit-button-padding-top' => '16.5',
                'buttons-form-submit-button-padding-right' => '28',
                'buttons-form-submit-button-padding-bottom' => '16.5',
                'buttons-form-submit-button-padding-left' => '28',
                'buttons-form-submit-button-use-static-height' => 'yes',
                'buttons-form-submit-button-static-height' => '50',
                'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles',
                'buttons-call-to-action-widget-button-background-color' => '#145ec1',
                'buttons-call-to-action-widget-button-border-color' => '#145ec1',
                'buttons-call-to-action-widget-button-text-color' => '#fff',
                'buttons-call-to-action-widget-button-icon-color' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-call-to-action-widget-button-box-shadow' => '0 0 0 0 rgba( 255, 255, 255, 0.00 )',
                'buttons-call-to-action-widget-button-background-color-hover' => '#2470d6',
                'buttons-call-to-action-widget-button-border-color-hover' => '#2470d6',
                'buttons-call-to-action-widget-button-text-color-hover' => '#fff',
                'buttons-call-to-action-widget-button-icon-color-hover' => 'rgba( 255, 255, 255, 0.5 )',
                'buttons-call-to-action-widget-button-box-shadow-hover' => '0px 10px 35px rgba( 36, 112, 214, 0.25 )',
                'buttons-call-to-action-widget-button-font-size' => '14',
                'buttons-call-to-action-widget-button-letter-spacing' => '0',
                'buttons-call-to-action-widget-button-border-radius' => '2',
                'buttons-call-to-action-widget-button-border-width' => '1',
                'buttons-call-to-action-widget-button-icon-size' => '14',
                'buttons-call-to-action-widget-button-margin-between-text-and-icon' => '15',
                'buttons-call-to-action-widget-button-padding-top' => '16.5',
                'buttons-call-to-action-widget-button-padding-right' => '28',
                'buttons-call-to-action-widget-button-padding-bottom' => '16.5',
                'buttons-call-to-action-widget-button-padding-left' => '28',
                'buttons-call-to-action-widget-button-use-static-height' => 'yes',
                'buttons-call-to-action-widget-button-static-height' => '50',
                'line-height-headings' => '1.4',
                'line-height-general' => '1.8',
                'font-size-h1' => '36',
                'font-size-h2' => '28',
                'font-size-h3' => '24',
                'font-size-h4' => '22',
                'font-size-h5' => '20',
                'font-size-h6' => '18',
                'font-size-content' => '15',
                'font-size-blockquote' => '18',
                'font-size-small-content' => '14',
                'font-size-smallest-content' => '13',
                'font-size-menu-links' => '14',
                'font-size-menu-links-icons' => '10',
                'font-size-call-to-action-widget-offer' => '48',
                'font-size-form-fields' => '13'
            ),
            'submit-button-position-in-comment-reply-form' => array( 'all' => 'left' ),
            'translate-publication-dates' => 'yes',
            'twitter-api' => array(
                'oauth-key' => '',
                'oauth-secret-key' => ''
            ),
            'under-single-blog-post-content-elements' => array(
                'elements-count' => '3',
                'element-1-type' => 'tags-and-categories',
                'element-1-similar-posts-style' => '02',
                'element-2-type' => 'author-box',
                'element-2-similar-posts-style' => '02',
                'element-3-type' => 'next-previous-posts-navigation',
                'element-3-similar-posts-style' => '02',
                'element-4-type' => '',
                'element-4-similar-posts-style' => '02',
                'element-5-type' => '',
                'element-5-similar-posts-style' => '02',
                'element-6-type' => '',
                'element-6-similar-posts-style' => '02',
                'ueldo_theme_options_under_single_blog_post_content_elements_element_1_all' => '',
                'ueldo_theme_options_under_single_blog_post_content_elements_element_2_all' => '',
                'ueldo_theme_options_under_single_blog_post_content_elements_element_3_all' => '',
                'ueldo_theme_options_under_single_blog_post_content_elements_element_4_all' => '',
                'ueldo_theme_options_under_single_blog_post_content_elements_element_5_all' => '',
                'ueldo_theme_options_under_single_blog_post_content_elements_element_6_all' => ''
            ),
            'vc-sections-on-blog-pages' => array(
                'posts-list-above' => array( 'all' => 'none' ),
                'posts-list-under' => array( 'all' => 'none' ),
                'single-post-above' => array( 'all' => 'none' ),
                'single-post-under' => array( 'all' => 'none' ),
                'archive-above' => array( 'all' => 'none' ),
                'archive-under' => array( 'all' => 'none' ),
                'search-above' => array( 'all' => 'none' ),
                'search-under' => array( 'all' => 'none' )
            ),
            'visual-composer-custom-fonts' => array( 'next-font-id' => '1' ),
            'woocommerce' => array(
                'single-product-sidebar' => 'yes-right',
                'products-list-sidebar' => 'yes-right',
                'cart-page-sidebar' => 'no',
                'checkout-page-sidebar' => 'no',
                'account-page-sidebar' => 'no',
                'responsive-sidebar-style' => 'static'
            )
        ));
    }

   /**
    *
    * get values for each field
    *
    */

    function ueldo_get_theme_options_value( $section, $language = false, $subsection = false ) {

        # get cache option class object
        global $ueldo_cache_option;

        # get ueldo theme options
        $options = $ueldo_cache_option -> get_option( 'ueldo_theme_options' );

        # not found ueldo theme options?
        if( $options == false || $options == '' ) $options = array();

        # default values
        $default = ueldo_get_all_default_theme_options();

        # get editor content
        if( ueldo_strpos_array( $language, ueldo_get_editor_keys() ) ) {

            # get the option value
            $result = $ueldo_cache_option -> get_option( $language );

            # do we have it?
            if( $result !== false ) return( $result );
            else {

                # is the content found?
                if( isset( $default[$section] ) && isset( $default[$section][$language] ) ) return( $default[$section][$language] );
                else {

                    # get the languages array
                    $languages = ueldo_get_languages_list();

                    # walk for each languages
                    for( $i = 0; $i < count( $languages ); $i++ ) {

                        # language key
                        $language_key = strtolower( $languages[$i] );

                        # check of the language key is the one used in editor
                        if( ueldo_endswith( $language, $language_key ) ) {

                            # replace the language key with "all" string
                            $language = ueldo_str_replace_last( $language_key, 'all', $language );

                            # try to get option
                            $result = $ueldo_cache_option -> get_option( $language );

                            # success?
                            if( $result !== false ) return( $result );

                            # try to return default result
                            return( isset( $default[$section] ) && isset( $default[$section][$language] ) ? $default[$section][$language] : '' );
                        }
                    }
                }
            }
        }

        # get other options
        else {

            # return the result depends on option type
            switch( ueldo_get_theme_option_type( $section ) ) {

                # single option
                case 'single':

                    # return the result
                    return( isset( $options[$section] ) ? $options[$section] : $default[$section] );

                break;

                # single option, depends on language
                case 'single-depends-on-language':

                    # return the result
                    if( isset( $options[$section] ) && isset( $options[$section][$language] ) ) return( $options[$section][$language] );
                    else {

                        if( isset( $options[$section] ) && isset( $options[$section]['all'] ) ) return( $options[$section]['all'] );
                        else return( $default[$section]['all'] );
                    }

                break;

                # multiple options
                case 'multiple':

                    # return
                    return( ( isset( $options[$section] ) && isset( $options[$section][$subsection] ) ) ? $options[$section][$subsection] : ( isset( $default[$section][$subsection] ) ? $default[$section][$subsection] : false ) );

                break;

                # multiple options, depends on language
                case 'multiple-depends-on-language':

                    # return
                    if( isset( $options[$section] ) && isset( $options[$section][$subsection] ) && isset( $options[$section][$subsection][$language] ) ) return( $options[$section][$subsection][$language] );
                    else {

                        if( isset( $options[$section] ) && isset( $options[$section][$subsection] ) && isset( $options[$section][$subsection]['all'] ) ) return( $options[$section][$subsection]['all'] );
                        else return( $default[$section][$subsection]['all'] );
                    }

                break;

                # multiple options, sometimes depends on language, sometimes not
                case 'multiple-sometimes-depends-on-language':

                    # switch the option key
                    switch( $section ) {

                        # side menu
                        case 'side-menu':

                            # keys depended on language
                            if( in_array( $subsection, array( 'menu-key', 'menu-link-font-family', 'menu-link-font-weight', 'menu-link-font-subset', 'menu-link-font-smoothing' ), true ) ) {

                                # return
                                if( isset( $options[$section] ) && isset( $options[$section][$subsection] ) && isset( $options[$section][$subsection][$language] ) ) return( $options[$section][$subsection][$language] );
                                else {

                                    if( isset( $options[$section] ) && isset( $options[$section][$subsection] ) && isset( $options[$section][$subsection]['all'] ) ) return( $options[$section][$subsection]['all'] );
                                    else return( $default[$section][$subsection]['all'] );
                                }
                            }

                            # other keys are not depended on language
                            else {

                                # return
                                return( ( isset( $options[$section] ) && isset( $options[$section][$subsection] ) ) ? $options[$section][$subsection] : ( isset( $default[$section][$subsection] ) ? $default[$section][$subsection] : false ) );
                            }

                        break;

                        # loader animation
                        case 'loader-animation':

                            # keys is depended on language
                            if( in_array( $subsection, array( 'logo-image' ), true ) ) {

                                # return
                                if( isset( $options[$section] ) && isset( $options[$section][$subsection] ) && isset( $options[$section][$subsection][$language] ) ) return( $options[$section][$subsection][$language] );
                                else {

                                    if( isset( $options[$section] ) && isset( $options[$section][$subsection] ) && isset( $options[$section][$subsection]['all'] ) ) return( $options[$section][$subsection]['all'] );
                                    else return( $default[$section][$subsection]['all'] );
                                }
                            }

                            # other keys are not depended on language
                            else {

                                # return
                                return( ( isset( $options[$section] ) && isset( $options[$section][$subsection] ) ) ? $options[$section][$subsection] : ( isset( $default[$section][$subsection] ) ? $default[$section][$subsection] : false ) );
                            }

                        break;
                    }

                break;

                # unknown option type
                default: return( false );
            }
        }

        # nothing found
        return( false );
    }

   /**
    *
    * get theme option type (single, single depends on language, multiple)
    *
    */

    function ueldo_get_theme_option_type( $section ) {

        # sections array
        $sections = array(
            '404-page-id' => 'single-depends-on-language',
            'blog-posts-list-style' => 'multiple',
            'blog-sidebar' => 'multiple',
            'boxed-website' => 'multiple',
            'comment-textarea-at-top' => 'single',
            'dynamic-theme-styles-cache' => 'multiple',
            'facebook-fanpage-url' => 'single-depends-on-language',
            'featured-image-on-lists-only' => 'single',
            'fonts' => 'multiple-depends-on-language',
            'footer-content' => 'multiple-depends-on-language',
            'google-maps' => 'multiple',
            'header' => 'multiple-depends-on-language',
            'lazy-load-images' => 'multiple',
            'loader-animation' => 'multiple-sometimes-depends-on-language',
            'local-scrolling-links-animation' => 'multiple',
            'opening-hours-status' => 'multiple',
            'retina-images-replacement' => 'multiple',
            'rtl' => 'multiple-depends-on-language',
            'side-menu' => 'multiple-sometimes-depends-on-language',
            'single-blog-post-style' => 'multiple',
            'submit-button-position-in-comment-reply-form' => 'single-depends-on-language',
            'styles-default' => 'multiple',
            'styles' => 'multiple',
            'translate-publication-dates' => 'single',
            'twitter-api' => 'multiple',
            'under-single-blog-post-content-elements' => 'multiple',
            'vc-sections-on-blog-pages' => 'multiple-depends-on-language',
            'visual-composer-custom-fonts' => 'multiple',
            'woocommerce' => 'multiple'
        );

        # return result
        return( isset( $sections[$section] ) ? $sections[$section] : false );
    }

   /**
    *
    * get editor keys
    *
    */

    function ueldo_get_editor_keys() {

        # return result
        return( array(
            'ueldo_theme_options_footer_content_',
            'ueldo_theme_options_side_menu_additional_content_before_',
            'ueldo_theme_options_side_menu_additional_content_after_',
            'ueldo_theme_options_under_single_blog_post_content_elements_element_1_',
            'ueldo_theme_options_under_single_blog_post_content_elements_element_2_',
            'ueldo_theme_options_under_single_blog_post_content_elements_element_3_',
            'ueldo_theme_options_under_single_blog_post_content_elements_element_4_',
            'ueldo_theme_options_under_single_blog_post_content_elements_element_5_',
            'ueldo_theme_options_under_single_blog_post_content_elements_element_6_'
        ));
    }

   /**
    *
    * register settings
    *
    */

    add_action( 'admin_init', 'ueldo_register_settings' );
    function ueldo_register_settings() {

        # get the languages array
        $languages = ueldo_get_languages_list();

        # there's no any language?
        if( $languages == false ) $languages = array( 'default' );

        # add theme options settings section
        add_settings_section( 'ueldo_admin_settings', '', null, 'ueldo_admin' );

        # add settings field: general theme options
        add_settings_field( 'ueldo_theme_options', '', null, 'ueldo_admin', 'ueldo_admin_settings' );
        register_setting( 'ueldo_admin', 'ueldo_theme_options', 'ueldo_validate_options' );

        # add settings field: footer content for each language
        for( $i = 0; $i < count( $languages ); $i++ ) {

            # language key for editor
            $lang_key = $languages[$i] == 'default' ? 'all' : esc_attr( $languages[$i] );

            # walk for each editor keys
            foreach( ueldo_get_editor_keys() as $editor_key ) {

                # add settings field
                add_settings_field( $editor_key . strtolower( esc_attr( $lang_key ) ), '', null, 'ueldo_admin', 'ueldo_admin_settings' );
                register_setting( 'ueldo_admin', $editor_key . strtolower( esc_attr( $lang_key ) ), 'ueldo_validate_contents' );
            }
        }
    }

   /**
    *
    * settings validation function
    *
    */

    function ueldo_validate_options( $input ) {

        # get cache option class object
        global $ueldo_cache_option;

        # getting current options
        $ueldo_theme_options = $ueldo_cache_option -> get_option( 'ueldo_theme_options' );

        # option keys
        $option_keys = ueldo_get_single_options_array();

        # for each option keys
        foreach( $option_keys as $option_key => $option_title ) {

            # if option key exists
            if( isset( $input[$option_key] ) ) {

                # protect inserts
                $ueldo_theme_options[$option_key] = ueldo_secure( $input[$option_key] );

               /**
                *
                * specific values, which require additional validation
                *
                */

                if( $option_key == 'lazy-load-images' ) {

                    # find threshold option
                    if( isset( $input[$option_key] ) && isset( $input[$option_key]['threshold'] ) ) {

                        # validate
                        $ueldo_theme_options[$option_key]['threshold'] = ueldo_validate_number_field( $input[$option_key]['threshold'], '0', false, '0' );
                    }
                }

                else if( $option_key == 'local-scrolling-links-animation' ) {

                    # find threshold option
                    if( isset( $input[$option_key] ) && isset( $input[$option_key]['animation-speed'] ) ) {

                        # validate
                        $ueldo_theme_options[$option_key]['animation-speed'] = ueldo_validate_number_field( $input[$option_key]['animation-speed'], '0', false, '0' );
                    }
                }

               /**
                *
                * end of specific values
                *
                */
            }
        }

        # return values
        return( $ueldo_theme_options );
    }

   /**
    *
    * contents validation function
    *
    */

    function ueldo_validate_contents( $input ) {

        # return result
        return( wp_kses_post( $input ) );
    }

   /**
    *
    * function for secure values
    * before saving in database
    *
    */

    function ueldo_secure( $data, $is_url = false ) {

        # if it is single variable, protect it
        if( !is_array( $data ) ) return( esc_attr( $data ) );

        # if array - recurence
        else {

            # recurence - protect every single variable
            foreach( $data as $key => $value ) {

                # get variable protection
                $data[$key] = ueldo_secure( $value );
            }
        }

        # return result
        return( $data );
    }

   /**
    *
    * validate number field
    *
    */

    function ueldo_validate_number_field( $value, $min, $max, $default ) {

        # is valid number?
        if( !ueldo_is_valid_number( $value ) ) return( $default );

        # is less than min?
        if( $min !== false && $value < $min ) return( $default );

        # is more than max?
        if( $max !== false && $value > $max ) return( $default );

        # all is ok - return value
        return( $value );
    }

   /**
    *
    * end of file.
    *
    */

?>