<?php

    # prevent direct file access
    if( !defined( 'ABSPATH' ) ) exit;

   /**
    *
    * get theme options data management functions
    *
    */

    require_once( get_template_directory() .'/_assets/_php/_theme-options/theme-options-data.php' );

   /**
    *
    * theme options page
    *
    */

    add_action( 'admin_menu', 'ueldo_add_admin_pages' );
    function ueldo_add_admin_pages() {

        # is ueldo plugin inactive?
        if( !ueldo_plugins::is_active_plugin( 'ueldo' ) ) {

            # add theme page for theme options
            $ueldo_theme_options_page = add_theme_page(
                esc_html( __( 'Ueldo - Theme Options', 'ueldo' ) ),
                esc_html( __( 'Ueldo - Theme Options', 'ueldo' ) ),
                'manage_options',
                'ueldo_admin',
                'ueldo_show_admin_page'
            );

            # load scripts and styles for theme options page
            add_action( 'load-'. $ueldo_theme_options_page, 'ueldo_load_scripts_for_theme_options_page' );
        }
    }

   /**
    *
    * add action - enqueue scripts and styles for
    * theme options page
    *
    */

    function ueldo_load_scripts_for_theme_options_page() {

        # add action for "admin_enqueue_scripts" hook
        add_action( 'admin_enqueue_scripts', 'ueldo_scripts_and_styles_for_theme_options_page' );
    }

   /**
    *
    * all scripts and styles needed by theme options page
    *
    */

    function ueldo_scripts_and_styles_for_theme_options_page() {

        # get styles cache global variable
        global $ueldo_styles_cache;

        # get cache option global variable
        global $ueldo_cache_option;

        # enqueue main theme functions script
        wp_enqueue_script( 'ueldo-theme-options-javascript-functions', get_template_directory_uri() .'/_assets/_js/theme-options.js', array( 'jquery' ), null, true );

        # localize strings for scripts
        wp_localize_script( 'ueldo-theme-options-javascript-functions', 'ueldo_theme_options_javascript_functions_l10n', array(
            'family' => esc_html( __( 'Family:', 'ueldo' ) ),
            'weight' => esc_html( __( 'Weight:', 'ueldo' ) ),
            'subset' => esc_html( __( 'Subset:', 'ueldo' ) ),
            'font_already_added' => esc_html( __( 'Font already added!', 'ueldo' ) ),
            'map_title' => esc_html( __( 'Map title:', 'ueldo' ) ),
            'map_title_value' => esc_html( esc_attr( __( 'New map', 'ueldo' ) ) ),
            'map_marker_title' => esc_html( __( 'Map marker title:', 'ueldo' ) ),
            'map_markers' => esc_html( __( 'Map markers:', 'ueldo' ) ),
            'map_marker_title_value' => esc_html( esc_attr( __( 'New marker', 'ueldo' ) ) ),
            'map_center_latitude' => esc_html( __( 'Map center latitude:', 'ueldo' ) ),
            'map_center_longitude' => esc_html( __( 'Map center longitude:', 'ueldo' ) ),
            'map_marker_latitude' => esc_html( __( 'Map marker latitude:', 'ueldo' ) ),
            'map_marker_longitude' => esc_html( __( 'Map marker longitude:', 'ueldo' ) ),
            'map_zoom' => esc_html( __( 'Map zoom:', 'ueldo' ) ),
            'find_out_how_to_get_map_coordinates_here' => esc_html( __( 'Find out how to get map coordinates here.', 'ueldo' ) ),
            'use_custom_marker_icon' => esc_html( __( 'Use custom marker icon?', 'ueldo' ) ),
            'yes_icon' => esc_html( __( 'Yes, as icon', 'ueldo' ) ),
            'yes_image' => esc_html( __( 'Yes, as image', 'ueldo' ) ),
            'yes' => esc_html( __( 'Yes', 'ueldo' ) ),
            'no' => esc_html( __( 'No', 'ueldo' ) ),
            'icon_library' => esc_html( __( 'Icon library', 'ueldo' ) ),
            'fontawesome' => esc_html( __( 'Font Awesome', 'ueldo' ) ),
            'openiconic' => esc_html( __( 'Open Iconic', 'ueldo' ) ),
            'typicons' => esc_html( __( 'Typicons', 'ueldo' ) ),
            'entypo' => esc_html( __( 'Entypo', 'ueldo' ) ),
            'linecons' => esc_html( __( 'Linecons', 'ueldo' ) ),
            'monosocial' => esc_html( __( 'Mono Social', 'ueldo' ) ),
            'material' => esc_html( __( 'Material', 'ueldo' ) ),
            'icon' => esc_html( __( 'Icon', 'ueldo' ) ),
            'search' => esc_html( __( 'Search...', 'ueldo' ) ),
            'is_visual_composer_active' => ueldo_plugins::is_active_plugin( 'visual-composer' ) ? 'yes' : 'no',
            'confirm_the_deletion' => esc_html( __( 'Confirm the deletion', 'ueldo' ) ),
            'you_did_not_added_any_marker_yet' => esc_html( __( 'You did not added any marker yet.', 'ueldo' ) ),
            'add_new_marker' => esc_html( __( 'Add new marker', 'ueldo' ) ),
            'custom_map_style' => esc_html( __( 'Custom map style:', 'ueldo' ) ),
            'you_can_add_custom_map_style_here_for_example_from' => esc_html( __( 'You can add custom map style here, for example from', 'ueldo' ) ),
            'snazzy_maps' => esc_html( __( 'Snazzy Maps', 'ueldo' ) ),
            'icon_color' => esc_html( __( 'Icon color', 'ueldo' ) ),
            'icon_background_color' => esc_html( __( 'Icon background color', 'ueldo' ) ),
            'icon_box_shadow' => esc_html( __( 'Icon box shadow', 'ueldo' ) ),
            'horizontal_length' => esc_html( __( 'Horizontal length', 'ueldo' ) ),
            'vertical_length' => esc_html( __( 'Vertical length', 'ueldo' ) ),
            'blur_radius' => esc_html( __( 'Blur radius', 'ueldo' ) ),
            'spread_radius' => esc_html( __( 'Spread radius', 'ueldo' ) ),
            'color' => esc_html( __( 'Color', 'ueldo' ) ),
            'marker_image' => esc_html( __( 'Marker image', 'ueldo' ) ),
            'select_image' => esc_html( __( 'Select image', 'ueldo' ) ),
            'icon_size' => esc_html( __( 'Icon size', 'ueldo' ) ),
            'icon_container_width' => esc_html( __( 'Icon container width', 'ueldo' ) ),
            'icon_container_height' => esc_html( __( 'Icon container height', 'ueldo' ) ),
            'icon_container_border_radius' => esc_html( __( 'Icon container border radius', 'ueldo' ) ),
            'icon_container_border_radius_pixels' => esc_html( __( 'Icon container border radius (pixels)', 'ueldo' ) ),
            'circle_100_percent' => esc_html( __( '100% (circle)', 'ueldo' ) ),
            'pixels' => esc_html( __( 'Pixels', 'ueldo' ) ),
            'single_rule' => esc_attr( esc_html( __( 'Single rule', 'ueldo' ) ) ),
            'rule_title' => esc_html( __( 'Rule title', 'ueldo' ) ),
            'single_exception' => esc_attr( esc_html( __( 'Single exception', 'ueldo' ) ) ),
            'exception_title' => esc_html( __( 'Exception title', 'ueldo' ) ),
            'apply_for_day_of_week' => esc_html( __( 'Apply for day of week:', 'ueldo' ) ),
            'monday' => esc_html( __( 'Monday', 'ueldo' ) ),
            'tuesday' => esc_html( __( 'Tuesday', 'ueldo' ) ),
            'wednesday' => esc_html( __( 'Wednesday', 'ueldo' ) ),
            'thursday' => esc_html( __( 'Thursday', 'ueldo' ) ),
            'friday' => esc_html( __( 'Friday', 'ueldo' ) ),
            'saturday' => esc_html( __( 'Saturday', 'ueldo' ) ),
            'sunday' => esc_html( __( 'Sunday', 'ueldo' ) ),
            'all_day_closed' => esc_html( __( 'All day closed?', 'ueldo' ) ),
            'opening_hours' => esc_html( __( 'Opening hours', 'ueldo' ) ),
            'add_new_opening_hours_set' => esc_html( __( 'Add new opening hours set', 'ueldo' ) ),
            'apply_from' => esc_html( __( 'Apply from:', 'ueldo' ) ),
            'apply_to' => esc_html( __( 'Apply to:', 'ueldo' ) ),
            'regular_opening_hours' => esc_html( __( 'Regular opening hours', 'ueldo' ) ),
            'status_name' => esc_html( __( 'Status name:', 'ueldo' ) ),
            'timezone' => esc_html( __( 'Timezone:', 'ueldo' ) ),
            'get_from_client_browser' => esc_html( __( 'Get from client browser', 'ueldo' ) ),
            'rules' => esc_html( __( 'Rules:', 'ueldo' ) ),
            'you_did_not_added_any_rule_yet' => esc_html( __( 'You did not added any rule yet.', 'ueldo' ) ),
            'add_new_rule' => esc_html( __( 'Add new rule', 'ueldo' ) ),
            'exceptions' => esc_html( __( 'Exceptions:', 'ueldo' ) ),
            'you_did_not_added_any_exception_yet' => esc_html( __( 'You did not added any exception yet.', 'ueldo' ) ),
            'add_new_exception' => esc_html( __( 'Add new exception', 'ueldo' ) ),
            'smoothing' => esc_html( __( 'Smoothing:', 'ueldo' ) ),
            'not_found_any_icons' => esc_html( __( 'Not found any icons.', 'ueldo' ) ),
            'please_wait' => esc_html( __( 'Please wait...', 'ueldo' ) ),
            'clear_cache_now' => esc_html( __( 'Clear cache now', 'ueldo' ) ),
            'dynamic_theme_styles_cache_cleared_correctly' => esc_html( __( 'Dynamic theme styles cache cleared correctly!', 'ueldo' ) ),
            'couldnt_clear_dynamic_theme_styles_cache_please_try_again' => esc_html( __( 'Couldn\'t clear dynamic theme styles cache, please try again.', 'ueldo' ) ),
            'dynamic_theme_styles_cache_ajax_file_path' => function_exists( 'ueldo_plugin_get_url' ) ? esc_url( ueldo_plugin_get_url() .'/_parts/_dynamic-styles-cache/dynamic-styles-cache-ajax.php' ) : '',
            'style_general_colors_google_map_marker_icon_color' => esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-google-map-marker-icon-color' ) ),
            'style_general_colors_google_map_marker_icon_container_background_color' => esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-google-map-marker-icon-container-background-color' ) ),
            'style_general_colors_google_map_marker_icon_container_box_shadow_horizontal_length' => $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'horizontal-length' ),
            'style_general_colors_google_map_marker_icon_container_box_shadow_vertical_length' => $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'vertical-length' ),
            'style_general_colors_google_map_marker_icon_container_box_shadow_blur_radius' => $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'blur-radius' ),
            'style_general_colors_google_map_marker_icon_container_box_shadow_spread_radius' => $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'spread-radius' ),
            'style_general_colors_google_map_marker_icon_container_box_shadow_color' => $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'color' )
        ));

        # add inline script with possible timezones array
        wp_add_inline_script( 'ueldo-theme-options-javascript-functions', ueldo_get_timezones_object_for_js() );

        # enqueue alpha color picker javascript functions
        wp_enqueue_script( 'wp-color-picker-alpha', get_stylesheet_directory_uri() . '/_assets/_libs/alpha-color-picker/wp-color-picker-alpha.js', array( 'jquery', 'wp-color-picker' ), null, true );

        # enqueue datepicker
        wp_enqueue_script( 'jquery-ui-datepicker', array( 'jquery' ) );

        # enqueue datepicker style
        wp_enqueue_style( 'ueldo-theme-options-datepicker-theme', get_template_directory_uri() .'/_assets/_css/datepicker-theme.css', false, null );

        # theme options page stylesheet
        wp_enqueue_style( 'ueldo-theme-options-stylesheet', get_template_directory_uri() .'/_assets/_css/theme-options.css', false, null );

        # enqueue color picker styles
        wp_enqueue_style( 'wp-color-picker' );

        # add inline style for theme options page stylesheet
        wp_add_inline_style( 'ueldo-theme-options-stylesheet', ueldo_theme_options_get_inline_styles() );

        # visual composer icons
        if( ueldo_plugins::is_active_plugin( 'visual-composer' ) ) {

            # walk for each vc iconfonts array
            foreach( ueldo_get_vc_iconfonts_array() as $iconfont ) {

                # enqueue style
                wp_enqueue_style( esc_attr( $iconfont['key'] ), esc_attr( $iconfont['url'] ), false, esc_attr( $iconfont['ver'] ) );
            }
        }

        # do we have custom icons added?
        if( ueldo_plugins::is_active_plugin( 'ueldo' ) && ueldo_plugin_is_any_custom_icon_added() ) {

            # enqueue custom icons stylesheet
            ueldo_plugin_enqueue_custom_icons_stylesheet();

            # get all custom icon fonts
            $icon_fonts = $ueldo_cache_option -> get_option( 'ueldo_custom_icons' );

            # do we have custom icons added?
            if( $icon_fonts != false ) {

                # prepare inline script content
                $script = 'var ueldo_custom_icons = []; ';

                # walk for each icon
                foreach( $icon_fonts as $icon_font ) {

                    # update script content
                    $script .= 'ueldo_custom_icons[\''. esc_attr( $icon_font['unique_key'] ) .'\'] = [ ';

                    # first icon flag
                    $is_first_icon = true;

                    # walk for each icons
                    foreach( $icon_font['icons'] as $icon ) {

                        # update script content
                        $script .= ( $is_first_icon == true ? '' : ', ' ) .'[ \''. $icon .'\' ]';

                        # update first icon flag
                        $is_first_icon = false;
                    }

                    # close script content
                    $script .= ' ]; ';
                }

                # add inline script
                wp_add_inline_script( 'ueldo-theme-options-javascript-functions', $script );
            }
        }
    }

   /**
    *
    * list of single options available for theme options page
    *
    */

    function ueldo_get_single_options_array() {

        # return result
        return( array(
            '404-page-id' => esc_html( __( '404 page', 'ueldo' ) ),
            'blog-posts-list-style' => esc_html( __( 'Blog posts list style', 'ueldo' ) ),
            'blog-sidebar' => esc_html( __( 'Blog sidebar', 'ueldo' ) ),
            'boxed-website' => esc_html( __( 'Website width', 'ueldo' ) ),
            'comment-textarea-at-top' => esc_html( __( 'Textarea field in comment reply form', 'ueldo' ) ),
            'dynamic-theme-styles-cache' => esc_html( __( 'Dynamic Theme Styles Cache', 'ueldo' ) ),
            'facebook-fanpage-url' => esc_html( __( 'Facebook FanPage URL', 'ueldo' ) ),
            'featured-image-on-lists-only' => esc_html( __( 'Featured image on lists only', 'ueldo' ) ),
            'fonts' => esc_html( __( 'Fonts', 'ueldo' ) ),
            'footer-content' => esc_html( __( 'Footer content', 'ueldo' ) ),
            'google-maps' => esc_html( __( 'Google maps', 'ueldo' ) ),
            'header' => esc_html( __( 'Header', 'ueldo' ) ),
            'lazy-load-images' => esc_html( __( 'Lazy load images', 'ueldo' ) ),
            'loader-animation' => esc_html( __( 'Loader animation', 'ueldo' ) ),
            'local-scrolling-links-animation' => esc_html( __( 'Local scrolling links animation', 'ueldo' ) ),
            'opening-hours-status' => esc_html( __( 'Opening hours status', 'ueldo' ) ),
            'retina-images-replacement' => esc_html( __( 'Retina images replacement', 'ueldo' ) ),
            'rtl' => esc_html( __( 'RTL languages', 'ueldo' ) ),
            'side-menu' => esc_html( __( 'Side menu', 'ueldo' ) ),
            'single-blog-post-style' => esc_html( __( 'Single blog post style', 'ueldo' ) ),
            'styles-default' => false,
            'styles' => false,
            'submit-button-position-in-comment-reply-form' => esc_html( __( 'Submit button position in comment reply form', 'ueldo' ) ),
            'translate-publication-dates' => esc_html( __( 'Publication dates', 'ueldo' ) ),
            'twitter-api' => esc_html( __( 'Twitter API keys', 'ueldo' ) ),
            'under-single-blog-post-content-elements' => esc_html( __( 'Under single blog post content elements', 'ueldo' ) ),
            'vc-sections-on-blog-pages' => esc_html( __( 'Additional Visual Composer sections on Blog pages', 'ueldo' ) ),
            'visual-composer-custom-fonts' => esc_html( __( 'Visual Composer custom shortcode fonts', 'ueldo' ) ),
            'woocommerce' => false
        ));
    }

   /**
    *
    * load single theme options
    *
    */

    function ueldo_load_single_theme_options() {

        # global variables
        global $ueldo_styles_cache;

        # get the languages array
        $languages = ueldo_get_languages_list();

        # there's no any language?
        if( $languages == false ) $languages = array( 'default' );

        # get the pages list
        $pages_list = get_pages();

        # include each single theme options
        foreach( ueldo_get_single_options_array() as $option_key => $option_title ) {

            # include
            if( $option_title !== false ) require_once( get_template_directory() .'/_assets/_php/_theme-options/_options/'. esc_attr( $option_key ) .'.php' );
        }
    }

   /**
    *
    * get image for theme options panel
    *
    */

    function ueldo_get_theme_options_image( $image ) {

        # return result
        return( get_template_directory_uri() .'/_assets/_img/_theme-options/'. esc_attr( $image ) );
    }

   /**
    *
    * this function displays theme options
    * page - Ueldo Theme Options
    *
    */

    function ueldo_show_admin_page() {

        # empty message
        $ueldo_message = isset( $_GET['settings-updated'] ) && $_GET['settings-updated'] == 'true' ? esc_html( __( 'Settings saved!', 'ueldo' ) ) : '';

        ?>
        <div class="wrap">

            <div class="ueldo-theme-options">

                <div id="ueldo-theme-options-loader">

                    <div class="ueldo-theme-options-loader-container">

                        <div class="ueldo-theme-options-loader-spinner">
                        </div>

                        <h3 class="ueldo-theme-options-loader-title"><?php echo esc_html( __( 'Loading theme options...', 'ueldo' ) ); ?></h3>

                    </div>

                </div>

                <div class="ueldo-theme-options-switcher">

                    <ul class="ueldo-theme-options-list">

                        <li data-option-key="<?php echo esc_attr( sanitize_title( esc_html( __( 'All settings', 'ueldo' ) ) ) ); ?>" class="ueldo-theme-options-list-active-element"><?php echo esc_html( __( 'All settings', 'ueldo' ) ); ?></li>

                        <?php

                            # walk for each single options
                            foreach( ueldo_get_single_options_array() as $option_key => $option_title ) {

                                # do we have option settings available?
                                if( $option_title === false ) continue;

                                # dynamic theme styles cache visible only if ueldo plugin is activated
                                if( $option_key == 'dynamic-theme-styles-cache' && ueldo_plugins::is_active_plugin( 'ueldo' ) == false ) continue;

                                ?>
                                <li data-option-key="<?php echo esc_attr( $option_key ); ?>"><?php echo esc_html( $option_title ); ?></li>
                                <?php
                            }

                        ?>

                    </ul>

                </div>

                <div class="ueldo-theme-options-container">

                    <?php

                        # plugin activation notice
                        ueldo_display_theme_options_plugin_activation_notice();

                        # do we have the message?
                        if( !empty( $ueldo_message ) ) {

                            ?>
                            <div class="updated">

                                <p><?php echo esc_html( $ueldo_message ); ?></p>

                            </div>
                            <?php

                        # end of message
                        }

                    ?>

                    <form action="options.php" method="post" enctype="multipart/form-data" name="ueldo-options-form" class="ueldo-theme-options-wrapper">

                        <?php

                            # main settings fields
                            settings_fields( 'ueldo_admin' );

                            # main settings section
                            do_settings_sections( 'ueldo_admin_settings' );

                            # load each single theme options element
                            ueldo_load_single_theme_options();

                            # display font selection list
                            ueldo_get_google_fonts_selection_list();

                            # protect default theme options in multilingual mode
                            ueldo_protect_default_theme_options_in_multilingual_mode();

                        ?>

                        <div class="ueldo-theme-options-save-changes">

                            <?php

                                # submit button
                                submit_button( esc_html( __( 'Save all changes', 'ueldo' ) ) );

                            ?>

                        </div>

                    </form>

                </div>

            </div>

        </div>
        <?php

        # clear the global hefos array
        ueldo_clear_all_hefos_array();
    }

   /**
    *
    * get google fonts selection list
    *
    */

    function ueldo_get_google_fonts_selection_list() {

        # open a file with google fonts list
        $google_fonts = ueldo_get_local_file_content( get_template_directory() .'/_assets/_php/_theme-options/_data/google-fonts.json' );

        # there's no any google fonts?
        if( $google_fonts == '' ) {

            ?>
            <div id="ueldo-theme-options-google-fonts-selection-field-fonts-list-container" data-visible="no">

                <div class="ueldo-theme-options-google-fonts-selection-field-fonts-list">

                    <div class="ueldo-theme-options-google-fonts-selection-field-fonts-list-nothing-found" data-visible="yes">

                        <p><?php echo sprintf( wp_kses( __( 'Couldn\'t find any Google Fonts. Please contact with <a href="%s">support@martanian.com</a> to find out more about this issue.', 'ueldo' ), array( 'a' => array( 'href' => array() ) ) ), esc_url( 'mailto:support@martanian.com' ) ); ?></p>

                    </div>

                </div>

            </div>
            <?php

            # end of the function.
            return( false );
        }

        # decode json
        $google_fonts_json = json_decode( $google_fonts );

        # do we have it?
        if( $google_fonts_json == null ) return( false );

        ?>
        <div id="ueldo-theme-options-google-fonts-selection-field-fonts-list-container" data-visible="no">

            <div class="ueldo-theme-options-google-fonts-selection-field-fonts-search">

                <input type="text" name="" placeholder="<?php echo esc_attr( __( 'Search the font...', 'ueldo' ) ); ?>" />

            </div>

            <div class="ueldo-theme-options-google-fonts-selection-field-fonts-list">

                <div class="ueldo-theme-options-google-fonts-selection-field-fonts-list-nothing-found" data-visible="no">

                    <p><?php echo esc_html( __( 'The font you are looking for could not be found. Please make sure that this font is available in Google Fonts directory.', 'ueldo' ) ); ?></p>

                </div>

                <?php

                    # walk for each google font
                    foreach( $google_fonts_json -> items as $google_font ) {

                        ?>
                        <div class="ueldo-theme-options-google-fonts-selection-field-fonts-list-single-font" data-font-family="<?php echo esc_attr( $google_font -> family ); ?>" data-visible="yes">

                            <span class="ueldo-theme-options-google-fonts-selection-field-fonts-list-single-font-name">

                                <span class="ueldo-theme-options-google-fonts-selection-field-fonts-list-single-font-name-selected"><?php echo esc_html( __( 'Selected font:', 'ueldo' ) ); ?></span>
                                <?php echo esc_html( $google_font -> family ); ?>

                            </span>

                            <div class="ueldo-theme-options-google-fonts-selection-field-fonts-list-single-font-details">

                                <h5><?php echo esc_html( __( 'Font weight:', 'ueldo' ) ); ?></h5>
                                <select name="" data-selector-of="weight">

                                    <?php

                                        # walk for each font variant
                                        foreach( $google_font -> variants as $variant ) {

                                            ?>
                                            <option value="<?php echo esc_attr( $variant ); ?>"><?php echo esc_html( $variant ); ?></option>
                                            <?php
                                        }

                                    ?>

                                </select>

                                <h5><?php echo esc_html( __( 'Font subset:', 'ueldo' ) ); ?></h5>
                                <select name="" multiple data-selector-of="subset">

                                    <?php

                                        # walk for each font variant
                                        foreach( $google_font -> subsets as $subset ) {

                                            ?>
                                            <option value="<?php echo esc_attr( $subset ); ?>"><?php echo esc_html( $subset ); ?></option>
                                            <?php
                                        }

                                    ?>

                                </select>

                                <p><?php echo esc_html( __( 'For PC: Hold down the control (ctrl) button to select multiple options', 'ueldo' ) ); ?><br /> <?php echo esc_html( __( 'For Mac: Hold down the command button to select multiple options', 'ueldo' ) ); ?></p>

                                <h5><?php echo esc_html( __( 'Font smoothing:', 'ueldo' ) ); ?></h5>

                                <div class="ueldo-theme-options-google-fonts-selection-field-fonts-list-single-font-details-font-smoothing-checkbox">

                                    <input type="checkbox" data-selector-of="smoothing" id="<?php echo esc_attr( sanitize_title( $google_font -> family ) ); ?>-font-smoothing" name="" checked="checked" />
                                    <label for="<?php echo esc_attr( sanitize_title( $google_font -> family ) ); ?>-font-smoothing"><?php echo esc_html( __( 'Enable font smoothing for this font.', 'ueldo' ) ); ?></label>

                                </div>

                                <button type="button" class="ueldo-theme-options-google-fonts-selection-field-fonts-list-single-font-details-button"><?php echo esc_html( __( 'Set this font', 'ueldo' ) ); ?></button>

                            </div>

                        </div>
                        <?php
                    }

                ?>

            </div>

        </div>
        <?php
    }

   /**
    *
    * get google fonts selection field
    *
    */

    function ueldo_get_google_fonts_selection_field( $family, $weight, $subset, $smoothing, $fieldOptions ) {

        # check if subsection and language is set
        if( !is_array( $fieldOptions ) ) {

            # check if subsection is set
            if( !isset( $fieldOptions['subsection'] ) || empty( $fieldOptions['subsection'] ) ) return false;

            # check if language is set
            if( !isset( $fieldOptions['language'] ) || empty( $fieldOptions['language'] ) ) return false;
        }

        ?>
        <div class="ueldo-theme-options-google-fonts-selection-field" data-is-field-active="no">

            <input type="hidden" name="ueldo_theme_options[<?php echo esc_attr( isset( $fieldOptions['section'] ) && !empty( $fieldOptions['section'] ) ? esc_attr( $fieldOptions['section'] ) : 'fonts' ); ?>][<?php echo esc_attr( $fieldOptions['subsection'] ); ?>-family][<?php echo esc_attr( $fieldOptions['language'] ); ?>]" value="<?php echo esc_attr( $family ); ?>" data-element-type="font-family" />
            <input type="hidden" name="ueldo_theme_options[<?php echo esc_attr( isset( $fieldOptions['section'] ) && !empty( $fieldOptions['section'] ) ? esc_attr( $fieldOptions['section'] ) : 'fonts' ); ?>][<?php echo esc_attr( $fieldOptions['subsection'] ); ?>-weight][<?php echo esc_attr( $fieldOptions['language'] ); ?>]" value="<?php echo esc_attr( $weight ); ?>" data-element-type="font-weight" />
            <input type="hidden" name="ueldo_theme_options[<?php echo esc_attr( isset( $fieldOptions['section'] ) && !empty( $fieldOptions['section'] ) ? esc_attr( $fieldOptions['section'] ) : 'fonts' ); ?>][<?php echo esc_attr( $fieldOptions['subsection'] ); ?>-subset][<?php echo esc_attr( $fieldOptions['language'] ); ?>]" value="<?php echo esc_attr( $subset ); ?>" data-element-type="font-subset" />
            <input type="hidden" name="ueldo_theme_options[<?php echo esc_attr( isset( $fieldOptions['section'] ) && !empty( $fieldOptions['section'] ) ? esc_attr( $fieldOptions['section'] ) : 'fonts' ); ?>][<?php echo esc_attr( $fieldOptions['subsection'] ); ?>-smoothing][<?php echo esc_attr( $fieldOptions['language'] ); ?>]" value="<?php echo esc_attr( $smoothing ); ?>" data-element-type="font-smoothing" />

            <div class="ueldo-theme-options-google-fonts-selection-field-selected-font">

                <?php echo esc_attr( __( 'Family:', 'ueldo' ) ); ?> <span data-element-type="font-family"><?php echo esc_html( $family ); ?></span>, <?php echo esc_attr( __( 'Weight:', 'ueldo' ) ); ?> <span data-element-type="font-weight"><?php echo esc_html( $weight ); ?></span><span class="ueldo-theme-options-google-fonts-selection-field-selected-font-subset-container" data-visible="<?php echo esc_attr( !empty( $subset ) ? 'yes' : 'no' ); ?>">, <?php echo esc_attr( __( 'Subset:', 'ueldo' ) ); ?> <span data-element-type="font-subset"><?php echo esc_html( $subset ); ?></span></span>, <?php echo esc_attr( __( 'Smoothing:', 'ueldo' ) ); ?> <span data-element-type="font-smoothing"><?php echo esc_html( $smoothing == 'yes' ? esc_html( __( 'Yes', 'ueldo' ) ) : esc_html( __( 'No', 'ueldo' ) ) ); ?></span>

            </div>

        </div>
        <?php
    }

   /**
    *
    * get google maps creation field
    *
    */

    function ueldo_get_google_maps_creation_field( $map_id ) {

        # get styles cache global variable
        global $ueldo_styles_cache;

        # get cache option global variable
        global $ueldo_cache_option;

        # update map data array
        $map_data = array(
            'title' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-title' ),
            'center-lat' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-center-lat' ),
            'center-lng' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-center-lng' ),
            'zoom' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-zoom' ),
            'custom-style' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-custom-style' ),
            'markers-next-marker-id' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-next-marker-id' ),
        );

        ?>
        <div class="ueldo-theme-options-google-maps-creation-field" data-visible="no">

            <div class="ueldo-theme-options-google-maps-creation-field-container">

                <div class="ueldo-theme-options-google-maps-creation-field-group">

                    <h5><?php echo esc_html( __( 'Map title:', 'ueldo' ) ); ?></h5>
                    <input type="text" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-title]" value="<?php echo esc_html( $map_data['title'] ); ?>" class="ueldo-theme-options-google-maps-creation-map-title" />

                </div>

                <div class="ueldo-theme-options-google-maps-creation-field-group">

                    <h5><?php echo esc_html( __( 'Map center latitude:', 'ueldo' ) ); ?></h5>
                    <input type="text" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-center-lat]" value="<?php echo esc_html( $map_data['center-lat'] ); ?>" />

                    <h5><?php echo esc_html( __( 'Map center longitude:', 'ueldo' ) ); ?></h5>
                    <input type="text" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-center-lng]" value="<?php echo esc_html( $map_data['center-lng'] ); ?>" />

                    <p><a href="<?php echo esc_url( ueldo_get_external_url( 'find-google-maps-coordinates' ) ); ?>" target="_blank"><?php echo esc_html( __( 'Find out how to get map coordinates here.', 'ueldo' ) ); ?></a></p>

                </div>

                <div class="ueldo-theme-options-google-maps-creation-field-group">

                    <h5><?php echo esc_html( __( 'Map zoom:', 'ueldo' ) ); ?></h5>
                    <select name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-zoom]">

                        <?php

                            # zoom levels, from 0 to 21
                            for( $i = 0; $i < 22; $i++ ) {

                                ?>
                                <option value="<?php echo esc_attr( $i ); ?>" <?php echo esc_attr( $i == $map_data['zoom'] ? 'selected' : '' ); ?>><?php echo esc_html( $i ); ?></option>
                                <?php
                            }

                        ?>

                    </select>

                </div>

                <div class="ueldo-theme-options-google-maps-creation-field-group">

                    <h5><?php echo esc_html( __( 'Map markers:', 'ueldo' ) ); ?></h5>

                    <div class="ueldo-theme-options-google-maps-creation-map-markers-field" data-map-id="<?php echo esc_attr( $map_id ); ?>">

                        <input type="hidden" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-next-marker-id]" value="<?php echo esc_attr( $map_data['markers-next-marker-id'] ); ?>" />

                        <div class="ueldo-theme-options-google-maps-creation-map-markers-field-nothing-found">

                            <p><?php echo esc_html( __( 'You did not added any marker yet.', 'ueldo' ) ); ?></p>

                        </div>

                        <?php

                            # do we have markers added?
                            if( $map_data['markers-next-marker-id'] > 1 ) {

                                # walk for each marker
                                for( $i = 0; $i < $map_data['markers-next-marker-id']; $i++ ) {

                                    # do we have marker added?
                                    if( ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-title' ) != false ) {

                                        # get marker data array
                                        $marker_data = array(
                                            'title' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-title' ),
                                            'lat' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-lat' ),
                                            'lng' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-lng' ),
                                            'use-custom-marker' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-use-custom-marker' ),
                                            'custom-icon-library' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon-library' ),
                                            'custom-icon' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon' ),
                                            'custom-icon-size' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon-size' ),
                                            'custom-icon-width' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon-width' ),
                                            'custom-icon-height' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon-height' ),
                                            'custom-icon-border-radius' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon-border-radius' ),
                                            'custom-icon-border-radius-px' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon-border-radius-px' ),
                                            'custom-icon-color' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon-color' ),
                                            'custom-icon-background-color' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon-background-color' ),
                                            'custom-icon-box-shadow-horizontal-length' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon-box-shadow-horizontal-length' ),
                                            'custom-icon-box-shadow-vertical-length' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon-box-shadow-vertical-length' ),
                                            'custom-icon-box-shadow-blur-radius' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon-box-shadow-blur-radius' ),
                                            'custom-icon-box-shadow-spread-radius' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon-box-shadow-spread-radius' ),
                                            'custom-icon-box-shadow-color' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon-box-shadow-color' ),
                                            'custom-marker-image' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-marker-image' )
                                        );

                                        ?>
                                        <div class="ueldo-theme-options-google-maps-creation-map-markers-field-single-marker">

                                            <div class="ueldo-theme-options-google-maps-creation-map-markers-field-single-marker-data">

                                                <span class="ueldo-theme-options-google-maps-creation-map-markers-field-single-marker-remove-confirm" data-visible="no"><?php echo esc_html( __( 'Confirm the deletion', 'ueldo' ) ); ?></span>
                                                <span class="ueldo-theme-options-google-maps-creation-map-markers-field-single-marker-remove" data-visible="yes"></span>
                                                <span class="ueldo-theme-options-google-maps-creation-map-markers-field-single-marker-edit"><i class="fa fa-pencil"></i></span>

                                                <span data-element-type="location"><?php echo esc_html( $marker_data['title'] ); ?></span>

                                            </div>

                                            <div class="ueldo-theme-options-google-maps-creation-map-markers-field-single-marker-details" data-visible="no">

                                                <div class="ueldo-theme-options-google-maps-creation-map-markers-field-single-marker-details-fields-group">

                                                    <h5><?php echo esc_html( __( 'Map marker title:', 'ueldo' ) ); ?></h5>
                                                    <input type="text" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-title]" value="<?php echo esc_attr( $marker_data['title'] ); ?>" class="ueldo-theme-options-google-maps-creation-map-markers-field-marker-title" />

                                                </div>

                                                <div class="ueldo-theme-options-google-maps-creation-map-markers-field-single-marker-details-fields-group">

                                                    <h5><?php echo esc_html( __( 'Map marker latitude:', 'ueldo' ) ); ?></h5>
                                                    <input type="text" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-lat]" value="<?php echo esc_attr( $marker_data['lat'] ); ?>" />

                                                    <h5><?php echo esc_html( __( 'Map marker longitude:', 'ueldo' ) ); ?></h5>
                                                    <input type="text" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-lng]" value="<?php echo esc_attr( $marker_data['lng'] ); ?>" />

                                                    <p><a href="<?php echo esc_url( ueldo_get_external_url( 'find-google-maps-coordinates' ) ); ?>" target="_blank"><?php echo esc_html( __( 'Find out how to get map coordinates here.', 'ueldo' ) ); ?></a></p>

                                                </div>

                                                <div class="ueldo-theme-options-google-maps-creation-map-markers-field-single-marker-details-fields-group">

                                                    <h5><?php echo esc_html( __( 'Use custom marker?', 'ueldo' ) ); ?></h5>
                                                    <select name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-use-custom-marker]" class="ueldo-theme-options-google-maps-creation-map-markers-field-use-custom-marker">

                                                        <option value="no" <?php echo esc_attr( $marker_data['use-custom-marker'] == 'no' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'No', 'ueldo' ) ); ?></option>
                                                        <option value="yes-icon" <?php echo esc_attr( $marker_data['use-custom-marker'] == 'yes-icon' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'Yes, as icon', 'ueldo' ) ); ?></option>
                                                        <option value="yes-image" <?php echo esc_attr( $marker_data['use-custom-marker'] == 'yes-image' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'Yes, as image', 'ueldo' ) ); ?></option>

                                                    </select>

                                                    <div class="ueldo-theme-options-google-maps-creation-map-markers-field-depended" data-depended-name="icon-library-selector" data-visible="<?php echo esc_attr( $marker_data['use-custom-marker'] == 'yes-icon' ? 'yes' : 'no' ); ?>">

                                                        <h5><?php echo esc_html( __( 'Icon library', 'ueldo' ) ); ?></h5>
                                                        <select name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-custom-icon-library]" class="ueldo-theme-options-google-maps-creation-map-markers-field-icon-library-selector">

                                                            <option value="fontawesome" <?php echo esc_attr( $marker_data['custom-icon-library'] == 'fontawesome' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'Font Awesome', 'ueldo' ) ); ?></option>

                                                            <?php

                                                                # is visual composer active?
                                                                if( ueldo_plugins::is_active_plugin( 'visual-composer' ) ) {

                                                                    ?>
                                                                    <option value="openiconic" <?php echo esc_attr( $marker_data['custom-icon-library'] == 'openiconic' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'Open Iconic', 'ueldo' ) ); ?></option>
                                                                    <option value="typicons" <?php echo esc_attr( $marker_data['custom-icon-library'] == 'typicons' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'Typicons', 'ueldo' ) ); ?></option>
                                                                    <option value="entypo" <?php echo esc_attr( $marker_data['custom-icon-library'] == 'entypo' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'Entypo', 'ueldo' ) ); ?></option>
                                                                    <option value="linecons" <?php echo esc_attr( $marker_data['custom-icon-library'] == 'linecons' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'Linecons', 'ueldo' ) ); ?></option>
                                                                    <option value="monosocial" <?php echo esc_attr( $marker_data['custom-icon-library'] == 'monosocial' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'Mono Social', 'ueldo' ) ); ?></option>
                                                                    <option value="material" <?php echo esc_attr( $marker_data['custom-icon-library'] == 'material' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'Material', 'ueldo' ) ); ?></option>
                                                                    <?php
                                                                }

                                                                # do we have custom icons added?
                                                                if( ueldo_plugins::is_active_plugin( 'ueldo' ) ) {

                                                                    # get all custom icons
                                                                    $icons = $ueldo_cache_option -> get_option( 'ueldo_custom_icons' );

                                                                    # do we have custom icons added?
                                                                    if( $icons != false ) {

                                                                        # walk for each icon
                                                                        foreach( $icons as $icon ) {

                                                                            ?>
                                                                            <option value="<?php echo esc_attr( $icon['unique_key'] ); ?>" <?php echo esc_attr( $marker_data['custom-icon-library'] == $icon['unique_key'] ? 'selected' : '' ); ?>><?php echo esc_html( __( 'Custom icons:', 'ueldo' ) ); ?> <?php echo esc_html( $icon['name'] ); ?></option>
                                                                            <?php
                                                                        }
                                                                    }
                                                                }

                                                            ?>

                                                        </select>

                                                    </div>

                                                    <div class="ueldo-theme-options-google-maps-creation-map-markers-field-depended" data-depended-name="iconpicker" data-visible="<?php echo esc_attr( $marker_data['use-custom-marker'] == 'yes-icon' ? 'yes' : 'no' ); ?>">

                                                        <h5><?php echo esc_html( __( 'Icon', 'ueldo' ) ); ?></h5>

                                                        <?php

                                                            # get icon library if visual composer is not activated
                                                            if( $marker_data['custom-icon-library'] != 'fontawesome' && ( !ueldo_plugins::is_active_plugin( 'visual-composer' ) || !ueldo_plugins::is_active_plugin( 'ueldo' ) || !ueldo_plugin_is_any_custom_icon_added() || !ueldo_plugin_custom_icon_exists( $marker_data['custom-icon-library'] ) ) ) {

                                                                # default icon library
                                                                $marker_data['custom-icon-library'] = 'fontawesome';

                                                                # default icon
                                                                $marker_data['custom-icon'] = 'fa fa-long-arrow-right';
                                                            }

                                                        ?>

                                                        <div class="ueldo-theme-options-iconpicker" data-icon-library="<?php echo esc_attr( $marker_data['custom-icon-library'] ); ?>">

                                                            <div class="ueldo-theme-options-iconpicker-button">

                                                                <span class="ueldo-theme-options-iconpicker-selected-icon"><i class="<?php echo esc_attr( $marker_data['custom-icon'] ); ?>"></i></span>
                                                                <input type="hidden" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-custom-icon]" value="<?php echo esc_attr( $marker_data['custom-icon'] ); ?>" />

                                                            </div>

                                                            <div class="ueldo-theme-options-iconpicker-icons-list" data-visible="no">

                                                                <input type="text" name="" placeholder="<?php echo esc_html( __( 'Search...', 'ueldo' ) ); ?>" />

                                                                <div class="ueldo-theme-options-iconpicker-icons-list-container">
                                                                </div>

                                                            </div>

                                                        </div>

                                                    </div>

                                                    <div class="ueldo-theme-options-google-maps-creation-map-markers-field-depended" data-depended-name="icon-colors" data-visible="<?php echo esc_attr( $marker_data['use-custom-marker'] == 'yes-icon' ? 'yes' : 'no' ); ?>">

                                                        <h5><?php echo esc_html( __( 'Icon size', 'ueldo' ) ); ?></h5>
                                                        <span class="ueldo-theme-options-px-field"><input type="text" class="ueldo-validate-number-field" data-number-field-minus-allowed="no" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-custom-icon-size]" value="<?php echo esc_attr( $marker_data['custom-icon-size'] ); ?>" /></span>

                                                        <h5><?php echo esc_html( __( 'Icon container width', 'ueldo' ) ); ?></h5>
                                                        <span class="ueldo-theme-options-px-field"><input type="text" class="ueldo-validate-number-field" data-number-field-minus-allowed="no" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-custom-icon-width]" value="<?php echo esc_attr( $marker_data['custom-icon-width'] ); ?>" /></span>

                                                        <h5><?php echo esc_html( __( 'Icon container height', 'ueldo' ) ); ?></h5>
                                                        <span class="ueldo-theme-options-px-field"><input type="text" class="ueldo-validate-number-field" data-number-field-minus-allowed="no" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-custom-icon-height]" value="<?php echo esc_attr( $marker_data['custom-icon-height'] ); ?>" /></span>

                                                        <h5><?php echo esc_html( __( 'Icon container border radius', 'ueldo' ) ); ?></h5>
                                                        <select name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-custom-icon-border-radius]" class="ueldo-theme-options-google-maps-creation-map-markers-field-icon-container-border-radius">

                                                            <option value="circle" <?php echo esc_attr( $marker_data['custom-icon-border-radius'] == 'circle' ? 'selected' : '' ); ?>><?php echo esc_html( __( '100% (circle)', 'ueldo' ) ); ?></option>
                                                            <option value="px" <?php echo esc_attr( $marker_data['custom-icon-border-radius'] == 'px' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'Pixels', 'ueldo' ) ); ?></option>

                                                        </select>

                                                        <div class="ueldo-theme-options-google-maps-creation-map-markers-field-depended" data-depended-name="icon-border-radius-px" data-visible="<?php echo esc_attr( $marker_data['custom-icon-border-radius'] == 'px' ? 'yes' : 'no' ); ?>">

                                                            <h5><?php echo esc_html( __( 'Icon container border radius (pixels)', 'ueldo' ) ); ?></h5>
                                                            <span class="ueldo-theme-options-px-field"><input type="text" class="ueldo-validate-number-field" data-number-field-minus-allowed="no" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-custom-icon-border-radius-px]" value="<?php echo esc_attr( $marker_data['custom-icon-border-radius-px'] ); ?>" /></span>

                                                        </div>

                                                        <h5><?php echo esc_html( __( 'Icon color', 'ueldo' ) ); ?></h5>
                                                        <input type="text" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-custom-icon-color]" value="<?php echo esc_attr( $marker_data['custom-icon-color'] ); ?>" class="ueldo-alpha-color-picker" data-alpha="true" data-default-color="<?php echo esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-google-map-marker-icon-color' ) ); ?>" />

                                                        <h5><?php echo esc_html( __( 'Icon container background color', 'ueldo' ) ); ?></h5>
                                                        <input type="text" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-custom-icon-background-color]" value="<?php echo esc_attr( $marker_data['custom-icon-background-color'] ); ?>" class="ueldo-alpha-color-picker" data-alpha="true" data-default-color="<?php echo esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-google-map-marker-icon-container-background-color' ) ); ?>" />

                                                        <h5><?php echo esc_html( __( 'Icon container box shadow', 'ueldo' ) ); ?></h5>
                                                        <div class="ueldo-theme-options-box-shadow-field">

                                                            <div class="ueldo-theme-options-box-shadow-field-single-value">

                                                                <span class="ueldo-theme-options-box-shadow-field-single-value-title"><?php echo esc_html( __( 'Horizontal length', 'ueldo' ) ); ?></span>
                                                                <span class="ueldo-theme-options-box-shadow-field-single-value-field">

                                                                    <input type="text" class="ueldo-validate-number-field" data-number-field-minus-allowed="yes" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-custom-icon-box-shadow-horizontal-length]" value="<?php echo esc_attr( $marker_data['custom-icon-box-shadow-horizontal-length'] ); ?>" />

                                                                </span>

                                                            </div>

                                                            <div class="ueldo-theme-options-box-shadow-field-single-value">

                                                                <span class="ueldo-theme-options-box-shadow-field-single-value-title"><?php echo esc_html( __( 'Vertical length', 'ueldo' ) ); ?></span>
                                                                <span class="ueldo-theme-options-box-shadow-field-single-value-field">

                                                                    <input type="text" class="ueldo-validate-number-field" data-number-field-minus-allowed="yes" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-custom-icon-box-shadow-vertical-length]" value="<?php echo esc_attr( $marker_data['custom-icon-box-shadow-vertical-length'] ); ?>" />

                                                                </span>

                                                            </div>

                                                            <div class="ueldo-theme-options-box-shadow-field-single-value">

                                                                <span class="ueldo-theme-options-box-shadow-field-single-value-title"><?php echo esc_html( __( 'Blur radius', 'ueldo' ) ); ?></span>
                                                                <span class="ueldo-theme-options-box-shadow-field-single-value-field">

                                                                    <input type="text" class="ueldo-validate-number-field" data-number-field-minus-allowed="yes" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-custom-icon-box-shadow-blur-radius]" value="<?php echo esc_attr( $marker_data['custom-icon-box-shadow-blur-radius'] ); ?>" />

                                                                </span>

                                                            </div>

                                                            <div class="ueldo-theme-options-box-shadow-field-single-value">

                                                                <span class="ueldo-theme-options-box-shadow-field-single-value-title"><?php echo esc_html( __( 'Spread radius', 'ueldo' ) ); ?></span>
                                                                <span class="ueldo-theme-options-box-shadow-field-single-value-field">

                                                                    <input type="text" class="ueldo-validate-number-field" data-number-field-minus-allowed="yes" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-custom-icon-box-shadow-spread-radius]" value="<?php echo esc_attr( $marker_data['custom-icon-box-shadow-spread-radius'] ); ?>" />

                                                                </span>

                                                            </div>

                                                            <div class="ueldo-theme-options-box-shadow-field-single-value">

                                                                <span class="ueldo-theme-options-box-shadow-field-single-value-title"><?php echo esc_html( __( 'Color', 'ueldo' ) ); ?></span>
                                                                <input type="text" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-custom-icon-box-shadow-color]" value="<?php echo esc_attr( $marker_data['custom-icon-box-shadow-color'] ); ?>" class="ueldo-alpha-color-picker" data-alpha="true" data-default-color="<?php echo esc_attr( $ueldo_styles_cache -> get_box_shadow_part_from_color_key( 'general-colors-google-map-marker-icon-container-box-shadow', 'color' ) ); ?>" />

                                                            </div>

                                                        </div>

                                                    </div>

                                                    <div class="ueldo-theme-options-google-maps-creation-map-markers-field-depended" data-depended-name="marker-image" data-visible="<?php echo esc_attr( $marker_data['use-custom-marker'] == 'yes-image' ? 'yes' : 'no' ); ?>">

                                                        <h5><?php echo esc_html( __( 'Marker image', 'ueldo' ) ); ?></h5>
                                                        <div class="ueldo-theme-options-google-maps-creation-map-markers-field-image-selection-container">

                                                            <?php

                                                                # do we have custom marker image?
                                                                if( $marker_data['custom-marker-image'] !== false && !empty( $marker_data['custom-marker-image'] ) ) {

                                                                    ?>
                                                                    <div class="ueldo-theme-options-google-maps-creation-map-markers-field-image-preview">

                                                                        <img src="<?php echo esc_url( $marker_data['custom-marker-image'] ); ?>" />

                                                                    </div>
                                                                    <?php
                                                                }

                                                            ?>

                                                            <input type="hidden" name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-markers-marker-<?php echo esc_attr( $i ); ?>-custom-marker-image]" value="<?php echo esc_url( $marker_data['custom-marker-image'] ); ?>" />
                                                            <input type="button" class="button ueldo-media-button" value="<?php echo esc_attr( __( 'Select image', 'ueldo' ) ); ?>" />

                                                        </div>

                                                    </div>

                                                </div>

                                            </div>

                                        </div>
                                        <?php
                                    }
                                }
                            }

                        ?>

                    </div>

                    <div class="ueldo-theme-options-google-maps-creation-add-new-marker"><?php echo esc_html( __( 'Add new marker', 'ueldo' ) ); ?></div>

                </div>

                <div class="ueldo-theme-options-google-maps-creation-field-group">

                    <h5><?php echo esc_html( __( 'Custom map style:', 'ueldo' ) ); ?></h5>
                    <p class="ueldo-theme-options-google-maps-creation-field-description-no-margin-top"><?php echo esc_html( __( 'You can add custom map style here, for example from', 'ueldo' ) ); ?> <a href="<?php echo esc_url( ueldo_get_external_url( 'snazzymaps' ) ); ?>" target="_blank"><?php echo esc_html( __( 'Snazzy Maps', 'ueldo' ) ); ?></a>.</p>

                    <textarea name="ueldo_theme_options[google-maps][google-map-<?php echo esc_attr( $map_id ); ?>-custom-style]" rows="5" cols="5"><?php echo esc_html( $map_data['custom-style'] ); ?></textarea>

                </div>

            </div>

        </div>
        <?php
    }

   /**
    *
    * get opening hours status creation field
    *
    */

    function ueldo_get_opening_hours_status_creation_field( $status_id ) {

        # update status data array
        $status_data = array(
            'title' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-title' ),
            'timezone' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-timezone' ),
            'rules-next-rule-id' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-next-rule-id' ),
            'exceptions-next-exception-id' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-next-exception-id' )
        );

        ?>
        <div class="ueldo-theme-options-opening-hours-status-creation-field">

            <div class="ueldo-theme-options-opening-hours-status-creation-field-container">

                <div class="ueldo-theme-options-opening-hours-status-creation-field-group">

                    <h5><?php echo esc_html( __( 'Status name:', 'ueldo' ) ); ?></h5>
                    <input type="text" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-title]" value="<?php echo esc_html( $status_data['title'] ); ?>" class="ueldo-theme-options-opening-hours-status-creation-status-title" />

                </div>

                <div class="ueldo-theme-options-opening-hours-status-creation-field-group">

                    <h5><?php echo esc_html( __( 'Timezone:', 'ueldo' ) ); ?></h5>
                    <select name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-timezone]">

                        <option value="use-browser" <?php echo esc_attr( $status_data['timezone'] == 'use-browser' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'Get from client browser', 'ueldo' ) ); ?></option>

                        <?php

                            # walk for all possible timezones
                            foreach( ueldo_generate_timezone_list() as $timezone => $timezone_name ) {

                                ?>
                                <option value="<?php echo esc_attr( $timezone ); ?>" <?php echo selected( $timezone, $status_data['timezone'] ); ?>><?php echo esc_html( $timezone_name ); ?></option>
                                <?php
                            }

                        ?>

                    </select>

                </div>

                <div class="ueldo-theme-options-opening-hours-status-creation-field-group">

                    <h5><?php echo esc_html( __( 'Rules:', 'ueldo' ) ); ?></h5>

                    <div class="ueldo-theme-options-opening-hours-status-creation-rules-field" data-status-id="<?php echo esc_attr( $status_id ); ?>">

                        <input type="hidden" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-rules-next-rule-id]" value="<?php echo esc_attr( $status_data['rules-next-rule-id'] ); ?>" />
                        <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-nothing-found">

                            <p><?php echo esc_html( __( 'You did not added any rule yet.', 'ueldo' ) ); ?></p>

                        </div>

                        <?php

                            # do we have rules added?
                            if( $status_data['rules-next-rule-id'] > 1 ) {

                                # walk for each rule
                                for( $i = 0; $i < $status_data['rules-next-rule-id']; $i++ ) {

                                    # do we have rule added?
                                    if( ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-title' ) != false ) {

                                        # get rule data array
                                        $rule_data = array(
                                            'title' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-title' ),
                                            'all-day-closed' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-all-day-closed' ),
                                            'next-opening-hours-id' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-next-opening-hours-id' ),
                                            'apply-for-monday' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-apply-for-monday' ),
                                            'apply-for-tuesday' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-apply-for-tuesday' ),
                                            'apply-for-wednesday' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-apply-for-wednesday' ),
                                            'apply-for-thursday' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-apply-for-thursday' ),
                                            'apply-for-friday' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-apply-for-friday' ),
                                            'apply-for-saturday' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-apply-for-saturday' ),
                                            'apply-for-sunday' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-apply-for-sunday' )
                                        );

                                        ?>
                                        <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule" data-rule-details-visible="no" data-rule-id="<?php echo esc_attr( $i ); ?>">

                                            <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-data">

                                                <span class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-remove-confirm" data-visible="no"><?php echo esc_html( __( 'Confirm the deletion', 'ueldo' ) ); ?></span>
                                                <span class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-remove" data-visible="yes"></span>
                                                <span class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-edit"><i class="fa fa-pencil"></i></span>

                                                <span data-element-type="rule-title"><?php echo esc_html( $rule_data['title'] ); ?></span>

                                            </div>

                                            <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details">

                                                <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-group">

                                                    <h5><?php echo esc_html( __( 'Rule title:', 'ueldo' ) ); ?></h5>
                                                    <input type="text" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-title]" value="<?php echo esc_attr( $rule_data['title'] ); ?>" class="ueldo-theme-options-opening-hours-creation-rules-rule-title" />

                                                </div>

                                                <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-group">

                                                    <h5><?php echo esc_html( __( 'Apply for day of week:', 'ueldo' ) ); ?></h5>

                                                    <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-weekdays">

                                                        <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-weekdays-single-day">

                                                            <input type="checkbox" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-monday]" id="status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-monday" <?php echo checked( $rule_data['apply-for-monday'], 'on' ); ?> />
                                                            <label for="status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-monday"><?php echo esc_html( __( 'Monday', 'ueldo' ) ); ?></label>

                                                        </div>

                                                        <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-weekdays-single-day">

                                                            <input type="checkbox" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-tuesday]" id="status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-tuesday" <?php echo checked( $rule_data['apply-for-tuesday'], 'on' ); ?> />
                                                            <label for="status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-tuesday"><?php echo esc_html( __( 'Tuesday', 'ueldo' ) ); ?></label>

                                                        </div>

                                                        <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-weekdays-single-day">

                                                            <input type="checkbox" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-wednesday]" id="status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-wednesday" <?php echo checked( $rule_data['apply-for-wednesday'], 'on' ); ?> />
                                                            <label for="status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-wednesday"><?php echo esc_html( __( 'Wednesday', 'ueldo' ) ); ?></label>

                                                        </div>

                                                        <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-weekdays-single-day">

                                                            <input type="checkbox" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-thursday]" id="status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-thursday" <?php echo checked( $rule_data['apply-for-thursday'], 'on' ); ?> />
                                                            <label for="status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-thursday"><?php echo esc_html( __( 'Thursday', 'ueldo' ) ); ?></label>

                                                        </div>

                                                        <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-weekdays-single-day ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-weekdays-single-day-bottom">

                                                            <input type="checkbox" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-friday]" id="status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-friday" <?php echo checked( $rule_data['apply-for-friday'], 'on' ); ?> />
                                                            <label for="status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-friday"><?php echo esc_html( __( 'Friday', 'ueldo' ) ); ?></label>

                                                        </div>

                                                        <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-weekdays-single-day ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-weekdays-single-day-bottom">

                                                            <input type="checkbox" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-saturday]" id="status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-saturday" <?php echo checked( $rule_data['apply-for-saturday'], 'on' ); ?> />
                                                            <label for="status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-saturday"><?php echo esc_html( __( 'Saturday', 'ueldo' ) ); ?></label>

                                                        </div>

                                                        <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-weekdays-single-day ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-weekdays-single-day-bottom">

                                                            <input type="checkbox" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-sunday]" id="status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-sunday" <?php echo checked( $rule_data['apply-for-sunday'], 'on' ); ?> />
                                                            <label for="status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-apply-for-sunday"><?php echo esc_html( __( 'Sunday', 'ueldo' ) ); ?></label>

                                                        </div>

                                                    </div>

                                                </div>

                                                <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-group">

                                                    <h5><?php echo esc_html( __( 'All day closed?', 'ueldo' ) ); ?></h5>

                                                    <select name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-all-day-closed]" data-field-name="all-day-closed">

                                                        <option value="no" <?php echo esc_attr( $rule_data['all-day-closed'] == 'no' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'No', 'ueldo' ) ); ?></option>
                                                        <option value="yes" <?php echo esc_attr( $rule_data['all-day-closed'] == 'yes' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'Yes', 'ueldo' ) ); ?></option>

                                                    </select>

                                                    <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-depended" data-depended-name="opening-hours" data-visible="<?php echo esc_attr( $rule_data['all-day-closed'] == 'no' ? 'yes' : 'no' ); ?>">

                                                        <h5><?php echo esc_html( __( 'Opening hours', 'ueldo' ) ); ?></h5>

                                                        <input type="hidden" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-next-opening-hours-id]" value="<?php echo esc_attr( $rule_data['next-opening-hours-id'] ); ?>" />
                                                        <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-opening-hours-group">

                                                            <?php

                                                                # walk for each opening hours
                                                                for( $j = 0; $j < $rule_data['next-opening-hours-id']; $j++ ) {

                                                                    # do we have opening hours added?
                                                                    if( ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-from-hour' ) != false ) {

                                                                        ?>
                                                                        <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-opening-hours" data-remove-confirm-visible="no">

                                                                            <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-opening-hours-remove">

                                                                                <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-opening-hours-remove-confirm">

                                                                                    <?php echo esc_html( __( 'Confirm the deletion', 'ueldo' ) ); ?>

                                                                                </div>

                                                                            </div>

                                                                            <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-opening-hours-fields">

                                                                                <input type="hidden" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-rules-rule-<?php echo esc_attr( $i ); ?>-opening-hours-<?php echo esc_attr( $j ); ?>-ignored]" value="<?php echo esc_attr( ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-ignored' ) ); ?>" />

                                                                                <?php

                                                                                    # get "from" hours
                                                                                    ueldo_opening_hours_creation_time_field(
                                                                                        'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-from',
                                                                                        ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-from-hour' ),
                                                                                        ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-from-minutes' ),
                                                                                        true
                                                                                    );

                                                                                    # get "to" hours
                                                                                    ueldo_opening_hours_creation_time_field(
                                                                                        'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-to',
                                                                                        ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-to-hour' ),
                                                                                        ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-rules-rule-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-to-minutes' )
                                                                                    );

                                                                                ?>

                                                                            </div>

                                                                        </div>
                                                                        <?php

                                                                    # end of single opening hours set
                                                                    }

                                                                # end of opening hours loop
                                                                }

                                                            ?>

                                                        </div>

                                                        <div class="ueldo-theme-options-opening-hours-status-creation-add-new-opening-hours-set"><?php echo esc_html( __( 'Add new opening hours set', 'ueldo' ) ); ?></div>

                                                    </div>

                                                </div>

                                            </div>

                                        </div>
                                        <?php

                                    # end of single rule
                                    }

                                # end of rules loop
                                }

                            # end of rules code
                            }

                        ?>

                    </div>

                    <div class="ueldo-theme-options-opening-hours-status-creation-add-new-rule"><?php echo esc_html( __( 'Add new rule', 'ueldo' ) ); ?></div>

                </div>

                <div class="ueldo-theme-options-opening-hours-status-creation-field-group">

                    <h5><?php echo esc_html( __( 'Exceptions:', 'ueldo' ) ); ?></h5>

                    <div class="ueldo-theme-options-opening-hours-status-creation-rules-field ueldo-theme-options-opening-hours-status-creation-rules-field-exceptions" data-status-id="<?php echo esc_attr( $status_id ); ?>">

                        <input type="hidden" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-exceptions-next-exception-id]" value="<?php echo esc_attr( $status_data['exceptions-next-exception-id'] ); ?>" />
                        <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-nothing-found">

                            <p><?php echo esc_html( __( 'You did not added any exception yet.', 'ueldo' ) ); ?></p>

                        </div>

                        <?php

                            # do we have exceptions added?
                            if( $status_data['exceptions-next-exception-id'] > 1 ) {

                                # walk for each rule
                                for( $i = 0; $i < $status_data['exceptions-next-exception-id']; $i++ ) {

                                    # do we have rule added?
                                    if( ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-title' ) != false ) {

                                        # get exception data array
                                        $exception_data = array(
                                            'title' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-title' ),
                                            'all-day-closed' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-all-day-closed' ),
                                            'next-opening-hours-id' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-next-opening-hours-id' ),
                                            'ignored' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-ignored' ),
                                            'apply-from' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-apply-from' ),
                                            'apply-to' => ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-apply-to' )
                                        );

                                        ?>
                                        <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule" data-rule-details-visible="no" data-rule-id="<?php echo esc_attr( $i ); ?>">

                                            <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-data">

                                                <span class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-remove-confirm" data-visible="no"><?php echo esc_html( __( 'Confirm the deletion', 'ueldo' ) ); ?></span>
                                                <span class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-remove" data-visible="yes"></span>
                                                <span class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-edit"><i class="fa fa-pencil"></i></span>

                                                <span data-element-type="rule-title"><?php echo esc_html( $exception_data['title'] ); ?></span>

                                            </div>

                                            <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details">

                                                <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-group">

                                                    <h5><?php echo esc_html( __( 'Exception title:', 'ueldo' ) ); ?></h5>
                                                    <input type="text" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-exceptions-exception-<?php echo esc_attr( $i ); ?>-title]" value="<?php echo esc_attr( $exception_data['title'] ); ?>" class="ueldo-theme-options-opening-hours-creation-rules-rule-title" />

                                                </div>

                                                <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-group">

                                                    <input type="hidden" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-exceptions-exception-<?php echo esc_attr( $i ); ?>-ignored]" value="<?php echo esc_attr( $exception_data['ignored'] ); ?>" />

                                                    <h5><?php echo esc_html( __( 'Apply from:', 'ueldo' ) ); ?></h5>
                                                    <input type="text" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-exceptions-exception-<?php echo esc_attr( $i ); ?>-apply-from]" value="<?php echo esc_attr( $exception_data['apply-from'] ); ?>" class="ueldo-theme-options-datepicker" readonly />

                                                    <h5><?php echo esc_html( __( 'Apply to:', 'ueldo' ) ); ?></h5>
                                                    <input type="text" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-exceptions-exception-<?php echo esc_attr( $i ); ?>-apply-to]" value="<?php echo esc_attr( $exception_data['apply-to'] ); ?>" class="ueldo-theme-options-datepicker" readonly />

                                                </div>

                                                <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-details-fields-group">

                                                    <h5><?php echo esc_html( __( 'All day closed?', 'ueldo' ) ); ?></h5>

                                                    <select name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-exceptions-exception-<?php echo esc_attr( $i ); ?>-all-day-closed]" data-field-name="all-day-closed">

                                                        <option value="no" <?php echo esc_attr( $exception_data['all-day-closed'] == 'no' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'No', 'ueldo' ) ); ?></option>
                                                        <option value="yes" <?php echo esc_attr( $exception_data['all-day-closed'] == 'yes' ? 'selected' : '' ); ?>><?php echo esc_html( __( 'Yes', 'ueldo' ) ); ?></option>

                                                    </select>

                                                    <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-depended" data-depended-name="opening-hours" data-visible="<?php echo esc_attr( $exception_data['all-day-closed'] == 'no' ? 'yes' : 'no' ); ?>">

                                                        <h5><?php echo esc_html( __( 'Opening hours', 'ueldo' ) ); ?></h5>

                                                        <input type="hidden" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-exceptions-exception-<?php echo esc_attr( $i ); ?>-next-opening-hours-id]" value="<?php echo esc_attr( $exception_data['next-opening-hours-id'] ); ?>" />
                                                        <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-opening-hours-group">

                                                            <?php

                                                                # walk for each opening hours
                                                                for( $j = 0; $j < $exception_data['next-opening-hours-id']; $j++ ) {

                                                                    # do we have opening hours added?
                                                                    if( ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-from-hour' ) != false ) {

                                                                        ?>
                                                                        <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-opening-hours" data-remove-confirm-visible="no">

                                                                            <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-opening-hours-remove">

                                                                                <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-opening-hours-remove-confirm">

                                                                                    <?php echo esc_html( __( 'Confirm the deletion', 'ueldo' ) ); ?>

                                                                                </div>

                                                                            </div>

                                                                            <div class="ueldo-theme-options-opening-hours-status-creation-rules-field-single-rule-opening-hours-fields">

                                                                                <input type="hidden" name="ueldo_theme_options[opening-hours-status][status-<?php echo esc_attr( $status_id ); ?>-exceptions-exception-<?php echo esc_attr( $i ); ?>-opening-hours-<?php echo esc_attr( $j ); ?>-ignored]" value="<?php echo esc_attr( ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-ignored' ) ); ?>" />

                                                                                <?php

                                                                                    # get "from" hours
                                                                                    ueldo_opening_hours_creation_time_field(
                                                                                        'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-from',
                                                                                        ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-from-hour' ),
                                                                                        ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-from-minutes' ),
                                                                                        true
                                                                                    );

                                                                                    # get "to" hours
                                                                                    ueldo_opening_hours_creation_time_field(
                                                                                        'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-to',
                                                                                        ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-to-hour' ),
                                                                                        ueldo_get_theme_options_value( 'opening-hours-status', false, 'status-'. esc_attr( $status_id ) .'-exceptions-exception-'. esc_attr( $i ) .'-opening-hours-'. esc_attr( $j ) .'-to-minutes' )
                                                                                    );

                                                                                ?>

                                                                            </div>

                                                                        </div>
                                                                        <?php

                                                                    # end of single opening hours set
                                                                    }

                                                                # end of opening hours loop
                                                                }

                                                            ?>

                                                        </div>

                                                        <div class="ueldo-theme-options-opening-hours-status-creation-add-new-opening-hours-set"><?php echo esc_html( __( 'Add new opening hours set', 'ueldo' ) ); ?></div>

                                                    </div>

                                                </div>

                                            </div>

                                        </div>
                                        <?php

                                    # end of single rule
                                    }

                                # end of rules loop
                                }

                            # end of rules code
                            }

                        ?>

                    </div>

                    <div class="ueldo-theme-options-opening-hours-status-creation-add-new-rule-exception"><?php echo esc_html( __( 'Add new exception', 'ueldo' ) ); ?></div>

                </div>

            </div>

        </div>
        <?php
    }

   /**
    *
    * time field for opening hours creation element
    *
    */

    function ueldo_opening_hours_creation_time_field( $base, $hour, $minutes, $is_first = false ) {

        ?>
        <div class="ueldo-theme-options-opening-hours-status-creation-time-fields <?php echo esc_attr( $is_first == true ? 'ueldo-theme-options-opening-hours-status-creation-time-fields-first' : '' ); ?>">

            <select name="ueldo_theme_options[opening-hours-status][<?php echo esc_attr( $base ); ?>-hour]" class="ueldo-theme-options-opening-hours-status-creation-time-fields-hour">

                <option value="00" <?php echo selected( '00', $hour ); ?>><?php echo esc_html( __( '00 (12 pm)', 'ueldo' ) ); ?></option>
                <option value="01" <?php echo selected( '01', $hour ); ?>><?php echo esc_html( __( '01 (1 am)', 'ueldo' ) ); ?></option>
                <option value="02" <?php echo selected( '02', $hour ); ?>><?php echo esc_html( __( '02 (2 am)', 'ueldo' ) ); ?></option>
                <option value="03" <?php echo selected( '03', $hour ); ?>><?php echo esc_html( __( '03 (3 am)', 'ueldo' ) ); ?></option>
                <option value="04" <?php echo selected( '04', $hour ); ?>><?php echo esc_html( __( '04 (4 am)', 'ueldo' ) ); ?></option>
                <option value="05" <?php echo selected( '05', $hour ); ?>><?php echo esc_html( __( '05 (5 am)', 'ueldo' ) ); ?></option>
                <option value="06" <?php echo selected( '06', $hour ); ?>><?php echo esc_html( __( '06 (6 am)', 'ueldo' ) ); ?></option>
                <option value="07" <?php echo selected( '07', $hour ); ?>><?php echo esc_html( __( '07 (7 am)', 'ueldo' ) ); ?></option>
                <option value="08" <?php echo selected( '08', $hour ); ?>><?php echo esc_html( __( '08 (8 am)', 'ueldo' ) ); ?></option>
                <option value="09" <?php echo selected( '09', $hour ); ?>><?php echo esc_html( __( '09 (9 am)', 'ueldo' ) ); ?></option>
                <option value="10" <?php echo selected( '10', $hour ); ?>><?php echo esc_html( __( '10 (10 am)', 'ueldo' ) ); ?></option>
                <option value="11" <?php echo selected( '11', $hour ); ?>><?php echo esc_html( __( '11 (11 am)', 'ueldo' ) ); ?></option>
                <option value="12" <?php echo selected( '12', $hour ); ?>><?php echo esc_html( __( '12 (12 am)', 'ueldo' ) ); ?></option>
                <option value="13" <?php echo selected( '13', $hour ); ?>><?php echo esc_html( __( '13 (1 pm)', 'ueldo' ) ); ?></option>
                <option value="14" <?php echo selected( '14', $hour ); ?>><?php echo esc_html( __( '14 (2 pm)', 'ueldo' ) ); ?></option>
                <option value="15" <?php echo selected( '15', $hour ); ?>><?php echo esc_html( __( '15 (3 pm)', 'ueldo' ) ); ?></option>
                <option value="16" <?php echo selected( '16', $hour ); ?>><?php echo esc_html( __( '16 (4 pm)', 'ueldo' ) ); ?></option>
                <option value="17" <?php echo selected( '17', $hour ); ?>><?php echo esc_html( __( '17 (5 pm)', 'ueldo' ) ); ?></option>
                <option value="18" <?php echo selected( '18', $hour ); ?>><?php echo esc_html( __( '18 (6 pm)', 'ueldo' ) ); ?></option>
                <option value="19" <?php echo selected( '19', $hour ); ?>><?php echo esc_html( __( '19 (7 pm)', 'ueldo' ) ); ?></option>
                <option value="20" <?php echo selected( '20', $hour ); ?>><?php echo esc_html( __( '20 (8 pm)', 'ueldo' ) ); ?></option>
                <option value="21" <?php echo selected( '21', $hour ); ?>><?php echo esc_html( __( '21 (9 pm)', 'ueldo' ) ); ?></option>
                <option value="22" <?php echo selected( '22', $hour ); ?>><?php echo esc_html( __( '22 (10 pm)', 'ueldo' ) ); ?></option>
                <option value="23" <?php echo selected( '23', $hour ); ?>><?php echo esc_html( __( '23 (11 pm)', 'ueldo' ) ); ?></option>

            </select>

            <span class="ueldo-theme-options-opening-hours-status-creation-time-fields-divider">:</span>

            <select name="ueldo_theme_options[opening-hours-status][<?php echo esc_attr( $base ); ?>-minutes]" class="ueldo-theme-options-opening-hours-status-creation-time-fields-minutes">

                <?php

                    # display minutes options
                    for( $i = 0; $i < 60; $i++ ) {

                        # get the minute value
                        $minute = $i < 10 ? '0'. $i : $i;

                        ?>
                        <option value="<?php echo esc_attr( $minute ); ?>" <?php echo selected( $minute, $minutes ); ?>><?php echo esc_html( $minute ); ?></option>
                        <?php
                    }

                ?>

            </select>

        </div>
        <?php
    }

   /**
    *
    * protect default theme options in multilingual mode
    *
    */

    function ueldo_protect_default_theme_options_in_multilingual_mode() {

        # is multilingual enabled?
        if( !ueldo_is_multilingual() || ueldo_get_languages_list() == false ) return;

        # default theme options array
        $default_options = array();

        # walk througt all default theme options
        foreach( ueldo_get_all_default_theme_options() as $option_key => $option_value ) {

            # is this option an array?
            if( is_array( $option_value ) ) {

                # is it not an multidimensional array?
                if( ( count( $option_value ) == count( $option_value, COUNT_RECURSIVE ) ) && isset( $option_value['all'] ) ) $default_options[$option_key] = ueldo_get_theme_options_value( $option_key, 'all' );
                else {

                    # walk for each child option
                    foreach( $option_value as $child_key => $child_value ) {

                        # is this option an array?
                        if( is_array( $child_value ) && isset( $child_value['all'] ) ) $default_options[$option_key][$child_key] = ueldo_get_theme_options_value( $option_key, 'all', $child_key );
                    }
                }
            }
        }

        ?>
        <div class="ueldo-theme-options-default-options-protection">
        <?php

        # walk for each saved options
        foreach( $default_options as $key => $value ) {

            # not an array?
            if( !is_array( $value ) ) {

                ?>
                <input type="hidden" name="ueldo_theme_options[<?php echo esc_attr( $key ); ?>][all]" value="<?php echo esc_attr( $value ); ?>" />
                <?php
            }

            # array of options
            else {

                # walk for each array elements
                foreach( $value as $sub_key => $sub_value ) {

                    ?>
                    <input type="hidden" name="ueldo_theme_options[<?php echo esc_attr( $key ); ?>][<?php echo esc_attr( $sub_key ); ?>][all]" value="<?php echo esc_attr( $sub_value ); ?>" />
                    <?php
                }
            }
        }

        ?>
        </div>
        <?php

        # remove temporary variables
        unset( $default_options, $option_key, $option_value, $key, $value, $sub_key, $sub_value );
    }

   /**
    *
    * theme options plugin activation notice
    *
    */

    function ueldo_display_theme_options_plugin_activation_notice() {

        # plugin is activated?
        if( ueldo_plugins::is_active_plugin( 'ueldo' ) ) return;

        ?>
        <div class="ueldo-theme-options-plugin-activation-notice">

            <h3><?php echo esc_html( __( 'Please activate the Ueldo Plugin!', 'ueldo' ) ); ?></h3>
            <p><?php echo wp_kses( __( 'This plugin contains a lot of great features, like <strong>demo data uploader</strong>, <strong>custom icons uploader</strong> and many other additional functions. It is also required for Visual Composer and other integrated plugins.', 'ueldo' ), array( 'strong' => array() ) ); ?></p>

            <p><a href="<?php echo esc_url( admin_url( 'themes.php?page=tgmpa-install-plugins' ) ); ?>"><?php echo esc_html( __( 'Go to plugins activation page!', 'ueldo' ) ); ?></a></p>

        </div>
        <?php
    }

   /**
    *
    * get inline styles for theme options page
    *
    */

    function ueldo_theme_options_get_inline_styles() {

        # global variables
        global $ueldo_styles_cache;

        # create object of styles cache class
        $styles = new ueldo_shortcodes_styles_cache();

        # update background color for loader animations
        $styles -> update_style(
            'ueldo-theme-options-animations-selection-field-option-container-inner, .ueldo-loader-style-04 .ueldo-loader-circle-inner',
            array(
                'background' => esc_attr( ueldo_get_theme_options_value( 'loader-animation', false, 'custom-colors-enabled' ) == 'yes' ? ueldo_get_theme_options_value( 'loader-animation', false, 'custom-colors-background' ) : '#'. get_background_color() )
            )
        );

        # update border color for loader animations spinners
        $styles -> update_style(
            'ueldo-loader-style-04, .ueldo-loader-style-03',
            array(
                'border-color' => esc_attr( ueldo_get_theme_options_value( 'loader-animation', false, 'custom-colors-enabled' ) == 'yes' ? ueldo_get_theme_options_value( 'loader-animation', false, 'custom-colors-spinner' ) : esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-main-color' ) ) )
            )
        );

        # update background color for loader animations spinners
        $styles -> update_style(
            'ueldo-loader-style-02, .ueldo-loader-style-01 .ueldo-loader-style-01-bounce-a, .ueldo-loader-style-01 .ueldo-loader-style-01-bounce-b, .ueldo-loader-style-05 > div, .ueldo-loader-style-06 > div, .ueldo-loader-style-07 > div > div, .ueldo-loader-style-08 > div > div, .ueldo-loader-style-09 > div',
            array(
                'background' => esc_attr( ueldo_get_theme_options_value( 'loader-animation', false, 'custom-colors-enabled' ) == 'yes' ? ueldo_get_theme_options_value( 'loader-animation', false, 'custom-colors-spinner' ) : esc_attr( $ueldo_styles_cache -> get_style( 'general-colors-main-color' ) ) )
            )
        );

        # save css style
        $styles -> save_styles();

        # return result
        return( ueldo_minify_css( $styles -> get_css() ) );
    }

   /**
    *
    * end of file.
    *
    */

?>