<?php

    # prevent direct file access
    if( !defined( 'ABSPATH' ) ) exit;

   /**
    *
    * show heading menu
    *
    */

    function ueldo_heading_menu( $menu, $nav_class = 'ueldo-header-bar-main-menu' ) {

        # remove incorrect characters
        $menu = str_replace( '&nbsp;', '', $menu );

        # there's no menu?
        if( empty( $menu ) ) return;

        # create new simple xml element
        $xml = new SimpleXMLElement( $menu );

        # do we have the list?
        if( isset( $xml -> ul ) ) {

            # walk for each list element
            for( $i = 0; $i < count( $xml -> ul -> li ); $i++ ) {

                # if list element is a parent for other list
                if( isset( $xml -> ul -> li[$i] -> ul ) ) {

                    # add icon
                    $xml -> ul -> li[$i] -> a -> addChild( 'i' );

                    # add icon class
                    $xml -> ul -> li[$i] -> a -> i -> addAttribute( 'class', 'fa fa-caret-down' );

                    # walk for each list elements
                    for( $j = 0; $j < count( $xml -> ul -> li[$i] -> ul -> li ); $j++ ) {

                        # configure submenus
                        ueldo_heading_menu_configure_submenus( $xml -> ul -> li[$i] -> ul -> li[$j] );
                    }
                }
            }
        }

        # bring back the xml to html format
        $menu = $xml -> asXML();

        # replacements
        $menu = preg_replace( '/<i class="(.*?)"\/>/', '<i class="$1"></i>', $menu );
        $menu = str_replace( '<div><ul>', '<ul>', str_replace( '</ul></div>', '</ul>', $menu ) );
        $menu = str_replace( '<nav><ul>', '<nav class="'. esc_attr( $nav_class ) .'"><ul>', $menu );

        # return result
        echo str_replace( '<?xml version="1.0"?>', '', do_shortcode( $menu ) );
    }

   /**
    *
    * configure heading menu submenus
    *
    */

    function ueldo_heading_menu_configure_submenus( $element ) {

        # do we have sub-child?
        if( isset( $element -> ul ) ) {

            # get anchor text
            $anchor = $element -> a -> __toString();

            # temporary clear anchor text
            $element -> a = '';

            # add icon
            $element -> a -> addChild( 'i' );

            # add icon class
            $element -> a -> i -> addAttribute( 'class', 'fa fa-caret-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) );

            # put back the anchor text
            $element -> a -> addChild( 'span', $anchor );

            # walk for each list elements
            for( $i = 0; $i < count( $element -> ul ); $i++ ) {

                # configure submenus
                ueldo_heading_menu_configure_submenus( $element -> ul -> li[$i] );
            }
        }
    }

   /**
    *
    * show "switch page" links
    *
    */

    function ueldo_show_switch_page_links( $page_type, $post_id = false ) {

        # get cache option class object
        global $ueldo_cache_option;

        # switch the page type
        switch( $page_type ) {

           /**
            *
            * single blog post
            *
            */

            case 'post':

                # do we have the post?
                if( $post_id == false ) return( false );
                else {

                    # get the previous post
                    $prev_post = get_adjacent_post( false, '', false );
                    $prev_link = !empty( $prev_post ) ? get_permalink( $prev_post ) : false;

                    # get the next post
                    $next_post = get_adjacent_post( false, '', true );
                    $next_link = !empty( $next_post ) ? get_permalink( $next_post ) : false;

                    # both doesn't exists?
                    if( $prev_post == null && $next_post == null ) return( false );

                    # prepare contents
                    $content = array(
                        'prev' => array(
                            'top' => esc_html( __( 'Previous post', 'ueldo' ) ),
                            'bottom' => !empty( $prev_post ) ? get_the_title( $prev_post ) : false
                        ),
                        'next' => array(
                            'top' => esc_html( __( 'Next post', 'ueldo' ) ),
                            'bottom' => !empty( $next_post ) ? get_the_title( $next_post ) : false
                        )
                    );
                }

            break;

           /**
            *
            * blog posts list and search results
            *
            */

            case 'blog':
            case 'search':

                # use global variable
                global $wp_query;

                # get the previous posts link
                $prev_link = ueldo_exclude_url( get_previous_posts_link( false ) );

                # get the next posts link
                $next_link = ueldo_exclude_url( get_next_posts_link( false ) );

                # both doesn't exists?
                if( $prev_link == null && $next_link == null ) return( false );

                # count posts pages
                $count_posts_pages = ceil( $wp_query -> found_posts / $ueldo_cache_option -> get_option( 'posts_per_page' ) );

                # current posts page
                $current_posts_page = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;

                # prepare contents
                $content = array(
                    'prev' => array(
                        'top' => esc_html( __( 'Page:', 'ueldo' ) ) .' '. esc_html( $current_posts_page - 1 ) .'/'. esc_html( $count_posts_pages ),
                        'bottom' => $page_type == 'blog' ? esc_html( __( 'Newest posts', 'ueldo' ) ) : esc_html( __( 'Newest results', 'ueldo' ) )
                    ),
                    'next' => array(
                        'top' => esc_html( __( 'Page:', 'ueldo' ) ) .' '. esc_html( $current_posts_page + 1 ) .'/'. esc_html( $count_posts_pages ),
                        'bottom' => $page_type == 'blog' ? esc_html( __( 'Older posts', 'ueldo' ) ) : esc_html( __( 'Older results', 'ueldo' ) )
                    )
                );

            break;

           /**
            *
            * nothing from list?
            *
            */

            default: return( false );
        }

        ?>
        <section class="ueldo-switch-page">

            <p class="ueldo-switch-page-left">

                <?php

                    # do we have the prev link?
                    if( $prev_link != false ) {

                        ?>
                        <a href="<?php echo esc_url( $prev_link ); ?>">

                            <i class="fa fa-long-arrow-<?php echo esc_attr( ueldo_is_rtl() ? 'right' : 'left' ); ?> ueldo-switch-page-icon"></i>

                            <span class="ueldo-switch-page-content">

                                <span class="ueldo-switch-page-content-highlight"><?php echo esc_html( $content['prev']['top'] ); ?></span>
                                <span class="ueldo-switch-page-content-title"><?php echo esc_html( $content['prev']['bottom'] ); ?></span>

                            </span>

                        </a>
                        <?php

                    # end of prev link
                    }

                ?>

            </p>

            <p class="ueldo-switch-page-right">

                <?php

                    # do we have the next link?
                    if( $next_link != false ) {

                        ?>
                        <a href="<?php echo esc_url( $next_link ); ?>">

                            <span class="ueldo-switch-page-content">

                                <span class="ueldo-switch-page-content-highlight"><?php echo esc_html( $content['next']['top'] ); ?></span>
                                <span class="ueldo-switch-page-content-title"><?php echo esc_html( $content['next']['bottom'] ); ?></span>

                            </span>

                            <i class="fa fa-long-arrow-<?php echo esc_attr( ueldo_is_rtl() ? 'left' : 'right' ); ?> ueldo-switch-page-icon"></i>

                        </a>
                        <?php

                    # end of next link
                    }

                ?>

            </p>

        </section>
        <?php
    }

   /**
    *
    * get the single post details data
    *
    */

    function ueldo_show_post_details() {

        ?>
        <div class="ueldo-blog-post-data">

            <img src="<?php echo esc_url( get_avatar_url( get_the_author_meta( 'ID' ), array( 'size' => esc_attr( ueldo_get_theme_options_value( 'retina-images-replacement', false, 'enabled' ) == 'yes' ? 80 : 40 ) ) ) ); ?>" alt="<?php echo esc_attr( get_the_author_meta( 'display_name', get_the_author_meta( 'ID' ) ) ); ?>" <?php echo ueldo_retina_ready_attr(); ?> />

            <ul>

                <li><?php the_author_posts_link(); ?></li>

                <li>

                    <?php

                        # get post publication status
                        $post_status = get_post_status( get_the_ID() );

                        # is post scheduled to publish it in future?
                        if( $post_status == 'future' ) {

                            # scheduled
                            echo esc_html( __( 'Scheduled to', 'ueldo' ) .' '. ueldo_get_default_publication_date() );
                        }

                        # is post drafted?
                        else if( $post_status == 'draft' || $post_status == 'auto-draft' ) {

                            # drafted
                            echo esc_html( __( 'Drafted', 'ueldo' ) .' ' );

                            # can we translate date to human time?
                            if( ueldo_get_theme_options_value( 'translate-publication-dates' ) == 'yes' ) ueldo_show_when( get_the_time( 'U', get_the_ID() ) );
                            else {

                                # drafted on ;)
                                echo esc_html( __( 'on', 'ueldo' ) .' ' );

                                # display default date and time
                                echo esc_html( ueldo_get_default_publication_date() );
                            }
                        }

                        # post published
                        else {

                            # published
                            echo esc_html( __( 'Published', 'ueldo' ) .' ' );

                            # can we translate date to human time?
                            if( ueldo_get_theme_options_value( 'translate-publication-dates' ) == 'yes' ) ueldo_show_when( get_the_time( 'U', get_the_ID() ) );
                            else {

                                # display default date and time
                                echo esc_html( ueldo_get_default_publication_date() );
                            }
                        }

                        # remove temporary variables
                        unset( $post_status );

                    ?>

                </li>

                <?php

                    # comments popup link
                    if( comments_open() ) {

                        ?>
                        <li><?php comments_popup_link( esc_html( __( 'No comments yet', 'ueldo' ) ), esc_html( __( '1 comment', 'ueldo' ) ), esc_html( __( '% comments', 'ueldo' ) ), '', esc_html( __( 'Comments Off', 'ueldo' ) ) ); ?></li>
                        <?php
                    }

                    # is sticky post?
                    if( is_sticky( get_the_ID() ) && is_paged() == false ) {

                        ?>
                        <li class="sticky"><?php echo esc_html( __( 'Sticky', 'ueldo' ) ); ?></li>
                        <?php
                    }

                ?>

            </ul>

        </div>
        <?php
    }

   /**
    *
    * get the single post heading
    *
    */

    function ueldo_show_post_heading() {

        ?>
        <div class="ueldo-blog-post-heading <?php echo esc_attr( ueldo_get_theme_options_value( 'single-blog-post-style', false, 'blog-post-data-and-title-centered' ) == 'yes' ? 'ueldo-blog-post-heading-content-centered' : '' ); ?>" data-is-single="true">

            <h1 class="ueldo-blog-post-title">

                <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>

            </h1>

            <?php

                # can we display post details?
                if( ueldo_get_theme_options_value( 'single-blog-post-style', false, 'display-post-data-under-title' ) == 'yes' ) {

                    # get the single post details data
                    ueldo_show_post_details();
                }

            ?>

        </div>
        <?php
    }

   /**
    *
    * custom search field widget
    *
    */

    add_filter( 'get_search_form', 'ueldo_custom_search_form_widget' );
    function ueldo_custom_search_form_widget( $form ) {

        # define the result
        $result = '<form role="search" method="get" id="searchform" action="'. esc_url( home_url( '/' ) ) .'" class="ueldo-search-form">

                       <span class="ueldo-search-field">

                           <input type="text" placeholder="'. esc_html( __( 'Search...', 'ueldo' ) ) .'" value="'. esc_attr( get_search_query() ) .'" name="s" />
                           <button type="submit"><i class="fa fa-search"></i></button>

                       </span>

                   </form>';

        # return result
        return( $result );
    }

   /**
    *
    * display facebook like button near the blog post content
    *
    */

    function ueldo_facebook_like_button_under_blog_content() {

        # get the current language key
        $lang_key = ueldo_get_current_language_key();

        # do we have facebook like button set?
        if( ueldo_is_facebook_like_button_set() ) {

            ?>
            <section class="facebook-like-share-button">

                <div class="fb-like" data-href="<?php echo esc_url( ueldo_get_theme_options_value( 'facebook-fanpage-url', esc_attr( $lang_key ) ) ); ?>" data-layout="box_count" data-action="like" data-size="small" data-show-faces="false" data-share="false">
                </div>

            </section>
            <?php

        # end of facebook button
        }
    }

   /**
    *
    * add facebook javascript sdk
    *
    */

    add_action( 'wp_enqueue_scripts', 'ueldo_facebook_javascript_sdk' );
    function ueldo_facebook_javascript_sdk() {

        # get current language locale
        $locale = ueldo_is_multilingual() ? ueldo_get_current_language_locale() : get_locale();

        # add the script
        wp_add_inline_script( 'ueldo-javascript-functions', '(function(d, s, id) { var js, fjs = d.getElementsByTagName(s)[0]; if (d.getElementById(id)) return; js = d.createElement(s); js.id = id; js.src = "//connect.facebook.net/'. esc_attr( $locale ) .'/sdk.js#xfbml=1&version=v2.7"; fjs.parentNode.insertBefore(js, fjs); }(document, "script", "facebook-jssdk"));' );
    }

   /**
    *
    * get tags and categories as a tagcloud
    *
    */

    function ueldo_display_as_tagcloud( $elements, $type = 'category' ) {

        # do we have the links
        if( $elements == false || $elements == null || !is_array( $elements ) || count( $elements ) < 1 ) return false;

        # walk each all links
        foreach( $elements as $element ) {

            # create link
            $link = $type == 'category' ? get_category_link( $element -> term_id ) : get_tag_link( $element -> term_id );

            ?>
            <a href="<?php echo esc_url( $link ); ?>" class="element"><?php echo esc_html( $element -> name ); ?></a>
            <?php
        }
    }

   /**
    *
    * comments "reply" form
    *
    */

    function ueldo_comments_reply_form() {

        # get cache option class object
        global $ueldo_cache_option;

        # current commenter
        $commenter = wp_get_current_commenter();

        # name and email required?
        $req = $ueldo_cache_option -> get_option( 'require_name_email' );

        # comment form
        comment_form( array(
            'title_reply_before' => '<h2 id="reply-title" class="comment-reply-title">',
            'title_reply_after' => '</h2>',
            'comment_notes_before' => '',
            'label_submit' => esc_html( __( 'Post reply', 'ueldo' ) ),
            'fields' => apply_filters( 'comment_form_default_fields', array(
                'author' => '<input class="ueldo-comment-form-input-field" id="author" name="author" placeholder="'. esc_html( __( 'Name...', 'ueldo' ) ) .'" type="text" value="'. esc_attr( $commenter['comment_author'] ) .'" size="30" aria-required="'. esc_attr( $req ? 'true' : 'false' ) .'" />',
                'email' => '<input class="ueldo-comment-form-input-field" id="email" name="email" placeholder="'. esc_html( __( 'E-mail address...', 'ueldo' ) ) .'" type="text" value="'. esc_attr( $commenter['comment_author_email'] ) .'" size="30" aria-required="'. esc_attr( $req ? 'true' : 'false' ) .'" />',
                'url' => '<input class="ueldo-comment-form-input-field" id="url" name="url" placeholder="'. esc_html( __( 'Website URL...', 'ueldo' ) ) .'" type="text" value="'. esc_attr( $commenter['comment_author_url'] ) .'" size="30" />',
            )),
            'comment_field' => '<textarea id="comment" name="comment" placeholder="'. esc_html( __( 'Comment...', 'ueldo' ) ) .'" cols="45" rows="8" aria-required="true"></textarea>'
        ));
    }

   /**
    *
    * comment field to bottom
    *
    */

    add_filter( 'comment_form_fields', 'ueldo_move_comment_field_to_bottom' );
    function ueldo_move_comment_field_to_bottom( $fields ) {

        # do we need to change it?
        if( ueldo_get_theme_options_value( 'comment-textarea-at-top' ) == 'yes' ) return( $fields );

        # get comment field copy
        $comment_field = $fields['comment'];

        # remove comment field
        unset( $fields['comment'] );

        # and add it again
        $fields['comment'] = $comment_field;

        # return updated result
        return( $fields );
    }

   /**
    *
    * custom comment template
    *
    */

    function ueldo_display_comment( $comment, $args, $depth ) {

        # get post data
        global $post;

        # get html tags
        if( 'div' === $args['style'] ) $html_tags = array( 'tag' => 'div', 'add-below' => 'comment' );
        else $html_tags = array( 'tag' => 'li', 'add-below' => 'div-comment' );

        ?>
        <<?php echo esc_attr( $html_tags['tag'] ); ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?> id="comment-<?php comment_ID() ?>">

            <?php

                # wrap list-style comments body
                if( 'div' != $args['style'] ) {

                    ?><div id="div-comment-<?php comment_ID() ?>" class="comment-body"><?php
                }

            ?>

            <div class="comment-author vcard">

                <?php

                    # display avatar
                    if( $args['avatar_size'] != 0 ) echo get_avatar( $comment, $args['avatar_size'] );

                ?>

                <cite class="fn"><?php echo get_comment_author_link(); ?></cite>

                <?php

                    # display author notice
                    if( $comment -> user_id === $post->post_author ) {

                        ?><span class="ueldo-comment-by-post-author"><?php echo esc_html( __( 'Author', 'ueldo' ) ); ?></span><?php
                    }

                ?>

            </div>

            <?php

                # comment is awaiting moderation
                if( $comment -> comment_approved == '0' ) {

                    ?><em class="comment-awaiting-moderation"><?php echo __( 'Your comment is awaiting moderation.', 'ueldo' ); ?></em><br /><?php
                }

            ?>

            <div class="comment-meta commentmetadata">

                <a href="<?php echo htmlspecialchars( get_comment_link( $comment -> comment_ID ) ); ?>"><?php

                    # can we display translated publication date?
                    if( ueldo_get_theme_options_value( 'translate-publication-dates' ) == 'yes' ) ueldo_show_when( get_comment_date( 'U', esc_attr( $comment -> comment_ID ) ) );
                    else printf( esc_html( __( '%1$s at %2$s', 'ueldo' ) ), get_comment_date(), get_comment_time() );

                ?></a>

                <?php edit_comment_link( esc_html( __( '(Edit)', 'ueldo' ) ), '  ', '' ); ?>

            </div>

            <?php comment_text(); ?>

            <div class="reply">

                <?php

                    # comment reply link
                    comment_reply_link(
                        array_merge(
                            $args,
                            array(
                                'add_below' => esc_attr( $html_tags['add-below'] ),
                                'depth' => esc_attr( $depth ),
                                'max_depth' => esc_attr( $args['max_depth'] )
                            )
                        )
                    );

                ?>

            </div>
            <?php

        # end of comment
        if( 'div' != $args['style'] ) { ?></div><?php }
    }

   /**
    *
    * display the content for 404 page
    *
    */

    function ueldo_get_404_page_content() {

        # get global cache object
        global $ueldo_cache_option;

        # get the current language key
        $lang_key = ueldo_get_current_language_key();

        # get 404 page ID
        $pageID = ueldo_get_theme_options_value( '404-page-id', esc_attr( $lang_key ) );

        # prepare the 404 page variable
        $page_404 = '';

        # if there's no page id
        if( !empty( $pageID ) ) $page_404 = $ueldo_cache_option -> get_post( $pageID );

        # do we have it?
        if( $page_404 != 'default' && $page_404 !== null && $page_404 !== false && !empty( $page_404 ) ) {

            # get page content
            $page_content = $page_404 -> post_content;

            ?>
            <section class="ueldo-content-default <?php echo esc_attr( ueldo_is_vc_page( $page_content ) ? 'ueldo-content-default-vc-page' : '' ); ?>">

                <div class="ueldo-content-container ueldo-content-wrapper">

                    <?php

                        # display it
                        echo apply_filters( 'the_content', $page_content );

                    ?>

                </div>

            </section>
            <?php

            # remove temporary variables
            unset( $page_content );
        }

        # there's no 404 page configured
        else {

            ?>
            <section class="ueldo-content-default" <?php echo ueldo_display_sidebar_attributes( 'posts-list' ); ?>>

                <div class="ueldo-content-container <?php echo esc_attr( ueldo_get_theme_options_value( 'blog-sidebar', false, 'posts-list' ) == 'no' ? 'ueldo-content-wrapper' : '' ); ?>">

                    <?php

                        # if sidebar is set, wrap the content
                        if( ueldo_get_theme_options_value( 'blog-sidebar', false, 'posts-list' ) != 'no' ) {

                            ?>
                            <div class="ueldo-content-wrapper">
                            <?php
                        }

                    ?>

                    <article class="ueldo-default-404-content">

                        <h1><span class="ueldo-heading-subtitle"><?php echo esc_html( __( 'Ooops...', 'ueldo' ) ); ?></span> <?php echo esc_html( __( 'Nothing found here...', 'ueldo' ) ); ?></h1>
                        <p>

                            <?php echo esc_html( __( 'We could not find the results you are looking for - it may be removed, or temporary hidden. Please try to use the search form, or', 'ueldo' ) ); ?>
                            <a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php echo esc_html( __( 'go back to home page', 'ueldo' ) ); ?></a>.

                        </p>

                        <form role="search" method="get" action="<?php echo esc_url( home_url( '/' ) ); ?>" class="ueldo-search-form">

                            <span class="ueldo-search-field">

                                <input type="text" placeholder="<?php echo esc_html( __( 'Search...', 'ueldo' ) ); ?>" value="<?php echo esc_attr( get_search_query() ); ?>" name="s" />
                                <button type="submit"><i class="fa fa-search"></i></button>

                            </span>

                        </form>

                    </article>

                    <?php

                        # display sidebar if set and close the content wrapper
                        if( ueldo_get_theme_options_value( 'blog-sidebar', false, 'posts-list' ) != 'no' ) {

                            ?>
                            </div>

                            <div class="ueldo-sidebar-wrapper">

                                <?php

                                    # get sidebar for blog
                                    get_sidebar();

                                ?>

                            </div>
                            <?php

                        # end of blog sidebar
                        }

                    ?>

                </div>

            </section>
            <?php
        }
    }

   /**
    *
    * get the custom css code
    *
    */

    function ueldo_get_custom_css_code( $content ) {

        # get custom CSS, if exists
        $post_content = explode( 'css=".vc_custom_', $content );

        # define the result
        $result = '';

        # do we have it?
        if( count( $post_content ) > 0 ) {

            # loop
            for( $i = 1; $i < count( $post_content ); $i++ ) {

                $post_content[$i] = explode( '"', $post_content[$i] );
                $result .= '.vc_custom_'. $post_content[$i][0];
            }
        }

        # return result
        return( $result );
    }

   /**
    *
    * remove empty paragraphs created by wpautop()
    *
    */

    add_filter( 'the_content', 'ueldo_remove_empty_p', 20, 1 );
    function ueldo_remove_empty_p( $content ) {

        # do the updates
        $content = preg_replace( '#<p>\s*+(<br\s*/*>)?\s*</p>#i', '', $content );
        $content = preg_replace( '~\s?<p>(\s|&nbsp;)+</p>\s?~', '', $content );

        # manually updates
        $content = str_replace( '<p><li', '<li', $content );
        $content = str_replace( '</li></p>', '</li>', $content );

        # return result
        return( $content );
    }

   /**
    *
    * author box
    *
    */

    function ueldo_display_author_box() {

        # author id
        $author_id = get_the_author_meta( 'ID' );

        # author description
        $description = get_the_author_meta( 'user_description' );

        # there's no description set?
        if( empty( $description ) ) return;

        ?>
        <section class="ueldo-author-box">

            <img src="<?php echo esc_url( get_avatar_url( $author_id, array( 'size' => esc_attr( ueldo_get_theme_options_value( 'retina-images-replacement', false, 'enabled' ) == 'yes' ? 240 : 120 ) ) ) ); ?>" alt="<?php echo esc_attr( get_the_author_meta( 'display_name', $author_id ) ); ?>" <?php echo ueldo_retina_ready_attr(); ?> class="ueldo-author-box-image" />

            <h3>

                <span class="ueldo-heading-subtitle"><?php echo esc_html( __( 'About post author', 'ueldo' ) ); ?></span>

                <?php

                    # do we have first or last author name?
                    if( get_the_author_meta( 'first_name', $author_id ) != '' || get_the_author_meta( 'last_name', $author_id ) != '' ) {

                        # getting author first name
                        if( get_the_author_meta( 'first_name', $author_id ) != '' ) echo esc_html( get_the_author_meta( 'first_name', $author_id ) );

                        # getting author last name
                        if( get_the_author_meta( 'last_name', $author_id ) != '' ) echo esc_html( ' '. get_the_author_meta( 'last_name', $author_id ) );
                    }

                    # get author nick
                    else {

                        # only author nick
                        echo esc_html( get_the_author_meta( 'display_name', $author_id ) );
                    }

                ?>

            </h3>

            <div class="ueldo-author-box-description">

                <?php

                    # display the description
                    echo wpautop( do_shortcode( $description ) );

                ?>

            </div>

        </section>
        <?php
    }

   /**
    *
    * display similar posts
    *
    */

    function ueldo_display_similar_posts( $post = false, $posts_style ) {

        # there's no post set?
        if( $post == false ) {

            # get last post
            foreach( get_posts( array( 'posts_per_page' => 2, 'ignore_sticky_posts' => 1 ) ) as $single_post ) {

                # save the post to variable
                $post = $single_post;
            }
        }

        # still there's no post?
        if( $post == false ) return;

        # create a copy of original post
        $orig_post = $post;

        # get current post tags
        $tags = wp_get_post_tags( $post -> ID );

        # do we have tags?
        if( $tags ) {

            # create tags ids array
            $tag_ids = array();
            foreach( $tags as $single_tag ) $tag_ids[] = $single_tag -> term_id;

            # create arguments array
            $args = array(
                'tag__in' => $tag_ids,
                'post__not_in' => array( $post -> ID ),
                'posts_per_page' => 2,
                'caller_get_posts' => 1
            );

            # new wp query
            $similar_posts = new wp_query( $args );

            # do we have posts?
            if( $similar_posts -> have_posts() ) {

                ?>
                <section class="ueldo-similar-posts">

                    <h2><?php echo esc_html( __( 'Similar articles', 'ueldo' ) ); ?></h2>
                    <div class="ueldo-similar-posts-container">

                        <?php

                            # posts loop
                            while( $similar_posts -> have_posts() ) {

                                # current post
                                $similar_posts -> the_post();

                                ?>
                                <div class="ueldo-similar-posts-single-post">

                                    <?php

                                        # display short post box
                                        ueldo_display_short_post_box( $posts_style );

                                    ?>

                                </div>
                                <?php

                            # end of posts loop
                            }

                        ?>

                    </div>

                </section>
                <?php
            }
        }

        # restore original post
        $post = $orig_post;

        # reset query
        wp_reset_query();
    }

   /**
    *
    * display short post box
    *
    */

    function ueldo_display_short_post_box( $style, $heading_type = 'h5' ) {

        # get cache option class object
        global $ueldo_cache_option;

        # which style do we need to display?
        switch( $style ) {

           /**
            *
            * short post box, style: 01
            *
            */

            case '01':

                ?>
                <div class="ueldo-short-post-box ueldo-short-post-box-01">

                    <?php

                        # get featured image
                        $featured_image = ueldo_get_featured_image( get_the_ID(), get_the_title() );

                        # do we have featured image?
                        if( $featured_image != '' ) {

                            ?>
                            <div class="ueldo-short-post-box-image">

                                <?php

                                    # display image
                                    ueldo_display_image_for_parent( $featured_image['src'], $featured_image['alt'] );

                                ?>

                            </div>
                            <?php
                        }

                    ?>

                    <<?php echo esc_attr( $heading_type ); ?>><a href="<?php echo esc_url( get_the_permalink() ); ?>"><?php the_title(); ?></a></<?php echo esc_attr( $heading_type ); ?>>
                    <div class="ueldo-short-post-box-author">

                        <img src="<?php echo esc_url( get_avatar_url( get_the_author_meta( 'ID' ), array( 'size' => esc_attr( ueldo_get_theme_options_value( 'retina-images-replacement', false, 'enabled' ) == 'yes' ? 100 : 50 ) ) ) ); ?>" alt="<?php echo esc_attr( get_the_author_meta( 'display_name', get_the_author_meta( 'ID' ) ) ); ?>" <?php echo ueldo_retina_ready_attr(); ?> />
                        <div class="ueldo-short-post-box-author-content">

                            <p class="ueldo-short-post-box-author-name"><?php the_author_posts_link(); ?></p>
                            <p>

                                <?php

                                    # can we translate date to human time?
                                    if( ueldo_get_theme_options_value( 'translate-publication-dates' ) == 'yes' ) ueldo_show_when( get_the_time( 'U', get_the_ID() ) );
                                    else {

                                        # display default date and time
                                        echo get_the_time( $ueldo_cache_option -> get_option( 'date_format' ), get_the_ID() ) .' '. esc_html( __( 'at', 'ueldo' ) ) .' '. get_the_time( $ueldo_cache_option -> get_option( 'time_format' ), get_the_ID() );
                                    }

                                ?>

                                <span class="ueldo-short-post-box-author-content-divider">
                                </span>

                                <?php

                                    # show comments count
                                    comments_popup_link( esc_html( __( 'No comments yet', 'ueldo' ) ), esc_html( __( '1 comment', 'ueldo' ) ), esc_html( __( '% comments', 'ueldo' ) ), '', esc_html( __( 'Comments Off', 'ueldo' ) ) );

                                ?>

                            </p>

                        </div>

                    </div>

                </div>
                <?php

            break;

           /**
            *
            * short post box, style: 02
            *
            */

            case '02':

                ?>
                <div class="ueldo-short-post-box ueldo-short-post-box-02">

                    <<?php echo esc_attr( $heading_type ); ?>><a href="<?php echo esc_url( get_the_permalink() ); ?>"><?php the_title(); ?></a></<?php echo esc_attr( $heading_type ); ?>>

                    <div class="ueldo-short-post-box-author">

                        <img src="<?php echo esc_url( get_avatar_url( get_the_author_meta( 'ID' ), array( 'size' => esc_attr( ueldo_get_theme_options_value( 'retina-images-replacement', false, 'enabled' ) == 'yes' ? 100 : 50 ) ) ) ); ?>" alt="<?php echo esc_attr( get_the_author_meta( 'display_name', get_the_author_meta( 'ID' ) ) ); ?>" <?php echo ueldo_retina_ready_attr(); ?> />
                        <div class="ueldo-short-post-box-author-content">

                            <p class="ueldo-short-post-box-author-name"><?php the_author_posts_link(); ?></p>
                            <p>

                                <?php

                                    # can we translate date to human time?
                                    if( ueldo_get_theme_options_value( 'translate-publication-dates' ) == 'yes' ) ueldo_show_when( get_the_time( 'U', get_the_ID() ) );
                                    else {

                                        # display default date and time
                                        echo get_the_time( $ueldo_cache_option -> get_option( 'date_format' ), get_the_ID() ) .' '. esc_html( __( 'at', 'ueldo' ) ) .' '. get_the_time( $ueldo_cache_option -> get_option( 'time_format' ), get_the_ID() );
                                    }

                                ?>

                                <span class="ueldo-short-post-box-author-content-divider">
                                </span>

                                <?php

                                    # show comments count
                                    comments_popup_link( esc_html( __( 'No comments yet', 'ueldo' ) ), esc_html( __( '1 comment', 'ueldo' ) ), esc_html( __( '% comments', 'ueldo' ) ), '', esc_html( __( 'Comments Off', 'ueldo' ) ) );

                                ?>

                            </p>

                        </div>

                    </div>

                </div>
                <?php

            break;

           /**
            *
            * short post box, style: 03
            *
            */

            case '03':

                # can we display post details?
                $can_show_post_details = ueldo_get_theme_options_value( 'blog-posts-list-style', false, 'display-post-data-under-title' ) == 'yes';

                ?>
                <div class="ueldo-short-post-box ueldo-short-post-box-03">

                    <<?php echo esc_attr( $heading_type ); ?> class="<?php echo esc_attr( $can_show_post_details == true ? '' : 'ueldo-short-post-box-title-without-post-details' ); ?>"><a href="<?php echo esc_url( get_the_permalink() ); ?>"><?php the_title(); ?></a></<?php echo esc_attr( $heading_type ); ?>>

                    <?php

                        # can we display post details?
                        if( $can_show_post_details == true ) {

                            ?>
                            <p class="ueldo-short-post-box-post-data">

                                <?php

                                    # can we translate date to human time?
                                    if( ueldo_get_theme_options_value( 'translate-publication-dates' ) == 'yes' ) ueldo_show_when( get_the_time( 'U', get_the_ID() ) );
                                    else {

                                        # display default date and time
                                        echo get_the_time( $ueldo_cache_option -> get_option( 'date_format' ), get_the_ID() ) .' '. esc_html( __( 'at', 'ueldo' ) ) .' '. get_the_time( $ueldo_cache_option -> get_option( 'time_format' ), get_the_ID() );
                                    }

                                ?>

                                <span class="ueldo-short-post-box-post-data-divider">
                                </span>

                                <?php

                                    # show comments count
                                    comments_popup_link( esc_html( __( 'No comments yet', 'ueldo' ) ), esc_html( __( '1 comment', 'ueldo' ) ), esc_html( __( '% comments', 'ueldo' ) ), '', esc_html( __( 'Comments Off', 'ueldo' ) ) );

                                ?>

                            </p>
                            <?php

                        # end of post details.
                        }

                        # post content (not for vc page)
                        if( !ueldo_is_vc_page( get_the_content() ) ) {

                            # get custom page excerpt
                            $ueldo_custom_page_excerpt = ueldo_get_single_page_custom_excerpt( get_the_ID() );

                            # do we have the excerpt set?
                            if( !empty( $ueldo_custom_page_excerpt ) ) echo apply_filters( 'the_content', $ueldo_custom_page_excerpt );
                            else {

                                # display the excerpt
                                the_excerpt( '' );
                            }

                            # remove temporary variable
                            unset( $ueldo_custom_page_excerpt );
                        }

                        # post content for vc page
                        else {

                            # display page excerpt
                            echo apply_filters( 'the_content', ueldo_get_single_page_custom_excerpt( get_the_ID() ) );
                        }

                    ?>

                    <p><a href="<?php echo esc_url( get_the_permalink() ); ?>"><?php echo esc_html( __( 'Read more', 'ueldo' ) ); ?></a></p>

                </div>
                <?php

            break;

           /**
            *
            * end of options
            *
            */
        }
    }

   /**
    *
    * display content default attributes for sidebar
    *
    */

    function ueldo_display_sidebar_attributes( $where ) {

        # choose an option depends on where we are
        switch( $where ) {

            # display sidebar on posts list
            case 'posts-list':

                # can we display the sidebar?
                $sidebar = ueldo_get_theme_options_value( 'blog-sidebar', false, 'posts-list' );

            break;

            # display sidebar on single post
            case 'single-post':

                # can we display the sidebar?
                $sidebar = ueldo_get_theme_options_value( 'blog-sidebar', false, 'single-post' );

            break;

            # display sidebar on woocommerce pages
            case 'woocommerce':

                # can we display the sidebar?
                $sidebar = ueldo_get_theme_options_value( 'woocommerce', false, ueldo_get_woocommerce_page_slug() );

            break;

            # unknown value
            default: return( false );
        }

        # sidebar is disabled?
        if( $sidebar == 'no' ) return( false );

        # get the sidebar side
        else {

            # get sidebar side
            $sidebar_side = $sidebar == 'yes-left' ? 'left' : 'right';

            # return result
            return( ' data-ueldo-content-default-sidebar-side="'. esc_attr( $sidebar_side ) .'"' );
        }
    }

   /**
    *
    * display image for parent
    *
    */

    function ueldo_display_image_for_parent( $src, $alt = '', $x_pos = '50%', $y_pos = '50%', $return = false, $size = 'cover', $repeat = 'no-repeat' ) {

        # image class name
        $class_name = 'ueldo-image-data-for-parent';

        # image size is different than "cover"?
        if( $size != 'cover' ) $class_name .= ' ueldo-image-size-auto';

        # image repeat is different than "no-repeat"?
        if( $repeat != 'no-repeat' ) $class_name .= ' ueldo-image-repeat-'. esc_attr( $repeat );

        # image html tag
        $img = '<img class="'. esc_attr( $class_name ) .'" alt="'. esc_attr( $alt ) .'"';

        # check for ssl
        if( strpos( $src, 'http://' ) !== false && is_ssl() ) $src = str_replace( 'http://', 'https://', $src );

        # set image source when lazy load is disabled
        if( ueldo_get_theme_options_value( 'lazy-load-images', false, 'enabled' ) == 'no' ) $img .= ' src="'. esc_url( $src ) .'"';

        # or when is enabled
        else $img .= ' src="'. esc_url( get_template_directory_uri() .'/_assets/_img/image-empty.jpg' ) .'" data-src="'. esc_url( $src ) .'"';

        # do we have x_pos changed?
        if( $x_pos != '50%' ) $img .= ' data-image-position-x="'. esc_attr( $x_pos ) .'"';

        # do we have y_pos changed?
        if( $y_pos != '50%' ) $img .= ' data-image-position-y="'. esc_attr( $y_pos ) .'"';

        # close the image html tag
        $img .= ' />';

        # prepare the result
        $result = '<span class="ueldo-image-parent-loading"><span class="ueldo-image-parent-loading-circle"></span></span>'. $img;

        # echo result...
        if( $return == false ) echo( !empty( $result ) ? $result : '' );

        # ...or return result
        else return( !empty( $result ) ? $result : '' );
    }

   /**
    *
    * display tags and categories
    *
    */

    function ueldo_display_tags_and_categories( $is_facebook_button ) {

        ?>
        <section class="ueldo-tags-and-categories" data-is-near-facebook-botton="<?php echo esc_attr( $is_facebook_button ); ?>">

            <?php

                # if post has tags
                if( get_the_tags( '' ) != '' ) {

                    ?>
                    <p>

                        <span class="ueldo-tags-and-categories-title"><?php echo esc_html( __( 'Tags:', 'ueldo' ) ); ?></span>
                        <?php ueldo_display_as_tagcloud( get_the_tags( '' ), 'tags' ); ?>

                    </p>
                    <?php
                }

            ?>

            <p>

                <span class="ueldo-tags-and-categories-title"><?php echo esc_html( __( 'Categories:', 'ueldo' ) ); ?></span>
                <?php ueldo_display_as_tagcloud( get_the_category( '' ), 'category' ); ?>

            </p>

        </section>
        <?php
    }

   /**
    *
    * display elements under single blog post content
    *
    */

    function ueldo_display_elements_under_single_blog_post_content( $post, $post_id ) {

        # elements count
        $elementsCount = ueldo_get_theme_options_value( 'under-single-blog-post-content-elements', false, 'elements-count' );

        # there's no any elements?
        if( $elementsCount == 0 ) return( false );

        # walk for each element
        for( $i = 0; $i < $elementsCount; $i++ ) {

            # get the element id
            $currentElementID = $i + 1;

            # read element type
            switch( ueldo_get_theme_options_value( 'under-single-blog-post-content-elements', false, 'element-'. esc_attr( $currentElementID ) .'-type' ) ) {

                # tags and categories
                case 'tags-and-categories':

                    # display tags and categories, without facebook button
                    ueldo_display_tags_and_categories( 'no' );

                break;

                # tags and categories with facebook
                case 'tags-and-categories-with-facebook':

                    # facebook like button
                    ueldo_facebook_like_button_under_blog_content();

                    # display tags and categories, with facebook button if exists
                    ueldo_display_tags_and_categories( ueldo_is_facebook_like_button_set() == true ? 'yes' : 'no' );

                break;

                # next / previous posts navigation
                case 'next-previous-posts-navigation':

                    # switch posts
                    ueldo_show_switch_page_links( 'post', $post_id );

                break;

                # author box
                case 'author-box':

                    # display author box
                    ueldo_display_author_box();

                break;

                # similar posts
                case 'similar-posts':

                    # similar posts
                    ueldo_display_similar_posts( $post, ueldo_get_theme_options_value( 'under-single-blog-post-content-elements', false, 'element-'. esc_attr( $currentElementID ) .'-similar-posts-style' ) );

                break;

                # custom code
                case 'custom-code':

                    # get the current language locale
                    $language = ueldo_get_current_language_locale();
                    $language = $language == false ? 'all' : strtolower( $language );

                    # get the custom code
                    $customCode = ueldo_get_theme_options_value( 'under-single-blog-post-content-elements', 'ueldo_theme_options_under_single_blog_post_content_elements_element_'. esc_attr( $currentElementID ) .'_'. esc_attr( $language ) );

                    # display the result
                    echo do_shortcode( $customCode );

                break;
            }
        }
    }

   /**
    *
    * get content of custom content elements under single blog post
    *
    */

    function ueldo_get_custom_code_elements_under_single_blog_post_content() {

        # elements count
        $elementsCount = ueldo_get_theme_options_value( 'under-single-blog-post-content-elements', false, 'elements-count' );

        # there's no any elements?
        if( $elementsCount == 0 ) return( false );

        # result variable
        $result = '';

        # walk for each element
        for( $i = 0; $i < $elementsCount; $i++ ) {

            # get the element id
            $currentElementID = $i + 1;

            # read element type
            switch( ueldo_get_theme_options_value( 'under-single-blog-post-content-elements', false, 'element-'. esc_attr( $currentElementID ) .'-type' ) ) {

                # do we have custom code element?
                case 'custom-code':

                    # get the current language locale
                    $language = ueldo_get_current_language_locale();
                    $language = $language == false ? 'all' : strtolower( $language );

                    # get the custom code
                    $customCode = ueldo_get_theme_options_value( 'under-single-blog-post-content-elements', 'ueldo_theme_options_under_single_blog_post_content_elements_element_'. esc_attr( $currentElementID ) .'_'. esc_attr( $language ) );

                    # update result
                    $result .= $customCode;

                break;
            }
        }

        # return result
        return( empty( $result ) ? false : $result );
    }

   /**
    *
    * get the ID for page, for custom header and footer functions
    *
    */

    function ueldo_get_page_id_for_custom_header_and_footer() {

        # get cache option class object
        global $ueldo_cache_option;

        # is it the 404 page?
        if( is_404() || ueldo_is_search_404() ) {

            # get the current language key
            $lang_key = ueldo_get_current_language_key();

            # get 404 page ID
            $pageID = ueldo_get_theme_options_value( '404-page-id', esc_attr( $lang_key ) );

            # do we have custom 404 page set?
            return( $pageID != 'default' && is_numeric( $pageID ) ? $pageID : false );
        }

        # return result
        return( ueldo_is_blog_page() ? $ueldo_cache_option -> get_option( 'page_for_posts' ) : get_the_ID() );
    }

   /**
    *
    * display footer content
    *
    */

    function ueldo_display_footer_content( $content = false ) {

        # find the content
        if( $content === false ) {

            # get the current language key for editor
            $lang_key = ueldo_get_current_language_key();

            # get the content
            $content = ueldo_get_theme_options_value( 'footer-content', 'ueldo_theme_options_footer_content_'. strtolower( esc_attr( $lang_key ) ) );
        }

        # return result
        echo apply_filters( 'the_content', $content );
    }

   /**
    *
    * display custom footer content
    *
    */

    function ueldo_display_custom_footer_content( $footer_id = false ) {

        # get custom footer content
        $content = ueldo_get_custom_footer_content( $footer_id );

        # display custom footer content
        echo apply_filters( 'the_content', $content );
    }

   /**
    *
    * get custom footer content
    *
    */

    function ueldo_get_custom_footer_content( $footer_id = false ) {

        # find a footer_id
        if( $footer_id == false ) {

            # get the current language key
            $lang_key = ueldo_get_current_language_key();

            # get custom footer ID
            $footer_id = ueldo_get_theme_options_value( 'footer-content', esc_attr( $lang_key ), 'get-content-from' );
        }

        # do we have correct footer ID set?
        if( $footer_id !== false && $footer_id !== null && is_numeric( $footer_id ) ) {

            # global cache object
            global $ueldo_cache_option;

            # get content for footer id
            $footer_content = $ueldo_cache_option -> get_post( $footer_id );

            # return unformatted footer content
            return( $footer_content !== null && $footer_content !== false ? $footer_content -> post_content : false );
        }

        # nothing found?
        return( false );
    }

   /**
    *
    * display footer
    *
    */

    function ueldo_display_footer() {

        # page settings box data
        $meta_data = get_post_meta( ueldo_get_page_id_for_custom_header_and_footer(), '_ueldo_custom_page_settings_meta_box_data', true );

        # do we have custom footer set for this page?
        if( !empty( $meta_data ) && isset( $meta_data['custom_footer_id'] ) && $meta_data['custom_footer_id'] != 'none' ) {

            # do we have default footer?
            if( $meta_data['custom_footer_id'] == 'default' ) {

                ?>
                <footer class="ueldo-footer" data-is-footer-position-fixed="<?php echo esc_attr( $meta_data['custom_footer_position'] == 'fixed-to-bottom' ? 'yes' : 'no' ); ?>">

                    <div class="ueldo-content-container">

                        <?php

                            # get the data for footer content default
                            $footer_content_default = get_post_meta( ueldo_get_page_id_for_custom_header_and_footer(), '_ueldo_custom_page_settings_meta_box_custom_default_footer_content', true );

                            # display footer content
                            ueldo_display_footer_content( $footer_content_default );

                        ?>

                    </div>

                </footer>
                <?php
            }

            # display custom footer
            else {

                ?>
                <footer class="ueldo-content-default ueldo-content-default-vc-page" data-is-footer-position-fixed="<?php echo esc_attr( $meta_data['custom_footer_position'] == 'fixed-to-bottom' ? 'yes' : 'no' ); ?>">

                    <div class="ueldo-content-container ueldo-content-wrapper">

                        <?php

                            # display custom footer content
                            ueldo_display_custom_footer_content( $meta_data['custom_footer_id'] );

                        ?>

                    </div>

                </footer>
                <?php
            }
        }

        # display global footer
        else {

            # get the current language key
            $lang_key = ueldo_get_current_language_key();

            # do we have default footer?
            if( ueldo_get_theme_options_value( 'footer-content', esc_attr( $lang_key ), 'get-content-from' ) == 'default' ) {

                ?>
                <footer class="ueldo-footer" data-is-footer-position-fixed="<?php echo esc_attr( ueldo_get_theme_options_value( 'footer-content', esc_attr( $lang_key ), 'position' ) == 'fixed-to-bottom' ? 'yes' : 'no' ); ?>">

                    <div class="ueldo-content-container">

                        <?php

                            # display footer content
                            ueldo_display_footer_content();

                        ?>

                    </div>

                </footer>
                <?php
            }

            # display custom footer
            else {

                ?>
                <footer class="ueldo-content-default ueldo-content-default-vc-page" data-is-footer-position-fixed="<?php echo esc_attr( ueldo_get_theme_options_value( 'footer-content', esc_attr( $lang_key ), 'position' ) == 'fixed-to-bottom' ? 'yes' : 'no' ); ?>">

                    <div class="ueldo-content-container ueldo-content-wrapper">

                        <?php

                            # display custom footer content
                            ueldo_display_custom_footer_content();

                        ?>

                    </div>

                </footer>
                <?php
            }
        }
    }

   /**
    *
    * display header bar
    *
    */

    function ueldo_display_header_bar() {

        # page settings box data
        $meta_data = get_post_meta( ueldo_get_page_id_for_custom_header_and_footer(), '_ueldo_custom_page_settings_meta_box_data', true );

        # do we have custom header set for this page?
        if( !empty( $meta_data ) && isset( $meta_data['custom_header_id'] ) && $meta_data['custom_header_id'] != 'none' ) {

            ?>
            <header class="ueldo-header-bar ueldo-header-bar-main ueldo-header-bar-position-<?php echo esc_attr( $meta_data['custom_header_position'] ); ?> <?php echo esc_attr( $meta_data['custom_header_id'] == 'default' ? 'ueldo-default-header-bar' : '' ); ?>">

                <div class="ueldo-content-container">

                    <?php

                        # display header bar content
                        if( $meta_data['custom_header_id'] != 'default' ) ueldo_display_custom_header_content( 'main', $meta_data['custom_header_id'] );
                        else ueldo_display_default_header_bar_content( 'main', $meta_data['default_header_logo_image'] );

                    ?>

                </div>

            </header>
            <?php

            # can we display second custom header for this page?
            if( $meta_data['custom_header_position'] == 'static' && $meta_data['use_second_header'] == 'yes' ) {

                ?>
                <header class="ueldo-header-bar ueldo-header-bar-additional <?php echo esc_attr( $meta_data['get_second_header_content_from'] == 'default' ? 'ueldo-default-header-bar' : '' ); ?>" data-visible-from="<?php echo esc_attr( $meta_data['second_header_visible_from'] ); ?>">

                    <div class="ueldo-content-container">

                        <?php

                            # display second header bar content
                            if( $meta_data['get_second_header_content_from'] != 'default' ) ueldo_display_custom_header_content( 'additional', $meta_data['get_second_header_content_from'] );
                            else ueldo_display_default_header_bar_content( 'additional', $meta_data['default_second_header_logo_image'] );

                        ?>

                    </div>

                </header>
                <?php
            }
        }

        # display global header
        else {

            # get the current language key
            $lang_key = ueldo_get_current_language_key();

            ?>
            <header class="ueldo-header-bar ueldo-header-bar-main ueldo-header-bar-position-<?php echo esc_attr( ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'position' ) ); ?> <?php echo esc_attr( ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'get-content-from' ) == 'default' ? 'ueldo-default-header-bar' : '' ); ?>">

                <div class="ueldo-content-container">

                    <?php

                        # display header bar content
                        if( ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'get-content-from' ) != 'default' ) ueldo_display_custom_header_content( 'main' );
                        else ueldo_display_default_header_bar_content( 'main' );

                    ?>

                </div>

            </header>
            <?php

            # do we have second header bar?
            if( ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'position' ) == 'static' && ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'use-second-header' ) == 'yes' ) {

                ?>
                <header class="ueldo-header-bar ueldo-header-bar-additional <?php echo esc_attr( ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'get-second-content-from' ) == 'default' ? 'ueldo-default-header-bar' : '' ); ?>" data-visible-from="<?php echo esc_attr( ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'second-header-visible-from' ) ); ?>">

                    <div class="ueldo-content-container">

                        <?php

                            # display second header bar content
                            if( ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'get-second-content-from' ) != 'default' ) ueldo_display_custom_header_content( 'additional' );
                            else ueldo_display_default_header_bar_content( 'additional' );

                        ?>

                    </div>

                </header>
                <?php
            }
        }

        # remove temporary variables
        unset( $lang_key, $meta_data );
    }

   /**
    *
    * display custom header content
    *
    */

    function ueldo_display_custom_header_content( $type, $header_id = false ) {

        # get custom header content
        $content = ueldo_get_custom_header_content( $type, $header_id );

        # display custom header content
        echo apply_filters( 'the_content', $content );
    }

   /**
    *
    * get custom header content
    *
    */

    function ueldo_get_custom_header_content( $type, $header_id = false ) {

        # find header_id if doesn't exists
        if( $header_id == false ) {

            # get the current language key
            $lang_key = ueldo_get_current_language_key();

            # get custom footer ID
            $header_id = ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), esc_attr( $type == 'main' ? 'get-content-from' : 'get-second-content-from' ) );
        }

        # do we have correct footer ID set?
        if( $header_id !== false && $header_id !== null && is_numeric( $header_id ) ) {

            # global cache object
            global $ueldo_cache_option;

            # get content for footer id
            $header_content = $ueldo_cache_option -> get_post( $header_id );

            # return unformatted footer content
            return( $header_content !== null && $header_content !== false ? $header_content -> post_content : false );
        }

        # nothing found?
        return( false );
    }

   /**
    *
    * display default header content
    *
    */

    function ueldo_display_default_header_bar_content( $type, $logo_image = false ) {

        # get the current language key
        $lang_key = ueldo_get_current_language_key();

        ?>
        <div class="ueldo-header-bar-logo">

            <a href="<?php echo esc_url( home_url( '/' ) ); ?>">

                <img src="<?php echo esc_url( $logo_image != false ? $logo_image : ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), esc_attr( $type == 'main' ? 'default-logo-image' : 'second-header-logo-image' ) ) ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>" <?php echo ueldo_retina_ready_attr(); ?> />

            </a>

        </div>
        <?php

        # ubermenu visibility flag
        $ubermenu_visible = false;

        # do we have ubermenu plugin activated?
        if( ueldo_plugins::is_active_plugin( 'ubermenu' ) ) {

            # check if function exists first
            if( function_exists( 'ubermenu_get_menu_instance_by_theme_location' ) && function_exists( 'ubermenu' ) ) {

                # is ubermenu plugin assigned to theme main menu?
                if( ubermenu_get_menu_instance_by_theme_location( 'ueldo_main_menu' ) !== false ) {

                    # ubermenu visible
                    $ubermenu_visible = true;

                    # display ubermenu
                    ubermenu( 'main', array( 'theme_location' => 'ueldo_main_menu' ) );
                }
            }
        }

        # ubermenu is not visible?
        if( $ubermenu_visible == false ) {

            # format the menu
            ueldo_heading_menu( wp_nav_menu( array(
                'theme_location' => 'ueldo_main_menu',
                'menu' => '',
                'container' => 'nav',
                'container_class' => 'ueldo-header-bar-main-menu',
                'container_id' => '',
                'menu_class' => '',
                'menu_id' => '',
                'echo' => false,
                'fallback_cb' => 'wp_page_menu',
                'before' => '',
                'after' => '',
                'link_before' => '',
                'link_after' => '',
                'items_wrap' => '<ul>%3$s</ul>',
                'depth' => 0,
                'walker' => ''
            ) ) );

            ?>
            <a href="#ueldo-show-hide-side-menu" class="ueldo-default-side-menu-button"><i class="fa fa-bars"></i></a>
            <?php
        }
    }

   /**
    *
    * display vc sections for blog page
    *
    */

    function ueldo_show_sections_for_blog( $position, $location ) {

        # get the current language key
        $lang_key = ueldo_get_current_language_key();

        # get the extras for selected location and position
        $extras_id = ueldo_get_theme_options_value( 'vc-sections-on-blog-pages', esc_attr( $lang_key ), esc_attr( $location ) .'-'. esc_attr( $position ) );

        # do we have extras set?
        if( $extras_id != 'none' && $extras_id !== null && $extras_id !== false && is_numeric( $extras_id ) ) {

            # global cache object
            global $ueldo_cache_option;

            # get the extras content
            $extras_content = $ueldo_cache_option -> get_post( $extras_id );

            # do we have the content?
            if( $extras_content !== null && $extras_content !== false ) {

                ?>
                <div class="ueldo-content-default ueldo-content-default-vc-page">

                    <div class="ueldo-content-container ueldo-content-wrapper">

                        <?php

                            # display extras content
                            echo apply_filters( 'the_content', $extras_content -> post_content );

                        ?>

                    </div>

                </div>
                <?php
            }
        }

        # remove temporary variables
        unset( $language, $lang_key, $extras_id, $extras_content );
    }

   /**
    *
    * display side menu
    *
    */

    function ueldo_display_side_menu() {

        # get the current language key
        $lang_key = ueldo_get_current_language_key();

        # temporary variable with side menu contents before and after the menu
        $temp = array(
            'menu-position' => ueldo_get_theme_options_value( 'side-menu', false, 'menu-position' ),
            'menu-links-alignment' => ueldo_get_theme_options_value( 'side-menu', false, 'menu-links-alignment' ),
            'content-before' => ueldo_get_theme_options_value( 'side-menu', 'ueldo_theme_options_side_menu_additional_content_before_'. strtolower( esc_attr( $lang_key ) ) ),
            'content-after' => ueldo_get_theme_options_value( 'side-menu', 'ueldo_theme_options_side_menu_additional_content_after_'. strtolower( esc_attr( $lang_key ) ) ),
            'custom-sizes-enabled' => ueldo_get_theme_options_value( 'side-menu', false, 'custom-sizes-enabled' ),
            'display-bottom-border-for-last-menu-link' => ueldo_get_theme_options_value( 'side-menu', false, 'custom-sizes-display-bottom-border-for-last-menu-link' ),
            'menu-vertical-alignment' => ueldo_get_theme_options_value( 'side-menu', false, 'menu-vertical-alignment' ),
            'style' => ueldo_get_theme_options_value( 'side-menu', false, 'style' )
        );

        # border bottom hide by default
        $bottom_border_class = 'ueldo-side-menu-hide-bottom-border-for-last-menu-item';

        # do we have custom sizes enabled?
        if( $temp['custom-sizes-enabled'] == 'yes' ) {

            # do we need to display bottom border for last menu item?
            if( $temp['display-bottom-border-for-last-menu-link'] == 'display' ) $bottom_border_class = '';
        }

        ?>
        <div id="ueldo-side-menu" class="ueldo-side-menu-container ueldo-side-menu-container-position-<?php echo esc_attr( $temp['menu-position'] ); ?> ueldo-side-menu-links-position-<?php echo esc_attr( $temp['menu-links-alignment'] ); ?> ueldo-side-menu-style-<?php echo esc_attr( $temp['style'] ); ?> <?php echo esc_attr( $bottom_border_class ); ?>" data-menu-vertical-alignment="<?php echo esc_attr( $temp['menu-vertical-alignment'] ); ?>" data-is-menu-visible="<?php echo esc_attr( $temp['style'] == 'flying-default-hidden' ? 'no' : 'yes' ); ?>" data-opacity-animation-enabled="<?php echo esc_attr( ueldo_get_theme_options_value( 'side-menu', false, 'opacity-animation-enabled' ) ); ?>">

            <div class="ueldo-side-menu-inner">

                <?php

                    # do we have the content before the menu?
                    if( !empty( $temp['content-before'] ) ) {

                        ?>
                        <div class="ueldo-side-menu-content-before-menu">

                            <?php

                                # display content before the menu
                                echo apply_filters( 'the_content', $temp['content-before'] );

                            ?>

                        </div>
                        <?php
                    }

                    # format the menu
                    echo do_shortcode( wp_nav_menu( array(
                        'theme_location' => '',
                        'menu' => esc_attr( ueldo_get_theme_options_value( 'side-menu', esc_attr( $lang_key ), 'menu-key' ) ),
                        'container' => 'nav',
                        'container_class' => 'ueldo-side-menu-nav ueldo-side-menu-submenu-links-'. esc_attr( ueldo_get_theme_options_value( 'side-menu', false, 'submenu-links' ) ),
                        'container_id' => '',
                        'menu_class' => '',
                        'menu_id' => '',
                        'echo' => false,
                        'fallback_cb' => 'wp_page_menu',
                        'before' => '',
                        'after' => '',
                        'link_before' => '<span class="ueldo-side-menu-link">',
                        'link_after' => '</span>',
                        'items_wrap' => '<ul>%3$s</ul>',
                        'depth' => 0,
                        'walker' => ''
                    ) ) );

                    # do we have the content after the menu?
                    if( !empty( $temp['content-after'] ) ) {

                        ?>
                        <div class="ueldo-side-menu-content-after-menu">

                            <?php

                                # display content after the menu
                                echo apply_filters( 'the_content', $temp['content-after'] );

                            ?>

                        </div>
                        <?php
                    }

                ?>

            </div>

        </div>
        <?php

        # remove temporary variables
        unset( $temp );
    }

   /**
    *
    * display loader animation
    *
    */

    function ueldo_display_loader_animation() {

        # do we have loader animation enabled?
        if( ueldo_get_theme_options_value( 'loader-animation', false, 'enabled' ) != 'yes' ) return( false );

        ?>
        <div id="ueldo-website-loader" class="ueldo-website-loader-container">

            <div class="ueldo-website-loader-container-inner">

                <?php

                    # get the current language key
                    $lang_key = ueldo_get_current_language_key();

                    # do we need to display logo above the loader animation?
                    if( ueldo_get_theme_options_value( 'loader-animation', false, 'add-logo' ) == 'yes-above' ) {

                        ?>
                        <div class="ueldo-website-loader-logo">

                            <img src="<?php echo esc_url( ueldo_get_theme_options_value( 'loader-animation', esc_attr( $lang_key ), 'logo-image' ) ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>" <?php echo ueldo_retina_ready_attr(); ?> />

                        </div>
                        <?php
                    }

                    ?>
                    <div class="ueldo-website-loader-spinners ueldo-website-loader-spinners-style-<?php echo esc_attr( ueldo_get_theme_options_value( 'loader-animation', false, 'style' ) ); ?>">

                        <?php

                            # switch loader animation by style type
                            switch( ueldo_get_theme_options_value( 'loader-animation', false, 'style' ) ) {

                                # style: 01
                                case '01':

                                    ?>
                                    <div class="ueldo-loader-style-01">

                                        <div class="ueldo-loader-style-01-bounce-a"></div>
                                        <div class="ueldo-loader-style-01-bounce-b"></div>

                                    </div>
                                    <?php

                                break;

                                # style: 02
                                case '02':

                                    ?>
                                    <div class="ueldo-loader-style-02"></div>
                                    <?php

                                break;

                                # style: 03
                                case '03':

                                    ?>
                                    <div class="ueldo-loader-style-03"></div>
                                    <?php

                                break;

                                # style: 04
                                case '04':

                                    ?>
                                    <div class="ueldo-loader-style-04"><div class="ueldo-loader-circle-inner"></div></div>
                                    <?php

                                break;

                                # style: 05
                                case '05':

                                    ?>
                                    <div class="ueldo-loader-style-05">

                                        <div class="ueldo-loader-style-05-bounce-a"></div>
                                        <div class="ueldo-loader-style-05-bounce-b"></div>
                                        <div class="ueldo-loader-style-05-bounce-c"></div>

                                    </div>
                                    <?php

                                break;

                                # style: 06
                                case '06':

                                    ?>
                                    <div class="ueldo-loader-style-06">

                                        <div class="ueldo-loader-style-06-square-a"></div>
                                        <div class="ueldo-loader-style-06-square-b"></div>
                                        <div class="ueldo-loader-style-06-square-c"></div>
                                        <div class="ueldo-loader-style-06-square-d"></div>

                                    </div>
                                    <?php

                                break;

                                # style: 07
                                case '07':

                                    ?>
                                    <div class="ueldo-loader-style-07">

                                        <div class="ueldo-loader-style-07-circle-a"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-07-circle-b"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-07-circle-c"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-07-circle-d"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-07-circle-e"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-07-circle-f"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-07-circle-g"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-07-circle-h"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-07-circle-i"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-07-circle-j"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-07-circle-k"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-07-circle-l"><div class="ueldo-loader-circle-inner"></div></div>

                                    </div>
                                    <?php

                                break;

                                # style: 08
                                case '08':

                                    ?>
                                    <div class="ueldo-loader-style-08">

                                        <div class="ueldo-loader-style-08-circle-a"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-08-circle-b"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-08-circle-c"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-08-circle-d"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-08-circle-e"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-08-circle-f"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-08-circle-g"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-08-circle-h"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-08-circle-i"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-08-circle-j"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-08-circle-k"><div class="ueldo-loader-circle-inner"></div></div>
                                        <div class="ueldo-loader-style-08-circle-l"><div class="ueldo-loader-circle-inner"></div></div>

                                    </div>
                                    <?php

                                break;

                                # style: 09
                                case '09':

                                    ?>
                                    <div class="ueldo-loader-style-09">

                                        <div class="ueldo-loader-style-09-rect-a"></div>
                                        <div class="ueldo-loader-style-09-rect-b"></div>
                                        <div class="ueldo-loader-style-09-rect-c"></div>
                                        <div class="ueldo-loader-style-09-rect-d"></div>
                                        <div class="ueldo-loader-style-09-rect-e"></div>

                                    </div>
                                    <?php

                                break;
                            }

                        ?>

                    </div>
                    <?php

                    # do we need to display logo above the loader animation?
                    if( ueldo_get_theme_options_value( 'loader-animation', false, 'add-logo' ) == 'yes-under' ) {

                        ?>
                        <div class="ueldo-website-loader-logo">

                            <img src="<?php echo esc_url( ueldo_get_theme_options_value( 'loader-animation', esc_attr( $lang_key ), 'logo-image' ) ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>" <?php echo ueldo_retina_ready_attr(); ?> />

                        </div>
                        <?php
                    }

                ?>

            </div>

        </div>
        <?php
    }

   /**
    *
    * end of file.
    *
    */

?>