<?php

    # prevent direct file access
    if( !defined( 'ABSPATH' ) ) exit;

   /**
    *
    * check if needles from array are found in haystack
    *
    */

    function ueldo_strpos_array( $haystack, $needle, $offset = 0 ) {

        # replace to array if it's not
        if( !is_array( $needle ) ) $needle = array( $needle );

        # search for a result
        foreach( $needle as $query ) {

            # found
            if( strpos( $haystack, $query, $offset ) !== false ) return( true );
        }

        # nothing found
        return( false );
    }

   /**
    *
    * check if needle is at the end of haystack
    *
    */

    function ueldo_endswith( $haystack, $needle ) {

        # check haystack length
        $haystack_length = strlen( $haystack );

        # check needle length
        $needle_length = strlen( $needle );

        # if needle is longer than haystack, return
        if( $needle_length > $haystack_length ) return( false );

        # return result
        return( substr_compare( $haystack, $needle, $haystack_length - $needle_length, $needle_length ) === 0 );
    }

   /**
    *
    * replace only the last occurence in a string
    *
    */

    function ueldo_str_replace_last( $search, $replace, $subject ) {

        # get the pos of the searched string
        $pos = strrpos( $subject, $search );

        # if the string is found
        if( $pos !== false ) {

            # do the replacement
            $subject = substr_replace( $subject, $replace, $pos, strlen( $search ) );
        }

        # return result
        return( $subject );
    }

   /**
    *
    * exclude URL from HTML content
    *
    */

    function ueldo_exclude_url( $html ) {

        # there's no SimpleXMLElement class?
        if( !class_exists( 'SimpleXMLElement' ) || $html == null ) return( false );

        # replace html tag to xml element
        $xml = new SimpleXMLElement( $html );

        # return result
        return( isset( $xml['href'] ) ? ( string ) $xml['href'] : false );
    }

   /**
    *
    * get domain name from URL
    *
    */

    function ueldo_get_domain_name( $url = false ) {

        # do we have url set?
        if( $url == false ) $url = esc_url( site_url() );

        # parse url
        $url = parse_url( $url );

        # create domain path
        $domain = esc_url( ( isset( $url['scheme'] ) ? esc_attr( $url['scheme'] .'://' ) : '' ) . ( isset( $url['host'] ) ? esc_attr( $url['host'] .'/' ) : '' ) );

        # return result
        return( !empty( $domain ) ? $domain : false );
    }

   /**
    *
    * get website directory
    *
    */

    function ueldo_get_website_dir() {

        # get website url
        $url = parse_url( esc_url( site_url() ) );

        # return result
        return( isset( $url['path'] ) && !empty( $url['path'] ) && $url['path'] != '/' ? esc_attr( $url['path'] .'/' ) : '/' );
    }

   /**
    *
    * get all positions of string inside another string
    *
    */

    function ueldo_strpos_all( $haystack, $needle ) {

        # define last string position variable
        $last_pos = 0;

        # prepare the result array
        $positions = array();

        # walk while last post is not the last found element
        while( ( $last_pos = strpos( $haystack, $needle, $last_pos ) ) !== false ) {

            # update positions array
            $positions[] = $last_pos;

            # update last position flag
            $last_pos += strlen( $needle );
        }

        # return result
        return( $positions == array() ? false : $positions );
    }

   /**
    *
    * all values in array are empty?
    *
    */

    function ueldo_all_false( $array ) {

        # all false flag
        $all_false = true;

        # walk for each keys in array
        foreach( $array as $key => $value ) {

            # is value not false?
            if( $value != false ) $all_false = false;
        }

        # return result
        return( $all_false );
    }

   /**
    *
    * translate date to "human" value
    *
    */

    function ueldo_show_when( $date, $display = true ) {

        # translate date
        $when = human_time_diff( $date, current_time( 'timestamp' ) ) . ' '. esc_html( __( 'ago', 'ueldo' ) );

        # display or return?
        if( $display == true ) echo esc_html( $when );
        else return( $when );
    }

   /**
    *
    * get post featured image
    *
    */

    function ueldo_get_featured_image( $post_id, $post_title, $small = false ) {

        # result array
        $result = array(
            'src' => '',
            'alt' => ''
        );

        # if we have post thumbnail
        if( has_post_thumbnail( $post_id ) ) {

            # get the post thumbnail
            $thumbnail = get_the_post_thumbnail( $post_id, $small == false ? 'post-thumbnail' : 'thumbnail' );

            # there is no thumbnail image?
            if( $thumbnail == '' || $thumbnail == false ) return( false );

            # is there a SimpleXMLElement class?
            if( class_exists( 'SimpleXMLElement' ) ) {

                # replace html tag to xml element
                $xml = new SimpleXMLElement( $thumbnail );

                # walk for each result element
                foreach( $result as $key => $value ) {

                    # update result array data
                    $result[$key] = isset( $xml[$key] ) ? ( string ) $xml[$key] : '';
                }
            }

            # there's no SimpleXMLElement class?
            else {

                # getting post thumbnail URL
                $thumbnail_url = explode( 'src="', $thumbnail );
                $thumbnail_url = substr( $thumbnail_url[1], 0, strpos( $thumbnail_url[1], '"' ) );

                # update result src
                $result['src'] = esc_url( $thumbnail_url );

                # set post title as image "alt"
                $result['alt'] = $post_title;
            }

            # return result
            return( $result['src'] != '' ? $result : false );
        }

        # nothing found
        return( false );
    }

   /**
    *
    * check if we have facebook like button set
    *
    */

    function ueldo_is_facebook_like_button_set() {

        # get the current language key
        $lang_key = ueldo_get_current_language_key();

        # do we have facebook like button set?
        return( ueldo_get_theme_options_value( 'facebook-fanpage-url', esc_attr( $lang_key ) ) != '' );
    }

   /**
    *
    * is footer position fixed to bottom?
    *
    */

    function ueldo_is_footer_position_fixed_to_bottom() {

        # get the current language key
        $lang_key = ueldo_get_current_language_key();

        # return result
        return( ueldo_get_theme_options_value( 'footer-content', esc_attr( $lang_key ), 'position' ) == 'fixed-to-bottom' );
    }

   /**
    *
    * minify the css
    *
    */

    function ueldo_minify_css( $buffer ) {

        # do the magic
        $buffer = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $buffer );
        $buffer = str_replace( ': ', ':', $buffer );
        $buffer = str_replace( array( "\r\n", "\r", "\n", "\t", '  ', '    ', '    ' ), '', $buffer );

        # return the result
        return( $buffer );
    }

   /**
    *
    * is visual composer content page?
    *
    */

    function ueldo_is_vc_page( $content ) {

        # return the result
        return( strpos( $content, '[vc_row' ) !== false );
    }

   /**
    *
    * limit the title size
    *
    */

    function ueldo_limit_the_title( $title ) {

        # title length limit
        $limit = 30;

        # return the title if it fit the limit
        if( strlen( $title ) <= $limit ) return( $title );

        # divide the title through the space
        $title_divided = explode( ' ', $title );

        # prepare the result variable
        $result = '';

        # walk for each title parts
        for( $i = 0; $i < count( $title_divided ); $i++ ) {

            # update the result variable
            $result .= $result == '' ? $title_divided[$i] : ' '. $title_divided[$i];

            # check the title length
            if( strlen( $result ) >= $limit ) return( $result .'...' );
        }

        # return the default title
        return( $title );
    }

   /**
    *
    * get local file content
    *
    */

    function ueldo_get_local_file_content( $path ) {

        # file exists?
        if( !file_exists( $path ) ) return( '' );

        # start output buffering
        ob_start();

        # include local file
        include( $path );

        # clean output buffering
        $contents = ob_get_clean();

        # return result
        return( $contents );
    }

   /**
    *
    * get google fonts url
    *
    */

    function ueldo_get_google_fonts_url() {

        # get google fonts array and update it with custom visual composer heading fonts
        $fonts_array = ueldo_update_fonts_array_with_custom_vc_heading_fonts( ueldo_get_configured_google_fonts_array() );

        # prepare the fonts urls array
        $fonts_urls = array();

        # walk for each font
        foreach( $fonts_array['fonts'] as $font_family => $font_weights ) {

            # prepare the font url
            $font_url = $font_family;

            # do we have the font weight set?
            if( is_array( $font_weights ) ) {

                # sort weight attributes
                sort( $font_weights );

                # update the font url
                $font_url .= ':';

                # is first font weight attribute
                $is_first = true;

                # walk for each weight attribute
                foreach( $font_weights as $font_weight_single ) {

                    # add comma before weight attribute
                    $font_url .= $is_first == false ? ',' : '';

                    # update the font url
                    $font_url .= $font_weight_single;

                    # set the first font weight flag
                    $is_first = false;
                }
            }

            # update fonts urls array
            $fonts_urls[] = $font_url;

            # reset the font url variable
            $font_url = false;
        }

        # prepare the result
        $result = implode( '|', $fonts_urls );

        # do we have subsets set?
        if( count( $fonts_array['subsets'] ) > 0 ) {

            # sort the subsets
            sort( $fonts_array['subsets'] );

            # add subsets to result
            $result .= '&subset='. implode( ',', $fonts_array['subsets'] );
        }

        # return the google fonts url
        return( add_query_arg( 'family', urlencode( $result ), '//fonts.googleapis.com/css' ) );
    }

   /**
    *
    * get google fonts array, reading from data managed in theme options
    *
    */

    function ueldo_get_configured_google_fonts_array() {

        # get the current language key
        $lang_key = ueldo_get_current_language_key();

        # fonts options keys
        $option_keys = array(
            'general-font',
            'general-bold-font',
            'menu-font',
            'headings-font',
            'headings-slim-font',
            'headings-bold-font',
            'headings-subtitle-font',
            'buttons-font',
            'form-fields-font',
            'blockquote-font',
            'alert-messages-font'
        );

        # prepare the fonts array
        $fonts = array( 'fonts' => array(), 'subsets' => array() );

        # walk for each font key
        foreach( $option_keys as $option_key ) {

            # get the font family option value
            $font_family = ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), esc_attr( $option_key .'-family' ) );

            # check if font family is already added to fonts array
            if( !array_key_exists( $font_family, $fonts['fonts'] ) ) $fonts['fonts'][$font_family] = array();

            # get the font weight option value
            $font_weight = ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), esc_attr( $option_key .'-weight' ) );

            # check if font weight is already added to font subarray in fonts array
            if( !in_array( $font_weight, $fonts['fonts'][$font_family] ) ) $fonts['fonts'][$font_family][] = $font_weight;

            # get the font subset option value
            $font_subset = ueldo_get_theme_options_value( 'fonts', esc_attr( $lang_key ), esc_attr( $option_key .'-subset' ) );

            # is more than one subset set?
            if( strpos( $font_subset, ',' ) !== false ) {

                # get all single subsets
                $font_subsets = explode( ',', $font_subset );

                # walk for each single subset
                foreach( $font_subsets as $single_font_subset ) {

                    # check every single subset if is already added to font subarray in fonts array
                    if( !in_array( $single_font_subset, $fonts['subsets'] ) ) $fonts['subsets'][] = $single_font_subset;
                }
            }

            else {

                # check if font subset is already added to font subarray in fonts array
                if( !in_array( $font_subset, $fonts['subsets'] ) && !empty( $font_subset ) ) $fonts['subsets'][] = $font_subset;
            }
        }

        # return result
        return( $fonts );
    }

   /**
    *
    * update default theme fonts array with fonts used for theme
    * shortcode for visual composer heading
    *
    */

    function ueldo_update_fonts_array_with_custom_vc_heading_fonts( $fonts ) {

        # get next font id, configured in theme options for heading vc shortcode
        $next_font_id = ueldo_get_theme_options_value( 'visual-composer-custom-fonts', false, 'next-font-id' );

        # do we have any font added?
        if( $next_font_id !== '1' ) {

            # walk for each custom fonts
            for( $i = 1; $i < $next_font_id; $i++ ) {

                # font data
                $font = array(
                    'family' => ueldo_get_theme_options_value( 'visual-composer-custom-fonts', false, 'font-'. esc_attr( $i ) .'-family' ),
                    'weight' => ueldo_get_theme_options_value( 'visual-composer-custom-fonts', false, 'font-'. esc_attr( $i ) .'-weight' ),
                    'subset' => ueldo_get_theme_options_value( 'visual-composer-custom-fonts', false, 'font-'. esc_attr( $i ) .'-subset' )
                );

                # do we have the font set?
                if( $font['family'] != false && $font['weight'] != false ) {

                    # check if font family is already added to fonts array
                    if( !array_key_exists( $font['family'], $fonts['fonts'] ) ) $fonts['fonts'][$font['family']] = array();

                    # check if font weight is already added to font subarray in fonts array
                    if( !in_array( $font['weight'], $fonts['fonts'][$font['family']] ) ) $fonts['fonts'][$font['family']][] = $font['weight'];

                    # is more than one subset set?
                    if( strpos( $font['subset'], ',' ) !== false ) {

                        # get all single subsets
                        $font_subsets = explode( ',', $font['subset'] );

                        # walk for each single subset
                        foreach( $font_subsets as $single_font_subset ) {

                            # check every single subset if is already added to font subarray in fonts array
                            if( !in_array( $single_font_subset, $fonts['subsets'] ) ) $fonts['subsets'][] = $single_font_subset;
                        }
                    }

                    else {

                        # check if font subset is already added to font subarray in fonts array
                        if( !in_array( $font['subset'], $fonts['subsets'] ) && !empty( $font['subset'] ) ) $fonts['subsets'][] = $font['subset'];
                    }
                }
            }
        }

        # return fonts array
        return( $fonts );
    }

   /**
    *
    * get image source url
    *
    */

    function ueldo_get_image_src( $image ) {

        # is image chosen?
        if( is_numeric( $image ) ) {

            # get image source
            $image_src = wp_get_attachment_image_src( $image, 'full' );

            # update image variable
            if( $image_src == false ) $image = esc_url( get_template_directory_uri() .'/_assets/_img/image.png' );
            else $image = $image_src[0];
        }

        # return image src
        return( $image );
    }

   /**
    *
    * get image dimensions
    *
    */

    function ueldo_get_image_dimensions( $image ) {

        # results array
        $result = array(
            'width' => '300',
            'height' => '225'
        );

        # is image chosen?
        if( is_numeric( $image ) ) {

            # get image source
            $image_date = wp_get_attachment_image_src( $image, 'full' );

            # do we have the image?
            if( $image_date !== false ) {

                # update image width
                $result['width'] = isset( $image_date[1] ) ? esc_attr( $image_date[1] ) : $result['width'];

                # update image height
                $result['height'] = isset( $image_date[2] ) ? esc_attr( $image_date[2] ) : $result['height'];
            }
        }

        # return result
        return( $result );
    }

   /**
    *
    * get box shadow attribute value
    *
    */

    function ueldo_get_box_shadow_attribute_value( $horizontal_length, $vertical_length, $blur_radius, $spread_radius, $color ) {

        # return result
        return( esc_attr( $horizontal_length ) .'px '. esc_attr( $vertical_length ) .'px '. esc_attr( $blur_radius ) .'px '. esc_attr( $spread_radius != 0 ? esc_attr( $spread_radius ) .'px ' : '' ) . esc_attr( $color ) );
    }

   /**
    *
    * get text shadow attribute value
    *
    */

    function ueldo_get_text_shadow_attribute_value( $horizontal_length, $vertical_length, $blur_radius, $color ) {

        # return result
        return( esc_attr( $horizontal_length ) .'px '. esc_attr( $vertical_length ) .'px '. esc_attr( $blur_radius ) .'px '. esc_attr( $color ) );
    }

   /**
    *
    * check if value is valid number
    *
    */

    function ueldo_is_valid_number( $value ) {

        # return result
        return( $value != '' && is_numeric( $value ) && strpos( $value, ',' ) === false && strpos( $value, 'x' ) === false && strpos( $value, 'e' ) === false );
    }

   /**
    *
    * check if value is valid float number
    *
    */

    function ueldo_is_valid_float( $value ) {

        # return result
        return( $value != '' && is_numeric( $value ) && strpos( $value, ',' ) === false && strpos( $value, 'x' ) === false && strpos( $value, 'e' ) === false );
    }

   /**
    *
    * get css line by attribute key and value
    *
    */

    function ueldo_get_css_line( $key, $value ) {

        # array of pixel values keys
        $pixel_keys = array(
            'font-size',
            'letter-spacing',
            'width',
            'min-width',
            'max-width',
            'height',
            'min-height',
            'max-height',
            'margin-left',
            'margin-right',
            'margin-top',
            'margin-bottom',
            'border-width',
            'border-top-width',
            'border-right-width',
            'border-bottom-width',
            'border-left-width',
            '-webkit-border-radius',
            '-moz-border-radius',
            'border-radius',
            '-webkit-border-bottom-left-radius',
            '-moz-border-bottom-left-radius',
            'border-bottom-left-radius',
            '-webkit-border-bottom-right-radius',
            '-moz-border-bottom-right-radius',
            'border-bottom-right-radius',
            '-webkit-border-top-left-radius',
            '-moz-border-top-left-radius',
            'border-top-left-radius',
            '-webkit-border-top-right-radius',
            '-moz-border-top-right-radius',
            'border-top-right-radius',
            'padding-left',
            'padding-right',
            'padding-top',
            'padding-bottom'
        );

        # values in pixels
        if( in_array( $key, $pixel_keys ) ) $value .= 'px';
        else if( $key == 'line-height' ) $value .= 'em';

        # remove "webkit-calc" helper
        if( strpos( $key, '-webkit-calc' ) ) $key = str_replace( '-webkit-calc', '', $key );

        # remove "moz-calc" helper
        if( strpos( $key, '-moz-calc' ) ) $key = str_replace( '-moz-calc', '', $key );

        # remove "calc" helper
        if( strpos( $key, '-calc' ) ) $key = str_replace( '-calc', '', $key );

        # remove "%" helper
        if( strpos( $key, '-%' ) ) $key = str_replace( '-%', '', $key );

        # remove "-string" helper
        if( strpos( $key, '-string' ) ) $key = str_replace( '-string', '', $key );

        # remove background image helpers
        if( in_array( $key, array( '-o-background-image', '-moz-background-image', '-webkit-background-image', '-ms-background-image' ), true ) ) $key = 'background-image';

        # remove "-0" values
        if( $value == '-0px' || $value == 'px' ) $value = '0px';

        # remove "--" values
        if( strpos( $value, '--' ) ) $value = str_replace( '--', '-', $value );

        # return result variable
        return( $key .': '. ( $key == 'font-family' ? '"'. $value .'"' : $value ) .'; ' );
    }

   /**
    *
    * is attribute with responsive parameters?
    *
    */

    function ueldo_is_css_param_responsive( $attributes ) {

        # result flag
        $is_responsive = false;

        # walk for each attribute
        foreach( $attributes as $attr_key => $attr_value ) {

            # is attribute value an array?
            if( is_array( $attr_value ) ) $is_responsive = true;
        }

        # return result
        return( $is_responsive );
    }

   /**
    *
    * create css string from array
    *
    */

    function ueldo_create_css_string_from_array( $styles, $add_dot = true ) {

        # prepare the result variable
        $css = '';

        # walk for each class
        foreach( $styles as $class => $attributes ) {

            # don't add styles if there's no attributes
            if( $attributes == array() ) continue;

            # update result variable
            if( !ueldo_is_css_param_responsive( $attributes ) ) $css .= esc_attr( $add_dot == true ? '.' : '' ) . $class .' { ';

            # walk for each attribute
            foreach( $attributes as $attr_key => $attr_value ) {

                # responsive
                if( in_array( $attr_key, array( 'general', '1200_more', '992_1199', '768_991', 'less_767', 'less_991' ), true ) ) {

                    # display responsive range closer
                    $display_range_closer = false;

                    # define responsive range
                    switch( $attr_key ) {

                        case '1200_more': $css .= '@media (min-width: 1200px) { '; $display_range_closer = true; break;
                        case '992_1199': $css .= '@media (min-width: 992px) and (max-width: 1199px) { '; $display_range_closer = true; break;
                        case '768_991': $css .= '@media (min-width: 768px) and (max-width: 991px) { '; $display_range_closer = true; break;
                        case 'less_767': $css .= '@media (max-width: 767px) { '; $display_range_closer = true; break;
                        case 'less_991': $css .= '@media (max-width: 991px) { '; $display_range_closer = true; break;
                    }

                    # update result variable
                    $css .= esc_attr( $add_dot == true ? '.' : '' ) . $class .' { ';

                    # get all attributes
                    foreach( $attr_value as $res_attr_key => $res_attr_value ) {

                        # update result variable
                        $css .= ueldo_get_css_line( $res_attr_key, $res_attr_value );
                    }

                    # close the responsive range
                    $css .= $display_range_closer == true ? ' } } ' : ' } ';
                }

                # general
                else {

                    # update result variable
                    $css .= ueldo_get_css_line( $attr_key, $attr_value );
                }
            }

            # close the result variable
            if( !ueldo_is_css_param_responsive( $attributes ) ) $css .= '} ';
        }

        # return result
        return( $css );
    }

   /**
    *
    * remove link from content, if link is added to whole box
    *
    */

    function ueldo_link_and_paragraph_allowed_to_box_only( $content, $is_link ) {

        # do we have link added to whole box?
        if( $is_link == true ) {

            # find all link tags in content
            $links_pos = ueldo_strpos_all( $content, '<a ' );

            # do we have any links?
            if( $links_pos != false ) {

                # to remove elements array
                $to_remove = array( '</a>' );

                # walk for each links positions
                foreach( $links_pos as $link_pos ) {

                    # link code begin
                    $link = substr( $content, $link_pos );

                    # link code end
                    $link = substr( $link, 0, ( strpos( $link, '>' ) + 1 ) );

                    # update array of elements to remove
                    $to_remove[] = $link;
                }

                # walk for each elements to remove
                foreach( $to_remove as $remove ) {

                    # update content
                    $content = str_replace( $remove, '', $content );
                }
            }
        }

        # find all paragraphs in content
        $paragraphs_pos = ueldo_strpos_all( $content, '<p ' );

        # to remove elements array
        $to_remove = array( '<p>', '</p>' );

        # do we have any links?
        if( $paragraphs_pos != false ) {

            # walk for each links positions
            foreach( $paragraphs_pos as $paragraph_pos ) {

                # link code begin
                $paragraph = substr( $content, $paragraph_pos );

                # link code end
                $paragraph = substr( $paragraph, 0, ( strpos( $paragraph, '>' ) + 1 ) );

                # update array of elements to remove
                $to_remove[] = $paragraph;
            }
        }

        # walk for each elements to remove
        foreach( $to_remove as $remove ) {

            # update content
            $content = str_replace( $remove, '', $content );
        }

        # return content
        return( $content );
    }

   /**
    *
    * generate timezones list
    *
    */

    function ueldo_generate_timezone_list() {

        # prepare regions array
        static $regions = array(
            DateTimeZone::AFRICA,
            DateTimeZone::AMERICA,
            DateTimeZone::ANTARCTICA,
            DateTimeZone::ASIA,
            DateTimeZone::ATLANTIC,
            DateTimeZone::AUSTRALIA,
            DateTimeZone::EUROPE,
            DateTimeZone::INDIAN,
            DateTimeZone::PACIFIC
        );

        # prepare timezones array
        $timezones = array();

        # walk for each region
        foreach( $regions as $region ) {

            # update timezones array
            $timezones = array_merge( $timezones, DateTimeZone::listIdentifiers( $region ) );
        }

        # prepare timezone offsets array
        $timezone_offsets = array();

        # walk for each timezone
        foreach( $timezones as $timezone ) {

            # get timezone details
            $datetimezone = new DateTimeZone( $timezone );

            # update timezone offsets array
            $timezone_offsets[$timezone] = $datetimezone -> getOffset( new DateTime );
        }

        # sort timezone by name
        ksort( $timezone_offsets );

        # prepare results array
        $timezone_list = array();

        # walk for each timezone offset
        foreach( $timezone_offsets as $timezone => $offset ) {

            # prepare offset prefix
            $pretty_offset = 'UTC'. esc_attr( $offset < 0 ? '-' : '+' ) . esc_attr( gmdate( 'H:i', abs( $offset ) ) );

            # update results array
            $timezone_list[esc_attr( $timezone )] = '('. esc_html( $pretty_offset ) .') '. esc_html( $timezone );
        }

        # return result
        return( $timezone_list );
    }

   /**
    *
    * get timezones object for JavaScript
    *
    */

    function ueldo_get_timezones_object_for_js() {

        # prepare result string
        $result = 'var ueldo_timezones_object = { ';

        # start flag
        $loop_started = false;

        # walk for each timezones
        foreach( ueldo_generate_timezone_list() as $timezone => $timezone_name ) {

            # update result string
            $result .= ( $loop_started == false ? '' : ', ' ) .'"'. esc_html( $timezone ) .'": "'. esc_html( $timezone_name ) .'"';

            # update flag
            if( $loop_started == false ) $loop_started = true;
        }

        # close the result string
        $result .= ' }; ';

        # return result
        return( $result );
    }

   /**
    *
    * get font family attributes
    *
    */

    function ueldo_get_font_family_attribute( $font, $language, $attribute ) {

        # switch by font attribute
        switch( $attribute ) {

            # get font family
            case 'font-family': return( esc_attr( ueldo_get_theme_options_value( 'fonts', esc_attr( $language ), esc_attr( $font .'-family' ) ) ) ); break;

            # get font weight
            case 'font-weight':

                # get font weight
                $font_weight = ueldo_get_theme_options_value( 'fonts', esc_attr( $language ), esc_attr( $font .'-weight' ) );

                # replace "regular" or "italic" to "normal"
                if( $font_weight == 'regular' || $font_weight == 'italic' ) return( 'normal' );

                # remove "italic" from number value
                if( strpos( $font_weight, 'italic' ) !== false ) return( str_replace( 'italic', '', $font_weight ) );

                # return font weight
                return( $font_weight );

            break;

            # get font style
            case 'font-style':

                # get font weight
                $font_weight = ueldo_get_theme_options_value( 'fonts', esc_attr( $language ), esc_attr( $font .'-weight' ) );

                # return result
                return( strpos( $font_weight, 'italic' ) !== false ? 'italic' : 'normal' );

            break;

            # get font smoothing for webkit
            case '-webkit-font-smoothing': return( ueldo_get_theme_options_value( 'fonts', esc_attr( $language ), esc_attr( $font .'-smoothing' ) ) == 'yes' ? 'antialiased' : 'auto' ); break;

            # get font smoothing for moz
            case '-moz-osx-font-smoothing': return( ueldo_get_theme_options_value( 'fonts', esc_attr( $language ), esc_attr( $font .'-smoothing' ) ) == 'yes' ? 'grayscale' : 'auto' ); break;
        }
    }

   /**
    *
    * get single page custom excerpt
    *
    */

    function ueldo_get_single_page_custom_excerpt( $page_id ) {

        # page settings box data
        $data = get_post_meta( $page_id, '_ueldo_custom_page_settings_meta_box_data', true );

        # return result
        return( is_array( $data ) && isset( $data['page_excerpt'] ) && !empty( $data['page_excerpt'] ) ? $data['page_excerpt'] : '' );
    }

   /**
    *
    * check if button content exists
    *
    */

    function ueldo_button_content_exists( $button_type, $button_text, $button_text_second_line, $action_after_click, $button_url, $show_button_icon ) {

        # content found flag
        $exists = false;

        # do we have button icon?
        if( $show_button_icon == 'yes' ) $exists = true;

        # is it standard button?
        if( $button_type == 'standard-button' && !empty( $button_text ) ) $exists = true;

        # is it two-line button?
        if( $button_type == 'two-line-button' && ( !empty( $button_text ) || !empty( $button_text_second_line ) ) ) $exists = true;

        # if not a link, button exists for sure
        if( $action_after_click != 'link' ) $exists = true;
        else {

            # is it link button?
            if( !empty( $button_url['url'] ) || !empty( $button_url['title'] ) ) $exists = true;
        }

        # return result
        return( $exists );
    }

   /**
    *
    * check if current page is blog page
    *
    */

    function ueldo_is_blog_page() {

        # return result
        return( is_home() || is_archive() || is_single() || is_search() );
    }

   /**
    *
    * get default font value for multilingual websites
    *
    */

    function ueldo_get_default_font_key( $font ) {

        # check if is multilingual
        $is_multilingual = ueldo_is_multilingual();

        # is is not a multilingual website?
        if( $is_multilingual == false ) return( $font );

        # get the current language key
        $lang_key = ueldo_get_current_language_key();

        # is the current language key set to "all"?
        if( $lang_key == 'all' ) {

            # get the default language key
            $lang_key = strtolower( ueldo_get_default_language_locale() );
        }

        # return result
        return( esc_attr( $font ) .'-'. esc_attr( $lang_key ) );
    }

   /**
    *
    * get extras contents styles
    *
    */

    function ueldo_get_extras_contents_styles() {

        # define location variable
        $location = '';

        # do we have blog posts list page?
        if( is_home() ) $location = 'posts-list';

        # do we have single blog post?
        if( is_single() ) $location = 'single-post';

        # do we have archive page?
        if( is_archive() ) $location = 'archive';

        # do we have search results page?
        if( is_search() ) $location = 'search';

        # nothing found?
        if( empty( $location ) ) return( false );

        # get the current language key
        $lang_key = ueldo_get_current_language_key();

        # get contents
        $contents = array(
            'above' => ueldo_get_theme_options_value( 'vc-sections-on-blog-pages', esc_attr( $lang_key ), esc_attr( $location ) .'-above' ),
            'under' => ueldo_get_theme_options_value( 'vc-sections-on-blog-pages', esc_attr( $lang_key ), esc_attr( $location ) .'-under' )
        );

        # define css styles variable
        $css_styles = '';

        # define custom vc css styles
        $vc_css = '';

        # walk for each contents
        foreach( $contents as $element ) {

            # do we have the content set?
            if( $element != 'none' && $element !== null && $element !== false && is_numeric( $element ) ) {

                # get global cache object
                global $ueldo_cache_option;

                # get the extras content
                $content = $ueldo_cache_option -> get_post( $element );

                # do we have the content?
                if( $content !== null && $content !== false ) {

                    # update css styles content
                    $css_styles .= ueldo_find_custom_vc_shortcodes_styles( $content -> post_content );

                    # update vc css styles
                    $vc_css .= ueldo_get_custom_css_code( $content -> post_content ) .' ';
                }
            }
        }

        # return result
        return( empty( $css_styles ) && empty( $vc_css ) ? false : $css_styles .' '. $vc_css );
    }

   /**
    *
    * get header contents styles
    *
    */

    function ueldo_get_header_contents_styles( $type ) {

        # page settings box data
        $meta_data = get_post_meta( ueldo_get_page_id_for_custom_header_and_footer(), '_ueldo_custom_page_settings_meta_box_data', true );

        # prepare the content variable
        $content = '';

        # prepare the vc custom css code
        $vc_css = '';

        # do we have custom header set for this page?
        if( !empty( $meta_data ) && isset( $meta_data['custom_header_id'] ) && $meta_data['custom_header_id'] != 'none' ) {

            # get "main" header styles
            if( $type == 'main' ) {

                # do we have default header set?
                if( $meta_data['custom_header_id'] == 'default' ) return( false );

                # get the content
                $content = ueldo_get_custom_header_content( $type, $meta_data['custom_header_id'] );
            }

            # get "additional" header styles
            else {

                # do we have additional header enabled?
                if( $meta_data['custom_header_position'] == 'static' && $meta_data['use_second_header'] == 'yes' ) {

                    # do we have default header set?
                    if( $meta_data['get_second_header_content_from'] == 'default' ) return( false );

                    # get the content
                    $content = ueldo_get_custom_header_content( $type, $meta_data['get_second_header_content_from'] );
                }
            }
        }

        # display header as same as for other pages
        else {

            # get the current language key
            $lang_key = ueldo_get_current_language_key();

            # get "main" header styles
            if( $type == 'main' ) {

                # do we have default header set?
                if( ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'get-content-from' ) == 'default' ) return( false );

                # get the content
                $content = ueldo_get_custom_header_content( $type );
            }

            # get "additional" header styles
            else {

                # do we have additional header enabled?
                if( ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'position' ) == 'static' && ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'use-second-header' ) == 'yes' ) {

                    # do we have default header set?
                    if( ueldo_get_theme_options_value( 'header', esc_attr( $lang_key ), 'get-second-content-from' ) == 'default' ) return( false );

                    # get the content
                    $content = ueldo_get_custom_header_content( $type );
                }
            }
        }

        # remove temporary variables
        unset( $meta_data, $lang_key );

        # find custom vc css code
        $vc_css = ueldo_get_custom_css_code( $content );

        # return result
        return( empty( $content ) && empty( $vc_css ) ? false : ueldo_find_custom_vc_shortcodes_styles( $content ) .' '. $vc_css );
    }

   /**
    *
    * get footer contents styles
    *
    */

    function ueldo_get_footer_contents_styles() {

        # page settings box data
        $meta_data = get_post_meta( ueldo_get_page_id_for_custom_header_and_footer(), '_ueldo_custom_page_settings_meta_box_data', true );

        # prepare the content variable
        $content = '';

        # prepare the vc custom css code
        $vc_css = '';

        # do we have custom footer set for this page?
        if( !empty( $meta_data ) && isset( $meta_data['custom_footer_id'] ) && $meta_data['custom_footer_id'] != 'none' ) {

            # do we have default footer?
            if( $meta_data['custom_footer_id'] == 'default' ) return( false );

            # display custom footer content
            $content = ueldo_get_custom_footer_content( $meta_data['custom_footer_id'] );
        }

        # display footer as same as for other pages
        else {

            # get the current language key
            $lang_key = ueldo_get_current_language_key();

            # do we have default footer?
            if( ueldo_get_theme_options_value( 'footer-content', esc_attr( $lang_key ), 'get-content-from' ) == 'default' ) return( false );

            # get the content
            $content = ueldo_get_custom_footer_content();
        }

        # remove temporary variables
        unset( $meta_data, $lang_key );

        # find custom vc css code
        $vc_css = ueldo_get_custom_css_code( $content );

        # return result
        return( empty( $content ) && empty( $vc_css ) ? false : ueldo_find_custom_vc_shortcodes_styles( $content ) .' '. $vc_css );
    }

   /**
    *
    * get array of all headers / footers / extras posts
    *
    */

    # global array of hefos elements
    $ueldo_hefos_array = false;

    # get hefos value
    function ueldo_get_all_hefos_array() {

        # get global variable
        global $ueldo_hefos_array;

        # is global variable empty?
        if( $ueldo_hefos_array == false ) {

            # update it with the posts list
            $ueldo_hefos_array = get_posts( array( 'post_type' => 'ueldohefo', 'posts_per_page' => -1, 'offset' => 0 ) );
        }

        # return global variable
        return( $ueldo_hefos_array );
    }

    # clear global hefos array
    function ueldo_clear_all_hefos_array() {

        # get global variable
        global $ueldo_hefos_array;

        # clear
        unset( $ueldo_hefos_array );
    }

   /**
    *
    * get all menus array
    *
    */

    function ueldo_get_all_menus_array() {

        # get all navigation menus
        $menus = get_terms( 'nav_menu', array( 'hide_empty' => true ) );

        # do we have any menu?
        if( $menus == false || $menus == null || !is_array( $menus ) ) return( array( esc_html( __( 'Not found any menu.', 'ueldo' ) ) => 'none' ) );

        # create result object
        $result = array();

        # walk foreach navigation menus
        foreach( $menus as $menu ) {

            # add to results array
            $result[esc_html( $menu -> name )] = esc_attr( $menu -> slug );
        }

        # return result
        return( $result );
    }

   /**
    *
    * get main menu slug
    *
    */

    function ueldo_get_main_menu_slug() {

        # get nav menu locations array
        $nav_locations = get_theme_mod( 'nav_menu_locations' );

        # get main menu id
        $main_menu_id = isset( $nav_locations['ueldo_main_menu'] ) ? $nav_locations['ueldo_main_menu'] : false;

        # get main menu object
        if( $main_menu_id !== false ) {

            # get main menu object
            $main_menu_object = wp_get_nav_menu_object( esc_attr( $main_menu_id ) );

            # return main menu slug
            return( $main_menu_object != false ? $main_menu_object -> slug : '' );
        }

        # nothing found
        return( '' );
    }

   /**
    *
    * get font attributes
    *
    */

    function ueldo_get_font_attributes( $family, $weight, $smoothing ) {

        # define default result array
        $result = array(
            'font-family' => esc_attr( $family ),
            'font-weight' => esc_attr( $weight ),
            '-webkit-font-smoothing' => esc_attr( $smoothing ) == 'yes' ? 'antialiased' : 'auto',
            '-moz-osx-font-smoothing' => esc_attr( $smoothing ) == 'yes' ? 'grayscale' : 'auto'
        );

        # add "font-style" data
        $result['font-style'] = strpos( $result['font-weight'], 'italic' ) !== false ? 'italic' : 'normal';

        # replace "regular" or "italic" to "normal"
        if( $result['font-weight'] == 'regular' || $result['font-weight'] == 'italic' ) $result['font-weight'] = 'normal';

        # remove "italic" from number value
        if( strpos( $result['font-weight'], 'italic' ) !== false ) $result['font-weight'] = str_replace( 'italic', '', $result['font-weight'] );

        # return result
        return( $result );
    }

   /**
    *
    * get external urls
    *
    */

    function ueldo_get_external_url( $key ) {

        # switch by key
        switch( $key ) {

            case 'martanian-portfolio': return( 'https://themeforest.net/user/martanian/portfolio' );
            case 'martanian-com': return( 'http://martanian.com' );
            case 'ueldo-com': return( 'https://ueldo.com/' );
            case 'find-google-maps-coordinates': return( 'https://support.google.com/maps/answer/18539' );
            case 'snazzymaps': return( 'https://snazzymaps.com' );
            case 'how-to-get-twitter-api-key': return( 'https://apps.twitter.com/' );
            case 'how-to-get-google-maps-api-key': return( 'https://developers.google.com/maps/documentation/javascript/get-api-key' );
            case 'facebook-envato': return( 'https://www.facebook.com/envato' );
            case 'twitter-embed-tool': return( 'https://publish.twitter.com/' );
            case 'facebook-faq-label-for-tracking-referrals': return( 'https://developers.facebook.com/docs/plugins/faqs#ref' );
            case 'facebook-faq-layout-for-like-button': return( 'https://developers.facebook.com/docs/plugins/like-button#faqlayout' );
            case 'flaticon': return( 'http://www.flaticon.com/' );
            case 'theme-online-documentation': return( 'https://ueldo.com/documentation/' );
            case 'theme-online-documentation-retina-ready': return( 'https://ueldo.com/documentation/high-resolution-images-replacement-retina-ready/' );
        }

        # nothing found?
        return( '#' );
    }

   /**
    *
    * change hex color to rgb
    *
    */

    function ueldo_hex2rgb( $hex ) {

        # make sure that we have hex color
        if( strpos( $hex, '#' ) === false ) {

            # rgba
            if( strpos( $hex, 'rgba' ) !== false ) {

                # extract colors
                $hex = explode( ',', str_replace( 'rgba', '', str_replace( '(', '', str_replace( ')', '', $hex ) ) ) );

                # get correct opacity value
                $hex[3] = substr( trim( $hex[3] ), 0, 1 ) == '.' ? '0'. trim( $hex[3] ) : trim( $hex[3] );

                # make sure that opacity value is correct
                switch( $hex[3] ) {

                    case '': $hex[3] = '1'; break;
                    case '.': $hex[3] = '1'; break;
                    case '0.': $hex[3] = '0'; break;
                    case '1.': $hex[3] = '1'; break;
                }

                # return result
                return( array( 'rgb' => join( ', ', array( trim( $hex[0] ), trim( $hex[1] ), trim( $hex[2] ) ) ), 'a' => ( string ) round( $hex[3], 2 ) ) );
            }

            # rgb
            else if( strpos( $hex, 'rgb' ) !== false ) {

                # extract colors
                $hex = explode( ',', str_replace( 'rgb', '', str_replace( '(', '', str_replace( ')', '', $hex ) ) ) );

                # return result
                return( array( 'rgb' => join( ', ', array( trim( $hex[0] ), trim( $hex[1] ), trim( $hex[2] ) ) ), 'a' => '1' ) );
            }

            # unknown
            return( false );
        }

        # convert hex to rgb
        else {

            # only 6 chars colors allowed
            if( strlen( $hex ) != 7 ) {

                # update the hex
                $hex = '#'. str_repeat( substr( $hex, 1, 1 ), 2 ) . str_repeat( substr( $hex, 2, 1 ), 2 ) . str_repeat( substr( $hex, 3, 1 ), 2 );
            }

            # translate rgb color to hex
            list( $r, $g, $b ) = sscanf( $hex, "#%02x%02x%02x" );

            # return result
            return( array( 'rgb' => join( ', ', array( $r, $g, $b ) ), 'a' => '1' ) );
        }
    }

   /**
    *
    * get default theme colors
    *
    */

    function ueldo_get_default_theme_styles() {

        # get theme options cache object
        global $ueldo_cache_option;

        # get ueldo theme options
        $options = $ueldo_cache_option -> get_option( 'ueldo_theme_options' );

        # do we have default theme colors saved in theme options?
        if( isset( $options['styles-default'] ) && is_array( $options['styles-default'] ) ) return( $options['styles-default'] );

        # unset temporary variables
        unset( $options );

        # get all default theme options
        $default_options = ueldo_get_all_default_theme_options();

        # return default theme options
        return( $default_options['styles-default'] );
    }

   /**
    *
    * get default icon from custom icons library
    *
    */

    function ueldo_get_custom_icon( $atts, $slug ) {

        # get theme options cache object
        global $ueldo_cache_option;

        # get all custom icon fonts
        $icon_fonts = $ueldo_cache_option -> get_option( 'ueldo_custom_icons' );

        # get icon library data
        $library = $atts[esc_attr( $slug ) .'library'];

        # do we have icon set?
        if( isset( $atts[esc_attr( $slug ) . esc_attr( $library )] ) && !empty( $atts[esc_attr( $slug ) . esc_attr( $library )] ) && isset( $icon_fonts[esc_attr( $library )] ) ) return( $atts[esc_attr( $slug ) . esc_attr( $library )] );

        # return default icon
        return( $icon_fonts != false && isset( $icon_fonts[esc_attr( $library )] ) && isset( $icon_fonts[esc_attr( $library )]['icons'] ) ? $icon_fonts[esc_attr( $library )]['icons'][0] : 'fa fa-long-arrow-right' );
    }

   /**
    *
    * retina-ready images attribute
    *
    */

    function ueldo_retina_ready_attr() {

        # display retina.js attribue
        echo ueldo_get_theme_options_value( 'retina-images-replacement', false, 'enabled' ) == 'yes' ? 'data-rjs="2"' : '';
    }

   /**
    *
    * is search page with no results?
    *
    */

    function ueldo_is_search_404() {

        # is search page?
        if( !is_search() ) return( false );

        # global query variable
        global $wp_query;

        # do we have any posts found?
        return( 0 != $wp_query -> found_posts ? false : true );
    }

   /**
    *
    * get default publication date
    *
    */

    function ueldo_get_default_publication_date() {

        # get cache option class object
        global $ueldo_cache_option;

        # return result
        return( get_the_time( $ueldo_cache_option -> get_option( 'date_format' ), get_the_ID() ) .' '. esc_html( __( 'at', 'ueldo' ) ) .' '. get_the_time( $ueldo_cache_option -> get_option( 'time_format' ), get_the_ID() ) );
    }

   /**
    *
    * simple math expression parser
    *
    */

    function ueldo_parse_math_expression( $expression ) {

        # is simple expression?
        if( strpos( $expression, '(' ) === false && strpos( $expression, ')' ) === false ) {

            # there's no operators inside?
            if( strpos( $expression, '+' ) === false && strpos( $expression, '-' ) === false && strpos( $expression, '*' ) === false && strpos( $expression, '/' ) === false ) return( trim( $expression ) );

            # explode attributes
            $vars = explode( ' ', trim( $expression ) );

            # do we have three parameters?
            if( count( $vars ) == 3 ) {

                # prepare result variable
                $result = 0;

                # switch by operator
                switch( $vars[1] ) {

                    # addition
                    case '+': $result = ( float ) $vars[0] + ( float ) $vars[2]; break;

                    # subtraction
                    case '-': $result = ( float ) $vars[0] - ( float ) $vars[2]; break;

                    # multiplication
                    case '*': $result = ( float ) $vars[0] * ( float ) $vars[2]; break;

                    # division
                    case '/': $result = ( float ) $vars[0] / ( float ) $vars[2]; break;
                }

                # return result
                return( ( string ) $result );
            }

            # out of our current skills
            return( '0' );
        }

        # not a simple expression
        else {

            # split expression
            $expression_split = str_split( trim( $expression ) );

            # is bracket opened flag
            $is_bracket_opened = false;

            # simple expression content
            $simple_expression_content = '';

            # walk to find a bracket
            for( $i = 0; $i < count( $expression_split ); $i++ ) {

                # do we have bracket opened?
                if( $is_bracket_opened == true && !in_array( $expression[$i], array( '(', ')' ), true ) ) {

                    # update simple expression content
                    $simple_expression_content .= $expression[$i];
                }

                # bracket opened
                if( $expression[$i] == '(' ) {

                    # first bracket
                    if( $is_bracket_opened == false ) {

                        # update flag
                        $is_bracket_opened = true;
                    }

                    # bracket inside bracket
                    else {

                        # clear expression content
                        $simple_expression_content = '';
                    }
                }

                # bracket closed
                else if( $expression[$i] == ')' ) {

                    # update flag
                    $is_bracket_opened = false;

                    # update expression string
                    $expression = str_replace( '('. $simple_expression_content .')', ueldo_parse_math_expression( $simple_expression_content ), $expression );

                    # break the loop
                    break;
                }
            }

            # do the recurence
            return( ueldo_parse_math_expression( $expression ) );
        }
    }

   /**
    *
    * class for cache shortcodes styles array
    *
    */

    class ueldo_shortcodes_styles_cache {

       /**
        *
        * array of styles
        *
        */

        public $styles = array();

       /**
        *
        * string of saved css
        *
        */

        public $css = '';

       /**
        *
        * update styles array
        *
        */

        public function update_style( $selector, $params ) {

            # do we have selector added?
            if( isset( $this -> styles[$selector] ) ) {

                # walk for each param
                foreach( $params as $param_key => $param_value ) {

                    # update styles array
                    if( !is_array( $param_value ) ) $this -> styles[$selector][$param_key] = $param_value;
                    else {

                        # walk for each param value sub-values
                        foreach( $param_value as $subparam_key => $subparam_value ) {

                            # update responsive styles array
                            $this -> styles[$selector][$param_key][$subparam_key] = $subparam_value;
                        }
                    }
                }
            }

            # add new selector to styles array
            else {

                # update styles array
                $this -> styles[$selector] = $params;
            }
        }

       /**
        *
        * save styles array to css
        *
        */

        public function save_styles( $add_dot = true ) {

            # update css element
            $this -> css .= ueldo_create_css_string_from_array( $this -> styles, $add_dot );

            # clear css styles array
            $this -> styles = array();
        }

       /**
        *
        * get css result
        *
        */

        public function get_css() {

            # return result
            return( $this -> css );
        }

       /**
        *
        * destructor
        *
        */

        public function __destruct() {

            # clear the variables
            unset( $this -> styles, $this -> css );
        }

       /**
        *
        * end of class.
        *
        */
    }

   /**
    *
    * end of file.
    *
    */

?>