<?php

    # prevent direct file access
    if( !defined( 'ABSPATH' ) ) exit;

    # current language key - global variable
    $ueldo_current_language_key = false;

   /**
    *
    * check if this website is multilingual
    *
    */

    function ueldo_is_multilingual() {

        # include the plugins script
        include_once( ABSPATH .'wp-admin/includes/plugin.php' );

        # multilingual plugin name
        $plugin = false;

        # do we have the wpml plugin?
        if( ueldo_plugins::is_active_plugin( 'wpml' ) ) $plugin = 'wpml';

        # do we have the polylang plugin?
        if( ueldo_plugins::is_active_plugin( 'polylang' ) ) $plugin = 'polylang';

        # return the result
        return( $plugin );
    }

   /**
    *
    * get the languages list
    *
    */

    function ueldo_get_languages_list() {

        # check if is multilingual
        $is_multilingual = ueldo_is_multilingual();

        # is is not a multilingual website?
        if( $is_multilingual == false ) return( false );

        # get the languages list from each plugin
        switch( $is_multilingual ) {

            # wpml
            case 'wpml':

                # there is no this function?
                if( !function_exists( 'icl_get_languages' ) ) return( false );

                # get the all languages array
                $languages = icl_get_languages( 'skip_missing=0' );

                # prepare the result
                $result = array();

                # walk for each language
                foreach( $languages as $language ) {

                    # update the result
                    $result[] = esc_attr( $language['code'] );
                }

                # return the result
                return( $result );

            break;

            # polylang
            case 'polylang':

                # there is no this function?
                if( !function_exists( 'pll_languages_list' ) ) return( false );

                # return the result
                return( pll_languages_list( array( 'fields' => 'locale' ) ) );

            break;
        }

        # false
        return( false );
    }

   /**
    *
    * get language name by slug
    *
    */

    function ueldo_get_language_name( $locale ) {

        # check if is multilingual
        $is_multilingual = ueldo_is_multilingual();

        # is is not a multilingual website?
        if( $is_multilingual == false ) return;

        # get the languages list from each plugin
        switch( $is_multilingual ) {

            # wpml
            case 'wpml':

                # there is no this function?
                if( !function_exists( 'icl_get_languages' ) ) return( false );

                # get the all languages array
                $languages = icl_get_languages( 'skip_missing=0' );

                # walk for each language
                foreach( $languages as $language ) {

                    # update the result
                    if( $language['code'] == $locale ) return( esc_html( $language['native_name'] ) );
                }

                # nothing found
                return( false );

            break;

            # polylang
            case 'polylang':

                # there is no this function?
                if( !function_exists( 'PLL' ) ) return( false );

                # get all languages list
                $list = PLL() -> model -> get_languages_list();

                # do we have the languages?
                if( !is_array( $list ) || count( $list ) == 0 ) return( false );

                # find our language
                for( $i = 0; $i < count( $list ); $i++ ) {

                    # compare
                    if( $list[$i] -> locale == $locale ) return esc_html( $list[$i] -> name );
                }

                # nothing found
                return( false );

            break;
        }

        # false
        return( false );
    }

   /**
    *
    * get current language key for theme options
    *
    */

    function ueldo_get_current_language_key() {

        # get current language key global variable
        global $ueldo_current_language_key;

        # do we have current language key set?
        if( $ueldo_current_language_key == false ) {

            # get the current language
            $language = ueldo_get_current_language_locale();

            # update global variable
            $ueldo_current_language_key = $language == false ? 'all' : strtolower( esc_attr( $language ) );
        }

        # return the current language key
        return( $ueldo_current_language_key );
    }

   /**
    *
    * get current language slug
    *
    */

    function ueldo_get_current_language_locale() {

        # check if is multilingual
        $is_multilingual = ueldo_is_multilingual();

        # is is not a multilingual website?
        if( $is_multilingual == false ) return( false );

        # get the languages list from each plugin
        switch( $is_multilingual ) {

            # wpml
            case 'wpml':

                # return result
                return( ICL_LANGUAGE_CODE );

            break;

            # polylang
            case 'polylang':

                # there is no this function?
                if( !function_exists( 'pll_current_language' ) ) return( false );

                # nothing found
                return pll_current_language( 'locale' );

            break;
        }

        # false
        return( false );
    }

   /**
    *
    * get original language locale (without lowercase)
    *
    */

    function ueldo_get_origin_language_locale( $locale ) {

        # get all languages list
        $languages = ueldo_get_languages_list();

        # do we have languages list?
        if( $languages != array() && $languages != false && $languages != null && is_array( $languages ) ) {

            # walk for each language
            foreach( $languages as $language ) {

                # compare locale
                if( strtolower( $language ) == $locale ) return( $language );
            }
        }

        # nothing found?
        return( false );
    }

   /**
    *
    * get the default language locale
    *
    */

    function ueldo_get_default_language_locale() {

        # check if is multilingual
        $is_multilingual = ueldo_is_multilingual();

        # is is not a multilingual website?
        if( $is_multilingual == false ) return( false );

        # get the languages list from each plugin
        switch( $is_multilingual ) {

            # wpml
            case 'wpml':

                # get globals
                global $sitepress;

                # return result
                return( $sitepress -> get_default_language() );

            break;

            # polylang
            case 'polylang':

                # there is no this function?
                if( !function_exists( 'pll_default_language' ) ) return( false );

                # return result
                return( pll_default_language( 'locale' ) );

            break;
        }

        # false
        return( false );
    }

   /**
    *
    * check if current language is RTL
    *
    */

    function ueldo_is_rtl() {

        # get the current language key
        $lang_key = ueldo_get_current_language_key();

        # return result
        return( ueldo_get_theme_options_value( 'rtl', esc_attr( $lang_key ), 'is-rtl' ) == 'yes' );
    }

   /**
    *
    * load rtl styles for admin pages?
    *
    */

    function ueldo_load_rtl_styles_for_admin() {

        # get the current language key
        $lang_key = ueldo_get_current_language_key();

        # switch by the option value
        switch( ueldo_get_theme_options_value( 'rtl', esc_attr( $lang_key ), 'load-rtl-admin-styles' ) ) {

            # auto - get value from wordpress is_rtl function
            case 'auto': return( is_rtl() );

            # yes, load rtl styles for admin
            case 'yes': return( true );

            # no, do not load rtl styles for admin
            case 'no': return( false );
        }
    }

   /**
    *
    * end of file.
    *
    */

?>