<?php

   /**
    *
    * functions
    *
    */

    # call the page settings box class
    function ueldo_call_page_settings_box_class() {

        # call the class
        new ueldo_page_settings_box();
    }

    # include stylesheet file
    function ueldo_scripts_and_styles_for_page_settings_box() {

        # theme options page stylesheet
        wp_enqueue_style( 'ueldo-page-settings-box-stylesheet', get_template_directory_uri() .'/_assets/_css/page-settings-box.css', false, null );

        # enqueue main theme functions script
        wp_enqueue_script( 'ueldo-page-settings-box-javascript-functions', get_template_directory_uri() .'/_assets/_js/page-settings-box.js', array( 'jquery' ), null, true );

        # localize strings for scripts
        wp_localize_script( 'ueldo-page-settings-box-javascript-functions', 'ueldo_page_settings_box_javascript_functions_l10n', array(
            'select_image' => esc_html( __( 'Select image', 'ueldo' ) )
        ));
    }

   /**
    *
    * hooks
    *
    */

    # start the page settings box class
    add_action( 'load-post.php', 'ueldo_call_page_settings_box_class' );
    add_action( 'load-post-new.php', 'ueldo_call_page_settings_box_class' );

    # add action for "admin_enqueue_scripts" hook
    add_action( 'admin_enqueue_scripts', 'ueldo_scripts_and_styles_for_page_settings_box' );

   /**
    *
    * class definition
    *
    */

    class ueldo_page_settings_box {

       /**
        *
        * hook into the appropriate actions when the class is constructed
        *
        */

        public function __construct() {

            # add meta box
            add_action( 'add_meta_boxes', array( $this, 'add_meta_box' ) );

            # save meta box
            add_action( 'save_post', array( $this, 'save' ) );
        }

       /**
        *
        * adds the meta box container
        *
        */

        public function add_meta_box( $post_type ) {

            # limit meta box to certain post types
            if( in_array( $post_type, array( 'page' ) ) ) {

                # add meta box
                add_meta_box(
                    'ueldo_custom_page_settings_meta_box',
                    esc_html( __( 'Ueldo theme - single page settings', 'ueldo' ) ),
                    array( $this, 'render_meta_box_content' ),
                    $post_type,
                    'advanced',
                    'high'
                );
            }
        }

       /**
        *
        * array of correct keys
        *
        */

        public function get_correct_keys_array() {

            # return result
            return( array(
                'page_excerpt',
                'custom_header_id',
                'custom_footer_id',
                'custom_header_position',
                'custom_footer_position',
                'use_second_header',
                'get_second_header_content_from',
                'second_header_visible_from',
                'default_header_logo_image',
                'default_second_header_logo_image'
            ));
        }

       /**
        *
        * save the meta when the post is saved
        *
        */

        public function save( $post_id ) {

           /**
            *
            * we need to verify this came from the our screen and with proper authorization,
            * because save_post can be triggered at other times
            *
            */

            # check if our nonce is set.
            if( !isset( $_POST['ueldo_custom_page_settings_meta_box_nonce'] ) ) return( $post_id );

            # get the nonce
            $nonce = $_POST['ueldo_custom_page_settings_meta_box_nonce'];

            # verify that the nonce is valid
            if( !wp_verify_nonce( $nonce, 'ueldo_custom_page_settings_meta_box' ) ) return( $post_id );

           /**
            *
            * if this is an autosave, our form has not been submitted,
            * so we don't want to do anything
            *
            */

            if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return( $post_id );

            # check the user's permissions
            if( 'page' == $_POST['post_type'] ) { if( !current_user_can( 'edit_page', $post_id ) ) return( $post_id ); }
            else { if( !current_user_can( 'edit_post', $post_id ) ) return( $post_id ); }

           /**
            *
            * ok, it's safe for us to save the data now
            *
            */

            # define result array
            $result = array();

            # walk for each data element
            foreach( $_POST['ueldo_custom_page_settings_meta_box_data'] as $key => $value ) {

                # is key correct?
                if( in_array( $key, $this -> get_correct_keys_array(), true ) ) {

                    # sanitize text field
                    $result[$key] = sanitize_text_field( $value );
                }
            }

            # update the meta field
            update_post_meta( $post_id, '_ueldo_custom_page_settings_meta_box_data', $result );

            # update meta data for custom default footer content
            update_post_meta( $post_id, '_ueldo_custom_page_settings_meta_box_custom_default_footer_content', wp_kses_post( $_POST['_ueldo_custom_page_settings_meta_box_custom_default_footer_content'] ) );
        }

       /**
        *
        * render meta box content
        *
        */

        public function render_meta_box_content( $post ) {

            # add an nonce field so we can check for it later
            wp_nonce_field( 'ueldo_custom_page_settings_meta_box', 'ueldo_custom_page_settings_meta_box_nonce' );

            # use get_post_meta to retrieve an existing value from the database
            $value = get_post_meta( $post -> ID, '_ueldo_custom_page_settings_meta_box_data', true );

            # get the data for footer content default
            $footer_content_default = get_post_meta( $post -> ID, '_ueldo_custom_page_settings_meta_box_custom_default_footer_content' );

            # there's no any value yet?
            if( $value == '' ) {

                # default value array
                $value = array(
                    'page_excerpt' => '',
                    'custom_header_id' => 'none',
                    'custom_footer_id' => 'none',
                    'custom_header_position' => 'flying',
                    'custom_footer_position' => 'static',
                    'use_second_header' => 'no',
                    'get_second_header_content_from' => 'default',
                    'second_header_visible_from' => '400',
                    'default_header_logo_image' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ),
                    'default_second_header_logo_image' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' )
                );
            }

            # get all headers / footers / extras array
            $hefos = ueldo_get_all_hefos_array();

            # page excerpt is not available for blog (posts) page
            if( $post -> ID != get_option( 'page_for_posts' ) ) {

                ?>
                <div class="ueldo-custom-page-settings-meta-box">

                    <h4 class="ueldo-custom-page-settings-meta-box-no-margin-header"><?php echo esc_html( __( 'Custom page content excerpt:', 'ueldo' ) ); ?></h4>
                    <textarea name="ueldo_custom_page_settings_meta_box_data[page_excerpt]"><?php echo esc_html( $value['page_excerpt'] ); ?></textarea>

                </div>
                <?php
            }

            ?>
            <div class="ueldo-custom-page-settings-meta-box" data-option-key="header">

                <h4 class="ueldo-custom-page-settings-meta-box-no-margin-header"><?php echo esc_html( __( 'Custom page header:', 'ueldo' ) ); ?></h4>
                <select name="ueldo_custom_page_settings_meta_box_data[custom_header_id]">

                    <option value="none" <?php selected( esc_attr( $value['custom_header_id'] ), 'none' ); ?>><?php echo esc_html( __( 'Use the same header as for other pages', 'ueldo' ) ); ?></option>
                    <option value="default" <?php selected( esc_attr( $value['custom_header_id'] ), 'default' ); ?>><?php echo esc_html( __( 'Use default theme header', 'ueldo' ) ); ?></option>

                    <?php

                        # do we have the hefos set?
                        if( $hefos !== null && $hefos !== false && is_array( $hefos ) ) {

                            # walk for each hefo
                            foreach( $hefos as $hefo ) {

                                ?>
                                <option value="<?php echo esc_attr( $hefo -> ID ); ?>" <?php selected( esc_attr( $value['custom_header_id'] ), esc_attr( $hefo -> ID ) ); ?>><?php echo esc_html( $hefo -> post_title ); ?></option>
                                <?php
                            }
                        }

                    ?>

                </select>

                <div class="ueldo-custom-page-settings-field-depended <?php echo esc_attr( $value['custom_header_id'] == 'none' ? 'ueldo-custom-page-settings-field-depended-hidden' : '' ); ?>" data-field-depended-key="custom-header-position">

                    <h4><?php echo esc_html( __( 'Custom header position:', 'ueldo' ) ); ?></h4>
                    <div class="ueldo-custom-page-settings-select-with-image-field">

                        <input type="hidden" name="ueldo_custom_page_settings_meta_box_data[custom_header_position]" value="<?php echo esc_attr( $value['custom_header_position'] ); ?>" />

                        <div class="ueldo-custom-page-settings-select-with-image-field-option <?php echo esc_attr( $value['custom_header_position'] == 'flying' ? 'ueldo-custom-page-settings-select-with-image-field-option-selected' : '' ); ?>" data-option-value="flying">

                            <div class="ueldo-custom-page-settings-select-with-image-field-option-image-container">

                                <img src="<?php echo esc_url( ueldo_get_theme_options_image( 'header-flying.gif' ) ); ?>" />

                            </div>

                            <span><?php echo esc_html( __( 'Flying', 'ueldo' ) ); ?></span>

                        </div>

                        <div class="ueldo-custom-page-settings-select-with-image-field-option <?php echo esc_attr( $value['custom_header_position'] == 'static' ? 'ueldo-custom-page-settings-select-with-image-field-option-selected' : '' ); ?>" data-option-value="static">

                            <div class="ueldo-custom-page-settings-select-with-image-field-option-image-container">

                                <img src="<?php echo esc_url( ueldo_get_theme_options_image( 'header-static.gif' ) ); ?>" />

                            </div>

                            <span><?php echo esc_html( __( 'Static', 'ueldo' ) ); ?></span>

                        </div>

                    </div>

                </div>

                <div class="ueldo-custom-page-settings-fields-group ueldo-custom-page-settings-field-depended <?php echo esc_attr( $value['custom_header_position'] == 'flying' ? 'ueldo-custom-page-settings-field-depended-hidden' : '' ); ?>" data-field-depended-key="use-second-header">

                    <h4 class="ueldo-custom-page-settings-meta-box-no-margin-header"><?php echo esc_html( __( 'Use second header (flying)?', 'ueldo' ) ); ?></h4>
                    <select name="ueldo_custom_page_settings_meta_box_data[use_second_header]" class="ueldo-header-use-second-header-field">

                        <option value="yes" <?php selected( esc_attr( $value['use_second_header'] ), 'yes' ); ?>><?php echo esc_html( __( 'Yes', 'ueldo' ) ); ?></option>
                        <option value="no" <?php selected( esc_attr( $value['use_second_header'] ), 'no' ); ?>><?php echo esc_html( __( 'No', 'ueldo' ) ); ?></option>

                    </select>

                    <div class="ueldo-custom-page-settings-field-depended <?php echo esc_attr( $value['use_second_header'] == 'no' ? 'ueldo-custom-page-settings-field-depended-hidden' : '' ); ?>" data-field-depended-key="second-header-options">

                        <h4><?php echo esc_html( __( 'Second header content:', 'ueldo' ) ); ?></h4>
                        <select name="ueldo_custom_page_settings_meta_box_data[get_second_header_content_from]">

                            <option value="default" <?php selected( esc_attr( $value['get_second_header_content_from'] ), 'default' ); ?>><?php echo esc_html( __( 'Use default theme header', 'ueldo' ) ); ?></option>

                            <?php

                                # do we have "headers and footers" added?
                                if( $hefos != false && $hefos != null && is_array( $hefos ) ) {

                                    # walk through each "headers and footers"
                                    foreach( $hefos as $hefo ) {

                                        ?>
                                        <option value="<?php echo esc_attr( $hefo -> ID ); ?>" <?php selected( esc_attr( $value['get_second_header_content_from'] ), esc_attr( $hefo -> ID ) ); ?>><?php echo esc_html( $hefo -> post_title ); ?></option>
                                        <?php
                                    }
                                }

                            ?>

                        </select>

                        <h4><?php echo esc_html( __( 'Second header visible from scroll to (px):', 'ueldo' ) ); ?></h4>
                        <input type="text" class="ueldo-validate-number-field" data-number-field-minus-allowed="no" name="ueldo_custom_page_settings_meta_box_data[second_header_visible_from]" value="<?php echo esc_attr( esc_attr( $value['second_header_visible_from'] ) ); ?>" />

                    </div>

                </div>

                <div class="ueldo-custom-page-settings-fields-group ueldo-custom-page-settings-field-depended <?php echo esc_attr( ( ( $value['custom_header_id'] != 'default' ) && ( $value['custom_header_position'] != 'static' || $value['use_second_header'] == 'no' || $value['get_second_header_content_from'] != 'default' ) ) ? 'ueldo-custom-page-settings-field-depended-hidden' : '' ); ?>" data-field-depended-key="logo-images">

                    <div class="ueldo-custom-page-settings-field-depended <?php echo esc_attr( esc_attr( $value['custom_header_id'] ) != 'default' ? 'ueldo-custom-page-settings-field-depended-hidden' : '' ); ?>" data-field-depended-key="header-logo-image">

                        <h4 class="ueldo-custom-page-settings-meta-box-no-margin-header"><?php echo esc_html( __( 'Custom header logo:', 'ueldo' ) ); ?></h4>
                        <div class="ueldo-custom-page-settings-header-image-selection-container">

                            <div class="ueldo-custom-page-settings-header-image-preview">

                                <img src="<?php echo esc_attr( $value['default_header_logo_image'] ); ?>" />

                            </div>

                            <input type="hidden" name="ueldo_custom_page_settings_meta_box_data[default_header_logo_image]" value="<?php echo esc_attr( $value['default_header_logo_image'] ); ?>" />
                            <input type="button" class="button ueldo-page-settings-meta-box-media-button" value="<?php echo esc_attr( __( 'Select logo image', 'ueldo' ) ); ?>" />

                        </div>

                    </div>

                    <div class="ueldo-custom-page-settings-field-depended <?php echo esc_attr( $value['custom_header_position'] != 'static' || $value['use_second_header'] == 'no' || $value['get_second_header_content_from'] != 'default' ? 'ueldo-custom-page-settings-field-depended-hidden' : '' ); ?>" data-field-depended-key="second-header-logo-image">

                        <h4><?php echo esc_html( __( 'Second custom header logo:', 'ueldo' ) ); ?></h4>
                        <div class="ueldo-custom-page-settings-header-image-selection-container">

                            <div class="ueldo-custom-page-settings-header-image-preview">

                                <img src="<?php echo esc_attr( $value['default_second_header_logo_image'] ); ?>" />

                            </div>

                            <input type="hidden" name="ueldo_custom_page_settings_meta_box_data[default_second_header_logo_image]" value="<?php echo esc_attr( $value['default_second_header_logo_image'] ); ?>" />
                            <input type="button" class="button ueldo-page-settings-meta-box-media-button" value="<?php echo esc_attr( __( 'Select logo image', 'ueldo' ) ); ?>" />

                        </div>

                    </div>

                </div>

            </div>

            <div class="ueldo-custom-page-settings-meta-box" data-option-key="footer">

                <h4 class="ueldo-custom-page-settings-meta-box-no-margin-header"><?php echo esc_html( __( 'Custom page footer:', 'ueldo' ) ); ?></h4>
                <select name="ueldo_custom_page_settings_meta_box_data[custom_footer_id]">

                    <option value="none" <?php selected( esc_attr( $value['custom_footer_id'] ), 'none' ); ?>><?php echo esc_html( __( 'Use the same footer as for other pages', 'ueldo' ) ); ?></option>
                    <option value="default" <?php selected( esc_attr( $value['custom_footer_id'] ), 'default' ); ?>><?php echo esc_html( __( 'Use default theme footer', 'ueldo' ) ); ?></option>

                    <?php

                        # do we have the hefos set?
                        if( $hefos !== null && $hefos !== false && is_array( $hefos ) ) {

                            # walk for each hefo
                            foreach( $hefos as $hefo ) {

                                ?>
                                <option value="<?php echo esc_attr( $hefo -> ID ); ?>" <?php selected( esc_attr( $value['custom_footer_id'] ), esc_attr( $hefo -> ID ) ); ?>><?php echo esc_html( $hefo -> post_title ); ?></option>
                                <?php
                            }
                        }

                    ?>

                </select>

                <div class="ueldo-custom-page-settings-field-depended <?php echo esc_attr( $value['custom_footer_id'] == 'none' ? 'ueldo-custom-page-settings-field-depended-hidden' : '' ); ?>" data-field-depended-key="custom-footer-position">

                    <h4><?php echo esc_html( __( 'Custom footer position:', 'ueldo' ) ); ?></h4>
                    <div class="ueldo-custom-page-settings-select-with-image-field">

                        <input type="hidden" name="ueldo_custom_page_settings_meta_box_data[custom_footer_position]" value="<?php echo esc_attr( $value['custom_footer_position'] ); ?>" />

                        <div class="ueldo-custom-page-settings-select-with-image-field-option <?php echo esc_attr( $value['custom_footer_position'] == 'static' ? 'ueldo-custom-page-settings-select-with-image-field-option-selected' : '' ); ?>" data-option-value="static">

                            <div class="ueldo-custom-page-settings-select-with-image-field-option-image-container">

                                <img src="<?php echo esc_url( ueldo_get_theme_options_image( 'footer-position-static.gif' ) ); ?>" />

                            </div>

                            <span><?php echo esc_html( __( 'Static', 'ueldo' ) ); ?></span>

                        </div>

                        <div class="ueldo-custom-page-settings-select-with-image-field-option <?php echo esc_attr( $value['custom_footer_position'] == 'fixed-to-bottom' ? 'ueldo-custom-page-settings-select-with-image-field-option-selected' : '' ); ?>" data-option-value="fixed-to-bottom">

                            <div class="ueldo-custom-page-settings-select-with-image-field-option-image-container">

                                <img src="<?php echo esc_url( ueldo_get_theme_options_image( 'footer-position-fixed-to-bottom.gif' ) ); ?>" />

                            </div>

                            <span><?php echo esc_html( __( 'Fixed to bottom', 'ueldo' ) ); ?></span>

                        </div>

                    </div>

                </div>

                <div class="ueldo-custom-page-settings-fields-group ueldo-custom-page-settings-field-depended <?php echo esc_attr( $value['custom_footer_id'] != 'default' ? 'ueldo-custom-page-settings-field-depended-hidden' : '' ); ?>" data-field-depended-key="custom-footer-default-content">

                    <h4 class="ueldo-custom-page-settings-meta-box-no-margin-header"><?php echo esc_html( __( 'Custom default footer content:', 'ueldo' ) ); ?></h4>

                    <?php

                        # prepare footer default content
                        $footer_content_default = !isset( $footer_content_default[0] ) ? date( 'Y' ) .' &copy; <a href="'. esc_url( ueldo_get_external_url( 'ueldo-com' ) ) .'">'. esc_html( __( 'Ueldo WordPress Theme', 'ueldo' ) ) .'</a> '. esc_html( __( 'created with heart by', 'ueldo' ) ) .' <a href="'. esc_url( ueldo_get_external_url( 'martanian-portfolio' ) ) .'" target="_blank">Martanian</a>' : $footer_content_default[0];

                        # display wp editor
                        wp_editor( $footer_content_default, '_ueldo_custom_page_settings_meta_box_custom_default_footer_content', array( 'tinymce' => false, 'quicktags' => true ) );

                    ?>

                </div>

            </div>
            <?php

            # clear global hefos array
            ueldo_clear_all_hefos_array();

            # clear variables
            unset( $value, $hefos, $hefo, $footer_content_default );
        }

       /**
        *
        * end of class methods.
        *
        */
    }

   /**
    *
    * remove revolution slider meta box from custom post type
    *
    */

    add_action( 'do_meta_boxes', 'ueldo_remove_rev_slider_meta_boxes_from_custom_post_type' );
    function ueldo_remove_rev_slider_meta_boxes_from_custom_post_type() {

        # remove meta box from custom post type
        remove_meta_box( 'mymetabox_revslider_0', 'ueldohefo', 'normal' );
    }

   /**
    *
    * end of file.
    *
    */

?>