<?php

   /**
    *
    * class to manage required plugins
    *
    */

    class ueldo_plugins {

       /**
        *
        * has activation checked been fired?
        *
        */

        public static $fired_already = false;

       /**
        *
        * array of plugins used by ueldo theme
        *
        */

        public static $plugins = array(

            'ueldo' => array(
                'name' => 'Ueldo Plugin',
                'active' => false
            ),

            'visual-composer' => array(
                'name' => 'WPBakery Page Builder',
                'active' => false
            ),

            'contact-form-7' => array(
                'name' => 'Contact Form 7',
                'active' => false
            ),

            'wpml' => array(
                'name' => 'WPML Multilingual CMS',
                'active' => false
            ),

            'polylang' => array(
                'name' => 'Polylang',
                'active' => false
            ),

            'mailchimp-for-wp' => array(
                'name' => 'MailChimp for WordPress',
                'active' => false
            ),

            'revolution-slider' => array(
                'name' => 'Slider Revolution',
                'active' => false
            ),

            'ubermenu' => array(
                'name' => 'UberMenu 3 - The Ultimate WordPress Mega Menu',
                'active' => false
            ),

            'woocommerce' => array(
                'name' => 'WooCommerce',
                'active' => false
            )
        );

       /**
        *
        * check plugins activation status
        *
        */

        public static function check_activation_status() {

            # do we have "ueldo" plugin activated?
            if( function_exists( 'ueldo_plugin_check_theme_name' ) ) self::$plugins['ueldo']['active'] = true;

            # do we have "visual composer" activated?
            if( class_exists( 'Vc_Manager' ) ) self::$plugins['visual-composer']['active'] = true;

            # do we have "contact form 7" activated?
            if( class_exists( 'WPCF7' ) ) self::$plugins['contact-form-7']['active'] = true;

            # do we have "wpml" activated?
            if( class_exists( 'SitePress' ) ) self::$plugins['wpml']['active'] = true;

            # do we have "polylang" activated?
            if( class_exists( 'Polylang' ) ) self::$plugins['polylang']['active'] = true;

            # do we have "mailchimp for wordpress" activated?
            if( function_exists( '_mc4wp_load_plugin' ) ) self::$plugins['mailchimp-for-wp']['active'] = true;

            # do we have "revolution slider" activated?
            if( class_exists( 'RevSliderFront' ) ) self::$plugins['revolution-slider']['active'] = true;

            # do we have "uber menu" plugin activated?
            if( class_exists( 'UberMenu' ) ) self::$plugins['ubermenu']['active'] = true;

            # do we have "woocommerce" plugin activated?
            if( class_exists( 'WooCommerce' ) ) self::$plugins['woocommerce']['active'] = true;

            # update flag
            self::$fired_already = true;
        }

       /**
        *
        * check if plugin is active
        *
        */

        public static function is_active_plugin( $slug, $refresh = false ) {

            # do we have to refresh plugins activation statuses?
            if( $refresh == true || self::$fired_already == false ) self::check_activation_status();

            # return result
            return( !isset( self::$plugins[$slug] ) ? false : self::$plugins[$slug]['active'] );
        }

       /**
        *
        * get plugin name
        *
        */

        public static function get_plugin_name( $slug ) {

            # return result
            return( !isset( self::$plugins[$slug] ) ? false : self::$plugins[$slug]['name'] );
        }

       /**
        *
        * get installed plugins
        *
        */

        public static function get_plugins() {

            # do we have "get_plugins" function?
            if( !function_exists( 'get_plugins' ) ) {

                # get the function file
                require_once( ABSPATH .'wp-admin/includes/plugin.php' );
         			}

            # return result
            return( get_plugins() );
        }

       /**
        *
        * check if is plugin installed
        *
        */

        public static function is_plugin_installed( $slug ) {

            # get plugins
            $plugins = self::get_plugins();

            # do we have any plugins found?
            if( is_array( $plugins ) && $plugins != array() ) {

                # get name of searched plugin
                if( $plugin_name = self::get_plugin_name( $slug ) ) {

                    # walk for each plugins
                    foreach( $plugins as $plugin_path => $plugin_data ) {

                        # compare with searched plugin
                        if( $plugin_data['Name'] == $plugin_name ) {

                            # return result
                            return( true );
                        }
                    }
                };
            }

            # plugin is not installed
            return( false );
        }

       /**
        *
        * activate selected plugin
        *
        */

        public static function activate_plugin( $slug ) {

            # get plugins
            $plugins = self::get_plugins();

            # do we have any plugins found?
            if( is_array( $plugins ) && $plugins != array() ) {

                # get name of searched plugin
                if( $plugin_name = self::get_plugin_name( $slug ) ) {

                    # walk for each plugins
                    foreach( $plugins as $plugin_path => $plugin_data ) {

                        # compare with searched plugin
                        if( $plugin_data['Name'] == $plugin_name ) {

                            # try to activate plugin
                            $result = activate_plugin( $plugin_path );

                            # all goes fine?
                            if( !is_wp_error( $result ) && self::is_active_plugin( $slug, true ) ) return( true );
                        }
                    }
                };
            }

            # plugin is not activated
            return( false );
        }

       /**
        *
        * install plugin
        *
        */

        public static function install_plugin( $slug ) {

            # do not execute if plugin is already installed
            if( self::is_plugin_installed( $slug ) ) return( true );

            # require all necessary files & classes
            require_once( ABSPATH .'wp-admin/includes/class-wp-upgrader.php' );
            require_once( ABSPATH .'wp-admin/includes/file.php' );
            require_once( ABSPATH .'wp-admin/includes/misc.php' );

        				# create plugin upgrader object
            $upgrader = new Plugin_Upgrader( new ueldo_plugin_installer_skin() );

            # get plugin download link
            if( $download_link = self::get_plugin_download_url( $slug ) ) {

                # proceed installation
                $upgrader -> install( $download_link );

                # return result
                return( self::is_plugin_installed( $slug ) );
            }

            # installation failed
            return( false );
        }

       /**
        *
        * get plugin download url
        *
        */

        public static function get_plugin_download_url( $slug ) {

            # switch by plugin slug
            switch( $slug ) {

                # ueldo plugin
                case 'ueldo': return( esc_url( get_template_directory_uri() .'/_assets/_plugins/ueldo-plugin.zip' ) );

                # visual composer plugin
                case 'visual-composer': return( esc_url( get_template_directory_uri() .'/_assets/_plugins/js_composer.zip' ) );

                # revolution slider plugin
                case 'revolution-slider': return( esc_url( get_template_directory_uri() .'/_assets/_plugins/revslider.zip' ) );

                # plugins from wordpress repo
                default:

                    # do we have plugins_api function?
                    if( !function_exists( 'plugins_api' ) ) {

                        # require necessary file
                        require_once( ABSPATH .'wp-admin/includes/plugin-install.php' );
                				}

                    # get response
                    $response = plugins_api(
                   					'plugin_information',
                   					array(
                      						'slug' => esc_attr( $slug ),
                      						'fields' => array(
                      							   'sections' => false,
                      						),
                   					)
                				);

                    # return result
                    return( !is_wp_error( $response ) && isset( $response -> download_link ) ? $response -> download_link : false );

                break;
            }

            # couldn't find download link
            return( false );
        }

       /**
        *
        * is known plugin
        *
        */

        public static function is_known_plugin( $slug ) {

            # return result
            return( in_array( $slug, array_keys( self::$plugins ), true ) );
        }

       /**
        *
        * end of class methods.
        *
        */
    }

   /**
    *
    * create own plugin installer skin - clean
    *
    */

    # there's no plugin installer skin class found?
    if( !class_exists( 'Plugin_Installer_Skin', false ) ) {

        # require wp-upgrader class
        require_once( ABSPATH .'wp-admin/includes/class-wp-upgrader.php' );
    }

    # extend plugin installer skin
    class ueldo_plugin_installer_skin extends Plugin_Installer_Skin {

       /**
        *
        * extend feedback method
        *
        *
        */

        public function feedback( $string ) { return( '' ); }
        public function header() { return( '' ); }
        public function footer() { return( '' ); }

       /**
        *
        * end of class methods.
        *
        */
    }

   /**
    *
    * fire class method on wp_loaded action
    *
    */

    # update plugins activation status after wp load
    add_action( 'wp_loaded', array( 'ueldo_plugins', 'check_activation_status' ) );

   /**
    *
    * end of class.
    *
    */

?>