<?php

    # prevent direct file access
    if( !defined( 'ABSPATH' ) ) exit;

   /**
    *
    * theme setup
    *
    */

    add_action( 'after_setup_theme', 'ueldo_setup' );
    function ueldo_setup() {

        # load languages from "_assets/_languages" directory
        load_theme_textdomain( 'ueldo', get_template_directory() .'/_assets/_languages' );

        # add support for automatic feed links
        add_theme_support( 'automatic-feed-links' );

        # add support for "title tag"
        add_theme_support( 'title-tag' );

        # add support for post thumbnails
        add_theme_support( 'post-thumbnails' );

        # add support for custom backgrounds
        add_theme_support( 'custom-background', array( 'default-color' => 'ffffff' ) );

        # add support for woocommerce
        add_theme_support( 'woocommerce' );

        # add support for woocommerce gallery zoom
        add_theme_support( 'wc-product-gallery-zoom' );

        # add support for woocommerce gallery lightbox
        add_theme_support( 'wc-product-gallery-lightbox' );

        # add support for woocommerce gallery slider
        add_theme_support( 'wc-product-gallery-slider' );

        # update global variable
        $GLOBALS['content_width'] = apply_filters( 'ueldo_content_width', 1100 );

        # register wp_nav menus
        if( function_exists( 'register_nav_menu' ) ) {

            # main menu
            register_nav_menu( 'ueldo_main_menu', esc_html( __( 'Ueldo - Main Menu', 'ueldo' ) ) );
        }
    }

   /**
    *
    * flush rewrite rules after theme activation
    *
    */

    add_action( 'after_switch_theme', 'ueldo_rewrite_flush' );
    function ueldo_rewrite_flush() {

        # register headings and footers custom post type
        if( function_exists( 'ueldo_plugin_create_post_type_headers_footers_extras' ) ) ueldo_plugin_create_post_type_headers_footers_extras();

        # flush rewrite rules
        flush_rewrite_rules();
    }

   /**
    *
    * comments reply script
    *
    */

    add_action( 'comment_form_before', 'ueldo_enqueue_comments_reply' );
    function ueldo_enqueue_comments_reply() {

        # get cache option class object
        global $ueldo_cache_option;

        # do we have "thread_comments" option?
        if( $ueldo_cache_option -> get_option( 'thread_comments' ) ) {

            # enqueue comments reply script
            wp_enqueue_script( 'comment-reply' );
      	}
    }

   /**
    *
    * enqueue scripts and styles
    *
    */

    add_action( 'wp_enqueue_scripts', 'ueldo_enqueue_scripts' );
    function ueldo_enqueue_scripts() {

        # get google api key
        $google_maps_api_key = ueldo_get_theme_options_value( 'google-maps', false, 'api-key' );

        # do we have api key added?
        if( !empty( $google_maps_api_key ) ) {

            # enqueue google maps script
            wp_enqueue_script( 'google-maps', ( is_ssl() ? 'https' : 'http' ) .'://maps.google.com/maps/api/js?key='. esc_attr( $google_maps_api_key ), array( 'jquery' ), null, true );

            # enqueue richmarker script
            wp_enqueue_script( 'richmarker', get_template_directory_uri() .'/_assets/_libs/richmarker.js', array( 'jquery' ), null, true );
        }

        # enqueue masonry script
        wp_enqueue_script( 'masonry' );

        # enqueue isotope script
        wp_enqueue_script( 'isotope', get_template_directory_uri() .'/_assets/_libs/isotope.pckd.min.js', array( 'jquery' ), null, true );

        # enqueue touchSwipe script
        wp_enqueue_script( 'touchswipe', get_template_directory_uri() .'/_assets/_libs/jquery.touchSwipe.min.js', array( 'jquery' ), null, true );

        # enqueue magnific popup script
        wp_enqueue_script( 'magnific-popup', get_template_directory_uri() .'/_assets/_libs/magnific-popup/magnific-popup.min.js', array( 'jquery' ), null, true );

        # enqueue event.move script
        wp_enqueue_script( 'jquery-event-move', get_template_directory_uri() .'/_assets/_libs/jquery.event.move.js', array( 'jquery' ), null, true );

        # enqueue main theme functions script
        wp_enqueue_script( 'ueldo-javascript-functions', get_template_directory_uri() .'/_assets/_js/functions.js', array( 'jquery', 'jquery-event-move' ), null, true );

        # enqueue google fonts
        wp_enqueue_style( 'ueldo-fonts', ueldo_get_google_fonts_url(), false, null );

        # enqueue font awesome stylesheet
        wp_enqueue_style( 'font-awesome-icons', get_template_directory_uri() .'/_assets/_libs/font-awesome/css/font-awesome.css', false, null );

        # enqueue magnific popup style
        wp_enqueue_style( 'magnific-popup', get_template_directory_uri() .'/_assets/_libs/magnific-popup/magnific-popup.css', false, null );

        # enqueue animate.css library
        wp_enqueue_style( 'animate-css', get_template_directory_uri() .'/_assets/_libs/animate.css', false, null );

        # enqueue custom css animations stylesheet
        wp_enqueue_style( 'ueldo-animations-stylesheet', get_template_directory_uri() .'/_assets/_css/animations.css', false, null );

        # enqueue main theme stylesheet
        wp_enqueue_style( 'ueldo-stylesheet', get_template_directory_uri() .'/style.css', false, null );

        # get customizer styles
        ueldo_customizer_get_styles_css();

        # enqueue forms stylesheet
        wp_enqueue_style( 'ueldo-forms-stylesheet', get_template_directory_uri() .'/_assets/_css/forms.css', false, null );

        # is visual composer plugin activated?
        if( ueldo_plugins::is_active_plugin( 'visual-composer' ) ) {

            # enqueue visual composer stylesheet
            wp_enqueue_style( 'ueldo-visual-composer-stylesheet', get_template_directory_uri() .'/_assets/_css/visual-composer.css', false, null );
        }

        # is woocommerce plugin activated?
        if( ueldo_plugins::is_active_plugin( 'woocommerce' ) ) {

            # enqueue visual composer stylesheet
            wp_enqueue_style( 'ueldo-woocommerce-stylesheet', get_template_directory_uri() .'/_assets/_css/woocommerce.css', false, null );
        }

        # lazy load for images?
        if( ueldo_get_theme_options_value( 'lazy-load-images', false, 'enabled' ) == 'yes' ) {

            # enqueue unveil script
            wp_enqueue_script( 'unveil', get_template_directory_uri() .'/_assets/_libs/jquery.unveil.js', array( 'jquery' ), null, true );
        }

        # localize template directory path for scripts
        wp_localize_script( 'ueldo-javascript-functions', 'ueldo_javascript_functions_l10n', array(
            'website_sizes_large_content_width' => ueldo_get_theme_options_value( 'boxed-website', false, 'large-content-width' ),
            'website_sizes_large_content_space' => ueldo_get_theme_options_value( 'boxed-website', false, 'large-content-space' ),
            'website_sizes_medium_content_width' => ueldo_get_theme_options_value( 'boxed-website', false, 'medium-content-width' ),
            'website_sizes_medium_content_space' => ueldo_get_theme_options_value( 'boxed-website', false, 'medium-content-space' ),
            'website_sizes_small_content_width' => ueldo_get_theme_options_value( 'boxed-website', false, 'small-content-width' ),
            'website_sizes_small_content_space' => ueldo_get_theme_options_value( 'boxed-website', false, 'small-content-space' ),
            'lazy_load_images_enabled' => ueldo_get_theme_options_value( 'lazy-load-images', false, 'enabled' ),
            'lazy_load_images_threshold' => ueldo_get_theme_options_value( 'lazy-load-images', false, 'threshold' ),
            'responsive_sidebar_style' => ueldo_get_theme_options_value( 'blog-sidebar', false, 'responsive-style' ),
            'local_scrolling_links_animation_enabled' => esc_attr( ueldo_get_theme_options_value( 'local-scrolling-links-animation', false, 'enabled' ) ),
            'local_scrolling_links_animation_speed' => esc_attr( ueldo_get_theme_options_value( 'local-scrolling-links-animation', false, 'animation-speed' ) ),
            'back' => esc_html( __( 'Back', 'ueldo' ) ),
            'is_rtl' => ueldo_is_rtl() == true ? 'yes' : 'no',
            'retina_images_replacement_enabled' => ueldo_get_theme_options_value( 'retina-images-replacement', false, 'enabled' ),
            'is_google_maps_available' => !empty( $google_maps_api_key ) ? 'yes' : 'no',
            'side_menu_closing_rules_anywhere_outside' => esc_attr( ueldo_get_theme_options_value( 'side-menu', false, 'closing-rules-anywhere-outside' ) ),
            'side_menu_closing_rules_any_link_inside' => esc_attr( ueldo_get_theme_options_value( 'side-menu', false, 'closing-rules-any-link-inside' ) ),
            'search' => esc_html( __( 'Search...', 'ueldo' ) )
        ));

        # do we have custom icons added?
        if( ueldo_plugins::is_active_plugin( 'ueldo' ) && ueldo_plugin_is_any_custom_icon_added() ) {

            # enqueue custom icons stylesheet
            ueldo_plugin_enqueue_custom_icons_stylesheet();
        }

        # retina images replacement enabled?
        if( ueldo_get_theme_options_value( 'retina-images-replacement', false, 'enabled' ) == 'yes' ) {

            # enqueue unveil script
            wp_enqueue_script( 'retina-js', get_template_directory_uri() .'/_assets/_libs/retina.js', array( 'jquery' ), null, true );
        }

        # right-to-left
        if( ueldo_is_rtl() ) {

            # enqueue right-to-left stylesheet
            wp_enqueue_style( 'ueldo-stylesheet-frontend-rtl', get_template_directory_uri() .'/_assets/_css/frontend-rtl.css', false, null );
        }

        # left-to-right
        else {

            # enqueue left-to-right stylesheet
            wp_enqueue_style( 'ueldo-stylesheet-frontend-ltr', get_template_directory_uri() .'/_assets/_css/frontend-ltr.css', false, null );
        }
    }

   /**
    *
    * load custom styles and scritps for admin page
    *
    */

    add_action( 'admin_enqueue_scripts', 'ueldo_custom_admin_scripts_and_styles' );
    function ueldo_custom_admin_scripts_and_styles( $hook ) {

        # only for "widgets.php" page
        if( $hook == 'widgets.php' ) {

            # enqueue media library
            wp_enqueue_media();

            # enqueue main theme functions script
            wp_enqueue_script( 'ueldo-javascript-admin-functions', get_template_directory_uri() .'/_assets/_js/admin-functions.js', array( 'jquery' ), null, true );

            # localize strings for scripts
            wp_localize_script( 'ueldo-javascript-admin-functions', 'ueldo_javascript_admin_functions_l10n', array(
                'media_title' => esc_html( __( 'Select or upload image for widget', 'ueldo' ) ),
                'button' => esc_html( __( 'Use this image', 'ueldo' ) )
            ));
        }

        # enqueue custom stylesheet for wp admin (sidebar widgets and custom vc fields)
        wp_enqueue_style( 'ueldo-wp-admin-css', get_template_directory_uri() .'/_assets/_css/wp-admin.css', false, null );

        # enqueue custom css animations stylesheet
        wp_enqueue_style( 'ueldo-animations-stylesheet', get_template_directory_uri() .'/_assets/_css/animations.css', false, null );

        # enqueue font awesome stylesheet
        wp_enqueue_style( 'font-awesome-icons', get_template_directory_uri() .'/_assets/_libs/font-awesome/css/font-awesome.css', false, null );

        # do we have custom icons added?
        if( ueldo_plugins::is_active_plugin( 'ueldo' ) && ueldo_plugin_is_any_custom_icon_added() ) {

            # enqueue custom icons stylesheet
            ueldo_plugin_enqueue_custom_icons_stylesheet();
        }

        # right-to-left
        if( ueldo_load_rtl_styles_for_admin() ) {

            # enqueue right-to-left stylesheet
            wp_enqueue_style( 'ueldo-stylesheet-backend-rtl', get_template_directory_uri() .'/_assets/_css/backend-rtl.css', false, null );
        }

        # left-to-right
        else {

            # enqueue left-to-right stylesheet
            wp_enqueue_style( 'ueldo-stylesheet-backend-ltr', get_template_directory_uri() .'/_assets/_css/backend-ltr.css', false, null );
        }
    }

   /**
    *
    * register blog sidebar
    *
    */

    add_action( 'widgets_init', 'ueldo_register_sidebars' );
    function ueldo_register_sidebars() {

        # register blog sidebar
        register_sidebar( array(
            'name' => esc_html( __( 'Blog sidebar', 'ueldo' ) ),
            'id' => 'blog-sidebar',
            'description' => esc_html( __( 'Blog sidebar', 'ueldo' ) ),
            'before_title' => '<h4>',
            'after_title' => '</h4>',
            'before_widget' => '<div class="widget">',
            'after_widget' => '</div>'
        ));
    }

   /**
    *
    * get array of theme functions files
    *
    */

    function ueldo_get_theme_functions_files() {

        # return array of always required files
        return( array(
            '/_assets/_php/_theme-options/theme-options.php',
            '/_assets/_php/plugins.php',
            '/_assets/_php/helpers.php',
            '/_assets/_php/content-mods.php',
            '/_assets/_php/languages.php',
            '/_assets/_php/external-plugins.php',
            '/_assets/_php/_customizer/styles-cache.php',
            '/_assets/_php/styles.php',
            '/_assets/_php/_customizer/customizer.php',
            '/_assets/_php/add-demo-assets.php'
        ));
    }

   /**
    *
    * include theme functions files
    *
    */

    foreach( ueldo_get_theme_functions_files() as $ueldo_function_file ) {

        # require function file
        require_once( get_template_directory() . esc_attr( $ueldo_function_file ) );
    }

    # add page settings box - only if is admin
    if( is_admin() ) require_once( get_template_directory() .'/_assets/_php/page-settings-box.php' );

    # include visual composer functions
    if( ueldo_plugins::is_active_plugin( 'ueldo' ) && ueldo_plugins::is_active_plugin( 'visual-composer' ) ) require_once( ueldo_plugin_get_path( '_parts/_visual-composer/visual-composer.php' ) );

    # include woocommerce functions
    if( ueldo_plugins::is_active_plugin( 'woocommerce' ) ) require_once( get_template_directory() .'/_assets/_php/woocommerce.php' );

   /**
    *
    * register required plugins
    *
    */

    # include tgm plugin activation class
    require_once( get_template_directory() .'/_assets/_plugins/class-tgm-plugin-activation.php' );

    # register plugins
    add_action( 'tgmpa_register', 'ueldo_register_required_plugins' );
    function ueldo_register_required_plugins() {

        # required plugins
        $plugins = array(
            array(
                'name' => esc_html( __( 'Ueldo Plugin', 'ueldo' ) ),
                'slug' => 'ueldo-plugin',
                'source' => get_stylesheet_directory() .'/_assets/_plugins/ueldo-plugin.zip',
                'version' => '1.2.7',
                'required' => true
            ),
            array(
                'name' => esc_html( __( 'WPBakery Page Builder', 'ueldo' ) ),
                'slug' => 'js_composer',
                'source' => get_stylesheet_directory() .'/_assets/_plugins/js_composer.zip',
                'version' => '5.4.7',
                'required' => true
            ),
            array(
                'name' => esc_html( __( 'Slider Revolution', 'ueldo' ) ),
                'slug' => 'revslider',
                'source' => get_stylesheet_directory() .'/_assets/_plugins/revslider.zip',
                'version' => '5.4.7.2',
                'required' => false
            ),
            array(
                'name' => esc_html( __( 'Contact Form 7', 'ueldo' ) ),
                'slug' => 'contact-form-7',
                'required' => false
            ),
            array(
                'name' => esc_html( __( 'Contact Form 7 Datepicker', 'ueldo' ) ),
                'slug' => 'contact-form-7-datepicker',
                'required' => false
            ),
            array(
                'name' => esc_html( __( 'MailChimp for WordPress', 'ueldo' ) ),
                'slug' => 'mailchimp-for-wp',
                'required' => false
            )
        );

        # start the script
        tgmpa( $plugins, array(
            'id' => 'ueldo'
        ));

        # remove temporary variable
        unset( $plugins );
    }

   /**
    *
    * end of file.
    *
    */

?>