<?php

   /**
    *
    * prepare the data for shortcode
    *
    */

    # extract shortcode arguments
    extract( shortcode_atts( array(
       'class_name' => '',
       'button_type' => 'standard-button',
       'button_visible_on_devices' => 'large,medium,small,extra-small',
       'button_text' => esc_html( __( 'Contact us', 'ueldo' ) ),
       'second_line_text' => esc_html( __( '1-800-123-4567', 'ueldo' ) ),
       'second_line_position' => 'bottom',
       'button_text_alignment' => esc_attr( ueldo_is_rtl() ? 'right' : 'left' ),
       'action_after_click' => 'link',
       'button_url' => ueldo_get_default_button_url( '#', esc_html( __( 'Contact us', 'ueldo' ) ), '_blank' ),
       'display_button_on_blog_only' => 'yes',
       'button_alignment' => esc_attr( ueldo_is_rtl() ? 'right' : 'left' ),
       'show_button_icon' => 'no',
       'button_icon_position' => 'after',
       'button_icon_visibility' => 'visible',
       'button_icon_library' => 'fontawesome',
       'button_icon_fontawesome' => 'fa fa-long-arrow-right',
       'button_icon_openiconic' => 'vc_icon_element-icon vc-oi vc-oi-dial',
       'button_icon_typicons' => 'typcn typcn-adjust-brightness',
       'button_icon_entypo' => 'entypo-icon entypo-icon-note',
       'button_icon_linecons' => 'vc_li vc_li-heart',
       'button_icon_monosocial' => 'vc-mono vc-mono-fivehundredpx',
       'button_icon_material' => 'vc-material vc-material-account_balance',
       'text_near_button_position' => 'after'
    ), $atts ));

    # get button link
    $button_url = vc_build_link( $button_url );

   /**
    *
    * button only on blog pages?
    *
    */

    if( $action_after_click == 'show_hide_flying_sidebar' && $display_button_on_blog_only == 'yes' && !ueldo_is_blog_page() ) return;

   /**
    *
    * get button icon
    *
    */

    # define the icon variable
    $button_icon = '';

    # is icon set?
    if( $show_button_icon == 'yes' ) {

        # switch the icon library
        switch( $button_icon_library ) {

            case 'fontawesome': $button_icon = $button_icon_fontawesome; break;
            case 'openiconic': $button_icon = $button_icon_openiconic; break;
            case 'typicons': $button_icon = $button_icon_typicons; break;
            case 'entypo': $button_icon = $button_icon_entypo; break;
            case 'linecons': $button_icon = $button_icon_linecons; break;
            case 'monosocial': $button_icon = $button_icon_monosocial; break;
            case 'material': $button_icon = $button_icon_material; break;
            default: $button_icon = ueldo_get_custom_icon( $atts, 'button_icon_' ); break;
        }
    }

   /**
    *
    * button visible on devices
    *
    */

    # explode devices list
    $button_visible_on_devices = !empty( $button_visible_on_devices ) ? explode( ',', $button_visible_on_devices ) : array();

    # prepare container visibility class names
    $container_visibility_class = '';

    # walk for each visible devices
    foreach( array( 'large', 'medium', 'small', 'extra-small' ) as $device ) {

        # update container class name
        if( !in_array( $device, $button_visible_on_devices, true ) ) $container_visibility_class .= ' ueldo-shortcode-button-hidden-on-'. esc_attr( $device ) .'-devices';
    }

   /**
    *
    * display buttons
    *
    */

    # do we have the button visible?
    if( $button_visible_on_devices != array() ) {

       /**
        *
        * standard button
        *
        */

        # standard button
        if( $button_type == 'standard-button' ) {

            # do we have button content set?
            $is_button = ueldo_button_content_exists( $button_type, $button_text, false, $action_after_click, $button_url, $show_button_icon );

            # do we have text near button set?
            $is_text_near_button = !empty( $content );

            # do we have button content or text near button set?
            if( $is_button == true || $is_text_near_button == true ) {

                # define button container class
                $button_container_class = 'ueldo-shortcode-button-container '. esc_attr( $container_visibility_class ) .' '. esc_attr( $class_name );

                # add the alignment option class
                $button_container_class .= ' ueldo-shortcode-button-container-alignment-'. esc_attr( $button_alignment );

                # update button container class with icon visibility
                if( $show_button_icon == 'yes' ) $button_container_class .= ' ueldo-shortcode-button-container-icon-visibility-'. esc_attr( $button_icon_visibility == 'on_hover_only' ? 'on-hover-only' : $button_icon_visibility );

                # button text alignment
                $button_container_class .= ' ueldo-shortcode-button-text-alignment-'. esc_attr( $button_text_alignment );

                ?>
                <div id="<?php echo esc_attr( $class_name ); ?>" class="<?php echo esc_attr( $button_container_class ); ?>">

                    <?php

                        # do we have text near button, and is it before the button?
                        if( $is_text_near_button == true && $text_near_button_position == 'before' ) {

                            ?>
                            <div class="ueldo-shortcode-button-text-near-button ueldo-shortcode-button-text-near-button-before">

                                <?php

                                    # display the text near button
                                    echo apply_filters( 'the_content', $content );

                                ?>

                            </div>
                            <?php
                        }

                        # do we have button content?
                        if( $is_button == true ) {

                            # define the button class
                            $button_class = 'ueldo-button';

                            # if button have no text
                            if( empty( $button_text ) ) $button_class .= ' ueldo-button-without-text';

                            # action is not a standard link?
                            if( $action_after_click != 'link' ) {

                                # switch the action
                                switch( $action_after_click ) {

                                    # show / hide flying sidebar
                                    case 'show_hide_flying_sidebar':

                                        # update button url array
                                        $button_url = array(
                                            'url' => '#ueldo-show-hide-flying-sidebar',
                                            'title' => esc_html( __( 'Show / hide flying sidebar', 'ueldo' ) ),
                                            'target' => '_self',
                                            'rel' => ''
                                        );

                                    break;

                                    # show / hide side menu
                                    case 'show_hide_side_menu':

                                        # update button url array
                                        $button_url = array(
                                            'url' => '#ueldo-show-hide-side-menu',
                                            'title' => esc_html( __( 'Show / hide side menu', 'ueldo' ) ),
                                            'target' => '_self',
                                            'rel' => ''
                                        );

                                    break;
                                }
                            }

                            ?>
                            <a href="<?php echo esc_url( $button_url['url'] ); ?>" target="<?php echo esc_attr( trim( $button_url['target'] ) == '_blank' ? '_blank' : '_self' ); ?>" title="<?php echo esc_attr( $button_url['title'] ); ?>" class="<?php echo esc_attr( $button_class ); ?>">

                                <?php

                                    # do we have button icon?
                                    if( $show_button_icon == 'yes' ) {

                                        # switch by the icon position
                                        switch( $button_icon_position ) {

                                            # icon before the button text
                                            case 'before':

                                                ?>
                                                <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-button-icon-before-text"></i>
                                                <?php

                                            break;

                                            # above the text, aligned to left
                                            case 'above-left':

                                                ?>
                                                <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-button-icon-above-left"></i>
                                                <?php

                                            break;

                                            # above the text, centered
                                            case 'above-centered':

                                                ?>
                                                <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-button-icon-above-centered"></i>
                                                <?php

                                            break;

                                            # above the text, aligned to right
                                            case 'above-right':

                                                ?>
                                                <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-button-icon-above-right"></i>
                                                <?php

                                            break;
                                        }
                                    }

                                    # do we have the button text set?
                                    if( !empty( $button_text ) ) {

                                        ?>
                                        <span class="ueldo-button-link-text <?php echo esc_attr( $show_button_icon == 'yes' ? 'ueldo-button-link-text-with-icon-'. esc_attr( $button_icon_position ) : '' ); ?>"><?php echo esc_html( $button_text ); ?></span>
                                        <?php
                                    }

                                    # do we have button icon?
                                    if( $show_button_icon == 'yes' ) {

                                        # switch by the icon position
                                        switch( $button_icon_position ) {

                                            # icon after the button text
                                            case 'after':

                                                ?>
                                                <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-button-icon-after-text"></i>
                                                <?php

                                            break;

                                            # under the text, aligned to left
                                            case 'under-left':

                                                ?>
                                                <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-button-icon-under-left"></i>
                                                <?php

                                            break;

                                            # under the text, centered
                                            case 'under-centered':

                                                ?>
                                                <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-button-icon-under-centered"></i>
                                                <?php

                                            break;

                                            # under the text, aligned to right
                                            case 'under-right':

                                                ?>
                                                <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-button-icon-under-right"></i>
                                                <?php

                                            break;
                                        }
                                    }

                                ?>

                            </a>
                            <?php
                        }

                        # do we have text near button, and is it after the button?
                        if( $is_text_near_button == true && $text_near_button_position == 'after' ) {

                            ?>
                            <div class="ueldo-shortcode-button-text-near-button ueldo-shortcode-button-text-near-button-after">

                                <?php

                                    # display the text near button
                                    echo apply_filters( 'the_content', $content );

                                ?>

                            </div>
                            <?php
                        }

                    ?>

                </div>
                <?php
            }
        }

       /**
        *
        * two-line button
        *
        */

        else {

            # do we have button content set?
            $is_button = ueldo_button_content_exists( $button_type, $button_text, $second_line_text, $action_after_click, $button_url, $show_button_icon );

            # do we have text near button set?
            $is_text_near_button = !empty( $content );

            # define button container class
            $button_container_class = 'ueldo-shortcode-two-line-button-container '. esc_attr( $container_visibility_class ) .' '. esc_attr( $class_name );

            # switch the alignment option
            switch( $button_alignment ) {

                case 'inline': $button_container_class .= ' ueldo-shortcode-two-line-button-container-alignment-inline'; break;
                case 'left': $button_container_class .= ' ueldo-shortcode-two-line-button-container-alignment-left'; break;
                case 'center': $button_container_class .= ' ueldo-shortcode-two-line-button-container-alignment-center'; break;
                case 'right': $button_container_class .= ' ueldo-shortcode-two-line-button-container-alignment-right'; break;
            }

            # there's no icon added to button?
            if( $show_button_icon == 'no' ) $button_container_class .= ' ueldo-shortcode-two-line-button-container-no-icon';
            else $button_container_class .= ' ueldo-shortcode-two-line-button-container-icon-visibility-'. esc_attr( $button_icon_visibility == 'on_hover_only' ? 'on-hover-only' : $button_icon_visibility );

            # button text alignment
            $button_container_class .= ' ueldo-shortcode-two-line-button-text-alignment-'. esc_attr( $button_text_alignment );

            ?>
            <div class="<?php echo esc_attr( $button_container_class ); ?>">

                <?php

                    # do we have text near button, and is it before the button?
                    if( $is_text_near_button == true && $text_near_button_position == 'before' ) {

                        ?>
                        <div class="ueldo-shortcode-two-line-button-text-near-button ueldo-shortcode-two-line-button-text-near-button-before">

                            <?php

                                # display the text near button
                                echo apply_filters( 'the_content', $content );

                            ?>

                        </div>
                        <?php
                    }

                    # do we have button content?
                    if( $is_button == true ) {

                        # action is not a standard link?
                        if( $action_after_click != 'link' ) {

                            # switch the action
                            switch( $action_after_click ) {

                                # show / hide flying sidebar
                                case 'show_hide_flying_sidebar':

                                    # update button url array
                                    $button_url = array(
                                        'url' => '#ueldo-show-hide-flying-sidebar',
                                        'title' => esc_html( __( 'Show / hide flying sidebar', 'ueldo' ) ),
                                        'target' => '_self',
                                        'rel' => ''
                                    );

                                    # show / hide side menu
                                    case 'show_hide_side_menu':

                                        # update button url array
                                        $button_url = array(
                                            'url' => '#ueldo-show-hide-side-menu',
                                            'title' => esc_html( __( 'Show / hide side menu', 'ueldo' ) ),
                                            'target' => '_self',
                                            'rel' => ''
                                        );

                                    break;

                                break;
                            }
                        }

                        ?>
                        <a href="<?php echo esc_url( $button_url['url'] ); ?>" target="<?php echo esc_attr( trim( $button_url['target'] ) == '_blank' ? '_blank' : '_self' ); ?>" title="<?php echo esc_attr( $button_url['title'] ); ?>" class="ueldo-shortcode-two-line-button">

                            <?php

                                # do we have button icon?
                                if( $show_button_icon == 'yes' ) {

                                    # switch by the icon position
                                    switch( $button_icon_position ) {

                                        # icon before the button text
                                        case 'before':

                                            ?>
                                            <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-shortcode-two-line-button-icon-before-text"></i>
                                            <?php

                                        break;

                                        # above the text, aligned to left
                                        case 'above-left':

                                            ?>
                                            <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-shortcode-two-line-button-icon-above-left"></i>
                                            <?php

                                        break;

                                        # above the text, centered
                                        case 'above-centered':

                                            ?>
                                            <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-shortcode-two-line-button-icon-above-centered"></i>
                                            <?php

                                        break;

                                        # above the text, aligned to right
                                        case 'above-right':

                                            ?>
                                            <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-shortcode-two-line-button-icon-above-right"></i>
                                            <?php

                                        break;
                                    }
                                }

                            ?>

                            <span class="ueldo-shortcode-two-line-button-content <?php echo esc_attr( $second_line_position == 'top' ? 'ueldo-shortcode-two-line-button-content-reversed' : '' ); ?> <?php echo esc_attr( $show_button_icon == 'yes' ? 'ueldo-shortcode-two-line-button-content-with-icon-'. esc_attr( $button_icon_position ) : '' ); ?>">

                                <?php

                                    # second line at top
                                    if( $second_line_position == 'top' ) {

                                        # do we have the phone number set?
                                        if( !empty( $second_line_text ) ) {

                                            ?>
                                            <span class="ueldo-shortcode-two-line-button-content-title">

                                                <?php

                                                    # phone number
                                                    echo esc_html( $second_line_text );

                                                ?>

                                            </span>
                                            <?php
                                        }

                                        # do we have the button text set?
                                        if( !empty( $button_text ) ) {

                                            ?>
                                            <span class="ueldo-shortcode-two-line-button-content-subtitle">

                                                <?php

                                                    # button text
                                                    echo esc_html( $button_text );

                                                ?>

                                            </span>
                                            <?php

                                        # end of button text
                                        }
                                    }

                                    # second line at bottom
                                    else {

                                        # do we have the button text set?
                                        if( !empty( $button_text ) ) {

                                            ?>
                                            <span class="ueldo-shortcode-two-line-button-content-subtitle">

                                                <?php

                                                    # button text
                                                    echo esc_html( $button_text );

                                                ?>

                                            </span>
                                            <?php

                                        # end of button text
                                        }

                                        # do we have the phone number set?
                                        if( !empty( $second_line_text ) ) {

                                            ?>
                                            <span class="ueldo-shortcode-two-line-button-content-title">

                                                <?php

                                                    # phone number
                                                    echo esc_html( $second_line_text );

                                                ?>

                                            </span>
                                            <?php
                                        }
                                    }

                                ?>

                            </span>

                            <?php

                                # do we have button icon?
                                if( $show_button_icon == 'yes' ) {

                                    # switch by the icon position
                                    switch( $button_icon_position ) {

                                        # icon before the button text
                                        case 'after':

                                            ?>
                                            <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-shortcode-two-line-button-icon-after-text"></i>
                                            <?php

                                        break;

                                        # under the text, aligned to left
                                        case 'under-left':

                                            ?>
                                            <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-shortcode-two-line-button-icon-under-left"></i>
                                            <?php

                                        break;

                                        # under the text, centered
                                        case 'under-centered':

                                            ?>
                                            <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-shortcode-two-line-button-icon-under-centered"></i>
                                            <?php

                                        break;

                                        # under the text, aligned to right
                                        case 'under-right':

                                            ?>
                                            <i class="<?php echo esc_attr( $button_icon ); ?> ueldo-shortcode-two-line-button-icon-under-right"></i>
                                            <?php

                                        break;
                                    }
                                }

                            ?>

                        </a>
                        <?php

                    # end of the button
                    }

                    # do we have text near button, and is it after the button?
                    if( $is_text_near_button == true && $text_near_button_position == 'after' ) {

                        ?>
                        <div class="ueldo-shortcode-two-line-button-text-near-button ueldo-shortcode-two-line-button-text-near-button-after">

                            <?php

                                # display the text near button
                                echo apply_filters( 'the_content', $content );

                            ?>

                        </div>
                        <?php
                    }

                ?>

            </div>
            <?php
        }
    }

    # clear the variables
    unset( $class_name, $button_type, $button_visible_on_devices, $button_text, $second_line_text, $second_line_position, $action_after_click, $button_url, $display_button_on_blog_only, $button_alignment, $show_button_icon, $button_icon_position, $button_icon_visibility, $button_icon_library, $button_icon_fontawesome, $button_icon_openiconic, $button_icon_typicons, $button_icon_entypo, $button_icon_linecons, $button_icon_monosocial, $button_icon_material, $text_near_button_position, $button_icon, $container_visibility_class, $device, $is_button, $is_text_near_button, $button_container_class, $button_class );

?>