<?php

   /**
    *
    * prepare the data for shortcode
    *
    */

    # extract shortcode arguments
    extract( shortcode_atts( array(
       'class_name' => '',
       'layer_title' => esc_html( __( 'Card background', 'ueldo' ) ),
       'layer_type' => 'color',
       'layer_visibility' => 'visible',
       'image' => esc_url( get_template_directory_uri() .'/_assets/_img/image.png' ),
       'image_size' => 'cover',
       'image_repeat' => 'no-repeat',
       'image_position_y' => '50%',
       'image_position_x' => '50%',
       'image_alt' => esc_html( __( 'Image', 'ueldo' ) ),
       'video_id' => 'e452W2Kj-yg',
       'text_content' => esc_html( __( 'Text', 'ueldo' ) ),
       'icon_library' => 'fontawesome',
       'icon_fontawesome' => 'fa fa-long-arrow-right',
       'icon_openiconic' => 'vc_icon_element-icon vc-oi vc-oi-dial',
       'icon_typicons' => 'typcn typcn-adjust-brightness',
       'icon_entypo' => 'entypo-icon entypo-icon-note',
       'icon_linecons' => 'vc_li vc_li-heart',
       'icon_monosocial' => 'vc-mono vc-mono-fivehundredpx',
       'icon_material' => 'vc-material vc-material-account_balance',
       'layer_add_link' => 'no',
       'layer_link_url' => ueldo_get_default_button_url( '#', esc_html( __( 'Contact us', 'ueldo' ) ) )
    ), $atts ));

    # create shortcode class name
    $shortcode_class = 'ueldo-shortcode-card-layer';

    # is this layer visible only on hover?
    if( $layer_visibility == 'on_hover_only' ) $shortcode_class .= ' ueldo-shortcode-card-layer-on-hover-only';

    # is this layer hidden on hover?
    if( $layer_visibility == 'hide_on_hover' ) $shortcode_class .= ' ueldo-shortcode-card-layer-hide-on-hover';

    # do we have to add link to this layer?
    if( $layer_add_link == 'yes' ) {

        # add shortcode class
        $shortcode_class .= ' ueldo-shortcode-card-layer-with-link';

        # get layer link url
        $layer_url = vc_build_link( $layer_link_url );
    }

    # add "card layer container" class if there's no link outside
    else {

        # add shortcode class
        $shortcode_class .= ' ueldo-shortcode-card-layer-container';
    }

    # update shortcode class name with unique class id
    $shortcode_class .= ' '. esc_attr( $class_name );

   /**
    *
    * display element
    *
    */

?>
<div class="ueldo-shortcode-card-layer-holder">

    <?php

        # do we have the link?
        if( $layer_add_link == 'yes' ) {

            ?><a href="<?php echo esc_url( $layer_url['url'] ); ?>" target="<?php echo esc_attr( trim( $layer_url['target'] ) == '_blank' ? '_blank' : '_self' ); ?>" class="ueldo-shortcode-card-layer-container"><?php
        }

    ?>
    <span class="<?php echo esc_attr( $shortcode_class ); ?>" data-layer-type="<?php echo esc_attr( $layer_type ); ?>" data-layer-link-url="<?php echo isset( $layer_url ) && isset( $layer_url['url'] ) ? esc_url( $layer_url['url'] ) : ''; ?>" data-layer-link-target="<?php echo isset( $layer_url ) && isset( $layer_url['target'] ) ? esc_attr( trim( $layer_url['target'] ) == '_blank' ? '_blank' : '_self' ) : ''; ?>">

        <?php

            # what do we need to display?
            switch( $layer_type ) {

                # display background image
                case 'image':

                    # display image
                    ueldo_display_image_for_parent( ueldo_get_image_src( $image ), $image_alt, $image_position_x, $image_position_y, false, $image_size, $image_repeat );

                break;

                # display youtube video
                case 'youtube_video':

                    # do we have video id set?
                    if( !empty( $video_id ) ) {

                        ?>
                        <span id="<?php echo esc_attr( $class_name ); ?>_video" class="ueldo-shortcode-card-layer-youtube-video-container" data-video-id="<?php echo esc_attr( $video_id ); ?>"></span>
                        <?php
                    }

                break;

                # display text
                case 'text':

                   ?>
                   <span class="ueldo-shortcode-card-layer-text"><?php echo esc_html( $text_content ); ?></span>
                   <?php

                break;

                # display icon
                case 'icon':

                    # define the icon variable
                    $icon = '';

                    # switch the icon library
                    switch( $icon_library ) {

                        case 'fontawesome': $icon = $icon_fontawesome; break;
                        case 'openiconic': $icon = $icon_openiconic; break;
                        case 'typicons': $icon = $icon_typicons; break;
                        case 'entypo': $icon = $icon_entypo; break;
                        case 'linecons': $icon = $icon_linecons; break;
                        case 'monosocial': $icon = $icon_monosocial; break;
                        case 'material': $icon = $icon_material; break;
                        default: $icon = ueldo_get_custom_icon( $atts, 'icon_' ); break;
                    }

                    ?>
                    <span class="ueldo-shortcode-card-layer-icon"><i class="<?php echo esc_attr( $icon ); ?>"></i></span>
                    <?php

                break;
            }

        ?>

    </span><?php

        # close link
        if( $layer_add_link == 'yes' ) {

            ?></a><?php
        }

    ?>

</div>
<?php

    # clear the variables
    unset( $class_name, $layer_title, $layer_type, $layer_visibility, $image, $image_size, $image_repeat, $image_position_y, $image_position_x, $image_alt, $video_id, $text_content, $icon_library, $icon_fontawesome, $icon_openiconic, $icon_typicons, $icon_entypo, $icon_linecons, $icon_monosocial, $icon_material, $shortcode_class, $icon );

?>