<?php

   /**
    *
    * prepare the data for shortcode
    *
    */

    # extract shortcode arguments
    extract( shortcode_atts( array(
       'class_name' => '',
       'google_map_id' => '',
       'horizontal_alignment' => esc_attr( ueldo_is_rtl() ? 'right' : 'left' ),
       'custom_colors_enabled' => 'theme_defaults',
       'box_shadow_type' => 'outset'
    ), $atts ));

    # is google map id empty?
    if( empty( $google_map_id ) ) {

        # find first available map
        for( $i = 0; $i < ueldo_get_theme_options_value( 'google-maps', false, 'next-map-id' ); $i++ ) {

            if( ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $i ) .'-title' ) != false ) {

                $google_map_id = $i;
                break;
            }
        }
    }

    # do we have the map?
    if( $google_map_id != 'none' && ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-title' ) != false ) {

        # get map data
        $map_data = array(
            'lat' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-center-lat' ),
            'lng' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-center-lng' ),
            'zoom' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-zoom' ),
            'next-marker-id' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-next-marker-id' ),
            'custom-style' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-custom-style' )
        );

        # predefine shortcode class
        $shortcode_class = 'ueldo-shortcode-google-map ueldo-google-map-container';

        # update shortcode class with horizontal alignment data
        $shortcode_class .= ' ueldo-shortcode-google-map-horizontal-alignment-'. esc_attr( $horizontal_alignment );

        # is inset box shadow?
        if( $custom_colors_enabled != 'theme_defaults' && $box_shadow_type != 'outset' ) $shortcode_class .= ' ueldo-shortcode-google-map-shadow-inset';

        # update shortcode class with unique class id
        $shortcode_class .= ' '. esc_attr( $class_name );

        ?>
        <div class="<?php echo esc_attr( $shortcode_class ); ?>">

            <div class="ueldo-google-map-data" data-lat="<?php echo esc_attr( $map_data['lat'] ); ?>" data-lng="<?php echo esc_attr( $map_data['lng'] ); ?>" data-zoom-level="<?php echo esc_attr( $map_data['zoom'] ); ?>">
            </div>

            <?php

                # do we have map markers added?
                if( $map_data['next-marker-id'] != '1' ) {

                    # walk for each map marker
                    for( $i = 1; $i < $map_data['next-marker-id']; $i++ ) {

                        # marker exists?
                        if( ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-marker-'. esc_attr( $i ) .'-title' ) == false ) continue;

                        # get marker data
                        $marker_data = array(
                            'lat' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-marker-'. esc_attr( $i ) .'-lat' ),
                            'lng' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-marker-'. esc_attr( $i ) .'-lng' ),
                            'use-custom-marker' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-marker-'. esc_attr( $i ) .'-use-custom-marker' ),
                            'custom-icon-library' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon-library' ),
                            'custom-icon' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-icon' ),
                            'custom-marker-image' => ueldo_get_theme_options_value( 'google-maps', false, 'google-map-'. esc_attr( $google_map_id ) .'-markers-marker-'. esc_attr( $i ) .'-custom-marker-image' )
                        );

                        ?>
                        <span class="ueldo-google-map-marker-data" data-lat="<?php echo esc_attr( $marker_data['lat'] ); ?>" data-lng="<?php echo esc_attr( $marker_data['lng'] ); ?>" data-use-custom-marker="<?php echo esc_attr( $marker_data['use-custom-marker'] ); ?>">

                            <?php

                                # what do we need to display?
                                switch( $marker_data['use-custom-marker'] ) {

                                    # can we display custom icon?
                                    case 'yes-icon':

                                        ?>
                                        <span class="ueldo-google-map-marker-content-custom-<?php echo esc_attr( $google_map_id ); ?>-<?php echo esc_attr( esc_attr( $i ) ); ?>">

                                            <i class="<?php echo ueldo_is_correct_icon_font( $marker_data['custom-icon-library'] ) ? esc_attr( $marker_data['custom-icon'] ) : 'fa fa-long-arrow-right'; ?>"></i>

                                        </span>
                                        <?php

                                    break;

                                    # can we display custom image?
                                    case 'yes-image':

                                        ?>
                                        <span class="ueldo-google-map-marker-content-custom-<?php echo esc_attr( $google_map_id ); ?>-<?php echo esc_attr( esc_attr( $i ) ); ?>">

                                            <img src="<?php echo esc_attr( $marker_data['custom-marker-image'] ); ?>" alt="<?php echo esc_html( 'Google map marker', 'ueldo' ); ?>" <?php echo ueldo_retina_ready_attr(); ?> />

                                        </span>
                                        <?php

                                    break;
                                }

                            ?>

                        </span>
                        <?php

                        # clear marker data
                        $marker_data = false;
                    }
                }

                # do we have custom map style added?
                if( !empty( $map_data['custom-style'] ) && json_decode( html_entity_decode( $map_data['custom-style'] ) ) != null ) {

                    ?>
                    <span class="ueldo-google-map-custom-style-data"><?php echo html_entity_decode( $map_data['custom-style'] ); ?></span>
                    <?php
                }

            ?>

        </div>

        <div class="ueldo-clear">
        </div>
        <?php

        # clear map data
        $map_data = false;
    }

    # clear the variables
    unset( $class_name, $google_map_id, $horizontal_alignment, $custom_colors_enabled, $box_shadow_type, $map_data, $shortcode_class, $marker_data );

?>