<?php

   /**
    *
    * prepare the data for shortcode
    *
    */

    # extract shortcode arguments
    extract( shortcode_atts( array(
       'class_name' => '',
       'list_type' => 'icon_list',
       'number_position' => esc_attr( ueldo_is_rtl() ? 'right' : 'left' ),
       'number_element_vertical_alignment' => 'middle',
       'icon_position' => esc_attr( ueldo_is_rtl() ? 'right' : 'left' ),
       'icon_library' => 'fontawesome',
       'icon_fontawesome' => 'fa fa-long-arrow-right',
       'icon_openiconic' => 'vc_icon_element-icon vc-oi vc-oi-dial',
       'icon_typicons' => 'typcn typcn-adjust-brightness',
       'icon_entypo' => 'entypo-icon entypo-icon-note',
       'icon_linecons' => 'vc_li vc_li-heart',
       'icon_monosocial' => 'vc-mono vc-mono-fivehundredpx',
       'icon_material' => 'vc-material vc-material-account_balance',
       'icon_vertical_alignment' => 'middle',
       'list_elements_from' => 'put_manually',
       'menu_id' => 'main-menu',
       'use_underline_decoration_for_links' => 'on_hover_only'
    ), $atts ));

   /**
    *
    * get list elements array
    *
    */

    # predefine list elements array
    $list_elements = array();

    # switch by list elements type
    switch( $list_elements_from ) {

        # custom list
        case 'put_manually':

            # remove paragraphs and "br" and then get list elements
            $temp = explode( "\n", str_replace( '<p>', '', str_replace( '</p>', '', str_replace( '<br />', '', $content ) ) ) );

            # walk for each list element
            foreach( $temp as $list_element ) {

                # is it empty?
                if( empty( $list_element ) ) continue;

                # update list elements array
                $list_elements[] = trim( $list_element );
            }

            # remove temporary variable
            unset( $temp );

        break;

        # menu
        case 'menu':

            # get nav menu items
            $items = wp_get_nav_menu_items( $menu_id );

            # do we have any?
            if( is_array( $items ) ) {

                # walk for each menu item
                foreach( $items as $item ) {

                    # update list elements array
                    $list_elements[] = '<a href="'. esc_url( $item -> url ) .'" target="'. esc_attr( empty( $item -> target ) ? '_self' : $item -> target ) .'" class="menu-item">'. esc_html( $item -> title ) .'</a>';
                }
            }

            # remote temporary variables
            unset( $items, $item );

        break;
    }

    # if there's no any list element added
    if( $list_elements == array() ) return;

   /**
    *
    * get shortcode class
    *
    */

    # shortcode class base
    $shortcode_class = 'ueldo-shortcode-icon-list';

    # update shortcode class with vertical alignment and icon/number position value
    switch( $list_type ) {

        # classes for icon list
        case 'icon_list':

            # update with vertical alignment
            $shortcode_class .= ' ueldo-shortcode-icon-list-vertical-alignment-'. $icon_vertical_alignment;

            # update with icon position
            $shortcode_class .= ' ueldo-shortcode-icon-list-content-'. $icon_position;

        break;

        # classes for number list
        case 'number_list':

            # update with vertical alignment
            $shortcode_class .= ' ueldo-shortcode-icon-list-vertical-alignment-'. $number_element_vertical_alignment;

            # update with number position
            $shortcode_class .= ' ueldo-shortcode-icon-list-content-'. $number_position;

        break;
    }

    # update shortcode class with underline decoration attribute
    switch( $use_underline_decoration_for_links ) {

        case 'yes':

            # update class
            $shortcode_class .= ' ueldo-shortcode-icon-list-underline-decoration-visible';

        break;

        case 'no':

            # update class
            $shortcode_class .= ' ueldo-shortcode-icon-list-underline-decoration-hidden';

        break;

        case 'on_hover_only':

            # update class
            $shortcode_class .= ' ueldo-shortcode-icon-list-underline-decoration-on-hover-only';

        break;
    }

    # update shortcode class with unique class ID
    $shortcode_class .= ' '. esc_attr( $class_name );

   /**
    *
    * display shortcode
    *
    */

?>
<div class="<?php echo esc_attr( $shortcode_class ); ?>">

    <?php

        # what kind of list type do we need to display?
        switch( $list_type ) {

            # display icon list
            case 'icon_list':

                # define the icon variable
                $icon = '';

                # switch the icon library
                switch( $icon_library ) {

                    case 'fontawesome': $icon = $icon_fontawesome; break;
                    case 'openiconic': $icon = $icon_openiconic; break;
                    case 'typicons': $icon = $icon_typicons; break;
                    case 'entypo': $icon = $icon_entypo; break;
                    case 'linecons': $icon = $icon_linecons; break;
                    case 'monosocial': $icon = $icon_monosocial; break;
                    case 'material': $icon = $icon_material; break;
                    default: $icon = ueldo_get_custom_icon( $atts, 'icon_' ); break;
                }

                # display list elements
                foreach( $list_elements as $list_element ) {

                    ?>
                    <div class="ueldo-shortcode-icon-list-single-element">

                        <?php

                            # icon position on left side
                            if( $icon_position == esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) ) {

                                ?>
                                <div class="ueldo-shortcode-icon-list-single-element-icon">

                                    <span class="ueldo-shortcode-icon-list-single-element-icon-middle-helper"></span>
                                    <i class="<?php echo esc_html( $icon ); ?>"></i>

                                </div>
                                <?php
                            }

                        ?>

                        <div class="ueldo-shortcode-icon-list-single-element-content">

                            <?php

                                # display list element content
                                echo apply_filters( 'the_content', $list_element );

                            ?>

                        </div>

                        <?php

                            # icon position on right side
                            if( $icon_position == esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) ) {

                                ?>
                                <div class="ueldo-shortcode-icon-list-single-element-icon">

                                    <span class="ueldo-shortcode-icon-list-single-element-icon-middle-helper"></span>
                                    <i class="<?php echo esc_html( $icon ); ?>"></i>

                                </div>
                                <?php
                            }

                        ?>

                    </div>
                    <?php
                }

            break;

            # display number list
            case 'number_list':

                # list elements counter
                $list_elements_counter = 1;

                # display list elements
                foreach( $list_elements as $list_element ) {

                    ?>
                    <div class="ueldo-shortcode-icon-list-single-element">

                        <?php

                            # number position on left side
                            if( $number_position == esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) ) {

                                ?>
                                <div class="ueldo-shortcode-icon-list-single-element-number">

                                    <span class="ueldo-shortcode-icon-list-single-element-number-middle-helper"></span>
                                    <span class="ueldo-shortcode-icon-list-single-element-number-value"><?php echo esc_attr( $list_elements_counter ); ?></span>

                                </div>
                                <?php
                            }

                        ?>

                        <div class="ueldo-shortcode-icon-list-single-element-content">

                            <?php

                                # display list element content
                                echo apply_filters( 'the_content', $list_element );

                            ?>

                        </div>

                        <?php

                            # number position on right side
                            if( $number_position == esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) ) {

                                ?>
                                <div class="ueldo-shortcode-icon-list-single-element-number">

                                    <span class="ueldo-shortcode-icon-list-single-element-number-middle-helper"></span>
                                    <span class="ueldo-shortcode-icon-list-single-element-number-value"><?php echo esc_attr( $list_elements_counter ); ?></span>

                                </div>
                                <?php
                            }

                        ?>

                    </div>
                    <?php

                    # update list elements counter
                    $list_elements_counter++;
                }

            break;

            # display simple list
            case 'just_list':

                # display list elements
                foreach( $list_elements as $list_element ) {

                    ?>
                    <div class="ueldo-shortcode-icon-list-single-element">

                        <div class="ueldo-shortcode-icon-list-single-element-content">

                            <?php

                                # display list element content
                                echo apply_filters( 'the_content', $list_element );

                            ?>

                        </div>

                    </div>
                    <?php
                }

            break;
        }

    ?>

</div>
<?php

    # clear the variables
    unset( $class_name, $list_type, $number_position, $number_element_vertical_alignment, $icon_position, $icon_library, $icon_fontawesome, $icon_openiconic, $icon_typicons, $icon_entypo, $icon_linecons, $icon_monosocial, $icon_material, $icon_vertical_alignment, $temp, $list_elements, $list_element, $shortcode_class, $icon, $list_elements_counter );

?>