<?php

   /**
    *
    * prepare the data for shortcode
    *
    */

    # extract shortcode arguments
    extract( shortcode_atts( array(
       'class_name' => '',
       'horizontal_alignment' => esc_attr( ueldo_is_rtl() ? 'right' : 'left' ),
       'image' => esc_url( get_template_directory_uri() .'/_assets/_img/image.png' ),
       'image_position_y' => '50%',
       'image_position_x' => '50%',
       'image_alt' => esc_html( __( 'Image', 'ueldo' ) ),
       'additional' => 'none',
       'gallery_slug' => esc_html( __( 'product-gallery', 'ueldo' ) ),
       'gallery_image_url' => '',
       'gallery_image_caption' => '',
       'video_url' => '',
       'video_title' => esc_html( __( 'Watch the video!', 'ueldo' ) )
    ), $atts ));

    # predefine shortcode class
    $shortcode_class = 'ueldo-shortcode-image';

    # update shortcode class with horizontal alignment setting
    $shortcode_class .= ' ueldo-shortcode-image-horizontal-alignment-'. esc_attr( $horizontal_alignment );

    # if we need to display image as gallery element
    if( $additional == 'gallery_image' ) {

        # update shortcode class
        $shortcode_class .= ' ueldo-shortcode-image-gallery-'. esc_attr( sanitize_title( $gallery_slug ) );
    }

    # update shortcode class with unique class ID
    $shortcode_class .= ' '. esc_attr( $class_name );

   /**
    *
    * display shortcode
    *
    */

?>
<div class="<?php echo esc_attr( $shortcode_class ); ?>">

    <?php

        # display image
        ueldo_display_image_for_parent( ueldo_get_image_src( $image ), $image_alt, $image_position_x, $image_position_y );

        # do we have any additional element to show?
        if( $additional != 'none' ) {

            # display additional element
            switch( $additional ) {

                # display video button
                case 'video_button':

                    # do we have a video url?
                    if( !empty( $video_url ) ) {

                        ?>
                        <div class="ueldo-play-video-button" data-video-url="<?php echo esc_url( $video_url ); ?>">

                            <div class="ueldo-play-video-button-middle">

                                <div class="ueldo-play-video-button-icon"><i class="fa fa-play"></i></div>
                                <?php if( !empty( $video_title ) ) { ?><div class="ueldo-play-video-button-title"><?php echo esc_attr( $video_title ); ?></div><?php } ?>

                            </div>

                        </div>
                        <?php
                    }

                break;

                # display gallery image layer
                case 'gallery_image':

                    # get image link
                    $gallery_image_url = vc_build_link( $gallery_image_url );

                    ?>
                    <div class="ueldo-image-caption">

                        <div class="ueldo-image-caption-middle">

                            <?php

                                # do we have gallery image url set?
                                if( !empty( $gallery_image_url['url'] ) || !empty( $gallery_image_url['title'] ) ) {

                                    ?>
                                    <a href="<?php echo esc_url( $gallery_image_url['url'] ); ?>" title="<?php echo esc_attr( $gallery_image_url['title'] ); ?>" target="<?php echo esc_attr( trim( $gallery_image_url['target'] ) == '_blank' ? '_blank' : '_self' ); ?>" class="ueldo-image-caption-icon ueldo-image-caption-icon-link animated ueldo-animated-fast ueldoFadeInDownSuperSmall"><i class="fa fa-link"></i></a>
                                    <?php
                                }

                            ?>

                            <div class="ueldo-image-caption-icon ueldo-image-caption-icon-show animated ueldo-animated-fast ueldoFadeInDownSuperSmall" title="<?php echo esc_attr( $gallery_image_caption ); ?>" data-mfp-src="<?php echo esc_url( ueldo_get_image_src( $image ) ); ?>"><i class="fa fa-search"></i></div>

                        </div>

                    </div>
                    <?php

                break;

                # display link image layer
                case 'as_link':

                    # get image link
                    $gallery_image_url = vc_build_link( $gallery_image_url );

                    # do we have gallery image url set?
                    if( !empty( $gallery_image_url['url'] ) || !empty( $gallery_image_url['title'] ) ) {

                        ?>
                        <div class="ueldo-image-caption">

                            <div class="ueldo-image-caption-middle">

                                <a href="<?php echo esc_url( $gallery_image_url['url'] ); ?>" title="<?php echo esc_attr( $gallery_image_url['title'] ); ?>" target="<?php echo esc_attr( trim( $gallery_image_url['target'] ) == '_blank' ? '_blank' : '_self' ); ?>" class="ueldo-image-caption-icon ueldo-image-caption-icon-link animated ueldo-animated-fast ueldoFadeInDownSuperSmall"><i class="fa fa-link"></i></a>

                            </div>

                        </div>
                        <?php
                    }

                break;
            }
        }

    ?>

</div>

<div class="ueldo-clear">
</div>
<?php

    # clear the variables
    unset( $class_name, $horizontal_alignment, $image, $image_position_y, $image_position_x, $image_alt, $additional, $gallery_slug, $gallery_image_url, $gallery_image_caption, $video_url, $video_title, $shortcode_class, $gallery_image_url );

?>