<?php

   /**
    *
    * prepare the data for shortcode
    *
    */

    # extract shortcode arguments
    extract( shortcode_atts( array(
       'class_name' => '',
       'visible_on_devices' => 'large,medium',
       'horizontal_alignment' => 'inline'
    ), $atts ));

   /**
    *
    * visibility on devices
    *
    */

    # explode devices list
    $visible_on_devices = !empty( $visible_on_devices ) ? explode( ',', $visible_on_devices ) : array();

    # prepare container visibility class names
    $container_visibility_class = '';

    # walk for each visible devices
    foreach( array( 'large', 'medium', 'small', 'extra-small' ) as $device ) {

        # update container class name
        if( !in_array( $device, $visible_on_devices, true ) ) $container_visibility_class .= ' ueldo-shortcode-languages-switcher-hidden-on-'. esc_attr( $device ) .'-devices';
    }

   /**
    *
    * element settings
    *
    */

    # globals
    global $post, $ueldo_cache_option;

    # check if is multilingual
    $is_multilingual = ueldo_is_multilingual();

    # is is not a multilingual website?
    if( $is_multilingual == false ) return;

    # current language details
    $current_language = array(
        'key' => '',
        'name' => ''
    );

    # get current language details
    switch( $is_multilingual ) {

        # wpml
        case 'wpml':

            # language key
            $current_language['key'] = ICL_LANGUAGE_CODE;

            # language name
            $current_language['name'] = ICL_LANGUAGE_NAME;

        break;

        # polylang
        case 'polylang':

            # do we have necessary functions?
            if( function_exists( 'pll_current_language' ) ) {

                # language key
                $current_language['key'] = pll_current_language( 'locale' );

                # language name
                $current_language['name'] = pll_current_language( 'name' );
            }

        break;
    }

?>
<div class="ueldo-shortcode-languages-switcher-container ueldo-shortcode-languages-switcher-container-horizontal-alignment-<?php echo esc_attr( $horizontal_alignment ); ?>">

    <div class="ueldo-shortcode-languages-switcher <?php echo esc_attr( $container_visibility_class ); ?> <?php echo esc_attr( $class_name ); ?>">

        <span class="ueldo-shortcode-languages-switcher-current-language" data-current-language-key="<?php echo esc_attr( $current_language['key'] ); ?>">

            <?php echo esc_html( $current_language['name'] ); ?>
            <i class="fa fa-caret-down"></i>

        </span>

        <ul class="ueldo-shortcode-languages-switcher-list">

            <?php

                # wpml
                if( $is_multilingual == 'wpml' && function_exists( 'icl_get_languages' ) ) {

                    # try to get wpml settings
                    $wpml_settings = $ueldo_cache_option -> get_option( 'icl_sitepress_settings' );

                    # skip missing languages?
                    $skip_missing = 0;

                    # do we have wpml settings?
                    if( $wpml_settings != false && $wpml_settings != null && is_array( $wpml_settings ) && isset( $wpml_settings['icl_lso_link_empty'] ) ) {

                        # update "skip missing" variable
                        $skip_missing = $wpml_settings['icl_lso_link_empty'] == 1 ? 0 : 1;
                    }

                    # get the all languages array
                    $languages = icl_get_languages( 'skip_missing='. esc_attr( $skip_missing ) );

                    # walk for each language
                    foreach( $languages as $language ) {

                        ?>
                        <li><a href="<?php echo esc_url( $language['url'] ); ?>"><?php echo esc_html( $language['native_name'] ); ?></a></li>
                        <?php
                    }
                }

                # polylang
                else if( $is_multilingual == 'polylang' && function_exists( 'pll_the_languages' ) ) {

                    # get the languages list
                    pll_the_languages( ( $post == null || $post == false ) ? array() : array( 'post_id' => $post -> ID ) );
                }

            ?>

        </ul>

    </div>

</div>
<?php

    # clear the variables
    unset( $class_name, $visible_on_devices, $horizontal_alignment, $visible_on_devices, $device, $container_visibility_class, $is_multilingual, $current_language, $wpml_settings, $skip_missing, $languages, $language );

?>