<?php

   /**
    *
    * prepare the data for shortcode
    *
    */

    # extract shortcode arguments
    extract( shortcode_atts( array(
       'class_name' => '',
       'page_or_post' => 'post',
       'page_id' => '',
       'display_selected_post' => 'no',
       'post_id' => '',
       'choose_by_cat_or_tag' => 'by_category',
       'category_id' => '',
       'tag_id' => '',
       'post_no' => 'latest',
       'heading_type' => 'h5',
       'read_more_text' => esc_html( __( 'Read more', 'ueldo' ) ),
       'display_as_box' => 'yes',
       'box_style' => '01',
       'display_as_card' => 'yes',
       'display_post_page_content_excerpt' => 'yes',
       'display_post_page_featured_image' => 'yes',
       'featured_image_position' => 'under-title'
    ), $atts ));

   /**
    *
    * display shortcode
    *
    */

?>
<div class="ueldo-shortcode-post-page-box <?php echo esc_attr( $class_name ); ?>">

    <?php

        # define element id
        $element_id = $page_or_post == 'page' ? $page_id : false;

        # find post id
        if( $element_id == false ) {

            # display selected post?
            if( $display_selected_post == 'yes' ) $element_id = $post_id;
            else {

                # calculate offset value
                $offset = $post_no == 'latest' ? '0' : str_replace( 'latest_minus_', '', esc_attr( $post_no ) );

                # switch by post group type
                switch( $choose_by_cat_or_tag ) {

                    # get from all published posts
                    case 'no':

                        # get posts
                        $result = get_posts( array(
                            'posts_per_page' => '1',
                            'offset' => esc_attr( $offset )
                        ));

                        # do we have the result found?
                        if( is_array( $result ) && isset( $result[0] ) && isset( $result[0] -> ID ) ) {

                            # update element id
                            $element_id = $result[0] -> ID;
                        }

                    break;

                    # choose post by category
                    case 'by_category':

                        # get posts from selected category
                        $result = get_posts( array(
                            'posts_per_page' => '1',
                            'offset' => esc_attr( $offset ),
                            'category' => esc_attr( $category_id )
                        ));

                        # do we have the result found?
                        if( is_array( $result ) && isset( $result[0] ) && isset( $result[0] -> ID ) ) {

                            # update element id
                            $element_id = $result[0] -> ID;
                        }

                    break;

                    # choose post by tag
                    case 'by_tag':

                        # get tag data by tag id
                        $tag = get_tag( $tag_id );

                        # do we have the tag?
                        if( $tag != null && isset( $tag -> slug ) ) {

                            # try to find the posts added with tag
                            $tag_query = new WP_Query( 'posts_per_page=1&offset='. esc_attr( $offset ) .'&tag='. esc_attr( $tag -> slug ) );

                            # do we have the posts?
                            if( $tag_query -> have_posts() ) {

                                # walk foreach posts
                                while( $tag_query -> have_posts() ) {

                                    # get the post
                                    $tag_query -> the_post();

                                    # update element id
                                    $element_id = get_the_ID();
                                }
                            }

                            # restore original post data
                            wp_reset_postdata();

                            # remove temporary variable
                            unset( $tag, $tag_query );
                        }

                    break;
                }

                # remove temporary variable
                unset( $result );
            }
        }

        # do we have element id found?
        if( $element_id != false ) {

            # get the post data
            $post = get_post( $element_id );

            # do we have the post?
            if( $post != null && isset( $post -> ID ) ) {

                # setup postdata
                setup_postdata( $GLOBALS['post'] =& $post );

                # do we have to display post as post box?
                if( $display_as_box == 'yes' ) {

                    # display single short post box
                    ueldo_display_short_post_box( $box_style, $heading_type );
                }

                # display post (not as box)
                else {

                    # display post as card?
                    if( $display_as_card == 'yes' ) {

                        ?>
                        <div class="ueldo-shortcode-post-page-box-card">
                        <?php
                    }

                    # featured image under post / page title or there's no featured image?
                    if( $display_post_page_featured_image == 'no' || ( $display_post_page_featured_image == 'yes' && $featured_image_position == 'under-title' ) ) {

                        ?>
                        <<?php echo esc_attr( $heading_type ); ?>><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></<?php echo esc_attr( $heading_type ); ?>>
                        <?php
                    }

                    # can we display featured image?
                    if( $display_post_page_featured_image == 'yes' ) {

                        # get featured image
                        $ueldo_featured_image = ueldo_get_featured_image( get_the_ID(), get_the_title() );

                        # do we have featured image?
                        if( $ueldo_featured_image != '' ) {

                            ?>
                            <div class="ueldo-post-page-featured-image">

                                <?php

                                    # display image
                                    ueldo_display_image_for_parent( $ueldo_featured_image['src'], $ueldo_featured_image['alt'] );

                                ?>

                            </div>
                            <?php

                        # end of featured image container
                        }

                    # end of featured image
                    }

                    # featured image above post / page title
                    if( $display_post_page_featured_image == 'yes' && $featured_image_position == 'above-title' ) {

                        ?>
                        <<?php echo esc_attr( $heading_type ); ?>><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></<?php echo esc_attr( $heading_type ); ?>>
                        <?php
                    }

                    # can we display content excerpt?
                    if( $display_post_page_content_excerpt == 'yes' ) {

                        # post content (not for vc page)
                        if( !ueldo_is_vc_page( get_the_content() ) ) {

                            # get custom page excerpt
                            $ueldo_custom_page_excerpt = ueldo_get_single_page_custom_excerpt( get_the_ID() );

                            # do we have the excerpt set?
                            if( !empty( $ueldo_custom_page_excerpt ) ) echo apply_filters( 'the_content', $ueldo_custom_page_excerpt );
                            else {

                                # display the content
                                the_excerpt( '' );
                            }

                            # remove temporary variable
                            unset( $ueldo_custom_page_excerpt );
                        }

                        # post content for vc page
                        else {

                            # display page excerpt
                            echo apply_filters( 'the_content', ueldo_get_single_page_custom_excerpt( get_the_ID() ) );
                        }
                    }

                    # if the post is required, don't display "read more" button
                    if( strpos( implode( ' ', get_post_class() ), 'post-password-required' ) == false ) {

                        ?>
                        <p><a href="<?php the_permalink(); ?>"><?php echo esc_html( $read_more_text ); ?></a></p>
                        <?php
                    }

                    # close card
                    if( $display_as_card == 'yes' ) {

                        ?>
                        </div>
                        <?php
                    }
                }
            }

            # restore original post data
            wp_reset_postdata();
        }

    ?>

</div>
<?php

    # clear the variables
    unset( $class_name, $page_or_post, $page_id, $display_selected_post, $post_id, $choose_by_cat_or_tag, $category_id, $tag_id, $post_no, $read_more_text, $display_as_box, $box_style, $display_as_card, $display_post_page_content_excerpt, $display_post_page_featured_image, $featured_image_position, $element_id, $offset, $result, $tag, $tag_query, $ueldo_featured_image, $ueldo_custom_page_excerpt );

?>