<?php

   /**
    *
    * prepare the data for shortcode
    *
    */

    # extract shortcode arguments
    extract( shortcode_atts( array(
       'class_name' => ''
    ), $atts ));

    # unique tabs slug
    $group_slugs = new ueldo_vc_shortcode_unique_tabs_slugs();

    # clear slugs array
    $group_slugs -> clear_tabs_slugs_array();

?>
<div class="ueldo-shortcode-pricing-list <?php echo esc_attr( $class_name ); ?>">

    <?php

        # divide content to shortcodes
        $shortcodes = ueldo_vc_find_custom_shortcodes( $content );

        # define groups array
        $groups = array();

        # global flag - is any icon set?
        $is_any_icon = false;

        # global flag - first group slug
        $first_group_slug = false;

        # walk for each pricing list group
        foreach( $shortcodes as $shortcode ) {

            # is it pricing list group?
            if( $shortcode['key'] != 'ueldo_shortcode_pricing_list_group' ) continue;

            # is shortcode icon set?
            $is_icon = isset( $shortcode['atts']['display_group_icon'] ) && $shortcode['atts']['display_group_icon'] == 'no' ? false : true;

            # find shortcode icon if is set
            if( $is_icon ) {

                # update global flag
                $is_any_icon = true;

                # define icon
                $icon = '';

                # get icon library
                $icon_library = isset( $shortcode['atts']['icon_library'] ) ? $shortcode['atts']['icon_library'] : 'fontawesome';

                # get icon depends on icon library
                switch( $icon_library ) {

                    case 'fontawesome': $icon = isset( $shortcode['atts']['icon_fontawesome'] ) ? $shortcode['atts']['icon_fontawesome'] : 'fa fa-long-arrow-right'; break;
                    case 'openiconic': $icon = isset( $shortcode['atts']['icon_openiconic'] ) ? $shortcode['atts']['icon_openiconic'] : 'vc_icon_element-icon vc-oi vc-oi-dial'; break;
                    case 'typicons': $icon = isset( $shortcode['atts']['icon_typicons'] ) ? $shortcode['atts']['icon_typicons'] : 'typcn typcn-adjust-brightness'; break;
                    case 'entypo': $icon = isset( $shortcode['atts']['icon_entypo'] ) ? $shortcode['atts']['icon_entypo'] : 'entypo-icon entypo-icon-note'; break;
                    case 'linecons': $icon = isset( $shortcode['atts']['icon_linecons'] ) ? $shortcode['atts']['icon_linecons'] : 'vc_li vc_li-heart'; break;
                    case 'monosocial': $icon = isset( $shortcode['atts']['icon_monosocial'] ) ? $shortcode['atts']['icon_monosocial'] : 'vc-mono vc-mono-fivehundredpx'; break;
                    case 'material': $icon = isset( $shortcode['atts']['icon_material'] ) ? $shortcode['atts']['icon_material'] : 'vc-material vc-material-account_balance'; break;
                    default: $icon = ueldo_get_custom_icon( $shortcode['atts'], 'icon_' ); break;
                }
            }

            # update groups array
            $group = array(
                'name' => isset( $shortcode['atts']['title'] ) ? esc_html( $shortcode['atts']['title'] ) : esc_html( __( 'Our offer', 'ueldo' ) ),
                'slug' => '',
                'description' => isset( $shortcode['atts']['description'] ) ? esc_html( $shortcode['atts']['description'] ) : 'Maecenas ut ornare eros. Cras vitae nibh eget mauris placerat pellentesque.',
                'icon' => $is_icon ? $icon : '',
                'buttons' => array(),
                'attributes' => array()
            );

            # update slug value
            $group['slug'] = $group_slugs -> get_tab_slug( $group['name'] );

            # update first group slug global flag
            if( $first_group_slug == false ) $first_group_slug = $group['slug'];

            # find attributes and buttons
            $shortcode_shortcodes = ueldo_vc_find_custom_shortcodes( $shortcode['shortcode-full'] );

            # walk for each shortcode shortcodes
            foreach( $shortcode_shortcodes as $shortcode_shortcode ) {

                # attribute or button?
                switch( $shortcode_shortcode['key'] ) {

                    case 'ueldo_shortcode_pricing_list_attribute': $group['attributes'][] = $shortcode_shortcode['shortcode-full']; break;
                    case 'ueldo_shortcode_button': $group['buttons'][] = $shortcode_shortcode['shortcode-full']; break;
                }
            }

            # update groups array
            $groups[] = $group;
            $group = false;
        }

        # if is any icon set
        if( $is_any_icon ) {

            ?>
            <div class="ueldo-shortcode-pricing-list-background-icons">

                <?php

                    # display icons
                    foreach( $groups as $group ) {

                        # is icon set for this group?
                        if( $group['icon'] != '' ) {

                            ?>
                            <i class="<?php echo esc_attr( $group['icon'] ); ?> ueldo-shortcode-pricing-list-background-icon" data-group-slug="<?php echo esc_attr( $group['slug'] ); ?>" data-visible="<?php echo esc_attr( $group['slug'] == $first_group_slug ? 'yes' : 'no' ); ?>"></i>
                            <?php
                        }
                    }

                ?>

            </div>
            <?php
        }

    ?>

    <div class="ueldo-shortcode-pricing-list-groups-selector">

        <?php

            # do we have more than one group?
            if( count( $groups ) > 1 ) {

                ?>
                <select name="ueldo-shortcode-pricing-list-group-selector">

                    <?php

                        # display option for each group
                        foreach( $groups as $group ) {

                            ?>
                            <option value="<?php echo esc_attr( $group['slug'] ); ?>" <?php selected( $first_group_slug, $group['slug'] ); ?>><?php echo esc_html( $group['name'] ); ?></option>
                            <?php
                        }

                    ?>

                </select>
                <?php
            }

        ?>
        <div class="ueldo-shortcode-pricing-list-groups-selector-descriptions">

            <?php

                # display content for each group
                foreach( $groups as $group ) {

                    ?>
                    <div class="ueldo-shortcode-pricing-list-groups-selector-descriptions-single-description" data-group-slug="<?php echo esc_attr( $group['slug'] ); ?>" data-visible="<?php echo esc_attr( $group['slug'] == $first_group_slug ? 'yes' : 'no' ); ?>">

                        <?php

                            # do we have group description?
                            if( !empty( $group['description'] ) ) echo apply_filters( 'the_content', $group['description'] );

                            # do we have buttons?
                            if( $group['buttons'] != array() ) {

                                # display all buttons for this group
                                foreach( $group['buttons'] as $button ) {

                                    # display button
                                    echo apply_filters( 'the_content', $button );
                                }
                            }

                        ?>

                    </div>
                    <?php
                }

            ?>

        </div>

    </div>

    <div class="ueldo-shortcode-pricing-list-groups-content">

        <?php

            # display all groups attributes
            foreach( $groups as $group ) {

                ?>
                <div class="ueldo-shortcode-pricing-list-groups-content-group-attributes" data-group-slug="<?php echo esc_attr( $group['slug'] ); ?>" data-visible="<?php echo esc_attr( $group['slug'] == $first_group_slug ? 'yes' : 'no' ); ?>">

                    <?php

                        # attributes counter
                        $attributes_counter = 0;

                        # display attributes
                        foreach( $group['attributes'] as $attribute ) {

                            # is it first attribute?
                            if( $attributes_counter == 0 ) {

                                ?>
                                <ul class="ueldo-shortcode-pricing-list-groups-content-group-attributes-list ueldo-shortcode-pricing-list-groups-content-group-attributes-list-left">
                                <?php
                            }

                            # is it half way attribute?
                            else if( $attributes_counter == ceil( count( $group['attributes'] ) / 2 ) ) {

                                ?>
                                </ul>
                                <ul class="ueldo-shortcode-pricing-list-groups-content-group-attributes-list ueldo-shortcode-pricing-list-groups-content-group-attributes-list-right">
                                <?php
                            }

                            # display attribute
                            echo apply_filters( 'the_content', $attribute );

                            # update attributes counter
                            $attributes_counter++;
                        }

                    ?>

                    </ul>

                </div>
                <?php
            }

        ?>

    </div>

</div>
<?php

    # clear the variables
    unset( $class_name, $group_slugs, $shortcodes, $shortcode, $groups, $group, $is_any_icon, $first_group_slug, $is_icon, $icon, $icon_library, $shortcode_shortcodes, $shortcode_shortcode, $attributes_counter, $attribute );

?>