<?php

   /**
    *
    * prepare the data for shortcode
    *
    */

    # extract shortcode arguments
    extract( shortcode_atts( array(
       'class_name' => '',
       'pricing_table_style' => '01',
       'content_alignment' => esc_attr( ueldo_is_rtl() ? 'right' : 'left' ),
       'horizontal_alignment' => esc_attr( ueldo_is_rtl() ? 'right' : 'left' ),
       'title' => esc_html( __( 'Regular', 'ueldo' ) ),
       'price_value' => esc_html( __( '25', 'ueldo' ) ),
       'price_currency' => esc_html( __( '$', 'ueldo' ) ),
       'price_currency_side' => esc_attr( ueldo_is_rtl() ? 'right' : 'left' ),
       'price_additional_element_text' => esc_html( __( '/ mo', 'ueldo' ) ),
       'show_ribbon' => 'no',
       'ribbon_position' => esc_attr( ueldo_is_rtl() ? 'right' : 'left' ),
       'ribbon_text' => esc_html( __( 'Popular', 'ueldo' ) ),
       'display_level_icons' => 'yes',
       'icon_library' => 'fontawesome',
       'icon_fontawesome' => 'fa fa-long-arrow-right',
       'icon_openiconic' => 'vc_icon_element-icon vc-oi vc-oi-dial',
       'icon_typicons' => 'typcn typcn-adjust-brightness',
       'icon_entypo' => 'entypo-icon entypo-icon-note',
       'icon_linecons' => 'vc_li vc_li-heart',
       'icon_monosocial' => 'vc-mono vc-mono-fivehundredpx',
       'icon_material' => 'vc-material vc-material-account_balance',
       'level_icons_repeat_number' => '1',
       'use_background_image' => 'no',
       'image' => esc_url( get_template_directory_uri() .'/_assets/_img/image.png' ),
       'image_position_y' => '50%',
       'image_position_x' => '50%',
       'image_alt' => esc_html( __( 'Image', 'ueldo' ) ),
       'custom_colors_enabled' => 'theme_defaults'
    ), $atts ));

    # prepare shortcode class
    $shortcode_class = 'ueldo-shortcode-pricing-table';

    # add pricing table style id to class name
    $shortcode_class .= ' ueldo-shortcode-pricing-table-style-'. esc_attr( $pricing_table_style );

    # add content alignment attribute to class name
    $shortcode_class .= ' ueldo-shortcode-pricing-table-content-alignment-'. esc_attr( $content_alignment );

    # add horizontal alignment attribute to class name
    $shortcode_class .= ' ueldo-shortcode-pricing-table-horizontal-alignment-'. esc_attr( $horizontal_alignment );

    # update shortcode class with unique class name
    $shortcode_class .= ' '. esc_attr( $class_name );

    # divide content to shortcodes
    $content_divided = !empty( $content ) ? ueldo_vc_find_custom_shortcodes( $content ) : false;

   /**
    *
    * display element
    *
    */

?>
<div class="<?php echo esc_attr( $shortcode_class ); ?>">

    <?php

        # ribbon
        if( $show_ribbon == 'yes' && !empty( $ribbon_text ) ) {

            ?>
            <div class="ueldo-shortcode-pricing-table-ribbon-container">

                <div class="ueldo-shortcode-pricing-table-ribbon ueldo-shortcode-pricing-table-ribbon-<?php echo esc_attr( $ribbon_position ); ?>"><?php echo esc_html( $ribbon_text ); ?></div>

            </div>
            <?php
        }

        # check if any button exists
        $button_exists = false;
        if( $content_divided !== false && is_array( $content_divided ) ) {

            # do we have any button added?
            for( $i = 0; $i < count( $content_divided ); $i++ ) {

                # is it single attribute element?
                if( $content_divided[$i]['key'] == 'ueldo_shortcode_button' ) {

                    $button_exists = true;
                    break;
                }
            }
        }

        # display pricing table content, depended on style
        switch( $pricing_table_style ) {

            case '01':

                # do we have content set?
                if( $content_divided !== false && is_array( $content_divided ) ) {

                    # attributes list opened flag
                    $attributes_list_opened = false;

                    # walk for each shortcode
                    for( $i = 0; $i < count( $content_divided ); $i++ ) {

                        # is it single attribute element?
                        if( $content_divided[$i]['key'] == 'ueldo_shortcode_pricing_table_attribute' ) {

                            # attributes list was not opened yet?
                            if( $attributes_list_opened == false ) {

                                # update flag
                                $attributes_list_opened = true;

                                ?>
                                <ul class="ueldo-shortcode-pricing-table-attributes">
                                <?php
                            }

                            # display attribute
                            echo apply_filters( 'the_content', $content_divided[$i]['shortcode-full'] );
                        }
                    }

                    # close attributes list
                    if( $attributes_list_opened == true ) {

                        # update flag
                        $attributes_list_opened = false;

                        ?>
                        </ul>
                        <?php
                    }
                }

                # can we display pricing table content?
                if( !empty( $title ) || ( !empty( $price_currency ) || $price_value != '' || !empty( $price_additional_element_text ) ) || $button_exists ) {

                    ?>
                    <div class="ueldo-shortcode-pricing-table-content">

                        <?php

                            # do we have table title?
                            if( !empty( $title ) ) {

                                ?>
                                <h6 class="ueldo-shortcode-pricing-table-content-title"><?php echo esc_html( $title ); ?></h6>
                                <?php
                            }

                            # do we have the price set?
                            if( !empty( $price_currency ) || $price_value != '' || !empty( $price_additional_element_text ) ) {

                                ?>
                                <span class="ueldo-shortcode-pricing-table-content-price">

                                    <?php if( !empty( $price_currency ) && $price_currency_side == 'left' ) { ?><span class="ueldo-shortcode-pricing-table-content-price-currency ueldo-shortcode-pricing-table-content-price-currency-left"><?php echo esc_html( $price_currency ); ?></span><?php } ?>
                                    <?php if( $price_value != '' ) { ?><span class="ueldo-shortcode-pricing-table-content-price-value"><?php echo esc_html( $price_value ); ?></span><?php } ?>
                                    <?php if( !empty( $price_currency ) && $price_currency_side == 'right' ) { ?><span class="ueldo-shortcode-pricing-table-content-price-currency ueldo-shortcode-pricing-table-content-price-currency-right"><?php echo esc_html( $price_currency ); ?></span><?php } ?>
                                    <?php if( !empty( $price_additional_element_text ) ) { ?><span class="ueldo-shortcode-pricing-table-content-price-after-value"><?php echo esc_html( $price_additional_element_text ); ?></span><?php } ?>

                                </span>
                                <?php
                            }

                            # do we have any buttons added in content?
                            if( $content_divided !== false && is_array( $content_divided ) ) {

                                # do we have any button added?
                                for( $i = 0; $i < count( $content_divided ); $i++ ) {

                                    # is it single attribute element?
                                    if( $content_divided[$i]['key'] == 'ueldo_shortcode_button' ) {

                                        # display button
                                        echo apply_filters( 'the_content', $content_divided[$i]['shortcode-full'] );
                                    }
                                }
                            }

                        ?>

                    </div>
                    <?php
               }

            break;

            case '02':

                ?>
                <div class="ueldo-shortcode-pricing-table-heading">

                    <?php

                        # do we have level icons set?
                        if( $display_level_icons == 'yes' ) {

                            ?>
                            <div class="ueldo-shortcode-pricing-table-level-icons">

                                <?php

                                    # define the icon variable
                                    $icon = '';

                                    # switch the icon library
                                    switch( $icon_library ) {

                                        case 'fontawesome': $icon = $icon_fontawesome; break;
                                        case 'openiconic': $icon = $icon_openiconic; break;
                                        case 'typicons': $icon = $icon_typicons; break;
                                        case 'entypo': $icon = $icon_entypo; break;
                                        case 'linecons': $icon = $icon_linecons; break;
                                        case 'monosocial': $icon = $icon_monosocial; break;
                                        case 'material': $icon = $icon_material; break;
                                        default: $icon = ueldo_get_custom_icon( $atts, 'icon_' ); break;
                                    }

                                    # display as many icons as requested
                                    for( $i = 0; $i < $level_icons_repeat_number; $i++ ) {

                                        ?>
                                        <i class="<?php echo esc_attr( $icon ); ?>"></i>
                                        <?php
                                    }

                                ?>

                            </div>
                            <?php
                        }

                        # do we have table title?
                        if( !empty( $title ) ) {

                            ?>
                            <h6 class="ueldo-shortcode-pricing-table-content-title"><?php echo esc_html( $title ); ?></h6>
                            <?php
                        }

                        # do we have the price set?
                        if( !empty( $price_currency ) || $price_value != '' || !empty( $price_additional_element_text ) ) {

                            ?>
                            <span class="ueldo-shortcode-pricing-table-content-price">

                                <?php if( !empty( $price_currency ) && $price_currency_side == 'left' ) { ?><span class="ueldo-shortcode-pricing-table-content-price-currency ueldo-shortcode-pricing-table-content-price-currency-left"><?php echo esc_html( $price_currency ); ?></span><?php } ?>
                                <?php if( $price_value != '' ) { ?><span class="ueldo-shortcode-pricing-table-content-price-value"><?php echo esc_html( $price_value ); ?></span><?php } ?>
                                <?php if( !empty( $price_currency ) && $price_currency_side == 'right' ) { ?><span class="ueldo-shortcode-pricing-table-content-price-currency ueldo-shortcode-pricing-table-content-price-currency-right"><?php echo esc_html( $price_currency ); ?></span><?php } ?>
                                <?php if( !empty( $price_additional_element_text ) ) { ?><span class="ueldo-shortcode-pricing-table-content-price-after-value"><?php echo esc_html( $price_additional_element_text ); ?></span><?php } ?>

                            </span>
                            <?php
                        }

                    ?>

                </div>
                <?php

                # do we have content set?
                if( $content_divided !== false && is_array( $content_divided ) ) {

                    # attributes list opened flag
                    $attributes_list_opened = false;

                    # walk for each shortcode
                    for( $i = 0; $i < count( $content_divided ); $i++ ) {

                        # is it single attribute element?
                        if( $content_divided[$i]['key'] == 'ueldo_shortcode_pricing_table_attribute' ) {

                            # attributes list was not opened yet?
                            if( $attributes_list_opened == false ) {

                                # update flag
                                $attributes_list_opened = true;

                                ?>
                                <ul class="ueldo-shortcode-pricing-table-attributes">
                                <?php
                            }

                            # display attribute
                            echo apply_filters( 'the_content', $content_divided[$i]['shortcode-full'] );
                        }
                    }

                    # close attributes list
                    if( $attributes_list_opened == true ) {

                        # update flag
                        $attributes_list_opened = false;

                        ?>
                        </ul>
                        <?php
                    }
                }

                # do we have any buttons added in content?
                if( $content_divided !== false && is_array( $content_divided ) ) {

                    # do we have any button added?
                    for( $i = 0; $i < count( $content_divided ); $i++ ) {

                        # is it single attribute element?
                        if( $content_divided[$i]['key'] == 'ueldo_shortcode_button' ) {

                            # display button
                            echo apply_filters( 'the_content', $content_divided[$i]['shortcode-full'] );
                        }
                    }
                }

            break;

            case '03':

                # can we display background image?
                if( $use_background_image == 'yes' ) {

                    ?>
                    <div class="ueldo-shortcode-pricing-table-background-image">

                        <?php

                            # display background image
                            ueldo_display_image_for_parent( ueldo_get_image_src( $image ), $image_alt, $image_position_y, $image_position_x );

                        ?>

                    </div>
                    <?php
                }

                ?>
                <div class="ueldo-shortcode-pricing-table-content">

                    <?php

                        # do we have table title?
                        if( !empty( $title ) ) {

                            ?>
                            <h6 class="ueldo-shortcode-pricing-table-content-title"><?php echo esc_html( $title ); ?></h6>

                            <div class="ueldo-shortcode-pricing-table-content-title-line">
                            </div>

                            <div class="ueldo-clear">
                            </div>
                            <?php
                        }

                        # do we have the price set?
                        if( !empty( $price_currency ) || $price_value != '' || !empty( $price_additional_element_text ) ) {

                            ?>
                            <span class="ueldo-shortcode-pricing-table-content-price">

                                <?php if( !empty( $price_currency ) && $price_currency_side == 'left' ) { ?><span class="ueldo-shortcode-pricing-table-content-price-currency ueldo-shortcode-pricing-table-content-price-currency-left"><?php echo esc_html( $price_currency ); ?></span><?php } ?>
                                <?php if( $price_value != '' ) { ?><span class="ueldo-shortcode-pricing-table-content-price-value"><?php echo esc_html( $price_value ); ?></span><?php } ?>
                                <?php if( !empty( $price_currency ) && $price_currency_side == 'right' ) { ?><span class="ueldo-shortcode-pricing-table-content-price-currency ueldo-shortcode-pricing-table-content-price-currency-right"><?php echo esc_html( $price_currency ); ?></span><?php } ?>
                                <?php if( !empty( $price_additional_element_text ) ) { ?><span class="ueldo-shortcode-pricing-table-content-price-after-value"><?php echo esc_html( $price_additional_element_text ); ?></span><?php } ?>

                            </span>
                            <?php
                        }

                        # do we have content set?
                        if( $content_divided !== false && is_array( $content_divided ) ) {

                            # attributes list opened flag
                            $attributes_list_opened = false;

                            # walk for each shortcode
                            for( $i = 0; $i < count( $content_divided ); $i++ ) {

                                # is it single attribute element?
                                if( $content_divided[$i]['key'] == 'ueldo_shortcode_pricing_table_attribute' ) {

                                    # attributes list was not opened yet?
                                    if( $attributes_list_opened == false ) {

                                        # update flag
                                        $attributes_list_opened = true;

                                        ?>
                                        <ul class="ueldo-shortcode-pricing-table-attributes">
                                        <?php
                                    }

                                    # display attribute
                                    echo apply_filters( 'the_content', $content_divided[$i]['shortcode-full'] );
                                }
                            }

                            # close attributes list
                            if( $attributes_list_opened == true ) {

                                # update flag
                                $attributes_list_opened = false;

                                ?>
                                </ul>
                                <?php
                            }
                        }

                        # do we have any buttons added in content?
                        if( $content_divided !== false && is_array( $content_divided ) ) {

                            # do we have any button added?
                            for( $i = 0; $i < count( $content_divided ); $i++ ) {

                                # is it single attribute element?
                                if( $content_divided[$i]['key'] == 'ueldo_shortcode_button' ) {

                                    # display button
                                    echo apply_filters( 'the_content', $content_divided[$i]['shortcode-full'] );
                                }
                            }
                        }

                    ?>

                </div>
                <?php

            break;
        }

    ?>

</div>

<div class="ueldo-clear">
</div>
<?php

    # clear the variables
    unset( $class_name, $pricing_table_style, $content_alignment, $horizontal_alignment, $title, $price_value, $price_currency, $price_currency_side, $price_additional_element_text, $show_ribbon, $ribbon_position, $ribbon_text, $display_level_icons, $icon_library, $icon_fontawesome, $icon_openiconic, $icon_typicons, $icon_entypo, $icon_linecons, $icon_monosocial, $icon_material, $level_icons_repeat_number, $use_background_image, $image, $image_position_y, $image_position_x, $image_alt, $custom_colors_enabled, $shortcode_class, $content_divided, $button_exists, $i, $attributes_list_opened, $icon );

?>