<?php

   /**
    *
    * prepare the data for shortcode
    *
    */

    # extract shortcode arguments
    extract( shortcode_atts( array(
       'class_name' => '',
       'layer_title' => esc_html( __( 'Row background', 'ueldo' ) ),
       'layer_for_row_or_section' => 'row',
       'layer_type' => 'color',
       'layer_visibility' => 'visible',
       'color_add_box_shadow' => 'no',
       'image' => esc_url( get_template_directory_uri() .'/_assets/_img/image.png' ),
       'image_size' => 'cover',
       'image_repeat' => 'no-repeat',
       'image_position_y' => '50%',
       'image_position_x' => '50%',
       'image_alt' => esc_html( __( 'Image', 'ueldo' ) ),
       'image_add_box_shadow' => 'no',
       'parallax_image' => esc_url( get_template_directory_uri() .'/_assets/_img/image.png' ),
       'parallax_image_position_y' => '50%',
       'parallax_image_position_x' => '50%',
       'parallax_image_alt' => esc_html( __( 'Image', 'ueldo' ) ),
       'parallax_speed' => '100%',
       'parallax_inset_box_shadow_top_bottom' => 'no',
       'video_id' => 'e452W2Kj-yg',
       'video_add_box_shadow' => 'no',
       'text_content' => esc_html( __( 'Text', 'ueldo' ) ),
       'icon_library' => 'fontawesome',
       'icon_fontawesome' => 'fa fa-long-arrow-right',
       'icon_openiconic' => 'vc_icon_element-icon vc-oi vc-oi-dial',
       'icon_typicons' => 'typcn typcn-adjust-brightness',
       'icon_entypo' => 'entypo-icon entypo-icon-note',
       'icon_linecons' => 'vc_li vc_li-heart',
       'icon_monosocial' => 'vc-mono vc-mono-fivehundredpx',
       'icon_material' => 'vc-material vc-material-account_balance',
       'animation' => '',
       'extra_class_name' => ''
    ), $atts ));

    # create shortcode class name
    $shortcode_class = 'ueldo-shortcode-row-layer';

    # is this layer visible only on hover?
    if( $layer_visibility == 'on_hover_only' ) $shortcode_class .= ' ueldo-shortcode-row-layer-on-hover-only';

    # is this layer hidden on hover?
    if( $layer_visibility == 'hide_on_hover' ) $shortcode_class .= ' ueldo-shortcode-row-layer-hide-on-hover';

    # add dedicated class if we need to display inset box shadow on top and bottom
    if( ( $layer_type == 'image' && in_array( $image_add_box_shadow, array( 'yes-inset-on-top', 'yes-inset-on-bottom', 'yes-inset' ), true ) ) || ( $layer_type == 'color' && in_array( $color_add_box_shadow, array( 'yes-inset-on-top', 'yes-inset-on-bottom', 'yes-inset' ), true ) ) || ( $layer_type == 'parallax_image' && $parallax_inset_box_shadow_top_bottom == 'yes' ) || ( $layer_type == 'youtube_video' && in_array( $video_add_box_shadow, array( 'yes-inset-on-top', 'yes-inset-on-bottom', 'yes-inset' ), true ) ) ) {

        # add class name
        $shortcode_class .= ' ueldo-shortcode-row-layer-with-box-shadow-inset';
    }

    # get the animation
    if( !empty( $animation ) ) $shortcode_class .= esc_attr( $this -> getCSSAnimation( $animation ) );

    # add extra class name
    $shortcode_class .= ' '. esc_attr( $extra_class_name );

    # update shortcode class name with unique class id
    $shortcode_class .= ' '. esc_attr( $class_name );

   /**
    *
    * display element
    *
    */

?>
<div class="<?php echo esc_attr( $shortcode_class ); ?>" data-layer-type="<?php echo esc_attr( $layer_type ); ?>" data-layer-for="<?php echo esc_attr( $layer_for_row_or_section ); ?>">

    <?php

        # what do we need to display?
        switch( $layer_type ) {

            # display background image
            case 'image':

                # display image
                ueldo_display_image_for_parent( ueldo_get_image_src( $image ), $image_alt, $image_position_x, $image_position_y, false, $image_size, $image_repeat );

            break;

            # display background image
            case 'parallax_image':

                # get original image dimensions
                $parallax_image_dimensions = ueldo_get_image_dimensions( $parallax_image );

                ?>
                <div class="ueldo-shortcode-row-layer-parallax" data-parallax-initial-vertical-position="<?php echo esc_attr( $parallax_image_position_y ); ?>" data-parallax-speed="<?php echo esc_attr( $parallax_speed ); ?>" data-parallax-original-width="<?php echo esc_attr( $parallax_image_dimensions['width'] ); ?>" data-parallax-original-height="<?php echo esc_attr( $parallax_image_dimensions['height'] ); ?>">

                    <?php

                        # display image
                        ueldo_display_image_for_parent( ueldo_get_image_src( $parallax_image ), $parallax_image_alt, '50%', $parallax_image_position_y );

                    ?>

                </div>
                <?php

            break;

            # display youtube video
            case 'youtube_video':

                # do we have video id set?
                if( !empty( $video_id ) ) {

                    ?>
                    <div id="<?php echo esc_attr( $class_name ); ?>_video" class="ueldo-shortcode-row-layer-youtube-video-container" data-video-id="<?php echo esc_attr( $video_id ); ?>"></div>
                    <?php
                }

            break;

            # display text
            case 'text':

               ?>
               <div class="ueldo-shortcode-row-layer-text"><?php echo esc_html( $text_content ); ?></div>
               <?php

            break;

            # display icon
            case 'icon':

                # define the icon variable
                $icon = '';

                # switch the icon library
                switch( $icon_library ) {

                    case 'fontawesome': $icon = $icon_fontawesome; break;
                    case 'openiconic': $icon = $icon_openiconic; break;
                    case 'typicons': $icon = $icon_typicons; break;
                    case 'entypo': $icon = $icon_entypo; break;
                    case 'linecons': $icon = $icon_linecons; break;
                    case 'monosocial': $icon = $icon_monosocial; break;
                    case 'material': $icon = $icon_material; break;
                    default: $icon = ueldo_get_custom_icon( $atts, 'icon_' ); break;
                }

                ?>
                <div class="ueldo-shortcode-row-layer-icon"><i class="<?php echo esc_attr( $icon ); ?>"></i></div>
                <?php

            break;
        }

    ?>

</div>
<?php

    # clear the variables
    unset( $class_name, $layer_title, $layer_for_row_or_section, $layer_type, $layer_visibility, $color_add_box_shadow, $image, $image_size, $image_repeat, $image_position_y, $image_position_x, $image_alt, $image_add_box_shadow, $parallax_image, $parallax_image_position_y, $parallax_image_position_x, $parallax_image_alt, $parallax_speed, $parallax_inset_box_shadow_top_bottom, $video_id, $video_add_box_shadow, $text_content, $icon_library, $icon_fontawesome, $icon_openiconic, $icon_typicons, $icon_entypo, $icon_linecons, $icon_monosocial, $icon_material, $shortcode_class, $parallax_image_dimensions, $icon );

?>