<?php

   /**
    *
    * installation class for "creative agency" demo template
    *
    */

    class ueldo_demo_contents_loader_base extends ueldo_demo_contents_loader_installation_helper {

       /**
        *
        * install template or its parts
        *
        */

        public static function install( $parts, $icons ) {

           /**
            *
            * install forms
            *
            */

            if( $parts == 'all' || in_array( 'forms', $parts, true ) ) {

                # add form in contact form 7 plugin and get its id
                if( ( $form_id = ueldo_add_demo_assets::add_contact_form() ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:contactform7|context:creative-agency|inside:false}', 'id="'. esc_attr( $form_id ) .'"' );

                    # remove temporary variables
                    unset( $form_id );
                }
            }

           /**
            *
            * install blog posts
            *
            */

            if( $parts == 'all' || in_array( 'posts', $parts, true ) ) {

                # do we have default image ID?
                if( self::get_solution( 'default-image-id' ) == false ) {

                    # add solution with default image ID
                    self::add_solution( 'default-image-id', ueldo_add_demo_assets::add_image( 'default-image' ) );
                }

                # get current user data
                $current_user = wp_get_current_user();

                # add blog post
                $new_post_id = ueldo_add_demo_assets::add_blog_post( array(
                    'title' => esc_html( __( 'We received an award for the best Creative Agency!', 'ueldo' ) ),
                    'content' => false,
                    'thumbnail' => self::get_solution( 'default-image-id' ),
                    'category' => array( wp_create_category( esc_html( __( 'Recent news', 'ueldo' ) ) ) ),
                    'tags' => array(
                        esc_html( __( 'Awards', 'ueldo' ) ),
                        esc_html( __( 'Creative Agency', 'ueldo' ) )
                    ),
                    'comments' => array(
                        array(
                            'author' => esc_html( __( 'John', 'ueldo' ) ),
                            'author-email' => esc_html( __( 'john@example.com', 'ueldo' ) ),
                         			'content' => 'Maecenas euismod lacus non eros ultricies, ac volutpat sem pretium. In mollis, lectus id mollis venenatis, sapien dui pretium velit, vel pellentesque nulla ipsum eu lectus. Nam at odio at diam pulvinar accumsan. Donec rutrum finibus sem, quis venenatis turpis accumsan non. Pellentesque suscipit egestas convallis. Nulla risus diam, malesuada in dui ut, venenatis hendrerit erat. Morbi tempor cursus mauris eu scelerisque.'
                        ),
                        array(
                         			'author' => esc_html( __( 'Mike', 'ueldo' ) ),
                         			'author-email' => esc_html( __( 'mike@example.com', 'ueldo' ) ),
                         			'content' => 'Vestibulum lectus nulla, volutpat vel molestie sit amet, bibendum in erat. Nunc gravida nibh in tempus facilisis. Suspendisse nec viverra ante, at sodales purus. Vivamus condimentum, diam in volutpat fermentum, nisl orci mollis ex, at interdum dolor dolor quis magna. Mauris sagittis libero quis finibus ullamcorper. Sed feugiat sagittis odio, non porta dui rhoncus et. Integer in orci semper justo ultricies consectetur eu non diam.'
                        )
                    )
                ));

                # wait until previous post is added
                if( $new_post_id !== false ) {

                    # clear temporary variable
                    unset( $new_post_id );

                    # add blog post
                    $new_post_id = ueldo_add_demo_assets::add_blog_post( array(
                        'title' => esc_html( __( 'How to reach out to the user on mobile', 'ueldo' ) ),
                        'content' => false,
                        'thumbnail' => self::get_solution( 'default-image-id' ),
                        'category' => array( wp_create_category( esc_html( __( 'Recent news', 'ueldo' ) ) ) ),
                        'tags' => array(
                            esc_html( __( 'Creative Agency', 'ueldo' ) ),
                            esc_html( __( 'Mobile', 'ueldo' ) )
                        ),
                        'comments' => array(
                            array(
                                'author' => esc_html( __( 'Susane', 'ueldo' ) ),
                                'author-email' => esc_html( __( 'susane@example.com', 'ueldo' ) ),
                                'content' => 'Cras eleifend, massa a rutrum iaculis, nisi purus convallis orci, quis auctor arcu arcu vitae tortor. Nam et nunc nec erat faucibus accumsan et non sapien. Proin quis ultrices felis. Nunc interdum massa tortor, non pellentesque quam dignissim eget. Phasellus sit amet volutpat mi. Vivamus elementum, urna eget molestie egestas, nisl turpis tristique neque, vel feugiat mauris nulla ac erat. Suspendisse finibus risus vel ultricies ornare.',
                                'replies' => array(
                                    array(
                                        'author' => esc_html( $current_user -> display_name ),
                                        'author-email' => esc_html( $current_user -> user_email ),
                                        'content' => 'Curabitur efficitur interdum nisi ac commodo. Ut vel efficitur leo, sit amet mollis sapien. Nulla id nisi diam. Integer ac pharetra massa. Donec ligula erat, ultrices ut quam nec, eleifend dictum purus. Phasellus placerat vestibulum bibendum. Ut placerat et neque quis sagittis. Aenean vitae dui sit amet enim tincidunt facilisis. Maecenas massa dolor, semper facilisis quam auctor, semper placerat ante.',
                                        'user_id' => esc_attr( $current_user -> ID )
                                    )
                                )
                            )
                        )
                    ));

                    # wait until previous post is added
                    if( $new_post_id !== false ) {

                        # clear temporary variable
                        unset( $new_post_id );

                        # add blog post
                        $new_post_id = ueldo_add_demo_assets::add_blog_post( array(
                            'title' => esc_html( __( 'How to become successful on online marketing', 'ueldo' ) ),
                            'content' => false,
                            'thumbnail' => self::get_solution( 'default-image-id' ),
                            'category' => array( wp_create_category( esc_html( __( 'Recent news', 'ueldo' ) ) ) ),
                            'tags' => array(
                                esc_html( __( 'Awards', 'ueldo' ) ),
                                esc_html( __( 'Creative Agency', 'ueldo' ) )
                            ),
                            'comments' => array(
                                array(
                                    'author' => esc_html( __( 'John', 'ueldo' ) ),
                                    'author-email' => esc_html( __( 'john@example.com', 'ueldo' ) ),
                                    'content' => 'Maecenas euismod lacus non eros ultricies, ac volutpat sem pretium. In mollis, lectus id mollis venenatis, sapien dui pretium velit, vel pellentesque nulla ipsum eu lectus. Nam at odio at diam pulvinar accumsan. Donec rutrum finibus sem, quis venenatis turpis accumsan non. Pellentesque suscipit egestas convallis. Nulla risus diam, malesuada in dui ut, venenatis hendrerit erat. Morbi tempor cursus mauris eu scelerisque.',
                                    'replies' => array(
                                        array(
                                            'author' => esc_html( __( 'Susane', 'ueldo' ) ),
                                         			'author-email' => esc_html( __( 'susane@example.com', 'ueldo' ) ),
                                            'content' => 'Cras eleifend, massa a rutrum iaculis, nisi purus convallis orci, quis auctor arcu arcu vitae tortor. Nam et nunc nec erat faucibus accumsan et non sapien. Proin quis ultrices felis. Nunc interdum massa tortor, non pellentesque quam dignissim eget. Phasellus sit amet volutpat mi. Vivamus elementum, urna eget molestie egestas, nisl turpis tristique neque, vel feugiat mauris nulla ac erat. Suspendisse finibus risus vel ultricies ornare.'
                                        )
                                    )
                                ),
                                array(
                                    'author' => esc_html( __( 'Mike', 'ueldo' ) ),
                                    'author-email' => esc_html( __( 'mike@example.com', 'ueldo' ) ),
                                    'content' => 'Vestibulum lectus nulla, volutpat vel molestie sit amet, bibendum in erat. Nunc gravida nibh in tempus facilisis. Suspendisse nec viverra ante, at sodales purus. Vivamus condimentum, diam in volutpat fermentum, nisl orci mollis ex, at interdum dolor dolor quis magna. Mauris sagittis libero quis finibus ullamcorper. Sed feugiat sagittis odio, non porta dui rhoncus et. Integer in orci semper justo ultricies consectetur eu non diam.'
                                )
                            )
                        ));

                        # wait until previous post is added
                        if( $new_post_id !== false ) {

                            # clear temporary variable
                            unset( $new_post_id );

                            # add blog post
                            $new_post_id = ueldo_add_demo_assets::add_blog_post( array(
                                'title' => esc_html( __( 'Case study – how to increase conversions with 400% within three days', 'ueldo' ) ),
                                'content' => false,
                                'thumbnail' => self::get_solution( 'default-image-id' ),
                                'category' => array( wp_create_category( esc_html( __( 'Recent news', 'ueldo' ) ) ) ),
                                'tags' => array(
                                    esc_html( __( 'Awards', 'ueldo' ) ),
                                    esc_html( __( 'Creative Agency', 'ueldo' ) )
                                ),
                                'comments' => array(
                                    array(
                                        'author' => esc_html( __( 'John', 'ueldo' ) ),
                                        'author-email' => esc_html( __( 'john@example.com', 'ueldo' ) ),
                                     			'content' => 'Maecenas euismod lacus non eros ultricies, ac volutpat sem pretium. In mollis, lectus id mollis venenatis, sapien dui pretium velit, vel pellentesque nulla ipsum eu lectus. Nam at odio at diam pulvinar accumsan. Donec rutrum finibus sem, quis venenatis turpis accumsan non. Pellentesque suscipit egestas convallis. Nulla risus diam, malesuada in dui ut, venenatis hendrerit erat. Morbi tempor cursus mauris eu scelerisque.'
                                    ),
                                    array(
                                        'author' => esc_html( $current_user -> display_name ),
                                        'author-email' => esc_html( $current_user -> user_email ),
                                        'content' => 'Curabitur efficitur interdum nisi ac commodo. Ut vel efficitur leo, sit amet mollis sapien. Nulla id nisi diam. Integer ac pharetra massa. Donec ligula erat, ultrices ut quam nec, eleifend dictum purus. Phasellus placerat vestibulum bibendum. Ut placerat et neque quis sagittis. Aenean vitae dui sit amet enim tincidunt facilisis. Maecenas massa dolor, semper facilisis quam auctor, semper placerat ante.',
                                        'user_id' => esc_attr( $current_user -> ID )
                                    )
                                )
                            ));

                            # wait until previous post is added
                            if( $new_post_id !== false ) {

                                # clear temporary variable
                                unset( $new_post_id );

                                # add blog post
                                $new_post_id = ueldo_add_demo_assets::add_blog_post( array(
                                    'title' => esc_html( __( 'Case study – 230% more positive reviews in Online Store of one of our Clients', 'ueldo' ) ),
                                    'content' => false,
                                    'thumbnail' => self::get_solution( 'default-image-id' ),
                                    'category' => array( wp_create_category( esc_html( __( 'Recent news', 'ueldo' ) ) ) ),
                                    'tags' => array(
                                        esc_html( __( 'Awards', 'ueldo' ) ),
                                        esc_html( __( 'Creative Agency', 'ueldo' ) ),
                                        esc_html( __( 'Mobile', 'ueldo' ) )
                                    ),
                                    'comments' => array(
                                        array(
                                            'author' => esc_html( __( 'Susane', 'ueldo' ) ),
                                            'author-email' => esc_html( __( 'susane@example.com', 'ueldo' ) ),
                                         			'content' => 'Cras eleifend, massa a rutrum iaculis, nisi purus convallis orci, quis auctor arcu arcu vitae tortor. Nam et nunc nec erat faucibus accumsan et non sapien. Proin quis ultrices felis. Nunc interdum massa tortor, non pellentesque quam dignissim eget. Phasellus sit amet volutpat mi. Vivamus elementum, urna eget molestie egestas, nisl turpis tristique neque, vel feugiat mauris nulla ac erat. Suspendisse finibus risus vel ultricies ornare.'
                                        ),
                                        array(
                                            'author' => esc_html( __( 'Mike', 'ueldo' ) ),
                                            'author-email' => esc_html( __( 'mike@example.com', 'ueldo' ) ),
                                         			'content' => 'Vestibulum lectus nulla, volutpat vel molestie sit amet, bibendum in erat. Nunc gravida nibh in tempus facilisis. Suspendisse nec viverra ante, at sodales purus. Vivamus condimentum, diam in volutpat fermentum, nisl orci mollis ex, at interdum dolor dolor quis magna. Mauris sagittis libero quis finibus ullamcorper. Sed feugiat sagittis odio, non porta dui rhoncus et. Integer in orci semper justo ultricies consectetur eu non diam.'
                                        )
                                    )
                                ));

                                # wait until previous post is added
                                if( $new_post_id !== false ) {

                                    # clear temporary variable
                                    unset( $new_post_id );

                                    # add blog post
                                    ueldo_add_demo_assets::add_blog_post( array(
                                        'title' => esc_html( __( 'How to get more traffic from the Organic Search results?', 'ueldo' ) ),
                                        'content' => false,
                                        'thumbnail' => self::get_solution( 'default-image-id' ),
                                        'category' => array( wp_create_category( esc_html( __( 'Recent news', 'ueldo' ) ) ) ),
                                        'tags' => array(
                                            esc_html( __( 'Creative Agency', 'ueldo' ) ),
                                            esc_html( __( 'Mobile', 'ueldo' ) )
                                        ),
                                        'comments' => array(
                                            array(
                                                'author' => esc_html( __( 'John', 'ueldo' ) ),
                                                'author-email' => esc_html( __( 'john@example.com', 'ueldo' ) ),
                                                'content' => 'Maecenas euismod lacus non eros ultricies, ac volutpat sem pretium. In mollis, lectus id mollis venenatis, sapien dui pretium velit, vel pellentesque nulla ipsum eu lectus. Nam at odio at diam pulvinar accumsan. Donec rutrum finibus sem, quis venenatis turpis accumsan non. Pellentesque suscipit egestas convallis. Nulla risus diam, malesuada in dui ut, venenatis hendrerit erat. Morbi tempor cursus mauris eu scelerisque.',
                                                'replies' => array(
                                                    array(
                                                        'author' => esc_html( $current_user -> display_name ),
                                                        'author-email' => esc_html( $current_user -> user_email ),
                                                        'content' => 'Curabitur efficitur interdum nisi ac commodo. Ut vel efficitur leo, sit amet mollis sapien. Nulla id nisi diam. Integer ac pharetra massa. Donec ligula erat, ultrices ut quam nec, eleifend dictum purus. Phasellus placerat vestibulum bibendum. Ut placerat et neque quis sagittis. Aenean vitae dui sit amet enim tincidunt facilisis. Maecenas massa dolor, semper facilisis quam auctor, semper placerat ante.',
                                                        'user_id' => esc_attr( $current_user -> ID )
                                                    )
                                                )
                                            ),
                                            array(
                                                'author' => esc_html( __( 'Susane', 'ueldo' ) ),
                                                'author-email' => esc_html( __( 'susane@example.com', 'ueldo' ) ),
                                                'content' => 'Cras eleifend, massa a rutrum iaculis, nisi purus convallis orci, quis auctor arcu arcu vitae tortor. Nam et nunc nec erat faucibus accumsan et non sapien. Proin quis ultrices felis. Nunc interdum massa tortor, non pellentesque quam dignissim eget. Phasellus sit amet volutpat mi. Vivamus elementum, urna eget molestie egestas, nisl turpis tristique neque, vel feugiat mauris nulla ac erat. Suspendisse finibus risus vel ultricies ornare.'
                                            )
                                        )
                                    ));
                                }
                            }
                        }
                    }
                }

                # remove temporary variables
                unset( $current_user );

                # posts per page
                update_option( 'posts_per_page', '10' );
            }

           /**
            *
            * add pages, but not fill it with contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # add pages and get its ids
                $pages_ids = ueldo_add_demo_assets::add_empty_pages( 'page', array(
                    '404-page' => esc_html( __( '404 page', 'ueldo' ) ),
                    'about-us' => esc_html( __( 'About us', 'ueldo' ) ),
                    'blog' => esc_html( __( 'Blog', 'ueldo' ) ),
                    'contact' => esc_html( __( 'Contact', 'ueldo' ) ),
                    'home' => esc_html( __( 'Home', 'ueldo' ) ),
                    'portfolio' => esc_html( __( 'Portfolio', 'ueldo' ) ),
                    'single-portfolio-project' => esc_html( __( 'Single portfolio project', 'ueldo' ) ),
                    'services' => esc_html( __( 'Services', 'ueldo' ) ),
                    'design' => esc_html( __( 'Design', 'ueldo' ) ),
                    'development' => esc_html( __( 'Development', 'ueldo' ) ),
                    'marketing' => esc_html( __( 'Marketing', 'ueldo' ) )
                ));

                # add headers, footers and extras
                $hefos_ids = ueldo_add_demo_assets::add_empty_pages( 'ueldohefo', array(
                    'footer' => esc_html( __( 'Footer', 'ueldo' ) ),
                    'header' => esc_html( __( 'Header', 'ueldo' ) )
                ));

                # add solution
                self::add_solution( 'pages-ids', array_merge( $pages_ids, $hefos_ids ) );

                # show page on front
                update_option( 'show_on_front', 'page' );

                # update blog posts page ID
                if( $pages_ids['blog'] != null && $pages_ids['blog'] != false ) update_option( 'page_for_posts', $pages_ids['blog'] );

                # update home page ID
                if( $pages_ids['home'] != null && $pages_ids['home'] != false ) update_option( 'page_on_front', $pages_ids['home'] );

                # remove temporary variables
                unset( $pages_ids );
            }

           /**
            *
            * install menus
            *
            */

            if( $parts == 'all' || in_array( 'menus', $parts, true ) ) {

                # add new menu
                if( is_int( $menu_id = ueldo_add_demo_assets::add_menu( 'creative-agency-main-menu', self::get_solution( 'pages-ids' ), true ) ) ) {

                    # add solution
                    self::add_solution( 'main-menu-id', esc_attr( $menu_id ) );
                }
            }

           /**
            *
            * get dynamic elements replacements
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) || in_array( 'pages', $parts, true ) ) {

                # get dynamic elements replacements
                $replacements = self::get_dynamic_elements_replacements( self::find_dynamic_elements( self::get_vc_contents() ), $icons, self::get_default_replacements() );
            }

           /**
            *
            * install theme options
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) ) {

                # update theme options
                update_option( 'ueldo_theme_options', self::get_theme_options_array() );

                # set additional content before side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_before_all', self::do_content_replacements( self::get_vc_contents( 'additional-before-side-menu' ), $replacements ) );

                # set additional content after side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_after_all', self::do_content_replacements( self::get_vc_contents( 'additional-after-side-menu' ), $replacements ) );

                # clear theme mods - background color and image
                remove_theme_mod( 'background_color' );
                remove_theme_mod( 'background_position_x' );
                remove_theme_mod( 'background_position_y' );
                remove_theme_mod( 'background_repeat' );
                remove_theme_mod( 'background_attachment' );
                remove_theme_mod( 'background_size' );
                remove_theme_mod( 'background_image' );
            }

           /**
            *
            * fill pages contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # walk for each pages
                foreach( self::get_solution( 'pages-ids' ) as $page_slug => $page_id ) {

                    # not for blog page
                    if( $page_slug == 'blog' ) continue;

                    # update page content
                    $result = wp_update_post( array(
                        'ID' => esc_attr( $page_id ),
                        'post_content' => self::do_content_replacements( self::get_vc_contents( esc_attr( $page_slug ) ), $replacements )
                    ));
                }

                # remove temporary variables
                unset( $replacements );
            }

           /**
            *
            * update permalinks structure
            *
            */

            if( $parts == 'all' || in_array( 'permalinks-structure', $parts, true ) ) {

                # global variable
                global $wp_rewrite;

                # write the rule
                $wp_rewrite -> set_permalink_structure( '/%postname%/' );

                # set the option
                update_option( 'rewrite_rules', false );

                # flush the rules and tell it to write htaccess
                $wp_rewrite -> flush_rules( true );
            }

           /**
            *
            * demo data installed
            *
            */

            exit( '{ "status": "ok" }' );
        }

       /**
        *
        * get possible data parts
        *
        */

        public static function get_possible_data_parts() {

            # return result
            return( array(
                'menus' => esc_html( __( 'Menus', 'ueldo' ) ),
                'posts' => esc_html( __( 'Posts', 'ueldo' ) ),
                'pages' => esc_html( __( 'Pages', 'ueldo' ) ),
                'theme-options' => esc_html( __( 'Theme options', 'ueldo' ) ),
                'forms' => esc_html( __( 'Forms', 'ueldo' ) ),
                'permalinks-structure' => esc_html( __( 'Permalinks structure', 'ueldo' ) )
            ));
        }

       /**
        *
        * get list of required plugins
        *
        */

        public static function get_required_plugins( $parts ) {

            # all data
            if( !is_array( $parts ) && $parts == 'all' ) {

                # return list of required plugins
                return( array(
                    'ueldo',
                    'visual-composer',
                    'contact-form-7'
                ));
            }

            # selected parts
            else {

                # prepare array of required plugins
                $result = array( 'ueldo' );

                # do we have to add pages?
                if( in_array( 'pages', $parts, true ) ) {

                    # return list of required plugins
                    return( array(
                        'visual-composer',
                        'contact-form-7'
                    ));
                }

                # do we have to add theme options?
                if( in_array( 'theme-options', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'visual-composer' ) );
                }

                # do we have to add forms?
                if( in_array( 'forms', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'contact-form-7' ) );
                }

                # return result
                return( $result );
            }
        }

       /**
        *
        * get default replacements
        *
        */

        public static function get_default_replacements() {

            # add logo image
            $logo_image_id = ueldo_add_demo_assets::add_image( 'creative-agency-logo' );

            # add white logo image
            $white_logo_image_id = ueldo_add_demo_assets::add_image( 'creative-agency-logo-white' );

            # return result
            return( array(
                '{ueldopredefinedsections:googlemap|context:creative-agency}' => 'google_map_id="1"',
                '{ueldopredefinedsections:image|context:creative-agency-logo}' => ( $logo_image_id == false ? '' : 'image="'. esc_attr( $logo_image_id ) .'"' ),
                '{ueldopredefinedsections:image|context:creative-agency-logo-white}' => ( $white_logo_image_id == false ? '' : 'image="'. esc_attr( $white_logo_image_id ) .'"' )
            ));
        }

       /**
        *
        * get trusted solution
        *
        */

        public static function get_trusted_solution( $type, $solution ) {

            # do we have solution found?
            if( !empty( $solution ) ) return( $solution );

            # switch by solution type
            switch( $type ) {

                # get most similar elements
                case 'main-menu-slug': return( self::get_most_similar_element( 'menu_slug', esc_html( __( 'Main menu - Creative Agency template', 'ueldo' ) ) ) );
                case '404-page-id': return( self::get_most_similar_element( 'page', esc_html( __( '404 page', 'ueldo' ) ) ) );
                case 'footer-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Footer', 'ueldo' ) ) ) );
                case 'header-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Header', 'ueldo' ) ) ) );
            }

            # nothing found
            return( false );
        }

       /**
        *
        * get theme options array
        *
        */

        public static function get_theme_options_array() {

            # return result
            return( array(
                '404-page-id' => array( 'all' => self::get_trusted_solution( '404-page-id', self::get_solution( 'pages-ids', '404-page' ) ) ),
                'blog-posts-list-style' => array(
                    'posts-list-style' => '01',
                    'display-post-data-under-title' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'yes'
                ),
                'blog-sidebar' => array(
                    'posts-list' => 'no',
                    'single-post' => 'no',
                    'responsive-style' => 'static'
                ),
                'boxed-website' => array(
                    'enabled' => 'no',
                    'large-content-width' => '1100',
                    'large-content-space' => '50',
                    'medium-content-width' => '890',
                    'medium-content-space' => '50',
                    'small-content-width' => '665',
                    'small-content-space' => '50'
                ),
                'comment-textarea-at-top' => 'yes',
                'dynamic-theme-styles-cache' => array(
                    'enabled' => 'no',
                    'clear-cache' => 'all-the-time-when-logged-in'
                ),
                'facebook-fanpage-url' => array( 'all' => 'https://www.facebook.com/envato' ),
                'featured-image-on-lists-only' => 'no',
                'fonts' => array(
                    'general-font-family' => array( 'all' => 'Heebo' ),
                    'general-font-weight' => array( 'all' => 'regular' ),
                    'general-font-subset' => array( 'all' => 'latin' ),
                    'general-font-smoothing' => array( 'all' => 'yes' ),
                    'general-bold-font-family' => array( 'all' => 'Heebo' ),
                    'general-bold-font-weight' => array( 'all' => '500' ),
                    'general-bold-font-subset' => array( 'all' => 'latin' ),
                    'general-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-font-family' => array( 'all' => 'Heebo' ),
                    'menu-font-weight' => array( 'all' => '500' ),
                    'menu-font-subset' => array( 'all' => 'latin' ),
                    'menu-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-font-family' => array( 'all' => 'Heebo' ),
                    'headings-font-weight' => array( 'all' => '500' ),
                    'headings-font-subset' => array( 'all' => 'latin' ),
                    'headings-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-slim-font-family' => array( 'all' => 'Heebo' ),
                    'headings-slim-font-weight' => array( 'all' => '300' ),
                    'headings-slim-font-subset' => array( 'all' => 'latin' ),
                    'headings-slim-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-bold-font-family' => array( 'all' => 'Heebo' ),
                    'headings-bold-font-weight' => array( 'all' => '700' ),
                    'headings-bold-font-subset' => array( 'all' => 'latin' ),
                    'headings-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-subtitle-font-family' => array( 'all' => 'Heebo' ),
                    'headings-subtitle-font-weight' => array( 'all' => '500' ),
                    'headings-subtitle-font-subset' => array( 'all' => 'latin' ),
                    'headings-subtitle-font-smoothing' => array( 'all' => 'yes' ),
                    'buttons-font-family' => array( 'all' => 'Heebo' ),
                    'buttons-font-weight' => array( 'all' => '700' ),
                    'buttons-font-subset' => array( 'all' => 'latin' ),
                    'buttons-font-smoothing' => array( 'all' => 'yes' ),
                    'form-fields-font-family' => array( 'all' => 'Heebo' ),
                    'form-fields-font-weight' => array( 'all' => 'regular' ),
                    'form-fields-font-subset' => array( 'all' => 'latin' ),
                    'form-fields-font-smoothing' => array( 'all' => 'yes' ),
                    'blockquote-font-family' => array( 'all' => 'Heebo' ),
                    'blockquote-font-weight' => array( 'all' => '700' ),
                    'blockquote-font-subset' => array( 'all' => 'latin' ),
                    'blockquote-font-smoothing' => array( 'all' => 'yes' ),
                    'alert-messages-font-family' => array( 'all' => 'Heebo' ),
                    'alert-messages-font-weight' => array( 'all' => 'regular' ),
                    'alert-messages-font-subset' => array( 'all' => 'latin' ),
                    'alert-messages-font-smoothing' => array( 'all' => 'yes' )
                ),
                'footer-content' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'footer-page-id', self::get_solution( 'pages-ids', 'footer' ) ) ),
                    'position' => array( 'all' => 'fixed-to-bottom' )
                ),
                'google-maps' => array(
                    'api-key' => '',
                    'next-map-id' => '2',
                    'google-map-1-title' => esc_html( __( 'Location map', 'ueldo' ) ),
                    'google-map-1-center-lat' => '40.713703',
                    'google-map-1-center-lng' => '-74.005325',
                    'google-map-1-zoom' => '12',
                    'google-map-1-markers-next-marker-id' => '2',
                    'google-map-1-markers-marker-1-title' => esc_html( __( 'Marker', 'ueldo' ) ),
                    'google-map-1-markers-marker-1-lat' => '40.713703',
                    'google-map-1-markers-marker-1-lng' => '-74.005325',
                    'google-map-1-markers-marker-1-use-custom-marker' => 'no',
                    'google-map-1-markers-marker-1-custom-icon-library' => 'fontawesome',
                    'google-map-1-markers-marker-1-custom-icon' => 'fa fa-address-book',
                    'google-map-1-markers-marker-1-custom-icon-size' => '18',
                    'google-map-1-markers-marker-1-custom-icon-width' => '36',
                    'google-map-1-markers-marker-1-custom-icon-height' => '36',
                    'google-map-1-markers-marker-1-custom-icon-border-radius' => 'circle',
                    'google-map-1-markers-marker-1-custom-icon-border-radius-px' => '4',
                    'google-map-1-markers-marker-1-custom-icon-color' => '#e87ab7',
                    'google-map-1-markers-marker-1-custom-icon-background-color' => '#fff',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-horizontal-length' => '0',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-vertical-length' => '5',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-blur-radius' => '20',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-spread-radius' => '0',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-color' => 'rgba( 0, 0, 0, 0.1 )',
                    'google-map-1-markers-marker-1-custom-marker-image' => '',
                    'google-map-1-custom-style' => '[{"featureType":"administrative","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":20}]},{"featureType":"road","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":40}]},{"featureType":"water","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-10},{"lightness":30}]},{"featureType":"landscape.man_made","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":10}]},{"featureType":"landscape.natural","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":60}]},{"featureType":"poi","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]},{"featureType":"transit","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]}]'
                ),
                'header' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'header-page-id', self::get_solution( 'pages-ids', 'header' ) ) ),
                    'position' => array( 'all' => 'flying' ),
                    'use-second-header' => array( 'all' => 'no' ),
                    'get-second-content-from' => array( 'all' => 'default' ),
                    'second-header-visible-from' => array( 'all' => '400' ),
                    'default-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'second-header-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) )
                ),
                'lazy-load-images' => array(
                    'enabled' => 'no',
                    'threshold' => '0'
                ),
                'loader-animation' => array(
                    'enabled' => 'yes',
                    'style' => '01',
                    'add-logo' => 'no',
                    'space-between-logo-and-spinner' => '30',
                    'logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'custom-colors-enabled' => 'no',
                    'custom-colors-background' => '#fff',
                    'custom-colors-spinner' => '#e87ab7'
                ),
                'local-scrolling-links-animation' => array(
                    'enabled' => 'yes',
                    'animation-speed' => '1000'
                ),
                'opening-hours-status' => array( 'next-status-id' => '1' ),
                'rtl' => array(
                    'is-rtl' => array( 'all' => 'no' ),
                    'load-rtl-admin-styles' => array( 'all' => 'auto' )
                ),
                'side-menu' => array(
                    'style' => 'flying-default-hidden',
                    'menu-key' => array( 'all' => self::get_trusted_solution( 'main-menu-slug', self::get_main_menu_slug() ) ),
                    'menu-link-font-family' => array( 'all' => 'Heebo' ),
                    'menu-link-font-weight' => array( 'all' => '500' ),
                    'menu-link-font-subset' => array( 'all' => 'latin' ),
                    'menu-link-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-position' => 'right',
                    'menu-links-alignment' => 'center',
                    'opacity-animation-enabled' => 'yes',
                    'submenu-links' => 'visible-on-click-as-new-layer',
                    'menu-vertical-alignment' => 'middle',
                    'custom-sizes-enabled' => 'no',
                    'custom-sizes-container-width' => '300',
                    'custom-sizes-menu-link-font-size' => '14',
                    'custom-sizes-menu-link-font-line-height' => '1.0',
                    'custom-sizes-menu-link-font-letter-spacing' => '0',
                    'custom-sizes-menu-link-padding-top-bottom' => '15',
                    'custom-sizes-menu-link-padding-left-right' => '25',
                    'custom-sizes-menu-link-margin-top-bottom' => '0',
                    'custom-sizes-menu-link-margin-left-right' => '0',
                    'custom-sizes-menu-link-bottom-border-width' => '1',
                    'custom-sizes-display-bottom-border-for-last-menu-link' => 'display',
                    'custom-sizes-menu-icon-font-size' => '10',
                    'custom-sizes-menu-icon-margin-top' => '0',
                    'custom-sizes-menu-margin-between-icon-and-title' => '10',
                    'custom-sizes-padding-top-bottom-additional-element-before-menu' => '20',
                    'custom-sizes-padding-left-right-additional-element-before-menu' => '30',
                    'custom-sizes-margin-top-additional-element-before-menu' => '0',
                    'custom-sizes-margin-right-additional-element-before-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-before-menu' => '0',
                    'custom-sizes-margin-left-additional-element-before-menu' => '0',
                    'custom-sizes-padding-top-bottom-additional-element-after-menu' => '20',
                    'custom-sizes-padding-left-right-additional-element-after-menu' => '30',
                    'custom-sizes-margin-top-additional-element-after-menu' => '0',
                    'custom-sizes-margin-right-additional-element-after-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-after-menu' => '0',
                    'custom-sizes-margin-left-additional-element-after-menu' => '0'
                ),
                'single-blog-post-style' => array(
                    'display-post-data-under-title' => 'yes',
                    'blog-post-data-and-title-centered' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'yes'
                ),
                'submit-button-position-in-comment-reply-form' => array( 'all' => 'left' ),
                'translate-publication-dates' => 'yes',
                'twitter-api' => array(
                    'oauth-key' => '',
                    'oauth-secret-key' => ''
                ),
                'under-single-blog-post-content-elements' => array(
                    'elements-count' => '3',
                    'element-1-type' => 'tags-and-categories-with-facebook',
                    'element-1-similar-posts-style' => '02',
                    'element-2-type' => 'author-box',
                    'element-2-similar-posts-style' => '02',
                    'element-3-type' => 'next-previous-posts-navigation',
                    'element-3-similar-posts-style' => '02',
                    'element-4-type' => '',
                    'element-4-similar-posts-style' => '02',
                    'element-5-type' => '',
                    'element-5-similar-posts-style' => '02',
                    'element-6-type' => '',
                    'element-6-similar-posts-style' => '02'
                ),
                'vc-sections-on-blog-pages' => array(
                    'posts-list-above' => array( 'all' => 'none' ),
                    'posts-list-under' => array( 'all' => 'none' ),
                    'single-post-above' => array( 'all' => 'none' ),
                    'single-post-under' => array( 'all' => 'none' ),
                    'archive-above' => array( 'all' => 'none' ),
                    'archive-under' => array( 'all' => 'none' ),
                    'search-above' => array( 'all' => 'none' ),
                    'search-under' => array( 'all' => 'none' )
                ),
                'visual-composer-custom-fonts' => array(
                    'next-font-id' => '2',
                    'font-1-family' => 'Roboto',
                    'font-1-weight' => '700',
                    'font-1-subset' => 'latin',
                    'font-1-smoothing' => 'yes'
                ),
                'styles' => array(
                    'line-height-headings' => '1.2',
                    'font-size-h1' => '48',
                    'general-colors-content-color' => '#9c9c9c',
                    'line-height-general' => '1.7',
                    'font-size-content' => '17',
                    'general-colors-image-box-shadow' => '0px 0px 0px 0px rgba(255,255,255,0.01)',
                    'buttons-global-button-padding-top' => '18',
                    'buttons-global-button-padding-bottom' => '16',
                    'general-colors-main-color' => '#e87ab7',
                    'buttons-global-button-background-color' => '#e87ab7',
                    'buttons-global-button-border-color' => '#e87ab7',
                    'font-size-h2' => '38',
                    'info-box-element-background-color' => '#ffffff',
                    'info-box-element-border-color' => '#ffffff',
                    'general-colors-headings-subtitle-color' => '#e87ab7',
                    'general-colors-blog-post-data-color' => '#e87ab7',
                    'general-colors-elements-border-color' => '#f6f9f9',
                    'font-size-h3' => '32',
                    'forms-checkbox-radio-main-color' => '#e87ab7',
                    'general-colors-blockquote-color' => '#e87ab7',
                    'buttons-global-button-background-color-hover' => '#313131',
                    'buttons-global-button-border-color-hover' => '#313131',
                    'buttons-global-button-box-shadow-hover' => '0px 10px 35px 0px rgba(49,49,49,0.15)',
                    'side-menu-box-shadow' => '-5px 0px 20px 0px rgba(49,49,49,0.15)',
                    'side-menu-background-color' => '#313131',
                    'side-menu-link-color' => 'rgba(255,255,255,0.45)'
                )
            ));
        }

       /**
        *
        * get default contents
        *
        */

        public static function get_vc_contents( $page_slug = false ) {

            # array of pages contents
            $contents = array(

                'home' => '[vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_65607528611287" large_height="75"][/vc_column][/vc_row][vc_row content_placement="middle"][vc_column offset="vc_col-lg-6 vc_col-md-8"][ueldo_shortcode_heading class_name="ueldo_vc_element_80685652318328" heading_tag="h1" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_41493973854186" heading_text="'. esc_html( __( 'Creative Agency with endless great ideas', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-4"][ueldo_shortcode_button class_name="ueldo_vc_element_51072392520286" button_visible_on_devices="large,medium" button_text="'. esc_html( __( 'More about us', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'about-us%2F|title:'. rawurlencode( esc_html( __( 'About us', 'ueldo' ) ) ) .'||" button_alignment="right"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_1508936041054" large_height="0" small_custom_sizes="yes" small_height="30"][ueldo_shortcode_button class_name="ueldo_vc_element_71620750449357" button_visible_on_devices="small,extra-small" button_text="'. esc_html( __( 'More about us', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'about-us%2F|title:'. rawurlencode( esc_html( __( 'About us', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_71252242582497" large_height="75"][/vc_column][/vc_row][vc_row][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_icon class_name="ueldo_vc_element_40793856228357" {ueldopredefinedsections:icon|key:flaticon-watercolor,flaticon-paint|url:https://www.flaticon.com/free-icon/watercolor_525651|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="15" custom_colors_enabled="custom_settings" icon_color="#e87ab7"][ueldo_shortcode_heading class_name="ueldo_vc_element_4439938075169" heading_tag="h3" display_heading_subtitle="no" heading_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'services%2Fdesign%2F|title:'. rawurlencode( esc_html( __( 'Design', 'ueldo' ) ) ) .'||"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_10283922215769" heading_text="'. esc_html( __( 'Design', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Nulla luctus in turpis vel finibus. Sed gravida dolor non dui commodo scelerisque. Morbi id tortor ultrices magna pulvinar.[/vc_column_text][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15089361330173" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_icon class_name="ueldo_vc_element_92563673874944" {ueldopredefinedsections:icon|key:flaticon-coding,flaticon-multimedia|url:https://www.flaticon.com/free-icon/coding_115764|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="15" custom_colors_enabled="custom_settings" icon_color="#e87ab7"][ueldo_shortcode_heading class_name="ueldo_vc_element_8327298528395" heading_tag="h3" display_heading_subtitle="no" heading_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'services%2Fdevelopment%2F|title:'. rawurlencode( esc_html( __( 'Development', 'ueldo' ) ) ) .'||"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_70583766078529" heading_text="'. esc_html( __( 'Development', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Nulla luctus in turpis vel finibus. Sed gravida dolor non dui commodo scelerisque. Morbi id tortor ultrices magna pulvinar.[/vc_column_text][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_1508936105242" large_height="0" small_custom_sizes="yes" small_height="45"][ueldo_shortcode_icon class_name="ueldo_vc_element_38684709836376" {ueldopredefinedsections:icon|key:flaticon-targeting,flaticon-arrow|url:https://www.flaticon.com/free-icon/targeting_115788|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="15" custom_colors_enabled="custom_settings" icon_color="#e87ab7"][ueldo_shortcode_heading class_name="ueldo_vc_element_5795406304194" heading_tag="h3" display_heading_subtitle="no" heading_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'services%2Fmarketing%2F|title:'. rawurlencode( esc_html( __( 'Marketing', 'ueldo' ) ) ) .'||"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_42117948372526" heading_text="'. esc_html( __( 'Marketing', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Nulla luctus in turpis vel finibus. Sed gravida dolor non dui commodo scelerisque. Morbi id tortor ultrices magna pulvinar.[/vc_column_text][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces" el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15083195967952" large_height="75"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15083217943068"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15087525109785" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="600" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_base="50%" medium_width_calc_px="496" small_custom_sizes="yes" small_width_type="calc" small_width_calc_base="50%" small_width_calc_px="384" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_35953166861849" large_width_type="px" large_width_px="598" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="494" small_custom_sizes="yes" small_width_type="px" small_width_px="382" extra_small_custom_sizes="yes"][ueldo_shortcode_card class_name="ueldo_vc_element_11244653119017" border_width="0" border_radius="2" padding_top="0" padding_right="0" padding_bottom="0" padding_left="0"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_73961709082521" layer_z_index="110" layer_type="image" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_74167300066980" layer_visibility="on_hover_only" layer_opacity="95%" layer_z_index="110" color="#e7a0b1" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_65128713936980" layer_title="'. esc_html( __( 'Content', 'ueldo' ) ) .'" layer_visibility="on_hover_only" layer_z_index="110" custom_layer_sizes="custom_settings" layer_type="text" text_content="'. esc_html( __( 'Ice Cream Ananas flavors', 'ueldo' ) ) .'" text_uppercase_enabled="no" text_alignment="left" text_font_size="18" text_color="#ffffff" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" large_height_type="px" large_height_px="18" large_layer_position="bottom_left" large_margin_bottom="53" large_margin_left="30"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_21654906140985" layer_title="'. esc_html( __( 'Content', 'ueldo' ) ) .'" layer_visibility="on_hover_only" layer_z_index="110" custom_layer_sizes="custom_settings" layer_type="text" text_content="'. esc_html( __( 'Check the details', 'ueldo' ) ) .'" text_font_family="headings-font" text_uppercase_enabled="no" text_alignment="left" text_font_size="16" text_color="rgba(255,255,255,0.7)" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" large_height_type="px" large_height_px="16" large_layer_position="bottom_left" large_margin_bottom="30" large_margin_left="30"][ueldo_shortcode_gap class_name="ueldo_vc_element_64028654589964" large_height="450" small_custom_sizes="yes" small_height="350"][/ueldo_shortcode_card][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_41807737241198" large_width_type="px" large_width_px="4" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_90760613958669" large_width_type="px" large_width_px="598" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="494" small_custom_sizes="yes" small_width_type="px" small_width_px="382" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15089968957097" large_height="0" extra_small_custom_sizes="yes" extra_small_height="4"][ueldo_shortcode_card class_name="ueldo_vc_element_61592391092510" border_width="0" border_radius="2" padding_top="0" padding_right="0" padding_bottom="0" padding_left="0"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_19422083140859" layer_z_index="110" layer_type="image" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_18331877207788" layer_visibility="on_hover_only" layer_opacity="95%" layer_z_index="110" color="#c3dae0" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_50869649847752" layer_title="'. esc_html( __( 'Content', 'ueldo' ) ) .'" layer_visibility="on_hover_only" layer_z_index="110" custom_layer_sizes="custom_settings" layer_type="text" text_content="'. esc_html( __( 'Ice Cream Ananas flavors', 'ueldo' ) ) .'" text_uppercase_enabled="no" text_alignment="left" text_font_size="18" text_color="#ffffff" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" large_height_type="px" large_height_px="18" large_layer_position="bottom_left" large_margin_bottom="53" large_margin_left="30"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_20836018107604" layer_title="'. esc_html( __( 'Content', 'ueldo' ) ) .'" layer_visibility="on_hover_only" layer_z_index="110" custom_layer_sizes="custom_settings" layer_type="text" text_content="'. esc_html( __( 'Check the details', 'ueldo' ) ) .'" text_font_family="headings-font" text_uppercase_enabled="no" text_alignment="left" text_font_size="16" text_color="rgba(255,255,255,0.7)" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" large_height_type="px" large_height_px="16" large_layer_position="bottom_left" large_margin_bottom="30" large_margin_left="30"][ueldo_shortcode_gap class_name="ueldo_vc_element_35912603635506" large_height="450" small_custom_sizes="yes" small_height="350"][/ueldo_shortcode_card][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_15083202712577" large_height="75"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_79188528340941" heading_tag="h1" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="60"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_64899669561051" heading_text="'. esc_html( __( 'Every great Marketing Campaign need a good Strategy.', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_column_text]Fusce ullamcorper, leo sed suscipit egestas, sapien mi consectetur leo, non fringilla erat mauris in ex. Aliquam erat volutpat. Integer interdum est at nisl tincidunt vulputate. Quisque in mauris ut augue lacinia tincidunt vitae interdum.[/vc_column_text][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15089969280657" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][vc_column_text]Pellentesque feugiat elit eget urna sagittis, at efficitur nulla mollis. Mauris ultricies erat turpis, a sodales erat consectetur in. Maecenas efficitur magna sem, vulputate fringilla mauris vehicula id. Cras sapien ante, tincidunt nec.[/vc_column_text][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_3951159732415"][ueldo_shortcode_button class_name="ueldo_vc_element_87808214230619" button_visible_on_devices="large,medium,small" button_text="'. esc_html( __( 'Find out more about campaign strategy', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'services%2Fmarketing%2F|title:'. rawurlencode( esc_html( __( 'Marketing', 'ueldo' ) ) ) .'||" button_alignment="center"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_33225090058309" button_visible_on_devices="extra-small" button_text="'. esc_html( __( 'Find out more about campaign strategy', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'services%2Fmarketing%2F|title:'. rawurlencode( esc_html( __( 'Marketing', 'ueldo' ) ) ) .'||" button_alignment="center" custom_sizes_enabled="custom_settings" standard_button_use_static_height="no"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_1290960267458" large_height="75"][/vc_column][/vc_row][/vc_section][vc_section el_class="ueldo-vc-section-overflow-visible"][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/6"][/vc_column][vc_column width="2/3"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15084196220384" custom_layer_sizes="custom_settings" color="rgba(255,255,255,0.01)" color_add_border="yes" color_border_width="5" large_width_type="calc" large_width_calc_px="30" large_margin_left="15" extra_small_layer_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_83089185952609"][ueldo_shortcode_heading class_name="ueldo_vc_element_15084192142239" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="60"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15084192260067" heading_text="``Orci varius natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Nunc nec porta ipsum. Curabitur dignissim vel nulla ac elementum.``" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" font_size="28"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_15084194774939" heading_tag="h6" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15084194885835" heading_text="'. esc_html( __( 'Susane Smith, CEO of OneOfOurClient, Inc.', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_image class_name="ueldo_vc_element_15084194214264" horizontal_alignment="center" border_radius="40" border_width="10" large_width_type="px" large_width_px="80" large_height_px="80" margin_bottom="-40"][/vc_column][vc_column width="1/6"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_27005856241563" large_height="75"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column width="1/4" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_8503350550877" heading_tag="h3" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_90151605831432" heading_text="'. esc_html( __( 'Est. 2001', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_8919859913186" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="75"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_79627935732310" heading_text="'. esc_html( __( 'Several years of experience & work with great Clients', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/4" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][ueldo_shortcode_info_box class_name="ueldo_vc_element_20449552095358" content_alignment="left" info_box_title="'. esc_html( __( 'Projects finished', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="200" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="273" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font" info_element_horizontal_alignment="left"][vc_column_text]Fusce risus nisi, laoreet at tristique vitae, ultrices sit amet urna. Curabitur a tempus.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_5692600988662" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_info_box class_name="ueldo_vc_element_79927715302389" content_alignment="left" info_box_title="'. esc_html( __( 'Team members', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="200" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="32" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font" info_element_horizontal_alignment="left"][vc_column_text]Fusce risus nisi, laoreet at tristique vitae, ultrices sit amet urna. Curabitur a tempus.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_2178652406945" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_info_box class_name="ueldo_vc_element_78456921838084" content_alignment="left" info_box_title="'. esc_html( __( 'Awards won', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="200" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="52" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font" info_element_horizontal_alignment="left"][vc_column_text]Fusce risus nisi, laoreet at tristique vitae, ultrices sit amet urna. Curabitur a tempus.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15084091913589" large_height="75"][/vc_column][/vc_row][/vc_section][vc_section el_class="ueldo-vc-section-overflow-visible"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15084092103321" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" color="#86afb9" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="20" large_margin_left="15" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="2" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_operator="+" extra_small_width_calc_px="30" extra_small_margin_left="-15"][ueldo_shortcode_gap class_name="ueldo_vc_element_15084144255034" large_height="45"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_1508414557478" custom_layer_sizes="custom_settings" layer_type="image" large_width_type="calc" large_width_calc_base="50%" large_width_calc_operator="+" large_width_calc_px="5" large_margin_left="-35" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="2" extra_small_layer_custom_sizes="yes" extra_small_height_type="px" extra_small_height_px="300" extra_small_margin_left="-15" extra_small_custom_row_border_radius="yes-unique-for-corners" extra_small_row_border_radius_top_right_corner="2" extra_small_row_border_radius_bottom_right_corner="2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15084146168443" large_height="450" extra_small_custom_sizes="yes" extra_small_height="345"][/vc_column][vc_column width="1/2"][ueldo_shortcode_heading class_name="ueldo_vc_element_15084139808545" heading_subtitle_text="'. esc_html( __( 'DIGITAL STRATEGY', 'ueldo' ) ) .'" custom_heading_subtitle_font_color_enabled="custom_settings" heading_subtitle_font_color="rgba(255,255,255,0.6)" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="30"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15084139878201" heading_text="'. esc_html( __( 'Present your Product most important attributes first and brightest.', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_color_enabled="custom_settings" font_color="#ffffff" font_color_hover="#ffffff"][/ueldo_shortcode_heading][vc_column_text]<span style="color: rgba( 255, 255, 255, 0.6 );">Sed consequat, purus et dictum euismod, magna leo ultricies velit, sed faucibus ligula dolor ut lectus. Duis placerat lorem rutrum, ornare lacus in, blandit risus. Proin convallis ante sit amet tellus lobortis.</span>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_22851124224625" large_height="45"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_64380983595364" large_height="75"][/vc_column][/vc_row][vc_row content_placement="middle"][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_7795133934005" heading_tag="h1" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="60"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_63224230555244" heading_text="'. esc_html( __( 'We\'re working with this amazing Clients, all around the world', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row content_placement="middle"][vc_column width="1/3"][ueldo_shortcode_image class_name="ueldo_vc_element_44821204619051" horizontal_alignment="center" border_radius="0" large_width_type="px" large_width_px="235" large_height_px="57" small_custom_sizes="yes" small_width_type="px" small_width_px="201" small_height_px="48" margin_bottom="0"][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_21296231247815" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_image class_name="ueldo_vc_element_71758385763724" horizontal_alignment="center" border_radius="0" large_width_type="px" large_width_px="258" large_height_px="64" small_custom_sizes="yes" small_width_type="px" small_width_px="201" small_height_px="50" margin_bottom="0"][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_29461074844802" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_image class_name="ueldo_vc_element_89302558852808" horizontal_alignment="center" border_radius="0" large_width_type="px" large_width_px="228" large_height_px="64" small_custom_sizes="yes" small_width_type="px" small_width_px="201" small_height_px="56" margin_bottom="0"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/6"][/vc_column][vc_column width="2/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_15084883721024"][vc_column_text]<p style="text-align: center;">Praesent rhoncus mauris ligula, nec lobortis sem blandit sed. Sed eget imperdiet nunc. Quisque dolor magna, volutpat nec justo eget, cursus elementum nulla. Integer hendrerit tellus volutpat. Sed elementum, nulla sed cursus malesuada, tellus lacus.</p>[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_97228655840263" button_text="'. esc_html( __( 'More about us', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'about-us%2F|title:'. rawurlencode( esc_html( __( 'About us', 'ueldo' ) ) ) .'||" button_alignment="center"][/ueldo_shortcode_button][/vc_column][vc_column width="1/6"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15084899149829" large_height="75"][/vc_column][/vc_row][/vc_section]',

                'about-us' => '[vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_54587392962718" large_height="75"][/vc_column][/vc_row][vc_row content_placement="middle"][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_209033653088" heading_tag="h1" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_46107153002629" heading_text="'. esc_html( __( 'Creative Agency you can trust and rely on.', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]Suspendisse et ultricies nisl, dapibus ultricies mauris. Maecenas leo felis, vulputate id fringilla ac, faucibus in sapien. Etiam porta erat lacinia sapien gravida, at lacinia tellus vehicula.[/vc_column_text][/vc_column][vc_column width="1/12" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-5 vc_col-md-5 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15087435035148" large_height="5" small_custom_sizes="yes" small_height="45"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15087433857546" vertical_alignment="top"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_35668464107128" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="25" medium_custom_sizes="yes" medium_width_percentage="70%" small_custom_sizes="yes" small_width_type="calc" small_width_calc_base="50%" small_width_calc_px="25" extra_small_custom_sizes="yes"][ueldo_shortcode_info_box class_name="ueldo_vc_element_70887433062073" content_alignment="left" info_box_title="'. esc_html( __( 'Percent of Satisfied Customers', 'ueldo' ) ) .'" info_box_subtitle="" info_element_display_as="progress-bar" progress_bar_value="97%" progress_bar_duration="2000" info_element_width="86" info_element_height="86" info_element_border_width="4" info_element_border_radius="px" info_element_border_radius_px="2" progress_bar_inset_border_radius="px" info_element_type="counter" info_element_counter_value="97" info_element_counter_duration="1500" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_font_size="45" info_element_counter_line_height="1" info_element_counter_font_family="Roboto,700" custom_colors_enabled="custom_settings" info_element_border_color="#e87ab7" info_element_border_color_hover="#e87ab7" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_72450506356421" large_width_type="px" large_width_px="50" medium_custom_sizes="yes" medium_width_percentage="0%" small_custom_sizes="yes" small_width_type="px" small_width_px="50" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_53140754859718" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="25" medium_custom_sizes="yes" medium_width_percentage="70%" small_custom_sizes="yes" small_width_type="calc" small_width_calc_base="50%" small_width_calc_px="25" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15089345108624" large_height="0" medium_custom_sizes="yes" medium_height="30" small_custom_sizes="yes" small_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_info_box class_name="ueldo_vc_element_31060933642310" content_alignment="left" info_box_title="'. esc_html( __( 'Percent of Clients from Recommendation', 'ueldo' ) ) .'" info_box_subtitle="" info_element_display_as="progress-bar" progress_bar_value="62%" info_element_width="86" info_element_height="86" info_element_border_width="4" info_element_border_radius="px" info_element_border_radius_px="2" progress_bar_inset_border_radius="px" info_element_type="counter" info_element_counter_value="62" info_element_counter_duration="1800" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_font_size="45" info_element_counter_line_height="1" info_element_counter_font_family="Roboto,700" custom_colors_enabled="custom_settings" info_element_border_color="#e87ab7" info_element_border_color_hover="#e87ab7" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_77589858639897" large_height="75"][/vc_column][/vc_row][/vc_section][vc_section][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_45163894185734" custom_layer_sizes="custom_settings" layer_type="image" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="70" large_margin_left="-35" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="2" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_operator="+" extra_small_width_calc_px="30" extra_small_margin_left="-15"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_30547835264144" layer_title="'. esc_html( __( 'Row background color', 'ueldo' ) ) .'" layer_opacity="85%" layer_z_index="2" custom_layer_sizes="custom_settings" color="#475356" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="70" large_margin_left="-35" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="2" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_operator="+" extra_small_width_calc_px="30" extra_small_margin_left="-15"][ueldo_shortcode_gap class_name="ueldo_vc_element_78957344955441" large_height="141" extra_small_custom_sizes="yes" extra_small_height="75"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15084978451291"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_31498279796825" large_width_type="px" large_width_px="150" small_custom_sizes="yes" small_width_type="px" small_width_px="60" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_49900734350024" large_width_type="calc" large_width_calc_px="300" large_content_alignment="center" small_custom_sizes="yes" small_width_type="calc" small_width_calc_px="120" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="60"][ueldo_shortcode_heading class_name="ueldo_vc_element_15084977371346" heading_tag="h1" text_align="center" custom_margins_enabled="custom_margins" custom_heading_subtitle_font_color_enabled="custom_settings" heading_subtitle_font_color="#ffffff" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="30" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15084977485578" heading_text="'. esc_html( __( 'We help you succeed with Online Marketing and grow your Company since 2001.', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_color_enabled="custom_settings" font_color="#ffffff" font_color_hover="#ffffff"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_35041561374308" large_width_type="px" large_width_px="150" small_custom_sizes="yes" small_width_type="px" small_width_px="60" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="30"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_32050479371200" large_height="141" extra_small_custom_sizes="yes" extra_small_height="75"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_94140941277073" large_height="75"][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_column_text]Ut rhoncus tristique erat, vel tincidunt libero pharetra sed. Pellentesque lacinia nisi nec lobortis pharetra. Integer id lacus a velit imperdiet aliquet. Nulla et hendrerit sapien, vitae pharetra ex. Donec malesuada auctor dolor, at dignissim sapien suscipit vel. Maecenas tincidunt ut lorem a fringilla. Nunc dapibus eget felis nec malesuada.[/vc_column_text][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15089978632388" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][vc_column_text]Morbi dignissim libero eget malesuada tempus. Maecenas quis ex ac ex imperdiet rutrum interdum tristique tortor. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Donec porttitor metus purus, et rutrum tortor commodo quis. Phasellus facilisis, ante quis pretium tempus, elit tellus.[/vc_column_text][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column offset="vc_col-lg-6 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15085002305815"][ueldo_shortcode_heading class_name="ueldo_vc_element_253644010169" heading_tag="h1" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="60"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_34058133596545" heading_text="'. esc_html( __( 'Meet our world-class, amazing Team', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/2" offset="vc_col-lg-6 vc_col-md-4 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_loop class_name="ueldo_vc_element_15085003163759" rows="2" masonry_enabled="yes" margin_between_columns="4" margin_between_rows="4"][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_88500721671627"][ueldo_shortcode_image class_name="ueldo_vc_element_67992506308185" additional="gallery_image" gallery_slug="team-gallery" border_radius="2" large_height_px="250"][ueldo_shortcode_heading class_name="ueldo_vc_element_41490862963920" heading_tag="h6" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_43078521415822" heading_text="'. esc_html( __( 'Susane Smith', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_39471364794054" heading_tag="h6" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_71511988637428" heading_text="'. esc_html( __( 'CEO', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_89932650127670"][ueldo_shortcode_image class_name="ueldo_vc_element_59757912481476" additional="gallery_image" gallery_slug="team-gallery" border_radius="2" large_height_px="250"][ueldo_shortcode_heading class_name="ueldo_vc_element_46876255970854" heading_tag="h6" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_59892551273433" heading_text="'. esc_html( __( 'Monica Wayne', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_27754835971810" heading_tag="h6" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_61757325483255" heading_text="'. esc_html( __( 'CTO', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_38097914208113"][ueldo_shortcode_image class_name="ueldo_vc_element_36045850148237" additional="gallery_image" gallery_slug="team-gallery" border_radius="2" large_height_px="250"][ueldo_shortcode_heading class_name="ueldo_vc_element_81825831851005" heading_tag="h6" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_35566588742881" heading_text="'. esc_html( __( 'Mike McDonovan', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_46409569511148" heading_tag="h6" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_29504295151615" heading_text="'. esc_html( __( 'CFO', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_83655057226802"][ueldo_shortcode_image class_name="ueldo_vc_element_67148586024339" additional="gallery_image" gallery_slug="team-gallery" border_radius="2" large_height_px="250"][ueldo_shortcode_heading class_name="ueldo_vc_element_82299477368853" heading_tag="h6" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_96207624893910" heading_text="'. esc_html( __( 'Anne Wayne', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_26817622656446" heading_tag="h6" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_44179593145119" heading_text="'. esc_html( __( 'Customer Relation Manager', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_42290468912276"][ueldo_shortcode_image class_name="ueldo_vc_element_85248011885569" additional="gallery_image" gallery_slug="team-gallery" border_radius="2" large_height_px="250"][ueldo_shortcode_heading class_name="ueldo_vc_element_25242500033406" heading_tag="h6" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_88520684119304" heading_text="'. esc_html( __( 'Sarah Smith', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_92915280810818" heading_tag="h6" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_72258648845823" heading_text="'. esc_html( __( 'Graphic Designer', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_34232529573781"][ueldo_shortcode_image class_name="ueldo_vc_element_42716966507125" additional="gallery_image" gallery_slug="team-gallery" border_radius="2" large_height_px="250"][ueldo_shortcode_heading class_name="ueldo_vc_element_15316850476616" heading_tag="h6" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_47937007320076" heading_text="'. esc_html( __( 'John Doe', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_87502420813165" heading_tag="h6" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_53233767340574" heading_text="'. esc_html( __( 'Front-end Developer', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/ueldo_shortcode_loop_cell][/ueldo_shortcode_loop][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15087610398592" large_height="45"][/vc_column][/vc_row][/vc_section][vc_section el_class="ueldo-vc-section-overflow-visible"][vc_row][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_icon class_name="ueldo_vc_element_15088297357274" icon_alignment="center" {ueldopredefinedsections:icon|key:flaticon-trophy,flaticon-cup|url:https://www.flaticon.com/free-icon/trophy_420105|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="60" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e87ab7"][ueldo_shortcode_heading class_name="ueldo_vc_element_15088295790729" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15088295853588" heading_text="'. esc_html( __( 'Read our amazing Success Stories', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">In hac habitasse platea dictumst. Donec ultricies sollicitudin ante, eu lobortis eros bibendum sed. Vestibulum odio metus, viverra sagittis tempus ut, gravida vel metus. Sed mattis magna at justo tincidunt tempor. Ut vitae feugiat justo.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15088298218539" large_height="25"][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/3"][ueldo_shortcode_button class_name="ueldo_vc_element_20828411504312" button_type="two-line-button" button_text="'. esc_html( __( '400% ONLINE TRAFFIC GROWTH', 'ueldo' ) ) .'" two_line_button_text_font_family="headings-font" second_line_text="'. esc_html( __( 'Example Construction, Inc.', 'ueldo' ) ) .'" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Download', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_position="above-left" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_icon_size="42" two_line_button_margin_between_icon_and_button_texts="20" two_line_button_padding_top="30" two_line_button_padding_right="30" two_line_button_padding_bottom="30" two_line_button_padding_left="30" two_line_button_use_static_width="yes-full-width" custom_colors_enabled="custom_settings" two_line_button_background_color="#ffffff" two_line_button_background_color_hover="#f7f9fa" two_line_button_border_color="#ffffff" two_line_button_border_color_hover="#f7f9fa" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_first_line_color="#cecece" two_line_button_first_line_color_hover="#cecece" two_line_button_first_line_text_shadow_color="rgba(255,255,255,0.01)" two_line_button_first_line_text_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_icon_color="#f4f4f4" two_line_button_icon_color_hover="#e73a30" two_line_button_icon_text_shadow_color="rgba(255,255,255,0.01)" two_line_button_icon_text_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_button][/vc_column][vc_column width="1/3"][ueldo_shortcode_button class_name="ueldo_vc_element_20796691732273" button_type="two-line-button" button_text="'. esc_html( __( 'CONVERSION INCREASED TO 4%', 'ueldo' ) ) .'" two_line_button_text_font_family="headings-font" second_line_text="'. esc_html( __( 'Some Insurance & Co.', 'ueldo' ) ) .'" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Download', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_position="above-left" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_icon_size="42" two_line_button_margin_between_icon_and_button_texts="20" two_line_button_padding_top="30" two_line_button_padding_right="30" two_line_button_padding_bottom="30" two_line_button_padding_left="30" two_line_button_use_static_width="yes-full-width" custom_colors_enabled="custom_settings" two_line_button_background_color="#ffffff" two_line_button_background_color_hover="#f7f9fa" two_line_button_border_color="#ffffff" two_line_button_border_color_hover="#f7f9fa" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_first_line_color="#cecece" two_line_button_first_line_color_hover="#cecece" two_line_button_first_line_text_shadow_color="rgba(255,255,255,0.01)" two_line_button_first_line_text_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_icon_color="#f4f4f4" two_line_button_icon_color_hover="#e73a30" two_line_button_icon_text_shadow_color="rgba(255,255,255,0.01)" two_line_button_icon_text_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_button][/vc_column][vc_column width="1/3"][ueldo_shortcode_button class_name="ueldo_vc_element_22166432887878" button_type="two-line-button" button_text="'. esc_html( __( 'BRAND RECOGNITION RATE UPDATED TO 72%', 'ueldo' ) ) .'" two_line_button_text_font_family="headings-font" second_line_text="'. esc_html( __( 'Just Another Company, LLC', 'ueldo' ) ) .'" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Download', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_position="above-left" button_icon_fontawesome="fa fa-file-pdf-o" custom_sizes_enabled="custom_settings" two_line_button_icon_size="42" two_line_button_margin_between_icon_and_button_texts="20" two_line_button_padding_top="30" two_line_button_padding_right="30" two_line_button_padding_bottom="30" two_line_button_padding_left="30" two_line_button_use_static_width="yes-full-width" custom_colors_enabled="custom_settings" two_line_button_background_color="#ffffff" two_line_button_background_color_hover="#f7f9fa" two_line_button_border_color="#ffffff" two_line_button_border_color_hover="#f7f9fa" two_line_button_box_shadow_color="rgba(255,255,255,0.01)" two_line_button_box_shadow_blur_radius_hover="0" two_line_button_box_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_first_line_color="#cecece" two_line_button_first_line_color_hover="#cecece" two_line_button_first_line_text_shadow_color="rgba(255,255,255,0.01)" two_line_button_first_line_text_shadow_color_hover="rgba(255,255,255,0.01)" two_line_button_icon_color="#f4f4f4" two_line_button_icon_color_hover="#e73a30" two_line_button_icon_text_shadow_color="rgba(255,255,255,0.01)" two_line_button_icon_text_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_1508829602187" large_height="75"][/vc_column][/vc_row][/vc_section][vc_section el_class="ueldo-vc-section-overflow-visible"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15084092103321" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" color="#86afb9" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="20" large_margin_left="15" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="2" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_operator="+" extra_small_width_calc_px="30" extra_small_margin_left="-15"][ueldo_shortcode_gap class_name="ueldo_vc_element_15084144255034" large_height="45"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_1508414557478" custom_layer_sizes="custom_settings" layer_type="image" large_width_type="calc" large_width_calc_base="50%" large_width_calc_operator="+" large_width_calc_px="5" large_margin_left="-35" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="2" extra_small_layer_custom_sizes="yes" extra_small_height_type="px" extra_small_height_px="300" extra_small_margin_left="-15" extra_small_custom_row_border_radius="yes-unique-for-corners" extra_small_row_border_radius_top_right_corner="2" extra_small_row_border_radius_bottom_right_corner="2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15084146168443" large_height="450" extra_small_custom_sizes="yes" extra_small_height="345"][/vc_column][vc_column width="1/2"][ueldo_shortcode_heading class_name="ueldo_vc_element_15084139808545" heading_subtitle_text="'. esc_html( __( 'DIGITAL STRATEGY', 'ueldo' ) ) .'" custom_heading_subtitle_font_color_enabled="custom_settings" heading_subtitle_font_color="rgba(255,255,255,0.6)" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="30"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15084139878201" heading_text="'. esc_html( __( 'Present your Product most important attributes first and brightest.', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_color_enabled="custom_settings" font_color="#ffffff" font_color_hover="#ffffff"][/ueldo_shortcode_heading][vc_column_text]<span style="color: rgba( 255, 255, 255, 0.6 );">Sed consequat, purus et dictum euismod, magna leo ultricies velit, sed faucibus ligula dolor ut lectus. Duis placerat lorem rutrum, ornare lacus in, blandit risus. Proin convallis ante sit amet tellus lobortis.</span>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_22851124224625" large_height="45"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_64587392962718" large_height="75"][/vc_column][/vc_row][/vc_section]',

                'contact' => '[vc_section][vc_row full_width="stretch_row_content_no_spaces" el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15087485868816"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15087486111948" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="600" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_base="50%" medium_width_calc_px="496" small_custom_sizes="yes" small_width_type="calc" small_width_calc_base="50%" small_width_calc_px="384" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15087485908835" large_width_type="px" large_width_px="1200" large_content_alignment="center" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="992" small_custom_sizes="yes" small_width_type="px" small_width_px="768" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15089991922485" large_height="45" extra_small_custom_sizes="yes" extra_small_height="0"][ueldo_shortcode_google_map class_name="ueldo_vc_element_15087447160805" {ueldopredefinedsections:googlemap|context:creative-agency} large_height_px="450" margin_bottom="75"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_80855224027010"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_58979699954012" large_width_type="calc" large_width_calc_px="140" medium_custom_sizes="yes" medium_width_percentage="100%"][ueldo_shortcode_heading class_name="ueldo_vc_element_19801120920961" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_72044853442110" heading_text="'. esc_html( __( 'Direct contact details', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_87167493372388" heading_tag="h4" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_75754157234227" heading_text="'. esc_html( __( 'Ueldo Creative Agency', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]'. esc_html( __( '1234 Example Street,', 'ueldo' ) ) .'<br />'. esc_html( __( 'Los Angeles, CA 98765', 'ueldo' ) ) .'<br /><br /><strong>'. esc_html( __( 'E-mail:', 'ueldo' ) ) .'</strong> <a href="'. esc_url( __( 'mailto:contact@example.com', 'ueldo' ) ) .'">'. esc_html( __( 'contact@example.com', 'ueldo' ) ) .'</a><br /><strong>'. esc_html( __( 'Postbox:', 'ueldo' ) ) .'</strong> 1234567[/vc_column_text][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12 vc_hidden-xs"][ueldo_shortcode_heading class_name="ueldo_vc_element_93374077232097" text_align="right" display_heading_subtitle="no" heading_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_70733129772085" heading_text="1-800-123-4567" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" font_size="42" line_height="1" letter_spacing="-3" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: right;">'. esc_html( __( 'Available 8:00am - 4:00pm', 'ueldo' ) ) .'<br />'. wp_kses( __( 'Also available on <a href="#">Skype</a>', 'ueldo' ), array( 'a' => array( 'href' => array(), 'target' => array() ) ) ) .'</p>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_gap class_name="ueldo_vc_element_1508999150957" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_heading class_name="ueldo_vc_element_16505881472150" display_heading_subtitle="no" heading_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_11949990364659" heading_text="1-800-123-4567" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" font_size="42" line_height="1" letter_spacing="-3" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]'. esc_html( __( 'Available 8:00am - 4:00pm', 'ueldo' ) ) .'<br />'. wp_kses( __( 'Also available on <a href="#">Skype</a>', 'ueldo' ), array( 'a' => array( 'href' => array(), 'target' => array() ) ) ) .'[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_57157314128915" large_height="75"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_97900362580605"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_62920568478432" large_width_type="calc" large_width_calc_px="140" medium_custom_sizes="yes" medium_width_percentage="88%"][ueldo_shortcode_heading class_name="ueldo_vc_element_85034977545202" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_56246128627473" heading_text="'. esc_html( __( 'Send us an email', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][contact-form-7 {ueldopredefinedsections:contactform7|context:creative-agency|inside:false}][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_48212919111452" large_height="75"][/vc_column][/vc_row][/vc_section]',

                '404-page' => '[vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_23544039339517" large_height="75"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15087496040376" heading_tag="h1" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15087496125317" heading_text="'. esc_html( __( 'Nothing found here...', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Nam posuere justo vitae consequat congue. Nulla facilisi. Nunc non rhoncus quam. Donec luctus malesuada ante, a porttitor felis finibus ut. Curabitur tortor purus, hendrerit a pharetra eu, bibendum vel nisi. Praesent viverra aliquet justo. Nunc tincidunt iaculis.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15087497463419" large_height="25"][ueldo_shortcode_button class_name="ueldo_vc_element_15087496923284" button_text="'. esc_html( __( 'Go to home page', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'|title:'. rawurlencode( esc_html( __( 'Home page', 'ueldo' ) ) ) .'||" button_alignment="center"][/ueldo_shortcode_button][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15087499255155" large_height="75"][/vc_column][/vc_row][/vc_section][vc_section][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15087501410539"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15087501498175" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="600" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_base="50%" medium_width_calc_px="496" small_custom_sizes="yes" small_width_type="calc" small_width_calc_base="50%" small_width_calc_px="384" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15087501654787" large_width_type="px" large_width_px="398" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="328" small_custom_sizes="yes" small_width_type="px" small_width_px="254" extra_small_custom_sizes="yes"][ueldo_shortcode_card class_name="ueldo_vc_element_27763624788185" border_width="0" border_radius="2" padding_top="0" padding_right="0" padding_bottom="0" padding_left="0"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_26959573054302" layer_z_index="110" layer_type="image" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_13532162838452" layer_visibility="on_hover_only" layer_opacity="95%" layer_z_index="110" color="#ffd041" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_54600301743578" layer_title="'. esc_html( __( 'Content', 'ueldo' ) ) .'" layer_visibility="on_hover_only" layer_z_index="110" custom_layer_sizes="custom_settings" layer_type="text" text_content="'. esc_html( __( 'Ice Cream Ananas flavors', 'ueldo' ) ) .'" text_uppercase_enabled="no" text_alignment="left" text_font_size="18" text_color="#ffffff" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" large_height_type="px" large_height_px="18" large_layer_position="bottom_left" large_margin_bottom="53" large_margin_left="30"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_73270866061859" layer_title="'. esc_html( __( 'Content', 'ueldo' ) ) .'" layer_visibility="on_hover_only" layer_z_index="110" custom_layer_sizes="custom_settings" layer_type="text" text_content="'. esc_html( __( 'Check the details', 'ueldo' ) ) .'" text_font_family="headings-font" text_uppercase_enabled="no" text_alignment="left" text_font_size="16" text_color="rgba(255,255,255,0.7)" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" large_height_type="px" large_height_px="16" large_layer_position="bottom_left" large_margin_bottom="30" large_margin_left="30"][ueldo_shortcode_gap class_name="ueldo_vc_element_94988006105838" large_height="350" small_custom_sizes="yes" small_height="300"][/ueldo_shortcode_card][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15087501896906" large_width_type="px" large_width_px="3" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="4" small_custom_sizes="yes" small_width_type="px" small_width_px="3" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15087501954114" large_width_type="px" large_width_px="398" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="328" small_custom_sizes="yes" small_width_type="px" small_width_px="254" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_47374420185028" large_height="0" extra_small_custom_sizes="yes" extra_small_height="4"][ueldo_shortcode_card class_name="ueldo_vc_element_10831951027947" border_width="0" border_radius="2" padding_top="0" padding_right="0" padding_bottom="0" padding_left="0"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_47338944133168" layer_z_index="110" layer_type="image" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_15667498789011" layer_visibility="on_hover_only" layer_opacity="95%" layer_z_index="110" color="#fecfda" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_68856103780383" layer_title="'. esc_html( __( 'Content', 'ueldo' ) ) .'" layer_visibility="on_hover_only" layer_z_index="110" custom_layer_sizes="custom_settings" layer_type="text" text_content="'. esc_html( __( 'Ice Cream Ananas flavors', 'ueldo' ) ) .'" text_uppercase_enabled="no" text_alignment="left" text_font_size="18" text_color="#ffffff" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" large_height_type="px" large_height_px="18" large_layer_position="bottom_left" large_margin_bottom="53" large_margin_left="30"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_22534589302826" layer_title="'. esc_html( __( 'Content', 'ueldo' ) ) .'" layer_visibility="on_hover_only" layer_z_index="110" custom_layer_sizes="custom_settings" layer_type="text" text_content="'. esc_html( __( 'Check the details', 'ueldo' ) ) .'" text_font_family="headings-font" text_uppercase_enabled="no" text_alignment="left" text_font_size="16" text_color="rgba(255,255,255,0.7)" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" large_height_type="px" large_height_px="16" large_layer_position="bottom_left" large_margin_bottom="30" large_margin_left="30"][ueldo_shortcode_gap class_name="ueldo_vc_element_58500802014040" large_height="350" small_custom_sizes="yes" small_height="300"][/ueldo_shortcode_card][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15087502061938" large_width_type="px" large_width_px="3" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="4" small_custom_sizes="yes" small_width_type="px" small_width_px="3" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15087502128196" large_width_type="px" large_width_px="398" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="328" small_custom_sizes="yes" small_width_type="px" small_width_px="254" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_59591321763953" large_height="0" extra_small_custom_sizes="yes" extra_small_height="4"][ueldo_shortcode_card class_name="ueldo_vc_element_66561867395590" border_width="0" border_radius="2" padding_top="0" padding_right="0" padding_bottom="0" padding_left="0"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_17386462803865" layer_z_index="110" layer_type="image" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_37886385508989" layer_visibility="on_hover_only" layer_opacity="95%" layer_z_index="110" color="#99dbd9" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_36541219918521" layer_title="'. esc_html( __( 'Content', 'ueldo' ) ) .'" layer_visibility="on_hover_only" layer_z_index="110" custom_layer_sizes="custom_settings" layer_type="text" text_content="'. esc_html( __( 'Ice Cream Ananas flavors', 'ueldo' ) ) .'" text_uppercase_enabled="no" text_alignment="left" text_font_size="18" text_color="#ffffff" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" large_height_type="px" large_height_px="18" large_layer_position="bottom_left" large_margin_bottom="53" large_margin_left="30"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_34416252772324" layer_title="'. esc_html( __( 'Content', 'ueldo' ) ) .'" layer_visibility="on_hover_only" layer_z_index="110" custom_layer_sizes="custom_settings" layer_type="text" text_content="'. esc_html( __( 'Check the details', 'ueldo' ) ) .'" text_font_family="headings-font" text_uppercase_enabled="no" text_alignment="left" text_font_size="16" text_color="rgba(255,255,255,0.7)" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" large_height_type="px" large_height_px="16" large_layer_position="bottom_left" large_margin_bottom="30" large_margin_left="30"][ueldo_shortcode_gap class_name="ueldo_vc_element_57102031521329" large_height="350" small_custom_sizes="yes" small_height="300"][/ueldo_shortcode_card][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column offset="vc_hidden-xs"][ueldo_shortcode_gap class_name="ueldo_vc_element_15087500399384" large_height="75" extra_small_custom_sizes="yes" extra_small_height="0"][/vc_column][/vc_row][/vc_section]',

                'portfolio' => '[vc_section][vc_row][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_41091459390954" large_height="75"][ueldo_shortcode_heading class_name="ueldo_vc_element_15088500176611" heading_tag="h1" text_align="center" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Portfolio of our works', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="30" custom_margin_bottom="75"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15088500461097" heading_text="'. esc_html( __( 'We put all of our hearts and knowledge to every single project.', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_image class_name="ueldo_vc_element_26029737572438" border_radius="2" large_height_px="350" small_custom_sizes="yes" margin_bottom="-30"][ueldo_shortcode_button class_name="ueldo_vc_element_45326152419781" button_type="two-line-button" button_text="'. esc_html( __( 'Check project details', 'ueldo' ) ) .'" two_line_button_text_font_family="headings-font" second_line_text="'. esc_html( __( 'Flaming Toys Distribution, Inc.', 'ueldo' ) ) .'" second_line_position="top" second_line_text_font_family="headings-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" custom_sizes_enabled="custom_settings" additional_margin_before="30" additional_margin_after="30" two_line_button_title_letter_spacing="0" two_line_button_subtitle_font_size="18" two_line_button_padding_top="25" two_line_button_padding_right="30" two_line_button_padding_bottom="25" two_line_button_padding_left="30" two_line_button_use_static_width="yes-full-width" two_line_button_border_radius="2" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_background_color="#ffffff" two_line_button_background_color_hover="#313131" two_line_button_box_shadow_vertical_length="10" two_line_button_box_shadow_blur_radius="35" two_line_button_box_shadow_color="rgba(0,0,0,0.05)" two_line_button_box_shadow_vertical_length_hover="10" two_line_button_box_shadow_color_hover="rgba(0,0,0,0.05)" two_line_button_first_line_color="#e87ab7" two_line_button_first_line_color_hover="#e87ab7" two_line_button_second_line_color_hover="#ffffff"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_15088506025713"][/vc_column][vc_column width="1/2"][ueldo_shortcode_image class_name="ueldo_vc_element_84751296244736" border_radius="2" large_height_px="350" small_custom_sizes="yes" margin_bottom="-30"][ueldo_shortcode_button class_name="ueldo_vc_element_44778030979140" button_type="two-line-button" button_text="'. esc_html( __( 'Check project details', 'ueldo' ) ) .'" two_line_button_text_font_family="headings-font" second_line_text="'. esc_html( __( 'Tasty Coconut Export, Inc.', 'ueldo' ) ) .'" second_line_position="top" second_line_text_font_family="headings-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" custom_sizes_enabled="custom_settings" additional_margin_before="30" additional_margin_after="30" two_line_button_title_letter_spacing="0" two_line_button_subtitle_font_size="18" two_line_button_padding_top="25" two_line_button_padding_right="30" two_line_button_padding_bottom="25" two_line_button_padding_left="30" two_line_button_use_static_width="yes-full-width" two_line_button_border_radius="2" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_background_color="#ffffff" two_line_button_background_color_hover="#313131" two_line_button_box_shadow_vertical_length="10" two_line_button_box_shadow_blur_radius="35" two_line_button_box_shadow_color="rgba(0,0,0,0.05)" two_line_button_box_shadow_vertical_length_hover="10" two_line_button_box_shadow_color_hover="rgba(0,0,0,0.05)" two_line_button_first_line_color="#e87ab7" two_line_button_first_line_color_hover="#e87ab7" two_line_button_second_line_color_hover="#ffffff"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_15088506060051"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_image class_name="ueldo_vc_element_39663426107500" border_radius="2" large_height_px="350" small_custom_sizes="yes" margin_bottom="-30"][ueldo_shortcode_button class_name="ueldo_vc_element_26229512687290" button_type="two-line-button" button_text="'. esc_html( __( 'Check project details', 'ueldo' ) ) .'" two_line_button_text_font_family="headings-font" second_line_text="'. esc_html( __( 'Get Tropical Plants, Inc.', 'ueldo' ) ) .'" second_line_position="top" second_line_text_font_family="headings-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" custom_sizes_enabled="custom_settings" additional_margin_before="30" additional_margin_after="30" two_line_button_title_letter_spacing="0" two_line_button_subtitle_font_size="18" two_line_button_padding_top="25" two_line_button_padding_right="30" two_line_button_padding_bottom="25" two_line_button_padding_left="30" two_line_button_use_static_width="yes-full-width" two_line_button_border_radius="2" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_background_color="#ffffff" two_line_button_background_color_hover="#313131" two_line_button_box_shadow_vertical_length="10" two_line_button_box_shadow_blur_radius="35" two_line_button_box_shadow_color="rgba(0,0,0,0.05)" two_line_button_box_shadow_vertical_length_hover="10" two_line_button_box_shadow_color_hover="rgba(0,0,0,0.05)" two_line_button_first_line_color="#e87ab7" two_line_button_first_line_color_hover="#e87ab7" two_line_button_second_line_color_hover="#ffffff"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_15089132242745"][/vc_column][vc_column width="1/2"][ueldo_shortcode_image class_name="ueldo_vc_element_89506688647563" border_radius="2" large_height_px="350" small_custom_sizes="yes" margin_bottom="-30"][ueldo_shortcode_button class_name="ueldo_vc_element_43892018892029" button_type="two-line-button" button_text="'. esc_html( __( 'Check project details', 'ueldo' ) ) .'" two_line_button_text_font_family="headings-font" second_line_text="'. esc_html( __( 'Fruity Ice Creams, Inc.', 'ueldo' ) ) .'" second_line_position="top" second_line_text_font_family="headings-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" custom_sizes_enabled="custom_settings" additional_margin_before="30" additional_margin_after="30" two_line_button_title_letter_spacing="0" two_line_button_subtitle_font_size="18" two_line_button_padding_top="25" two_line_button_padding_right="30" two_line_button_padding_bottom="25" two_line_button_padding_left="30" two_line_button_use_static_width="yes-full-width" two_line_button_border_radius="2" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_background_color="#ffffff" two_line_button_background_color_hover="#313131" two_line_button_box_shadow_vertical_length="10" two_line_button_box_shadow_blur_radius="35" two_line_button_box_shadow_color="rgba(0,0,0,0.05)" two_line_button_box_shadow_vertical_length_hover="10" two_line_button_box_shadow_color_hover="rgba(0,0,0,0.05)" two_line_button_first_line_color="#e87ab7" two_line_button_first_line_color_hover="#e87ab7" two_line_button_second_line_color_hover="#ffffff"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_15089132280781"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_image class_name="ueldo_vc_element_89215102700710" border_radius="2" large_height_px="350" small_custom_sizes="yes" margin_bottom="-30"][ueldo_shortcode_button class_name="ueldo_vc_element_35763116515027" button_type="two-line-button" button_text="'. esc_html( __( 'Check project details', 'ueldo' ) ) .'" two_line_button_text_font_family="headings-font" second_line_text="'. esc_html( __( 'Example Clothes, Inc.', 'ueldo' ) ) .'" second_line_position="top" second_line_text_font_family="headings-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" custom_sizes_enabled="custom_settings" additional_margin_before="30" additional_margin_after="30" two_line_button_title_letter_spacing="0" two_line_button_subtitle_font_size="18" two_line_button_padding_top="25" two_line_button_padding_right="30" two_line_button_padding_bottom="25" two_line_button_padding_left="30" two_line_button_use_static_width="yes-full-width" two_line_button_border_radius="2" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_background_color="#ffffff" two_line_button_background_color_hover="#313131" two_line_button_box_shadow_vertical_length="10" two_line_button_box_shadow_blur_radius="35" two_line_button_box_shadow_color="rgba(0,0,0,0.05)" two_line_button_box_shadow_vertical_length_hover="10" two_line_button_box_shadow_color_hover="rgba(0,0,0,0.05)" two_line_button_first_line_color="#e87ab7" two_line_button_first_line_color_hover="#e87ab7" two_line_button_second_line_color_hover="#ffffff"][/ueldo_shortcode_button][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_1508998088874" large_height="0" extra_small_custom_sizes="yes"][ueldo_shortcode_image class_name="ueldo_vc_element_63469425906099" border_radius="2" large_height_px="350" small_custom_sizes="yes" margin_bottom="-30"][ueldo_shortcode_button class_name="ueldo_vc_element_16229190845734" button_type="two-line-button" button_text="'. esc_html( __( 'Check project details', 'ueldo' ) ) .'" two_line_button_text_font_family="headings-font" second_line_text="'. esc_html( __( 'Blue Bananas Trade, Inc.', 'ueldo' ) ) .'" second_line_position="top" second_line_text_font_family="headings-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" custom_sizes_enabled="custom_settings" additional_margin_before="30" additional_margin_after="30" two_line_button_title_letter_spacing="0" two_line_button_subtitle_font_size="18" two_line_button_padding_top="25" two_line_button_padding_right="30" two_line_button_padding_bottom="25" two_line_button_padding_left="30" two_line_button_use_static_width="yes-full-width" two_line_button_border_radius="2" two_line_button_border_width="0" custom_colors_enabled="custom_settings" two_line_button_background_color="#ffffff" two_line_button_background_color_hover="#313131" two_line_button_box_shadow_vertical_length="10" two_line_button_box_shadow_blur_radius="35" two_line_button_box_shadow_color="rgba(0,0,0,0.05)" two_line_button_box_shadow_vertical_length_hover="10" two_line_button_box_shadow_color_hover="rgba(0,0,0,0.05)" two_line_button_first_line_color="#e87ab7" two_line_button_first_line_color_hover="#e87ab7" two_line_button_second_line_color_hover="#ffffff"][/ueldo_shortcode_button][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_57787249984679" large_height="75"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="2/3" offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15088465834401" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15088465900149" heading_text="'. esc_html( __( 'Let\'s do something together. Today!', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/3" offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_button class_name="ueldo_vc_element_58172872537472" button_visible_on_devices="large,medium,small" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" button_alignment="right"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_15089981290386" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_button class_name="ueldo_vc_element_12110931816824" button_visible_on_devices="extra-small" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_53806992738499" large_height="75"][/vc_column][/vc_row][/vc_section]',

                'single-portfolio-project' => '[vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_90153125835476" large_height="75"][ueldo_shortcode_heading class_name="ueldo_vc_element_96582773113677" heading_tag="h1" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_98845081184406" heading_text="'. esc_html( __( 'Fruity Ice Creams, Inc.', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]Donec sollicitudin consequat sapien, non dapibus lorem laoreet ac. Pellentesque consectetur dapibus augue sit amet sagittis. Nunc mi tortor, porta non dignissim tincidunt, sagittis at dolor. Curabitur ac magna nec odio sagittis tincidunt a in erat. Nunc sollicitudin orci eget lectus pretium, a congue nunc auctor. In dictum arcu leo, at elementum dui.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15089154661631" large_height="25"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][ueldo_shortcode_info_box class_name="ueldo_vc_element_37914400632636" content_alignment="left" display_additional_info_box_element="yes" info_box_title="'. esc_html( __( 'Conversion rate increased', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="200" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="407" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font" info_element_horizontal_alignment="left" additional_info_element_position="left_center" additional_info_element_width="28" additional_info_element_height="28" additional_info_element_margin_left="98" additional_info_element_border_radius="px" additional_info_element_border_radius_px="0" additional_info_element_text="%" additional_info_element_text_custom_font_enabled="custom_settings" additional_info_element_text_font_size="28" additional_info_element_text_font_family="headings-bold-font" custom_colors_enabled="custom_settings" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)" additional_info_element_background_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" additional_info_element_background_color_hover="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" additional_info_element_text_color="#e87ab7" additional_info_element_text_color_hover="#e87ab7" additional_info_element_box_shadow_blur_radius="0" additional_info_element_box_shadow_color="rgba(255,255,255,0.01)" additional_info_element_box_shadow_blur_radius_hover="0" additional_info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][vc_column_text]Fusce risus nisi, laoreet at tristique vitae, ultrices sit amet urna. Curabitur a tempus.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_37333552363439" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_info_box class_name="ueldo_vc_element_93213471438326" content_alignment="left" display_additional_info_box_element="yes" info_box_title="'. esc_html( __( 'Online Traffic Increased', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="200" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="289" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font" info_element_horizontal_alignment="left" additional_info_element_position="left_center" additional_info_element_width="28" additional_info_element_height="28" additional_info_element_margin_left="98" additional_info_element_border_radius="px" additional_info_element_border_radius_px="0" additional_info_element_text="%" additional_info_element_text_custom_font_enabled="custom_settings" additional_info_element_text_font_size="28" additional_info_element_text_font_family="headings-bold-font" custom_colors_enabled="custom_settings" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)" additional_info_element_background_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" additional_info_element_background_color_hover="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" additional_info_element_text_color="#e87ab7" additional_info_element_text_color_hover="#e87ab7" additional_info_element_box_shadow_blur_radius="0" additional_info_element_box_shadow_color="rgba(255,255,255,0.01)" additional_info_element_box_shadow_blur_radius_hover="0" additional_info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][vc_column_text]Fusce risus nisi, laoreet at tristique vitae, ultrices sit amet urna. Curabitur a tempus.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_45583572453260" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_info_box class_name="ueldo_vc_element_22036999902184" content_alignment="left" display_additional_info_box_element="yes" info_box_title="'. esc_html( __( 'Brand Recognition Rate', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="200" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="72" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font" info_element_horizontal_alignment="left" additional_info_element_position="left_center" additional_info_element_width="28" additional_info_element_height="28" additional_info_element_margin_left="70" additional_info_element_border_radius="px" additional_info_element_border_radius_px="0" additional_info_element_text="%" additional_info_element_text_custom_font_enabled="custom_settings" additional_info_element_text_font_size="28" additional_info_element_text_font_family="headings-bold-font" custom_colors_enabled="custom_settings" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)" additional_info_element_background_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" additional_info_element_background_color_hover="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" additional_info_element_text_color="#e87ab7" additional_info_element_text_color_hover="#e87ab7" additional_info_element_box_shadow_blur_radius="0" additional_info_element_box_shadow_color="rgba(255,255,255,0.01)" additional_info_element_box_shadow_blur_radius_hover="0" additional_info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][vc_column_text]Fusce risus nisi, laoreet at tristique vitae, ultrices sit amet urna. Curabitur a tempus.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][/vc_row][/vc_section][vc_section][vc_row full_width="stretch_row_content_no_spaces" el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15083195967952" large_height="75"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15083217943068"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15087525109785" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="600" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_base="50%" medium_width_calc_px="496" small_custom_sizes="yes" small_width_type="calc" small_width_calc_base="50%" small_width_calc_px="384" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_35953166861849" large_width_type="px" large_width_px="598" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="494" small_custom_sizes="yes" small_width_type="px" small_width_px="382" extra_small_custom_sizes="yes"][ueldo_shortcode_card class_name="ueldo_vc_element_11244653119017" border_width="0" border_radius="2" padding_top="0" padding_right="0" padding_bottom="0" padding_left="0"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_73961709082521" layer_z_index="110" layer_type="image" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_74167300066980" layer_visibility="on_hover_only" layer_opacity="95%" layer_z_index="110" color="#fdd34b" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_65128713936980" layer_title="'. esc_html( __( 'Content', 'ueldo' ) ) .'" layer_visibility="on_hover_only" layer_z_index="110" custom_layer_sizes="custom_settings" layer_type="text" text_content="'. esc_html( __( 'Ice Cream Ananas flavors', 'ueldo' ) ) .'" text_uppercase_enabled="no" text_alignment="left" text_font_size="18" text_color="#ffffff" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" large_height_type="px" large_height_px="18" large_layer_position="bottom_left" large_margin_bottom="53" large_margin_left="30"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_21654906140985" layer_title="'. esc_html( __( 'Content', 'ueldo' ) ) .'" layer_visibility="on_hover_only" layer_z_index="110" custom_layer_sizes="custom_settings" layer_type="text" text_content="'. esc_html( __( 'Check the details', 'ueldo' ) ) .'" text_font_family="headings-font" text_uppercase_enabled="no" text_alignment="left" text_font_size="16" text_color="rgba(255,255,255,0.7)" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" large_height_type="px" large_height_px="16" large_layer_position="bottom_left" large_margin_bottom="30" large_margin_left="30"][ueldo_shortcode_gap class_name="ueldo_vc_element_57130367740036" large_height="450" small_custom_sizes="yes" small_height="350"][/ueldo_shortcode_card][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_41807737241198" large_width_type="px" large_width_px="4" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_90760613958669" large_width_type="px" large_width_px="598" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="494" small_custom_sizes="yes" small_width_type="px" small_width_px="382" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_1508998259301" large_height="0" extra_small_custom_sizes="yes" extra_small_height="4"][ueldo_shortcode_card class_name="ueldo_vc_element_61592391092510" border_width="0" border_radius="2" padding_top="0" padding_right="0" padding_bottom="0" padding_left="0"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_19422083140859" layer_type="image" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_18331877207788" layer_visibility="on_hover_only" layer_opacity="95%" layer_z_index="110" color="#a5d6d5" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_50869649847752" layer_title="'. esc_html( __( 'Content', 'ueldo' ) ) .'" layer_visibility="on_hover_only" layer_z_index="110" custom_layer_sizes="custom_settings" layer_type="text" text_content="'. esc_html( __( 'Ice Cream Ananas flavors', 'ueldo' ) ) .'" text_uppercase_enabled="no" text_alignment="left" text_font_size="18" text_color="#ffffff" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" large_height_type="px" large_height_px="18" large_layer_position="bottom_left" large_margin_bottom="53" large_margin_left="30"][ueldo_shortcode_card_layer class_name="ueldo_vc_element_20836018107604" layer_title="'. esc_html( __( 'Content', 'ueldo' ) ) .'" layer_visibility="on_hover_only" layer_z_index="110" custom_layer_sizes="custom_settings" layer_type="text" text_content="'. esc_html( __( 'Check the details', 'ueldo' ) ) .'" text_font_family="headings-font" text_uppercase_enabled="no" text_alignment="left" text_font_size="16" text_color="rgba(255,255,255,0.7)" layer_add_link="yes" layer_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2Fsingle-portfolio-project%2F|title:'. rawurlencode( esc_html( __( 'Single portfolio project', 'ueldo' ) ) ) .'||" large_height_type="px" large_height_px="16" large_layer_position="bottom_left" large_margin_bottom="30" large_margin_left="30"][ueldo_shortcode_gap class_name="ueldo_vc_element_73745197732861" large_height="450" small_custom_sizes="yes" small_height="350"][/ueldo_shortcode_card][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_25959572676607" large_height="75"][/vc_column][/vc_row][vc_row][vc_column width="1/2"][ueldo_shortcode_heading class_name="ueldo_vc_element_74480947594889" heading_tag="h4" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_18493710226403" heading_text="'. esc_html( __( 'The Challenge', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]Aliquam velit odio, dictum nec laoreet ut, auctor eu arcu. Nam lorem quam, accumsan sit amet volutpat nec, vulputate ut erat. Vestibulum lorem nibh, ornare sit amet volutpat vel, tincidunt eu metus. Vestibulum non venenatis ipsum, eget porta nunc.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_75219294453177" large_height="40"][/vc_column][vc_column width="1/2"][ueldo_shortcode_heading class_name="ueldo_vc_element_12769698545648" heading_tag="h4" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_20857202537486" heading_text="'. esc_html( __( 'The Solution', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]Vivamus accumsan arcu feugiat imperdiet lacinia. Nulla fermentum scelerisque enim, et porta sapien volutpat eget. Vestibulum efficitur viverra tellus quis scelerisque. Nulla nec rutrum arcu, quis finibus felis. Cras dignissim leo leo, eu rutrum lacus facilisis ut.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_76871078225659" large_height="40"][/vc_column][/vc_row][/vc_section][vc_section][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_heading class_name="ueldo_vc_element_53100549599504" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_97673689017711" heading_text="'. esc_html( __( 'Which services did we provide?', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][ueldo_shortcode_button class_name="ueldo_vc_element_76534050331992" button_text="'. esc_html( __( 'Design', 'ueldo' ) ) .'" standard_button_text_font_family="headings-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'services%2Fdesign%2F|title:'. rawurlencode( esc_html( __( 'Design', 'ueldo' ) ) ) .'||" button_alignment="inline" custom_sizes_enabled="custom_settings" additional_margin_after="4" additional_margin_under="4" standard_button_padding_top="13" standard_button_padding_right="18" standard_button_padding_bottom="11" standard_button_padding_left="18" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_background_color_hover="#e87ab6" standard_button_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-elements-border-color' ) ) .'" standard_button_border_color_hover="#e87ab6" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="5" standard_button_box_shadow_blur_radius_hover="15" standard_button_box_shadow_color_hover="rgba(232,122,182,0.1)" standard_button_text_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-headings-color' ) ) .'" standard_button_text_color_hover="#ffffff"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_70838159034870" button_text="'. esc_html( __( 'WordPress', 'ueldo' ) ) .'" standard_button_text_font_family="headings-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'services%2F|title:'. rawurlencode( esc_html( __( 'Services', 'ueldo' ) ) ) .'||" button_alignment="inline" custom_sizes_enabled="custom_settings" additional_margin_after="4" additional_margin_under="4" standard_button_padding_top="13" standard_button_padding_right="18" standard_button_padding_bottom="11" standard_button_padding_left="18" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_background_color_hover="#e87ab6" standard_button_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-elements-border-color' ) ) .'" standard_button_border_color_hover="#e87ab6" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="5" standard_button_box_shadow_blur_radius_hover="15" standard_button_box_shadow_color_hover="rgba(232,122,182,0.1)" standard_button_text_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-headings-color' ) ) .'" standard_button_text_color_hover="#ffffff"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_37161757148050" button_text="'. esc_html( __( 'Development', 'ueldo' ) ) .'" standard_button_text_font_family="headings-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'services%2Fdevelopment%2F|title:'. rawurlencode( esc_html( __( 'Development', 'ueldo' ) ) ) .'||" button_alignment="inline" custom_sizes_enabled="custom_settings" additional_margin_after="4" additional_margin_under="4" standard_button_padding_top="13" standard_button_padding_right="18" standard_button_padding_bottom="11" standard_button_padding_left="18" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_background_color_hover="#e87ab6" standard_button_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-elements-border-color' ) ) .'" standard_button_border_color_hover="#e87ab6" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="5" standard_button_box_shadow_blur_radius_hover="15" standard_button_box_shadow_color_hover="rgba(232,122,182,0.1)" standard_button_text_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-headings-color' ) ) .'" standard_button_text_color_hover="#ffffff"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_94260079845889" button_text="'. esc_html( __( 'Social media strategy', 'ueldo' ) ) .'" standard_button_text_font_family="headings-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'services%2F|title:'. rawurlencode( esc_html( __( 'Services', 'ueldo' ) ) ) .'||" button_alignment="inline" custom_sizes_enabled="custom_settings" additional_margin_after="4" additional_margin_under="4" standard_button_padding_top="13" standard_button_padding_right="18" standard_button_padding_bottom="11" standard_button_padding_left="18" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_background_color_hover="#e87ab6" standard_button_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-elements-border-color' ) ) .'" standard_button_border_color_hover="#e87ab6" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="5" standard_button_box_shadow_blur_radius_hover="15" standard_button_box_shadow_color_hover="rgba(232,122,182,0.1)" standard_button_text_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-headings-color' ) ) .'" standard_button_text_color_hover="#ffffff"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_20610543504035" button_text="'. esc_html( __( 'Marketing', 'ueldo' ) ) .'" standard_button_text_font_family="headings-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'services%2Fmarketing%2F|title:'. rawurlencode( esc_html( __( 'Marketing', 'ueldo' ) ) ) .'||" button_alignment="inline" custom_sizes_enabled="custom_settings" additional_margin_after="4" additional_margin_under="4" standard_button_padding_top="13" standard_button_padding_right="18" standard_button_padding_bottom="11" standard_button_padding_left="18" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_background_color_hover="#e87ab6" standard_button_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-elements-border-color' ) ) .'" standard_button_border_color_hover="#e87ab6" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="5" standard_button_box_shadow_blur_radius_hover="15" standard_button_box_shadow_color_hover="rgba(232,122,182,0.1)" standard_button_text_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-headings-color' ) ) .'" standard_button_text_color_hover="#ffffff"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_54757946795901" button_text="'. esc_html( __( 'Copywriting', 'ueldo' ) ) .'" standard_button_text_font_family="headings-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'services%2F|title:'. rawurlencode( esc_html( __( 'Services', 'ueldo' ) ) ) .'||" button_alignment="inline" custom_sizes_enabled="custom_settings" additional_margin_after="4" additional_margin_under="4" standard_button_padding_top="13" standard_button_padding_right="18" standard_button_padding_bottom="11" standard_button_padding_left="18" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_background_color_hover="#e87ab6" standard_button_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-elements-border-color' ) ) .'" standard_button_border_color_hover="#e87ab6" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="5" standard_button_box_shadow_blur_radius_hover="15" standard_button_box_shadow_color_hover="rgba(232,122,182,0.1)" standard_button_text_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-headings-color' ) ) .'" standard_button_text_color_hover="#ffffff"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15089166693027" large_height="71"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_loop class_name="ueldo_vc_element_15089166809046" rows="2" masonry_enabled="yes" margin_between_columns="4" margin_between_rows="4"][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_55649836792989"][ueldo_shortcode_image class_name="ueldo_vc_element_63778536710201" additional="gallery_image" gallery_slug="gallery" border_radius="2" large_height_px="350" margin_bottom="0"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_49162017667233"][ueldo_shortcode_image class_name="ueldo_vc_element_27911506669048" additional="gallery_image" gallery_slug="gallery" border_radius="2" large_height_px="350" margin_bottom="0"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_34481895484561"][ueldo_shortcode_image class_name="ueldo_vc_element_40355669261919" additional="gallery_image" gallery_slug="gallery" border_radius="2" large_height_px="350" margin_bottom="0"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_23062159524628" width="double"][ueldo_shortcode_image class_name="ueldo_vc_element_39769504385333" additional="gallery_image" gallery_slug="gallery" border_radius="2" large_height_px="350" margin_bottom="0"][/ueldo_shortcode_loop_cell][ueldo_shortcode_loop_cell class_name="ueldo_vc_element_53096672120600"][ueldo_shortcode_image class_name="ueldo_vc_element_64616697315835" additional="gallery_image" gallery_slug="gallery" border_radius="2" large_height_px="350" margin_bottom="0"][/ueldo_shortcode_loop_cell][/ueldo_shortcode_loop][ueldo_shortcode_gap class_name="ueldo_vc_element_15099832039414" large_height="71"][/vc_column][/vc_row][/vc_section][vc_section][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="2/3" offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15088465834401" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15088465900149" heading_text="'. esc_html( __( 'Let\'s do something together. Today!', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/3" offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_button class_name="ueldo_vc_element_58172872537472" button_visible_on_devices="large,medium,small" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" button_alignment="right"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_15089981290386" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_button class_name="ueldo_vc_element_12110931816824" button_visible_on_devices="extra-small" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_53806992738499" large_height="75"][/vc_column][/vc_row][/vc_section]',

                'services' => '[vc_section][vc_row][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_17620840919697"][ueldo_shortcode_heading class_name="ueldo_vc_element_50954862452637" heading_tag="h1" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="60"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_16054256071148" heading_text="'. esc_html( __( 'We are Creative Digital Agency with impressive experience.', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_icon class_name="ueldo_vc_element_2613168246954" {ueldopredefinedsections:icon|key:flaticon-watercolor,flaticon-paint|url:https://www.flaticon.com/free-icon/watercolor_525651|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e87ab7" icon_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_heading class_name="ueldo_vc_element_50667464502280" heading_tag="h4" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_88279523460116" heading_text="'. esc_html( __( 'Design', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" font_size="32" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Integer facilisis orci a quam condimentum placerat. In metus diam, facilisis et leo et, tempus dictum ante, nulla felis.[/vc_column_text][ueldo_shortcode_icon_list class_name="ueldo_vc_element_39495600765488" icon_fontawesome="fa fa-check" icon_sizes="custom_settings" icon_height="24" icon_vertical_alignment="top" margin_right="45" margin_bottom="45"]Donec arcu mi euismod,<br /><br />Hendrerit ut augue donec,<br /><br />Vitae viverra ex curabitur,<br /><br />Metus vitae aliquam ex imperdiet,<br /><br />Morbi ultrices justo sed,[/ueldo_shortcode_icon_list][ueldo_shortcode_button class_name="ueldo_vc_element_51303908604904" button_text="'. esc_html( __( 'Read more', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'services%2Fdesign%2F|title:'. rawurlencode( esc_html( __( 'Design', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_96453967895953" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_icon class_name="ueldo_vc_element_1805369559451" {ueldopredefinedsections:icon|key:flaticon-coding,flaticon-multimedia|url:https://www.flaticon.com/free-icon/coding_115764|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e87ab7" icon_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_heading class_name="ueldo_vc_element_97130169316612" heading_tag="h4" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_26264780185784" heading_text="'. esc_html( __( 'Development', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" font_size="32" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Integer facilisis orci a quam condimentum placerat. In metus diam, facilisis et leo et, tempus dictum ante, nulla felis.[/vc_column_text][ueldo_shortcode_icon_list class_name="ueldo_vc_element_84992576603559" icon_fontawesome="fa fa-check" icon_sizes="custom_settings" icon_height="24" icon_vertical_alignment="top" margin_right="45" margin_bottom="45"]Donec arcu mi euismod,<br /><br />Hendrerit ut augue donec,<br /><br />Vitae viverra ex curabitur,<br /><br />Metus vitae aliquam ex imperdiet,<br /><br />Morbi ultrices justo sed,[/ueldo_shortcode_icon_list][ueldo_shortcode_button class_name="ueldo_vc_element_83305482429369" button_text="'. esc_html( __( 'Read more', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'services%2Fdevelopment%2F|title:'. rawurlencode( esc_html( __( 'Development', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_49726977574754" large_height="0" small_custom_sizes="yes" small_height="45"][ueldo_shortcode_icon class_name="ueldo_vc_element_2819882141228" {ueldopredefinedsections:icon|key:flaticon-targeting,flaticon-arrow|url:https://www.flaticon.com/free-icon/targeting_115788|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e87ab7" icon_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_heading class_name="ueldo_vc_element_89518837316662" heading_tag="h4" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_48337324411488" heading_text="'. esc_html( __( 'Marketing', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" font_size="32" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Integer facilisis orci a quam condimentum placerat. In metus diam, facilisis et leo et, tempus dictum ante, nulla felis.[/vc_column_text][ueldo_shortcode_icon_list class_name="ueldo_vc_element_34159232738093" icon_fontawesome="fa fa-check" icon_sizes="custom_settings" icon_height="24" icon_vertical_alignment="top" margin_right="45" margin_bottom="45"]Donec arcu mi euismod,<br /><br />Hendrerit ut augue donec,<br /><br />Vitae viverra ex curabitur,<br /><br />Metus vitae aliquam ex imperdiet,<br /><br />Morbi ultrices justo sed,[/ueldo_shortcode_icon_list][ueldo_shortcode_button class_name="ueldo_vc_element_85660811918017" button_text="'. esc_html( __( 'Read more', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'services%2Fmarketing%2F|title:'. rawurlencode( esc_html( __( 'Marketing', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15088462275995" large_height="75"][/vc_column][/vc_row][/vc_section][vc_section el_class="ueldo-vc-section-overflow-visible"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15084092103321" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" color="#f7f9fa" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="20" large_margin_left="15" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="2" extra_small_layer_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_operator="+" extra_small_width_calc_px="30" extra_small_margin_left="-15"][ueldo_shortcode_gap class_name="ueldo_vc_element_15084144255034" large_height="45"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_1508414557478" custom_layer_sizes="custom_settings" layer_type="image" large_width_type="calc" large_width_calc_base="50%" large_width_calc_operator="+" large_width_calc_px="5" large_margin_left="-35" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="2" extra_small_layer_custom_sizes="yes" extra_small_height_type="px" extra_small_height_px="300" extra_small_margin_left="-15" extra_small_custom_row_border_radius="yes-unique-for-corners" extra_small_row_border_radius_top_right_corner="2" extra_small_row_border_radius_bottom_right_corner="2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15084146168443" large_height="450" extra_small_custom_sizes="yes" extra_small_height="345"][/vc_column][vc_column width="1/2"][ueldo_shortcode_heading class_name="ueldo_vc_element_15084139808545" heading_subtitle_text="'. esc_html( __( 'DIGITAL STRATEGY', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="30"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15084139878201" heading_text="'. esc_html( __( 'Creative Campaigns & Ideas right for your Online Business. For you since 2001', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]Sed consequat, purus et dictum euismod, magna leo ultricies velit, sed faucibus ligula dolor ut lectus. Duis placerat lorem rutrum, ornare lacus in, blandit risus. Proin convallis ante sit amet tellus lobortis.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_22851124224625" large_height="45"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_57787249984679" large_height="75"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="2/3" offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15088465834401" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15088465900149" heading_text="'. esc_html( __( 'Let\'s do something together. Today!', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/3" offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_button class_name="ueldo_vc_element_58172872537472" button_visible_on_devices="large,medium,small" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" button_alignment="right"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_15089981290386" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_button class_name="ueldo_vc_element_12110931816824" button_visible_on_devices="extra-small" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_53806992738499" large_height="75"][/vc_column][/vc_row][/vc_section]',

                'design' => '[vc_section][vc_row][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_75325203632939"][ueldo_shortcode_heading class_name="ueldo_vc_element_15088355624866" heading_tag="h1" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15088355689808" heading_text="'. esc_html( __( 'Good design is a great way to express your brand.', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Quisque at quam at lacus sodales feugiat vitae sit amet turpis. Nunc consequat, est ut dictum malesuada, elit magna convallis quam, facilisis faucibus sem dui id ipsum. Nullam non lorem malesuada, tempus risus nec, hendrerit erat. Morbi non turpis lacus.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15088357499571" large_height="40"][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][/vc_section][vc_section][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_tabs class_name="ueldo_vc_element_45733540746353" tabs_content_style="style-03" content_position="right" circle_navigation_alignment="left" image_container_border_radius="2" custom_tab_image_enabled="yes"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_8528255545350" single_tab_title="'. esc_html( __( 'Strategy & Planning', 'ueldo' ) ) .'"][ueldo_shortcode_icon class_name="ueldo_vc_element_41535706145485" {ueldopredefinedsections:icon|key:flaticon-targeting,flaticon-arrow|url:https://www.flaticon.com/free-icon/targeting_115788|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e87ab7" icon_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_heading class_name="ueldo_vc_element_49806594846999" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_91588882173813" heading_text="'. esc_html( __( 'Strategy & Planning', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Duis sagittis gravida dui, finibus egestas ipsum scelerisque vel. Donec ultrices vehicula erat, non sagittis enim venenatis sed. Quisque arcu erat, venenatis eget nibh sit amet, ullamcorper ultricies enim. Nam blandit tincidunt egestas.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15088379735488" large_height="25"][ueldo_shortcode_button class_name="ueldo_vc_element_85058283175564" button_text="'. esc_html( __( 'Ask us a Question', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_81427612838686"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_tabs class_name="ueldo_vc_element_19029032083906" tabs_content_style="style-03" circle_navigation_alignment="left" image_container_border_radius="2" custom_tab_image_enabled="yes"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_9339808896336" single_tab_title="'. esc_html( __( 'Trends tracking', 'ueldo' ) ) .'"][ueldo_shortcode_icon class_name="ueldo_vc_element_58138906207482" {ueldopredefinedsections:icon|key:flaticon-route,flaticon-gps|url:https://www.flaticon.com/free-icon/route_149435|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e87ab7" icon_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_heading class_name="ueldo_vc_element_54282617912354" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_47587145808160" heading_text="'. esc_html( __( 'Trends tracking', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Duis sagittis gravida dui, finibus egestas ipsum scelerisque vel. Donec ultrices vehicula erat, non sagittis enim venenatis sed. Quisque arcu erat, venenatis eget nibh sit amet, ullamcorper ultricies enim. Nam blandit tincidunt egestas.[/vc_column_text][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_85880652367968"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_tabs class_name="ueldo_vc_element_76025661839969" tabs_content_style="style-03" content_position="right" circle_navigation_alignment="left" image_container_border_radius="2" custom_tab_image_enabled="yes"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_5888059563500" single_tab_title="'. esc_html( __( 'Implementation', 'ueldo' ) ) .'"][ueldo_shortcode_icon class_name="ueldo_vc_element_54245238746118" {ueldopredefinedsections:icon|key:flaticon-watercolor,flaticon-paint|url:https://www.flaticon.com/free-icon/watercolor_525651|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e87ab7" icon_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_heading class_name="ueldo_vc_element_97611264457747" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_57493225649353" heading_text="'. esc_html( __( 'Implementation', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Duis sagittis gravida dui, finibus egestas ipsum scelerisque vel. Donec ultrices vehicula erat, non sagittis enim venenatis sed. Quisque arcu erat, venenatis eget nibh sit amet, ullamcorper ultricies enim. Nam blandit tincidunt egestas.[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_25193635413295" button_text="'. esc_html( __( 'Check realizations', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2F|title:'. rawurlencode( esc_html( __( 'Portfolio', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_17023603984062" large_height="75"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_heading class_name="ueldo_vc_element_15088385390111" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1508838548419" heading_text="'. esc_html( __( 'Let\'s do something together.', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]Morbi elit mi, tempor eget lobortis vel, consequat vel mauris. Ut posuere eget ante a facilisis. Morbi bibendum mi et tempus rhoncus. Duis laoreet ut lorem vitae sollicitudin. Suspendisse vel feugiat urna, sed efficitur tellus. Nullam ut nulla at nunc dapibus tristique. Nullam pharetra metus vestibulum ex porta sodales.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15088387189549" large_height="25"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][ueldo_shortcode_info_box class_name="ueldo_vc_element_20449552095358" content_alignment="left" info_box_title="'. esc_html( __( 'Projects finished', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="200" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="273" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font" info_element_horizontal_alignment="left"][vc_column_text]Fusce risus nisi, laoreet at tristique vitae, ultrices sit amet urna. Curabitur a tempus.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_78064679833398" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_info_box class_name="ueldo_vc_element_79927715302389" content_alignment="left" info_box_title="'. esc_html( __( 'Team members', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="200" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="32" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font" info_element_horizontal_alignment="left"][vc_column_text]Fusce risus nisi, laoreet at tristique vitae, ultrices sit amet urna. Curabitur a tempus.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_32767128555083" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_info_box class_name="ueldo_vc_element_78456921838084" content_alignment="left" info_box_title="'. esc_html( __( 'Awards won', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="200" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="52" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font" info_element_horizontal_alignment="left"][vc_column_text]Fusce risus nisi, laoreet at tristique vitae, ultrices sit amet urna. Curabitur a tempus.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_50458893465691" large_height="75"][/vc_column][/vc_row][/vc_section]',

                'development' => '[vc_section][vc_row][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_75325203632939"][ueldo_shortcode_heading class_name="ueldo_vc_element_15088355624866" heading_tag="h1" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15088355689808" heading_text="'. esc_html( __( 'A top-flight code quality & performance for your project', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Quisque at quam at lacus sodales feugiat vitae sit amet turpis. Nunc consequat, est ut dictum malesuada, elit magna convallis quam, facilisis faucibus sem dui id ipsum. Nullam non lorem malesuada, tempus risus nec, hendrerit erat. Morbi non turpis lacus.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15088357499571" large_height="40"][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][/vc_section][vc_section][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_tabs class_name="ueldo_vc_element_45733540746353" tabs_content_style="style-03" content_position="right" circle_navigation_alignment="left" image_container_border_radius="2" custom_tab_image_enabled="yes"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_8528255545350" single_tab_title="'. esc_html( __( 'Strategy & Planning', 'ueldo' ) ) .'"][ueldo_shortcode_icon class_name="ueldo_vc_element_41535706145485" {ueldopredefinedsections:icon|key:flaticon-targeting,flaticon-arrow|url:https://www.flaticon.com/free-icon/targeting_115788|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e87ab7" icon_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_heading class_name="ueldo_vc_element_49806594846999" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_91588882173813" heading_text="'. esc_html( __( 'Strategy & Planning', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Duis sagittis gravida dui, finibus egestas ipsum scelerisque vel. Donec ultrices vehicula erat, non sagittis enim venenatis sed. Quisque arcu erat, venenatis eget nibh sit amet, ullamcorper ultricies enim. Nam blandit tincidunt egestas.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15088379735488" large_height="25"][ueldo_shortcode_button class_name="ueldo_vc_element_85058283175564" button_text="'. esc_html( __( 'Ask us a Question', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_81427612838686"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_tabs class_name="ueldo_vc_element_19029032083906" tabs_content_style="style-03" circle_navigation_alignment="left" image_container_border_radius="2" custom_tab_image_enabled="yes"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_9339808896336" single_tab_title="'. esc_html( __( 'Trends tracking', 'ueldo' ) ) .'"][ueldo_shortcode_icon class_name="ueldo_vc_element_58138906207482" {ueldopredefinedsections:icon|key:flaticon-route,flaticon-gps|url:https://www.flaticon.com/free-icon/route_149435|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e87ab7" icon_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_heading class_name="ueldo_vc_element_54282617912354" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_47587145808160" heading_text="'. esc_html( __( 'Trends tracking', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Duis sagittis gravida dui, finibus egestas ipsum scelerisque vel. Donec ultrices vehicula erat, non sagittis enim venenatis sed. Quisque arcu erat, venenatis eget nibh sit amet, ullamcorper ultricies enim. Nam blandit tincidunt egestas.[/vc_column_text][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_85880652367968"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_tabs class_name="ueldo_vc_element_76025661839969" tabs_content_style="style-03" content_position="right" circle_navigation_alignment="left" image_container_border_radius="2" custom_tab_image_enabled="yes"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_5888059563500" single_tab_title="'. esc_html( __( 'Implementation', 'ueldo' ) ) .'"][ueldo_shortcode_icon class_name="ueldo_vc_element_54245238746118" {ueldopredefinedsections:icon|key:flaticon-watercolor,flaticon-paint|url:https://www.flaticon.com/free-icon/watercolor_525651|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e87ab7" icon_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_heading class_name="ueldo_vc_element_97611264457747" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_57493225649353" heading_text="'. esc_html( __( 'Implementation', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Duis sagittis gravida dui, finibus egestas ipsum scelerisque vel. Donec ultrices vehicula erat, non sagittis enim venenatis sed. Quisque arcu erat, venenatis eget nibh sit amet, ullamcorper ultricies enim. Nam blandit tincidunt egestas.[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_25193635413295" button_text="'. esc_html( __( 'Check realizations', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2F|title:'. rawurlencode( esc_html( __( 'Portfolio', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_17023603984062" large_height="75"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_heading class_name="ueldo_vc_element_15088385390111" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1508838548419" heading_text="'. esc_html( __( 'Let\'s do something together.', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]Morbi elit mi, tempor eget lobortis vel, consequat vel mauris. Ut posuere eget ante a facilisis. Morbi bibendum mi et tempus rhoncus. Duis laoreet ut lorem vitae sollicitudin. Suspendisse vel feugiat urna, sed efficitur tellus. Nullam ut nulla at nunc dapibus tristique. Nullam pharetra metus vestibulum ex porta sodales.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15088387189549" large_height="25"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][ueldo_shortcode_info_box class_name="ueldo_vc_element_20449552095358" content_alignment="left" info_box_title="'. esc_html( __( 'Projects finished', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="200" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="273" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font" info_element_horizontal_alignment="left"][vc_column_text]Fusce risus nisi, laoreet at tristique vitae, ultrices sit amet urna. Curabitur a tempus.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_78064679833398" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_info_box class_name="ueldo_vc_element_79927715302389" content_alignment="left" info_box_title="'. esc_html( __( 'Team members', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="200" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="32" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font" info_element_horizontal_alignment="left"][vc_column_text]Fusce risus nisi, laoreet at tristique vitae, ultrices sit amet urna. Curabitur a tempus.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_32767128555083" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_info_box class_name="ueldo_vc_element_78456921838084" content_alignment="left" info_box_title="'. esc_html( __( 'Awards won', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="200" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="52" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font" info_element_horizontal_alignment="left"][vc_column_text]Fusce risus nisi, laoreet at tristique vitae, ultrices sit amet urna. Curabitur a tempus.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_50458893465691" large_height="75"][/vc_column][/vc_row][/vc_section]',

                'marketing' => '[vc_section][vc_row][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_75325203632939"][ueldo_shortcode_heading class_name="ueldo_vc_element_15088355624866" heading_tag="h1" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15088355689808" heading_text="'. esc_html( __( 'We help you promote your Online Business and reach more Customers.', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Quisque at quam at lacus sodales feugiat vitae sit amet turpis. Nunc consequat, est ut dictum malesuada, elit magna convallis quam, facilisis faucibus sem dui id ipsum. Nullam non lorem malesuada, tempus risus nec, hendrerit erat. Morbi non turpis lacus.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15088357499571" large_height="40"][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][/vc_section][vc_section][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_tabs class_name="ueldo_vc_element_45733540746353" tabs_content_style="style-03" content_position="right" circle_navigation_alignment="left" image_container_border_radius="2" custom_tab_image_enabled="yes"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_8528255545350" single_tab_title="'. esc_html( __( 'Strategy & Planning', 'ueldo' ) ) .'"][ueldo_shortcode_icon class_name="ueldo_vc_element_41535706145485" {ueldopredefinedsections:icon|key:flaticon-targeting,flaticon-arrow|url:https://www.flaticon.com/free-icon/targeting_115788|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e87ab7" icon_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_heading class_name="ueldo_vc_element_49806594846999" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_91588882173813" heading_text="'. esc_html( __( 'Strategy & Planning', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Duis sagittis gravida dui, finibus egestas ipsum scelerisque vel. Donec ultrices vehicula erat, non sagittis enim venenatis sed. Quisque arcu erat, venenatis eget nibh sit amet, ullamcorper ultricies enim. Nam blandit tincidunt egestas.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15088379735488" large_height="25"][ueldo_shortcode_button class_name="ueldo_vc_element_85058283175564" button_text="'. esc_html( __( 'Ask us a Question', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_81427612838686"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_tabs class_name="ueldo_vc_element_19029032083906" tabs_content_style="style-03" circle_navigation_alignment="left" image_container_border_radius="2" custom_tab_image_enabled="yes"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_9339808896336" single_tab_title="'. esc_html( __( 'Trends tracking', 'ueldo' ) ) .'"][ueldo_shortcode_icon class_name="ueldo_vc_element_58138906207482" {ueldopredefinedsections:icon|key:flaticon-route,flaticon-gps|url:https://www.flaticon.com/free-icon/route_149435|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e87ab7" icon_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_heading class_name="ueldo_vc_element_54282617912354" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_47587145808160" heading_text="'. esc_html( __( 'Trends tracking', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Duis sagittis gravida dui, finibus egestas ipsum scelerisque vel. Donec ultrices vehicula erat, non sagittis enim venenatis sed. Quisque arcu erat, venenatis eget nibh sit amet, ullamcorper ultricies enim. Nam blandit tincidunt egestas.[/vc_column_text][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_85880652367968"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_tabs class_name="ueldo_vc_element_76025661839969" tabs_content_style="style-03" content_position="right" circle_navigation_alignment="left" image_container_border_radius="2" custom_tab_image_enabled="yes"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_5888059563500" single_tab_title="'. esc_html( __( 'Implementation', 'ueldo' ) ) .'"][ueldo_shortcode_icon class_name="ueldo_vc_element_54245238746118" {ueldopredefinedsections:icon|key:flaticon-watercolor,flaticon-paint|url:https://www.flaticon.com/free-icon/watercolor_525651|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#e87ab7" icon_shadow_color="rgba(255,255,255,0.01)"][ueldo_shortcode_heading class_name="ueldo_vc_element_97611264457747" heading_tag="h3" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_57493225649353" heading_text="'. esc_html( __( 'Implementation', 'ueldo' ) ) .'" font_family="headings-bold-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][vc_column_text]Duis sagittis gravida dui, finibus egestas ipsum scelerisque vel. Donec ultrices vehicula erat, non sagittis enim venenatis sed. Quisque arcu erat, venenatis eget nibh sit amet, ullamcorper ultricies enim. Nam blandit tincidunt egestas.[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_25193635413295" button_text="'. esc_html( __( 'Check realizations', 'ueldo' ) ) .'" standard_button_text_font_family="buttons-font" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'portfolio%2F|title:'. rawurlencode( esc_html( __( 'Portfolio', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_17023603984062" large_height="75"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_heading class_name="ueldo_vc_element_15088385390111" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1508838548419" heading_text="'. esc_html( __( 'Let\'s do something together.', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][vc_column_text]Morbi elit mi, tempor eget lobortis vel, consequat vel mauris. Ut posuere eget ante a facilisis. Morbi bibendum mi et tempus rhoncus. Duis laoreet ut lorem vitae sollicitudin. Suspendisse vel feugiat urna, sed efficitur tellus. Nullam ut nulla at nunc dapibus tristique. Nullam pharetra metus vestibulum ex porta sodales.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15088387189549" large_height="25"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][ueldo_shortcode_info_box class_name="ueldo_vc_element_20449552095358" content_alignment="left" info_box_title="'. esc_html( __( 'Projects finished', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="200" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="273" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font" info_element_horizontal_alignment="left"][vc_column_text]Fusce risus nisi, laoreet at tristique vitae, ultrices sit amet urna. Curabitur a tempus.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_78064679833398" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_info_box class_name="ueldo_vc_element_79927715302389" content_alignment="left" info_box_title="'. esc_html( __( 'Team members', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="200" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="32" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font" info_element_horizontal_alignment="left"][vc_column_text]Fusce risus nisi, laoreet at tristique vitae, ultrices sit amet urna. Curabitur a tempus.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_32767128555083" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_info_box class_name="ueldo_vc_element_78456921838084" content_alignment="left" info_box_title="'. esc_html( __( 'Awards won', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h5" info_element_width="200" info_element_height="48" info_element_border_radius="px" info_element_border_radius_px="0" info_element_type="counter" info_element_counter_value="52" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_line_height="1" info_element_counter_font_family="headings-bold-font" info_element_horizontal_alignment="left"][vc_column_text]Fusce risus nisi, laoreet at tristique vitae, ultrices sit amet urna. Curabitur a tempus.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_50458893465691" large_height="75"][/vc_column][/vc_row][/vc_section]',

                'footer' => '[vc_section full_width="stretch_row" el_class="ueldo-vc-section-overflow-visible"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15084899646164" layer_for_row_or_section="section" color="#f6f9f9"][ueldo_shortcode_gap class_name="ueldo_vc_element_38404208295813" large_height="75"][/vc_column][/vc_row][vc_row][vc_column width="1/4" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15084937259971" text_align="center" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Contact us!', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="30" custom_margin_bottom="60"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15084937357205123456789" heading_text="'. esc_html( __( 'Creative Agency with impressive ideas.', 'ueldo' ) ) .'" font_family="headings-bold-font"][/ueldo_shortcode_heading][ueldo_shortcode_inline_container class_name="ueldo_vc_element_84264888575108"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_21297931939776" large_width_percentage="100%" large_content_alignment="center" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][ueldo_shortcode_button class_name="ueldo_vc_element_61735302901878" button_visible_on_devices="large,medium,small" button_text="" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-facebook" custom_sizes_enabled="custom_settings" additional_margin_after="45" standard_button_icon_size="28" standard_button_padding_top="0" standard_button_padding_right="0" standard_button_padding_bottom="0" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_border_radius="0" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="#f6f9f9" standard_button_background_color_hover="#f6f9f9" standard_button_border_color="#f6f9f9" standard_button_border_color_hover="#f6f9f9" standard_button_box_shadow_color="rgba(246,249,249,0.01)" standard_button_box_shadow_color_hover="rgba(246,249,249,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#e87ab7" standard_button_icon_color_hover="#313131"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_94827111915879" button_visible_on_devices="large,medium,small" button_text="" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-twitter" custom_sizes_enabled="custom_settings" additional_margin_after="45" standard_button_icon_size="28" standard_button_padding_top="0" standard_button_padding_right="0" standard_button_padding_bottom="0" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_border_radius="0" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="#f6f9f9" standard_button_background_color_hover="#f6f9f9" standard_button_border_color="#f6f9f9" standard_button_border_color_hover="#f6f9f9" standard_button_box_shadow_color="rgba(246,249,249,0.01)" standard_button_box_shadow_color_hover="rgba(246,249,249,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#e87ab7" standard_button_icon_color_hover="#313131"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_80565051434025" button_visible_on_devices="large,medium,small" button_text="" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-linkedin" custom_sizes_enabled="custom_settings" additional_margin_after="45" standard_button_icon_size="28" standard_button_padding_top="0" standard_button_padding_right="0" standard_button_padding_bottom="0" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_border_radius="0" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="#f6f9f9" standard_button_background_color_hover="#f6f9f9" standard_button_border_color="#f6f9f9" standard_button_border_color_hover="#f6f9f9" standard_button_box_shadow_color="rgba(246,249,249,0.01)" standard_button_box_shadow_color_hover="rgba(246,249,249,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#e87ab7" standard_button_icon_color_hover="#313131"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_88706466435078" button_visible_on_devices="large,medium,small" button_text="" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-instagram" custom_sizes_enabled="custom_settings" additional_margin_after="45" standard_button_icon_size="28" standard_button_padding_top="0" standard_button_padding_right="0" standard_button_padding_bottom="0" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_border_radius="0" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="#f6f9f9" standard_button_background_color_hover="#f6f9f9" standard_button_border_color="#f6f9f9" standard_button_border_color_hover="#f6f9f9" standard_button_box_shadow_color="rgba(246,249,249,0.01)" standard_button_box_shadow_color_hover="rgba(246,249,249,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#e87ab7" standard_button_icon_color_hover="#313131"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_88526059164490" button_visible_on_devices="large,medium,small" button_text="" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-google-plus" custom_sizes_enabled="custom_settings" standard_button_icon_size="28" standard_button_padding_top="0" standard_button_padding_right="0" standard_button_padding_bottom="0" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_border_radius="0" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="#f6f9f9" standard_button_background_color_hover="#f6f9f9" standard_button_border_color="#f6f9f9" standard_button_border_color_hover="#f6f9f9" standard_button_box_shadow_color="rgba(246,249,249,0.01)" standard_button_box_shadow_color_hover="rgba(246,249,249,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#e87ab7" standard_button_icon_color_hover="#313131"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_inline_container class_name="ueldo_vc_element_50904790784553"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_38354002445890" large_width_percentage="0%" large_content_alignment="center" extra_small_custom_sizes="yes" extra_small_content_alignment="center"][ueldo_shortcode_button class_name="ueldo_vc_element_79664073894372" button_visible_on_devices="extra-small" button_text="" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-facebook" custom_sizes_enabled="custom_settings" additional_margin_after="15" standard_button_icon_size="28" standard_button_padding_top="0" standard_button_padding_right="0" standard_button_padding_bottom="0" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_border_radius="0" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="#f6f9f9" standard_button_background_color_hover="#f6f9f9" standard_button_border_color="#f6f9f9" standard_button_border_color_hover="#f6f9f9" standard_button_box_shadow_color="rgba(246,249,249,0.01)" standard_button_box_shadow_color_hover="rgba(246,249,249,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#e87ab7" standard_button_icon_color_hover="#313131"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_51976934693348" button_visible_on_devices="extra-small" button_text="" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-twitter" custom_sizes_enabled="custom_settings" additional_margin_after="15" standard_button_icon_size="28" standard_button_padding_top="0" standard_button_padding_right="0" standard_button_padding_bottom="0" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_border_radius="0" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="#f6f9f9" standard_button_background_color_hover="#f6f9f9" standard_button_border_color="#f6f9f9" standard_button_border_color_hover="#f6f9f9" standard_button_box_shadow_color="rgba(246,249,249,0.01)" standard_button_box_shadow_color_hover="rgba(246,249,249,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#e87ab7" standard_button_icon_color_hover="#313131"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_44135884623582" button_visible_on_devices="extra-small" button_text="" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-linkedin" custom_sizes_enabled="custom_settings" additional_margin_after="15" standard_button_icon_size="28" standard_button_padding_top="0" standard_button_padding_right="0" standard_button_padding_bottom="0" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_border_radius="0" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="#f6f9f9" standard_button_background_color_hover="#f6f9f9" standard_button_border_color="#f6f9f9" standard_button_border_color_hover="#f6f9f9" standard_button_box_shadow_color="rgba(246,249,249,0.01)" standard_button_box_shadow_color_hover="rgba(246,249,249,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#e87ab7" standard_button_icon_color_hover="#313131"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_51860807004645" button_visible_on_devices="extra-small" button_text="" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-instagram" custom_sizes_enabled="custom_settings" additional_margin_after="15" standard_button_icon_size="28" standard_button_padding_top="0" standard_button_padding_right="0" standard_button_padding_bottom="0" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_border_radius="0" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="#f6f9f9" standard_button_background_color_hover="#f6f9f9" standard_button_border_color="#f6f9f9" standard_button_border_color_hover="#f6f9f9" standard_button_box_shadow_color="rgba(246,249,249,0.01)" standard_button_box_shadow_color_hover="rgba(246,249,249,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#e87ab7" standard_button_icon_color_hover="#313131"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_93702487007120" button_visible_on_devices="extra-small" button_text="" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-google-plus" custom_sizes_enabled="custom_settings" standard_button_icon_size="28" standard_button_padding_top="0" standard_button_padding_right="0" standard_button_padding_bottom="0" standard_button_padding_left="0" standard_button_use_static_height="no" standard_button_border_radius="0" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="#f6f9f9" standard_button_background_color_hover="#f6f9f9" standard_button_border_color="#f6f9f9" standard_button_border_color_hover="#f6f9f9" standard_button_box_shadow_color="rgba(246,249,249,0.01)" standard_button_box_shadow_color_hover="rgba(246,249,249,0.01)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="#e87ab7" standard_button_icon_color_hover="#313131"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_15084940797464" large_height="75"][/vc_column][vc_column width="1/4" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row content_placement="top"][vc_column width="1/3"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15084950417024"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_895742118263" large_width_percentage="10%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_592017903370" large_width_percentage="80%"][vc_column_text]<p style="text-align: center;"><strong>'. esc_html( __( 'WordPress theme', 'ueldo' ) ) .'</strong></p><p style="text-align: center;">2017 - '. date( 'Y' ) .' &copy; <a href="'. esc_url( ueldo_get_external_url( 'ueldo-com' ) ) .'" target="_blank">'. esc_html( __( 'Ueldo', 'ueldo' ) ) .'</a> '. esc_html( __( 'WordPress theme by', 'ueldo' ) ) .' <a href="'. esc_url( ueldo_get_external_url( 'martanian-com' ) ) .'" target="_blank">Martanian</a></p>[/vc_column_text][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_590784230738" large_width_percentage="10%"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_76456814954444" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][vc_column_text]<p style="text-align: center;"><strong>'. esc_html( __( 'Contact us', 'ueldo' ) ) .'</strong></p><p style="text-align: center;"><a href="'. esc_url( __( 'mailto:contact@example.com', 'ueldo' ) ) .'">'. esc_html( __( 'contact@example.com', 'ueldo' ) ) .'</a><br /><a href="tel:18001234567">1-800-123-4567</a></p>[/vc_column_text][/vc_column][vc_column width="1/3"][ueldo_shortcode_gap class_name="ueldo_vc_element_91505583995881" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][vc_column_text]<p style="text-align: center;"><strong>'. esc_html( __( 'Visit us', 'ueldo' ) ) .'</strong></p><p style="text-align: center;">'. esc_html( __( '1234 Example Street,', 'ueldo' ) ) .'<br />'. esc_html( __( 'Los Angeles, CA 98765', 'ueldo' ) ) .'</p>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_99932646309768"][/vc_column][/vc_row][/vc_section]',

                'header' => '[vc_section][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15083195705644" color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'"][ueldo_shortcode_gap class_name="ueldo_vc_element_67767169985593" large_height="8"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15083192211738"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15083192514012" large_width_type="px" large_width_px="15"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_94446086851442" large_width_type="calc" large_width_calc_base="35%" large_width_calc_px="15" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_base="50%" extra_small_width_calc_px="123"][ueldo_shortcode_button class_name="ueldo_vc_element_27006528447931" button_visible_on_devices="large,medium,small" button_text="1-800-123-4567" standard_button_text_font_family="Roboto,700" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-phone" custom_sizes_enabled="custom_settings" standard_button_font_size="15" standard_button_icon_size="21" standard_button_padding_top="14.5" standard_button_padding_bottom="14.5" standard_button_use_static_height="no" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_background_color_hover="#f1f1f1" standard_button_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_border_color_hover="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="0" standard_button_box_shadow_blur_radius_hover="0" standard_button_box_shadow_color_hover="rgba(255,255,255,0.01)" standard_button_text_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-headings-color' ) ) .'" standard_button_text_color_hover="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-headings-color' ) ) .'" standard_button_icon_color="#86afb8" standard_button_icon_color_hover="#86afb8"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_47958932339507" button_visible_on_devices="extra-small" button_text="" standard_button_text_font_family="Roboto,700" button_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-phone" custom_sizes_enabled="custom_settings" standard_button_font_size="15" standard_button_icon_size="21" standard_button_padding_top="14.5" standard_button_padding_right="20" standard_button_padding_bottom="14.5" standard_button_padding_left="20" standard_button_use_static_height="no" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_background_color_hover="#f1f1f1" standard_button_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_border_color_hover="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="0" standard_button_box_shadow_blur_radius_hover="0" standard_button_box_shadow_color_hover="rgba(255,255,255,0.01)" standard_button_text_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-headings-color' ) ) .'" standard_button_text_color_hover="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-headings-color' ) ) .'" standard_button_icon_color="#86afb8" standard_button_icon_color_hover="#86afb8"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_73391352533026" large_width_percentage="30%" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="216" extra_small_content_alignment="center"][ueldo_shortcode_website_logo class_name="ueldo_vc_element_15084801341939" horizontal_alignment="center" large_width_type="px" large_width_px="216" large_height_type="px" large_height_px="63" {ueldopredefinedsections:image|context:creative-agency-logo}][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15083192277955" large_width_type="calc" large_width_calc_base="35%" large_width_calc_px="15" large_content_alignment="right" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_base="50%" extra_small_width_calc_px="123"][ueldo_shortcode_button class_name="ueldo_vc_element_17408943789274" button_visible_on_devices="large,medium,small" button_text="'. esc_html( __( 'Open menu', 'ueldo' ) ) .'" standard_button_text_font_family="Roboto,700" action_after_click="show_hide_side_menu" button_alignment="right" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-bars" custom_sizes_enabled="custom_settings" standard_button_font_size="15" standard_button_icon_size="21" standard_button_padding_top="14.5" standard_button_padding_bottom="14.5" standard_button_use_static_height="no" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_background_color_hover="#f1f1f1" standard_button_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_border_color_hover="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="0" standard_button_box_shadow_blur_radius_hover="0" standard_button_box_shadow_color_hover="rgba(255,255,255,0.01)" standard_button_text_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-headings-color' ) ) .'" standard_button_text_color_hover="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-headings-color' ) ) .'" standard_button_icon_color="#86afb8" standard_button_icon_color_hover="#86afb8"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_74647943972635" button_visible_on_devices="extra-small" button_text="" standard_button_text_font_family="Roboto,700" action_after_click="show_hide_side_menu" button_alignment="right" show_button_icon="yes" button_icon_position="before" button_icon_fontawesome="fa fa-bars" custom_sizes_enabled="custom_settings" standard_button_font_size="15" standard_button_icon_size="21" standard_button_padding_top="14.5" standard_button_padding_right="20" standard_button_padding_bottom="14.5" standard_button_padding_left="20" standard_button_use_static_height="no" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_background_color_hover="#f1f1f1" standard_button_border_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_border_color_hover="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-website-background' ) ) .'" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_vertical_length_hover="0" standard_button_box_shadow_blur_radius_hover="0" standard_button_box_shadow_color_hover="rgba(255,255,255,0.01)" standard_button_text_color="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-headings-color' ) ) .'" standard_button_text_color_hover="'. esc_attr( ueldo_get_theme_options_value( 'styles', false, 'general-colors-headings-color' ) ) .'" standard_button_icon_color="#86afb8" standard_button_icon_color_hover="#86afb8"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15083192581729" large_width_type="px" large_width_px="15"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_32627372722803" large_height="8"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row_content"][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_delimiter class_name="ueldo_vc_element_15083191445168" large_height="1" margin_bottom="0"][/vc_column][/vc_row][/vc_section]',

                'additional-before-side-menu' => '[vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15089276340198" large_height="20"][ueldo_shortcode_button class_name="ueldo_vc_element_15089275890718" button_text="'. esc_html( __( 'Close menu', 'ueldo' ) ) .'" standard_button_text_font_family="Roboto,700" button_text_alignment="center" action_after_click="show_hide_side_menu" button_alignment="center" show_button_icon="yes" button_icon_fontawesome="fa fa-bars" custom_colors_enabled="custom_settings" standard_button_background_color_hover="#86afb8" standard_button_border_color_hover="#86afb8" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_color_hover="rgba(134,175,184,0.15)" standard_button_text_color="#ffffff" standard_button_text_color_hover="#ffffff" standard_button_icon_color="rgba(255,255,255,0.5)" standard_button_icon_color_hover="rgba(255,255,255,0.5)"][/ueldo_shortcode_button][/vc_column][/vc_row][/vc_section]',

                'additional-after-side-menu' => '[vc_section][vc_row][vc_column][ueldo_shortcode_website_logo class_name="ueldo_vc_element_1508927524714" horizontal_alignment="center" large_width_type="px" large_width_px="97" large_height_type="px" large_height_px="63" margin_bottom="20" {ueldopredefinedsections:image|context:creative-agency-logo-white}][/vc_column][/vc_row][/vc_section]'
            );

            # return result
            return( $page_slug == false ? $contents : ( isset( $contents[esc_attr( $page_slug )] ) ? $contents[esc_attr( $page_slug )] : false ) );
        }

       /**
        *
        * end of class methods.
        *
        */
    }

   /**
    *
    * end of file.
    *
    */

?>