<?php

   /**
    *
    * installation class for "kayaks" demo template
    *
    */

    class ueldo_demo_contents_loader_base extends ueldo_demo_contents_loader_installation_helper {

       /**
        *
        * install template or its parts
        *
        */

        public static function install( $parts, $icons ) {

           /**
            *
            * install revolution slider
            *
            */

            if( $parts == 'all' || in_array( 'revolution-slider-sliders', $parts, true ) ) {

                # upload revolution slider and get its id
                if( ( $slider_id = ueldo_add_demo_assets::upload_revslider( 'kayaks-home-page' ) ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:revslider|context:kayaks-home-page}', 'alias="'. esc_attr( $slider_id ) .'"' );

                    # remove temporary variables
                    unset( $slider_id );
                }
            }

           /**
            *
            * install forms
            *
            */

            if( $parts == 'all' || in_array( 'forms', $parts, true ) ) {

                # add form in contact form 7 plugin and get its id
                if( ( $form_id = ueldo_add_demo_assets::add_contact_form() ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:contactform7|context:kayaks|inside:true}', 'id=``'. esc_attr( $form_id ) .'``' );

                    # remove temporary variables
                    unset( $form_id );
                }

                # add form in mc4wp plugin and get its id
                if( ( $form_id = ueldo_add_demo_assets::add_mc4wp_form( 'kayaks' ) ) !== false ) {

                    # add new solution
                    self::add_solution( '{ueldopredefinedsections:mc4wp|context:kayaks|inside:true}', 'id=``'. esc_attr( $form_id ) .'``' );

                    # remove temporary variables
                    unset( $form_id );
                }
            }

           /**
            *
            * install blog posts
            *
            */

            if( $parts == 'all' || in_array( 'posts', $parts, true ) ) {

                # do we have default image ID?
                if( self::get_solution( 'default-image-id' ) == false ) {

                    # add solution with default image ID
                    self::add_solution( 'default-image-id', ueldo_add_demo_assets::add_image( 'default-image' ) );
                }

                # get current user data
                $current_user = wp_get_current_user();

                # add blog post
                $new_post_id = ueldo_add_demo_assets::add_blog_post( array(
                    'title' => esc_html( __( 'Awesome weather forecast for the coming weekend', 'ueldo' ) ),
                    'content' => false,
                    'thumbnail' => self::get_solution( 'default-image-id' ),
                    'category' => array( wp_create_category( esc_html( __( 'Weather forecast', 'ueldo' ) ) ) ),
                    'tags' => array(
                        esc_html( __( 'Weather', 'ueldo' ) ),
                        esc_html( __( 'Weekend', 'ueldo' ) )
                    ),
                    'comments' => array(
                        array(
                            'author' => esc_html( __( 'John', 'ueldo' ) ),
                            'author-email' => esc_html( __( 'john@example.com', 'ueldo' ) ),
                         			'content' => 'Phasellus massa nisi, facilisis vel pellentesque at, molestie id augue. Vestibulum nec interdum urna. Nulla hendrerit posuere est eu vehicula. Phasellus nec eros mi. Suspendisse sit amet tincidunt nunc. Phasellus rhoncus magna a vestibulum tristique. Sed id nunc leo. Fusce ullamcorper porta vulputate. Vivamus et massa massa. Donec nisi nulla, viverra fringilla mi euismod, mollis volutpat purus. In dictum massa lobortis, congue mi nec, venenatis felis.',
                            'replies' => array(
                                array(
                                    'author' => esc_html( __( 'Susane', 'ueldo' ) ),
                                    'author-email' => esc_html( __( 'susane@example.com', 'ueldo' ) ),
                                    'content' => 'Nam euismod elementum tellus ac tincidunt. Praesent venenatis molestie nisl quis condimentum. In nulla velit, dictum vel dolor eget, suscipit feugiat velit. Duis in magna sit amet metus sodales laoreet. Cras gravida nunc sed ex luctus interdum ut posuere ligula. Phasellus suscipit felis eget sem viverra, nec sagittis tortor pellentesque. Duis ante turpis, varius at varius sed, placerat ac purus. Maecenas molestie neque a rutrum semper.'
                                )
                            )
                        ),
                        array(
                            'author' => esc_html( $current_user -> display_name ),
                            'author-email' => esc_html( $current_user -> user_email ),
                            'content' => 'Nulla porta sodales sem vel tempus. Vivamus interdum ante ex, ut imperdiet ex vestibulum ut. In pretium diam a viverra lacinia. Fusce cursus, arcu nec pharetra imperdiet, neque lorem malesuada lectus, in egestas elit massa a erat. Donec efficitur sem vitae magna facilisis feugiat. Integer rhoncus augue a sollicitudin semper. Aliquam quis augue at libero imperdiet consequat molestie semper risus.',
                            'user_id' => esc_attr( $current_user -> ID )
                        )
                    )
                ));

                # wait until previous post is added
                if( $new_post_id !== false ) {

                    # clear temporary variable
                    unset( $new_post_id );

                    # add blog post
                    $new_post_id = ueldo_add_demo_assets::add_blog_post( array(
                        'title' => esc_html( __( 'An idea for active leisure time', 'ueldo' ) ),
                        'content' => false,
                        'thumbnail' => self::get_solution( 'default-image-id' ),
                        'category' => array( wp_create_category( esc_html( __( 'Weekend', 'ueldo' ) ) ) ),
                        'tags' => array(
                            esc_html( __( 'Leisure time', 'ueldo' ) ),
                            esc_html( __( 'Weekend', 'ueldo' ) )
                        ),
                        'comments' => array(
                            array(
                             			'author' => esc_html( __( 'Tom', 'ueldo' ) ),
                             			'author-email' => esc_html( __( 'tom@example.com', 'ueldo' ) ),
                             			'content' => 'Curabitur ac finibus tortor, et pellentesque justo. Mauris ultricies eleifend sollicitudin. Praesent vitae dolor suscipit, ullamcorper turpis vitae, fringilla metus. Pellentesque hendrerit, mi vitae sagittis convallis, tortor tellus blandit nibh, quis gravida quam quam ac sem. Integer efficitur placerat lorem, sit amet aliquam turpis iaculis efficitur. Vivamus porttitor efficitur nunc nec vehicula. Morbi maximus orci ut pellentesque cursus. Fusce ultrices vehicula sem.'
                            )
                        )
                    ));

                    # wait until previous post is added
                    if( $new_post_id !== false ) {

                        # clear temporary variable
                        unset( $new_post_id );

                        # add blog post
                        ueldo_add_demo_assets::add_blog_post( array(
                            'title' => esc_html( __( 'Recreation for the whole family', 'ueldo' ) ),
                            'content' => false,
                            'thumbnail' => self::get_solution( 'default-image-id' ),
                            'category' => array( wp_create_category( esc_html( __( 'Weekend', 'ueldo' ) ) ) ),
                            'tags' => array(
                                esc_html( __( 'Leisure time', 'ueldo' ) ),
                                esc_html( __( 'Weekend', 'ueldo' ) )
                            ),
                            'comments' => array(
                                array(
                                    'author' => esc_html( __( 'John', 'ueldo' ) ),
                                    'author-email' => esc_html( __( 'john@example.com', 'ueldo' ) ),
                                    'content' => 'Nam id vulputate justo. Morbi hendrerit nisi quis aliquam dapibus. Suspendisse hendrerit diam et sapien suscipit, ac eleifend ex hendrerit. Nullam non metus arcu. Suspendisse semper dignissim imperdiet. Vivamus tellus nibh, sagittis et erat vel, condimentum feugiat lacus. Etiam auctor tortor pulvinar velit tempor placerat. Ut sapien est, dignissim quis aliquam quis, sagittis eget sem. Maecenas et dictum tortor. Nulla sed consequat odio.',
                                    'replies' => array(
                                        array(
                                            'author' => esc_html( $current_user -> display_name ),
                                            'author-email' => esc_html( $current_user -> user_email ),
                                            'content' => 'Nulla porta sodales sem vel tempus. Vivamus interdum ante ex, ut imperdiet ex vestibulum ut. In pretium diam a viverra lacinia. Fusce cursus, arcu nec pharetra imperdiet, neque lorem malesuada lectus, in egestas elit massa a erat. Donec efficitur sem vitae magna facilisis feugiat. Integer rhoncus augue a sollicitudin semper. Aliquam quis augue at libero imperdiet consequat molestie semper risus.',
                                            'user_id' => esc_attr( $current_user -> ID )
                                        )
                                    )
                                ),
                                array(
                                    'author' => esc_html( __( 'Monica', 'ueldo' ) ),
                                    'author-email' => esc_html( __( 'monica@example.com', 'ueldo' ) ),
                                    'content' => 'Morbi molestie arcu a erat mattis, ut pulvinar mi sagittis. Nam euismod elementum tellus ac tincidunt. Praesent venenatis molestie nisl quis condimentum. In nulla velit, dictum vel dolor eget, suscipit feugiat velit. Duis in magna sit amet metus sodales laoreet. Cras gravida nunc sed ex luctus interdum ut posuere ligula. Phasellus suscipit felis eget sem viverra, nec sagittis tortor pellentesque. Duis ante turpis, varius at varius sed, placerat ac purus. Maecenas molestie neque a rutrum semper.'
                                )
                            )
                        ));
                    }
                }

                # remove temporary variables
                unset( $current_user );

                # posts per page
                update_option( 'posts_per_page', '10' );
            }

           /**
            *
            * add pages, but not fill it with contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # add pages and get its ids
                $pages_ids = ueldo_add_demo_assets::add_empty_pages( 'page', array(
                    '404-page' => esc_html( __( '404 page', 'ueldo' ) ),
                    'about-us' => esc_html( __( 'About us', 'ueldo' ) ),
                    'blog' => esc_html( __( 'Blog', 'ueldo' ) ),
                    'contact' => esc_html( __( 'Contact', 'ueldo' ) ),
                    'guided-tours' => esc_html( __( 'Guided tours', 'ueldo' ) ),
                    'home' => esc_html( __( 'Home', 'ueldo' ) ),
                    'kayak-rental' => esc_html( __( 'Kayak rental', 'ueldo' ) ),
                    'paddle-rental' => esc_html( __( 'Paddle rental', 'ueldo' ) )
                ));

                # add headers, footers and extras
                $hefos_ids = ueldo_add_demo_assets::add_empty_pages( 'ueldohefo', array(
                    'services-header' => esc_html( __( 'Services header', 'ueldo' ) ),
                    'under-blog-section' => esc_html( __( 'Under blog section', 'ueldo' ) ),
                    'home-page-header' => esc_html( __( 'Home page header', 'ueldo' ) ),
                    'footer' => esc_html( __( 'Footer', 'ueldo' ) ),
                    'header' => esc_html( __( 'Header', 'ueldo' ) )
                ));

                # add solution
                self::add_solution( 'pages-ids', array_merge( $pages_ids, $hefos_ids ) );

                # show page on front
                update_option( 'show_on_front', 'page' );

                # update blog posts page ID
                if( $pages_ids['blog'] != null && $pages_ids['blog'] != false ) update_option( 'page_for_posts', $pages_ids['blog'] );

                # update home page ID
                if( $pages_ids['home'] != null && $pages_ids['home'] != false ) update_option( 'page_on_front', $pages_ids['home'] );

                # do we have "paddle rental" page correctly added?
                if( $pages_ids['paddle-rental'] != null && $pages_ids['paddle-rental'] != false ) {

                    # set custom post meta option for 404 page
                    add_post_meta( esc_attr( $pages_ids['paddle-rental'] ), '_ueldo_custom_page_settings_meta_box_data', array(
                        'page_excerpt' => '',
                        'custom_header_id' => self::get_trusted_solution( 'header-page-id', self::get_solution( 'pages-ids', 'services-header' ) ),
                        'custom_header_position' => 'static',
                        'use_second_header' => 'no',
                        'get_second_header_content_from' => 'default',
                        'second_header_visible_from' => '400',
                        'default_header_logo_image' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ),
                        'default_second_header_logo_image' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ),
                        'custom_footer_id' => 'none',
                        'custom_footer_position' => 'static'
                    ));
                }

                # do we have "guided tours" page correctly added?
                if( $pages_ids['guided-tours'] != null && $pages_ids['guided-tours'] != false ) {

                    # set custom post meta option for 404 page
                    add_post_meta( esc_attr( $pages_ids['guided-tours'] ), '_ueldo_custom_page_settings_meta_box_data', array(
                        'page_excerpt' => '',
                        'custom_header_id' => self::get_trusted_solution( 'header-page-id', self::get_solution( 'pages-ids', 'services-header' ) ),
                        'custom_header_position' => 'static',
                        'use_second_header' => 'no',
                        'get_second_header_content_from' => 'default',
                        'second_header_visible_from' => '400',
                        'default_header_logo_image' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ),
                        'default_second_header_logo_image' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ),
                        'custom_footer_id' => 'none',
                        'custom_footer_position' => 'static'
                    ));
                }

                # do we have "kayak rental" page correctly added?
                if( $pages_ids['kayak-rental'] != null && $pages_ids['kayak-rental'] != false ) {

                    # set custom post meta option for 404 page
                    add_post_meta( esc_attr( $pages_ids['kayak-rental'] ), '_ueldo_custom_page_settings_meta_box_data', array(
                        'page_excerpt' => '',
                        'custom_header_id' => self::get_trusted_solution( 'header-page-id', self::get_solution( 'pages-ids', 'services-header' ) ),
                        'custom_header_position' => 'static',
                        'use_second_header' => 'no',
                        'get_second_header_content_from' => 'default',
                        'second_header_visible_from' => '400',
                        'default_header_logo_image' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ),
                        'default_second_header_logo_image' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ),
                        'custom_footer_id' => 'none',
                        'custom_footer_position' => 'static'
                    ));
                }

                # do we have home page correctly added?
                if( $pages_ids['home'] != null && $pages_ids['home'] != false ) {

                    # set custom post meta option for 404 page
                    add_post_meta( esc_attr( $pages_ids['home'] ), '_ueldo_custom_page_settings_meta_box_data', array(
                        'page_excerpt' => '',
                        'custom_header_id' => self::get_trusted_solution( 'header-page-id', self::get_solution( 'pages-ids', 'home-page-header' ) ),
                        'custom_header_position' => 'static',
                        'use_second_header' => 'no',
                        'get_second_header_content_from' => 'default',
                        'second_header_visible_from' => '400',
                        'default_header_logo_image' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ),
                        'default_second_header_logo_image' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ),
                        'custom_footer_id' => 'none',
                        'custom_footer_position' => 'static'
                    ));
                }

                # remove temporary variables
                unset( $pages_ids );
            }

           /**
            *
            * install menus
            *
            */

            if( $parts == 'all' || in_array( 'menus', $parts, true ) ) {

                # add new menu
                if( is_int( $menu_id = ueldo_add_demo_assets::add_menu( 'kayaks-main-menu', self::get_solution( 'pages-ids' ), true ) ) ) {

                    # add solution
                    self::add_solution( 'main-menu-id', esc_attr( $menu_id ) );
                }
            }

           /**
            *
            * configure sidebars & widgets
            *
            */

            if( $parts == 'all' || in_array( 'sidebars-and-widgets', $parts, true ) ) {

                # temporary variable
                $temp = array(
                    'sidebar_pages_menu_id' => ueldo_add_demo_assets::add_menu( 'kayaks-pages-menu' )
                );

                # sidebars and widgets data array
                $sw_data = array(
                    'widget_categories' => array(
                        '1' => array(
                            'title' => esc_html( __( 'Categories', 'ueldo' ) ),
                            'count' => 0,
                            'hierarchical' => 0,
                            'dropdown' => 0,
                        ),
                        '_multiwidget' => true
                    ),
                    'widget_text' => array( '_multiwidget' => true ),
                    'widget_rss' => array( '_multiwidget' => true ),
                    'widget_search' => array(
                        '1' => array( 'title' => '' ),
                        '_multiwidget' => true
                    ),
                    'widget_recent-posts' => array( '_multiwidget' => true ),
                    'widget_recent-comments' => array( '_multiwidget' => true ),
                    'widget_archives' => array( '_multiwidget' => true ),
                    'widget_meta' => array( '_multiwidget' => true ),
                    'widget_pages' => array( '_multiwidget' => true ),
                    'widget_calendar' => array( '_multiwidget' => true ),
                    'widget_media_audio' => array( '_multiwidget' => true ),
                    'widget_media_image' => array( '_multiwidget' => true ),
                    'widget_media_video' => array( '_multiwidget' => true ),
                    'widget_tag_cloud' => array(
                        '1' => array(
                            'title' => esc_html( __( 'Popular tags', 'ueldo' ) ),
                            'count' => 0,
                            'taxonomy' => 'post_tag'
                        ),
                        '_multiwidget' => true
                    ),
                    'widget_nav_menu' => array(
                        '1' => array(
                            'title' => esc_html( __( 'Pages', 'ueldo' ) ),
                            'nav_menu' => esc_attr( $temp['sidebar_pages_menu_id'] )
                        ),
                        '_multiwidget' => true
                    ),
                    'widget_custom_html' => array( '_multiwidget' => true ),
                    'widget_rev-slider-widget' => array( '_multiwidget' => true ),
                    'widget_ueldo_popular_posts_widget' => array( '_multiwidget' => true ),
                    'widget_ueldo_call_to_action_widget' => array(
                        '1' => array(
                            'button_url' => ueldo_get_website_dir() .'contact/',
                            'background_image_url' => '',
                            'button_icon' => '',
                            'button_in_new_tab' => '',
                            'big_title' => esc_html( __( '-30%', 'ueldo' ) ),
                            'title' => esc_html( __( 'Limited offer!', 'ueldo' ) ),
                            'content' => 'Praesent ac feugiat est. Vestibulum commodo ultrices elementum. Nulla nec fringilla felis.',
                            'button_text' => esc_html( __( 'Book a Tour', 'ueldo' ) )
                        ),
                        '_multiwidget' => true
                    ),
                    'widget_mc4wp_form_widget' => array( '_multiwidget' => true ),
                    'widget_media_gallery' => array( '_multiwidget' => true ),
                    'sidebars_widgets' => array(
                        'wp_inactive_widgets' => array(),
                        'blog-sidebar' => array(
                            '0' => 'search-1',
                            '1' => 'ueldo_call_to_action_widget-1',
                            '2' => 'nav_menu-1',
                            '3' => 'tag_cloud-1',
                            '4' => 'categories-1'
                        ),
                        'array_version' => 3
                    )
                );

                # remove temporary variables
                unset( $temp );

                # walk for each options
                foreach( $sw_data as $option_key => $option_data ) {

                    # update option
                    update_option( $option_key, $option_data );
                }
            }

           /**
            *
            * get dynamic elements replacements
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) || in_array( 'pages', $parts, true ) ) {

                # get dynamic elements replacements
                $replacements = self::get_dynamic_elements_replacements( self::find_dynamic_elements( self::get_vc_contents() ), $icons, self::get_default_replacements() );
            }

           /**
            *
            * install theme options
            *
            */

            if( $parts == 'all' || in_array( 'theme-options', $parts, true ) ) {

                # update theme options
                update_option( 'ueldo_theme_options', self::get_theme_options_array() );

                # set additional content before side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_before_all', self::do_content_replacements( self::get_vc_contents( 'additional-before-side-menu' ), $replacements ) );

                # set additional content after side menu
                update_option( 'ueldo_theme_options_side_menu_additional_content_after_all', self::do_content_replacements( self::get_vc_contents( 'additional-after-side-menu' ), $replacements ) );

                # clear theme mods - background color and image
                remove_theme_mod( 'background_color' );
                remove_theme_mod( 'background_position_x' );
                remove_theme_mod( 'background_position_y' );
                remove_theme_mod( 'background_repeat' );
                remove_theme_mod( 'background_attachment' );
                remove_theme_mod( 'background_size' );
                remove_theme_mod( 'background_image' );
            }

           /**
            *
            * fill pages contents
            *
            */

            if( $parts == 'all' || in_array( 'pages', $parts, true ) ) {

                # walk for each pages
                foreach( self::get_solution( 'pages-ids' ) as $page_slug => $page_id ) {

                    # not for blog page
                    if( $page_slug == 'blog' ) continue;

                    # update page content
                    $result = wp_update_post( array(
                        'ID' => esc_attr( $page_id ),
                        'post_content' => self::do_content_replacements( self::get_vc_contents( esc_attr( $page_slug ) ), $replacements )
                    ));
                }

                # remove temporary variables
                unset( $replacements );
            }

           /**
            *
            * update permalinks structure
            *
            */

            if( $parts == 'all' || in_array( 'permalinks-structure', $parts, true ) ) {

                # global variable
                global $wp_rewrite;

                # write the rule
                $wp_rewrite -> set_permalink_structure( '/%postname%/' );

                # set the option
                update_option( 'rewrite_rules', false );

                # flush the rules and tell it to write htaccess
                $wp_rewrite -> flush_rules( true );
            }

           /**
            *
            * demo data installed
            *
            */

            exit( '{ "status": "ok" }' );
        }

       /**
        *
        * get possible data parts
        *
        */

        public static function get_possible_data_parts() {

            # return result
            return( array(
                'menus' => esc_html( __( 'Menus', 'ueldo' ) ),
                'posts' => esc_html( __( 'Posts', 'ueldo' ) ),
                'pages' => esc_html( __( 'Pages', 'ueldo' ) ),
                'theme-options' => esc_html( __( 'Theme options', 'ueldo' ) ),
                'forms' => esc_html( __( 'Forms', 'ueldo' ) ),
                'sidebars-and-widgets' => esc_html( __( 'Sidebars & widgets', 'ueldo' ) ),
                'revolution-slider-sliders' => esc_html( __( 'Revolution Slider sliders', 'ueldo' ) ),
                'permalinks-structure' => esc_html( __( 'Permalinks structure', 'ueldo' ) )
            ));
        }

       /**
        *
        * get list of required plugins
        *
        */

        public static function get_required_plugins( $parts ) {

            # all data
            if( !is_array( $parts ) && $parts == 'all' ) {

                # return list of required plugins
                return( array(
                    'ueldo',
                    'visual-composer',
                    'revolution-slider',
                    'contact-form-7',
                    'mailchimp-for-wp'
                ));
            }

            # selected parts
            else {

                # prepare array of required plugins
                $result = array( 'ueldo' );

                # do we have to add pages?
                if( in_array( 'pages', $parts, true ) ) {

                    # return list of required plugins
                    return( array(
                        'visual-composer',
                        'revolution-slider',
                        'contact-form-7',
                        'mailchimp-for-wp'
                    ));
                }

                # do we have to add theme options?
                if( in_array( 'theme-options', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'visual-composer' ) );
                }

                # do we have to add forms?
                if( in_array( 'forms', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'contact-form-7', 'mailchimp-for-wp' ) );
                }

                # do we have to add revolution slider sliders?
                if( in_array( 'revolution-slider-sliders', $parts, true ) ) {

                    # update results array
                    $result = array_merge( $result, array( 'revolution-slider' ) );
                }

                # return result
                return( $result );
            }
        }

       /**
        *
        * get default replacements
        *
        */

        public static function get_default_replacements() {

            # add pages menu
            $pages_menu_id = ueldo_add_demo_assets::add_menu( 'kayaks-pages-menu' );

            # add wave white image
            $wave_white_image_id = ueldo_add_demo_assets::add_image( 'kayaks-wave-white' );

            # add wave color image
            $wave_color_image_id = ueldo_add_demo_assets::add_image( 'kayaks-wave-color-demo-like' );

            # add logo image
            $logo_image_id = ueldo_add_demo_assets::add_image( 'kayaks-logo' );

            # return result
            return( array(
                '{ueldopredefinedsections:googlemap|context:kayaks}' => 'google_map_id="1"',
                '{ueldopredefinedsections:menu|context:kayaks-pages-menu}' => ( $pages_menu_id == false ? '' : 'menu_id="'. esc_attr( $pages_menu_id ) .'"' ),
                '{ueldopredefinedsections:image|context:kayaks-wave-white}' => ( $wave_white_image_id == false ? '' : 'image="'. esc_attr( $wave_white_image_id ) .'"' ),
                '{ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}' => ( $wave_color_image_id == false ? '' : 'image="'. esc_attr( $wave_color_image_id ) .'"' ),
                '{ueldopredefinedsections:image|context:kayaks-logo}' => ( $logo_image_id == false ? '' : 'image="'. esc_attr( $logo_image_id ) .'"' )
            ));
        }

       /**
        *
        * get trusted solution
        *
        */

        public static function get_trusted_solution( $type, $solution ) {

            # do we have solution found?
            if( !empty( $solution ) ) return( $solution );

            # switch by solution type
            switch( $type ) {

                # get most similar elements
                case 'main-menu-slug': return( self::get_most_similar_element( 'menu_slug', esc_html( __( 'Main menu - Kayaks template', 'ueldo' ) ) ) );
                case '404-page-id': return( self::get_most_similar_element( 'page', esc_html( __( '404 page', 'ueldo' ) ) ) );
                case 'footer-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Footer', 'ueldo' ) ) ) );
                case 'header-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Header', 'ueldo' ) ) ) );
                case 'services-header-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Services header', 'ueldo' ) ) ) );
                case 'home-page-header-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Home page header', 'ueldo' ) ) ) );
                case 'under-blog-section-page-id': return( self::get_most_similar_element( 'ueldohefo', esc_html( __( 'Under blog section', 'ueldo' ) ) ) );
            }

            # nothing found
            return( false );
        }

       /**
        *
        * get theme options array
        *
        */

        public static function get_theme_options_array() {

            # return result
            return( array(
                '404-page-id' => array( 'all' => self::get_trusted_solution( '404-page-id', self::get_solution( 'pages-ids', '404-page' ) ) ),
                'blog-posts-list-style' => array(
                    'posts-list-style' => 'default',
                    'display-post-data-under-title' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'yes'
                ),
                'blog-sidebar' => array(
                    'posts-list' => 'yes-right',
                    'single-post' => 'yes-right',
                    'responsive-style' => 'static'
                ),
                'boxed-website' => array(
                    'enabled' => 'no',
                    'large-content-width' => '1100',
                    'large-content-space' => '50',
                    'medium-content-width' => '890',
                    'medium-content-space' => '50',
                    'small-content-width' => '665',
                    'small-content-space' => '50'
                ),
                'comment-textarea-at-top' => 'yes',
                'dynamic-theme-styles-cache' => array(
                    'enabled' => 'no',
                    'clear-cache' => 'all-the-time-when-logged-in'
                ),
                'facebook-fanpage-url' => array( 'all' => 'https://www.facebook.com/envato' ),
                'featured-image-on-lists-only' => 'no',
                'fonts' => array(
                    'general-font-family' => array( 'all' => 'Open Sans' ),
                    'general-font-weight' => array( 'all' => '300' ),
                    'general-font-subset' => array( 'all' => 'latin' ),
                    'general-font-smoothing' => array( 'all' => 'yes' ),
                    'general-bold-font-family' => array( 'all' => 'Open Sans' ),
                    'general-bold-font-weight' => array( 'all' => '600' ),
                    'general-bold-font-subset' => array( 'all' => 'latin' ),
                    'general-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-font-family' => array( 'all' => 'Roboto' ),
                    'menu-font-weight' => array( 'all' => '500' ),
                    'menu-font-subset' => array( 'all' => 'latin' ),
                    'menu-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-font-family' => array( 'all' => 'Crimson Text' ),
                    'headings-font-weight' => array( 'all' => '700' ),
                    'headings-font-subset' => array( 'all' => 'latin' ),
                    'headings-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-slim-font-family' => array( 'all' => 'Crimson Text' ),
                    'headings-slim-font-weight' => array( 'all' => 'regular' ),
                    'headings-slim-font-subset' => array( 'all' => 'latin' ),
                    'headings-slim-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-bold-font-family' => array( 'all' => 'Roboto' ),
                    'headings-bold-font-weight' => array( 'all' => '900' ),
                    'headings-bold-font-subset' => array( 'all' => 'latin' ),
                    'headings-bold-font-smoothing' => array( 'all' => 'yes' ),
                    'headings-subtitle-font-family' => array( 'all' => 'Roboto' ),
                    'headings-subtitle-font-weight' => array( 'all' => '700' ),
                    'headings-subtitle-font-subset' => array( 'all' => 'latin' ),
                    'headings-subtitle-font-smoothing' => array( 'all' => 'yes' ),
                    'buttons-font-family' => array( 'all' => 'Roboto' ),
                    'buttons-font-weight' => array( 'all' => '700' ),
                    'buttons-font-subset' => array( 'all' => 'latin' ),
                    'buttons-font-smoothing' => array( 'all' => 'yes' ),
                    'form-fields-font-family' => array( 'all' => 'Open Sans' ),
                    'form-fields-font-weight' => array( 'all' => '400' ),
                    'form-fields-font-subset' => array( 'all' => 'latin' ),
                    'form-fields-font-smoothing' => array( 'all' => 'yes' ),
                    'blockquote-font-family' => array( 'all' => 'Roboto' ),
                    'blockquote-font-weight' => array( 'all' => '500' ),
                    'blockquote-font-subset' => array( 'all' => 'latin' ),
                    'blockquote-font-smoothing' => array( 'all' => 'yes' ),
                    'alert-messages-font-family' => array( 'all' => 'Roboto' ),
                    'alert-messages-font-weight' => array( 'all' => '400' ),
                    'alert-messages-font-subset' => array( 'all' => 'latin' ),
                    'alert-messages-font-smoothing' => array( 'all' => 'yes' )
                ),
                'footer-content' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'footer-page-id', self::get_solution( 'pages-ids', 'footer' ) ) ),
                    'position' => array( 'all' => 'static' )
                ),
                'google-maps' => array(
                    'api-key' => '',
                    'next-map-id' => '2',
                    'google-map-1-title' => esc_html( __( 'Location map', 'ueldo' ) ),
                    'google-map-1-center-lat' => '41.670650',
                    'google-map-1-center-lng' => '-87.040978',
                    'google-map-1-zoom' => '10',
                    'google-map-1-markers-next-marker-id' => '2',
                    'google-map-1-markers-marker-1-title' => esc_html( __( 'Marker', 'ueldo' ) ),
                    'google-map-1-markers-marker-1-lat' => '41.670650',
                    'google-map-1-markers-marker-1-lng' => '-87.040978',
                    'google-map-1-markers-marker-1-use-custom-marker' => 'no',
                    'google-map-1-markers-marker-1-custom-icon-library' => 'fontawesome',
                    'google-map-1-markers-marker-1-custom-icon' => 'fa fa-address-book',
                    'google-map-1-markers-marker-1-custom-icon-size' => '18',
                    'google-map-1-markers-marker-1-custom-icon-width' => '36',
                    'google-map-1-markers-marker-1-custom-icon-height' => '36',
                    'google-map-1-markers-marker-1-custom-icon-border-radius' => 'circle',
                    'google-map-1-markers-marker-1-custom-icon-border-radius-px' => '4',
                    'google-map-1-markers-marker-1-custom-icon-color' => '#e6491b',
                    'google-map-1-markers-marker-1-custom-icon-background-color' => '#fff',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-horizontal-length' => '0',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-vertical-length' => '5',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-blur-radius' => '20',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-spread-radius' => '0',
                    'google-map-1-markers-marker-1-custom-icon-box-shadow-color' => 'rgba( 0, 0, 0, 0.1 )',
                    'google-map-1-markers-marker-1-custom-marker-image' => '',
                    'google-map-1-custom-style' => '[{"featureType":"administrative","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":20}]},{"featureType":"road","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-100},{"lightness":40}]},{"featureType":"water","elementType":"all","stylers":[{"visibility":"on"},{"saturation":-10},{"lightness":30}]},{"featureType":"landscape.man_made","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":10}]},{"featureType":"landscape.natural","elementType":"all","stylers":[{"visibility":"simplified"},{"saturation":-60},{"lightness":60}]},{"featureType":"poi","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]},{"featureType":"transit","elementType":"all","stylers":[{"visibility":"off"},{"saturation":-100},{"lightness":60}]}]'
                ),
                'header' => array(
                    'get-content-from' => array( 'all' => self::get_trusted_solution( 'header-page-id', self::get_solution( 'pages-ids', 'header' ) ) ),
                    'position' => array( 'all' => 'flying' ),
                    'use-second-header' => array( 'all' => 'no' ),
                    'get-second-content-from' => array( 'all' => 'default' ),
                    'second-header-visible-from' => array( 'all' => '400' ),
                    'default-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'second-header-logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) )
                ),
                'lazy-load-images' => array(
                    'enabled' => 'no',
                    'threshold' => '0'
                ),
                'loader-animation' => array(
                    'enabled' => 'yes',
                    'style' => '01',
                    'add-logo' => 'no',
                    'space-between-logo-and-spinner' => '30',
                    'logo-image' => array( 'all' => esc_url( get_template_directory_uri() .'/_assets/_img/logo.png' ) ),
                    'custom-colors-enabled' => 'no',
                    'custom-colors-background' => '#fff',
                    'custom-colors-spinner' => '#e6491b'
                ),
                'local-scrolling-links-animation' => array(
                    'enabled' => 'yes',
                    'animation-speed' => '1000'
                ),
                'opening-hours-status' => array( 'next-status-id' => '1' ),
                'rtl' => array(
                    'is-rtl' => array( 'all' => 'no' ),
                    'load-rtl-admin-styles' => array( 'all' => 'auto' )
                ),
                'side-menu' => array(
                    'style' => 'flying-default-hidden',
                    'menu-key' => array( 'all' => self::get_trusted_solution( 'main-menu-slug', self::get_main_menu_slug() ) ),
                    'menu-link-font-family' => array( 'all' => 'Roboto' ),
                    'menu-link-font-weight' => array( 'all' => '500' ),
                    'menu-link-font-subset' => array( 'all' => 'latin' ),
                    'menu-link-font-smoothing' => array( 'all' => 'yes' ),
                    'menu-position' => 'left',
                    'menu-links-alignment' => 'center',
                    'opacity-animation-enabled' => 'yes',
                    'submenu-links' => 'visible-on-click-as-new-layer',
                    'menu-vertical-alignment' => 'middle',
                    'custom-sizes-enabled' => 'yes',
                    'custom-sizes-container-width' => '300',
                    'custom-sizes-menu-link-font-size' => '14',
                    'custom-sizes-menu-link-font-line-height' => '1.0',
                    'custom-sizes-menu-link-font-letter-spacing' => '0',
                    'custom-sizes-menu-link-padding-top-bottom' => '25',
                    'custom-sizes-menu-link-padding-left-right' => '25',
                    'custom-sizes-menu-link-margin-top-bottom' => '0',
                    'custom-sizes-menu-link-margin-left-right' => '0',
                    'custom-sizes-menu-link-bottom-border-width' => '1',
                    'custom-sizes-display-bottom-border-for-last-menu-link' => 'display',
                    'custom-sizes-menu-icon-font-size' => '10',
                    'custom-sizes-menu-icon-margin-top' => '0',
                    'custom-sizes-menu-margin-between-icon-and-title' => '10',
                    'custom-sizes-padding-top-bottom-additional-element-before-menu' => '20',
                    'custom-sizes-padding-left-right-additional-element-before-menu' => '30',
                    'custom-sizes-margin-top-additional-element-before-menu' => '0',
                    'custom-sizes-margin-right-additional-element-before-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-before-menu' => '0',
                    'custom-sizes-margin-left-additional-element-before-menu' => '0',
                    'custom-sizes-padding-top-bottom-additional-element-after-menu' => '20',
                    'custom-sizes-padding-left-right-additional-element-after-menu' => '30',
                    'custom-sizes-margin-top-additional-element-after-menu' => '0',
                    'custom-sizes-margin-right-additional-element-after-menu' => '0',
                    'custom-sizes-margin-bottom-additional-element-after-menu' => '0',
                    'custom-sizes-margin-left-additional-element-after-menu' => '0'
                ),
                'single-blog-post-style' => array(
                    'display-post-data-under-title' => 'yes',
                    'blog-post-data-and-title-centered' => 'yes',
                    'featured-image-reverse-indent-allowed' => 'yes'
                ),
                'submit-button-position-in-comment-reply-form' => array( 'all' => 'center' ),
                'translate-publication-dates' => 'yes',
                'twitter-api' => array(
                    'oauth-key' => '',
                    'oauth-secret-key' => ''
                ),
                'under-single-blog-post-content-elements' => array(
                    'elements-count' => '3',
                    'element-1-type' => 'tags-and-categories-with-facebook',
                    'element-1-similar-posts-style' => '02',
                    'element-2-type' => 'author-box',
                    'element-2-similar-posts-style' => '02',
                    'element-3-type' => 'next-previous-posts-navigation',
                    'element-3-similar-posts-style' => '02',
                    'element-4-type' => '',
                    'element-4-similar-posts-style' => '02',
                    'element-5-type' => '',
                    'element-5-similar-posts-style' => '02',
                    'element-6-type' => '',
                    'element-6-similar-posts-style' => '02'
                ),
                'vc-sections-on-blog-pages' => array(
                    'posts-list-above' => array( 'all' => 'none' ),
                    'posts-list-under' => array( 'all' => self::get_trusted_solution( 'under-blog-section-page-id', self::get_solution( 'pages-ids', 'under-blog-section' ) ) ),
                    'single-post-above' => array( 'all' => 'none' ),
                    'single-post-under' => array( 'all' => self::get_trusted_solution( 'under-blog-section-page-id', self::get_solution( 'pages-ids', 'under-blog-section' ) ) ),
                    'archive-above' => array( 'all' => 'none' ),
                    'archive-under' => array( 'all' => self::get_trusted_solution( 'under-blog-section-page-id', self::get_solution( 'pages-ids', 'under-blog-section' ) ) ),
                    'search-above' => array( 'all' => 'none' ),
                    'search-under' => array( 'all' => self::get_trusted_solution( 'under-blog-section-page-id', self::get_solution( 'pages-ids', 'under-blog-section' ) ) )
                ),
                'visual-composer-custom-fonts' => array( 'next-font-id' => '1' ),
                'styles' => array(
                    'general-colors-main-color' => '#e6491b',
                    'general-colors-headings-color' => '#482823',
                    'general-colors-google-map-marker-icon-color' => '#e6491b',
                    'general-colors-elements-border-color' => '#f6f4f4',
                    'general-colors-elements-hover-border-color' => '#f6f4f4',
                    'general-colors-elements-hover-box-shadow' => '0px 10px 35px 0px rgba(228,222,204,0.25)',
                    'info-box-element-background-color' => '#f6f2e7',
                    'info-box-element-border-color' => '#efebe0',
                    'general-colors-image-box-shadow' => '0px 0px 0px 0px rgba(255,255,255,0)',
                    'font-size-h1' => '48',
                    'font-size-h2' => '42',
                    'line-height-headings' => '1',
                    'buttons-global-button-background-color' => '#e6491b',
                    'buttons-global-button-border-color' => '#e6491b',
                    'buttons-global-button-background-color-hover' => '#ff701e',
                    'buttons-global-button-border-color-hover' => '#ff701e',
                    'buttons-global-button-box-shadow-hover' => '0px 10px 35px 0px rgba(255,112,30,0.25)',
                    'buttons-global-button-border-radius' => '25',
                    'gallery-image-overlay-background-color' => 'rgba(246,242,231,0.45)',
                    'gallery-image-buttons-color' => '#fff',
                    'gallery-image-buttons-box-shadow' => '0px 0px 60px 0px rgba(0,0,0,0.55)',
                    'header-bar-and-menu-background-color' => 'rgba(255,255,255,0.01)',
                    'header-bar-and-menu-active-or-hover-link-color' => '#e6491b',
                    'header-bar-and-menu-submenu-background-color' => '#e6491b',
                    'header-bar-and-menu-link-color' => '#482823',
                    'header-bar-and-menu-submenu-element-link-color' => 'rgba(255,255,255,0.7)',
                    'general-colors-headings-subtitle-color' => '#e6491b',
                    'general-colors-blog-post-data-color' => '#e6491b',
                    'forms-field-background-color' => '#ffffff',
                    'forms-field-inset-box-shadow' => '0px 0px 0px 0px rgba(241,236,222,0.01)',
                    'forms-field-border-color' => '#eae8e8',
                    'forms-field-border-color-on-hover' => '#ccc6b9',
                    'forms-checkbox-radio-main-color' => '#e6491b',
                    'general-colors-blockquote-color' => '#e6491b',
                    'side-menu-box-shadow' => '-5px 0px 20px 0px rgba(230,73,27,0.15)',
                    'side-menu-background-color' => '#e6491b'
                )
            ));
        }

       /**
        *
        * get default contents
        *
        */

        public static function get_vc_contents( $page_slug = false ) {

            # array of pages contents
            $contents = array(

                'home' => '[vc_section full_width="stretch_row_content" css=".vc_custom_1505817140836{margin-top: -81px !important;}"][vc_row full_width="stretch_row_content_no_spaces"][vc_column][rev_slider {ueldopredefinedsections:revslider|context:kayaks-home-page}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_28811928735489" layer_for_row_or_section="section" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_38682702196003" layer_for_row_or_section="section" layer_opacity="65%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_28619961088446"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][ueldo_shortcode_info_box class_name="ueldo_vc_element_40012988677261" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'kayak-rental%2F|title:'. rawurlencode( esc_html( __( 'Kayak rental', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Kayak Rental', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h4" {ueldopredefinedsections:icon|key:flaticon-kayak,flaticon-transport|url:https://www.flaticon.com/free-icon/kayak_140476|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color_hover="#e6491b" info_element_border_color_hover="#e6491b" info_element_icon_color_hover="#efebe0" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][ueldo_shortcode_gap class_name="ueldo_vc_element_96521194125311" large_height="30"][vc_column_text]Nulla sit amet rutrum metus. In hac habitasse platea dictumst. Aenean aliquam, turpis eget congue.[/vc_column_text][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_44599983243398" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][/vc_column][vc_column width="1/3"][ueldo_shortcode_info_box class_name="ueldo_vc_element_62346046707574" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'paddle-rental%2F|title:'. rawurlencode( esc_html( __( 'Paddle rental', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Paddle Rental', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h4" {ueldopredefinedsections:icon|key:flaticon-paddle,flaticon-beach|url:https://www.flaticon.com/free-icon/paddle_437151|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color_hover="#e6491b" info_element_border_color_hover="#e6491b" info_element_icon_color_hover="#efebe0" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][ueldo_shortcode_gap class_name="ueldo_vc_element_61734975934262" large_height="30"][vc_column_text]Suspendisse elementum bibendum leo, ac mollis ligula lobortis et. In lobortis dapibus ipsum, suspendisse.[/vc_column_text][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_29950724114993" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][/vc_column][vc_column width="1/3"][ueldo_shortcode_info_box class_name="ueldo_vc_element_58458808113695" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'guided-tours%2F|title:'. rawurlencode( esc_html( __( 'Guided tours', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Guided tours', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h4" {ueldopredefinedsections:icon|key:flaticon-canoe,flaticon-transport|url:https://www.flaticon.com/free-icon/canoe_140767|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color_hover="#e6491b" info_element_border_color_hover="#e6491b" info_element_icon_color_hover="#efebe0" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][ueldo_shortcode_gap class_name="ueldo_vc_element_31593488797780" large_height="30"][vc_column_text]Vestibulum ac euismod orci. Nulla malesuada fringilla dignissim. Sed pulvinar finibus nunc, in auctor.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_49808093497538" large_height="90"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_heading class_name="ueldo_vc_element_15060767904409" heading_tag="h1" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="45"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1506076801957" heading_text="'. esc_html( __( 'Beautiful Green River attractions', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_95154346333464" layer_z_index="5" custom_layer_sizes="custom_settings" layer_type="image" image_add_box_shadow="yes-outset" image_outset_box_shadow_vertical_length="10" image_outset_box_shadow_blur_radius="25" image_outset_box_shadow_color="rgba(72,40,35,0.08)" image_add_border="yes" image_border_width="8" image_border_color="#ffffff" large_width_type="px" large_width_px="600" large_height_type="px" large_height_px="400" large_layer_position="bottom_left" large_margin_bottom="30" large_margin_left="60" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="4" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="490" medium_height_type="px" medium_height_px="327" medium_layer_position="bottom_left" medium_margin_bottom="30" medium_margin_left="20" medium_custom_row_border_radius="yes-copy-from-large" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="402" small_height_type="px" small_height_px="268" small_layer_position="bottom_left" small_margin_bottom="30" small_margin_left="-20" small_custom_row_border_radius="yes-copy-from-medium" extra_small_layer_visibility="no"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15055613666946" layer_z_index="6" custom_layer_sizes="custom_settings" layer_type="text" text_content="'. esc_html( __( 'Beautiful Green River attractions', 'ueldo' ) ) .'" text_font_family="headings-font" text_uppercase_enabled="no" text_alignment="left" text_font_size="50" text_line_height="1" large_width_type="px" large_width_px="565" large_height_type="px" large_margin_top="45" medium_layer_custom_sizes="yes" medium_width_type="px" medium_width_px="460" medium_height_type="px" medium_margin_top="45" small_layer_custom_sizes="yes" small_width_type="px" small_width_px="317" small_height_type="px" small_height_px="150" small_margin_top="60" extra_small_layer_visibility="no"][/vc_column][vc_column width="1/2"][ueldo_shortcode_card class_name="ueldo_vc_element_15055606278079" border_width="0" padding_top="55" padding_right="0" padding_bottom="55" padding_left="0" custom_colors_enabled="custom_settings" box_shadow_color="rgba(255,255,255,0.01)" box_shadow_color_hover="rgba(255,255,255,0.01)" background_color="#f6f2e7" background_color_hover="#f6f2e7"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15060719887493"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15060719931266" large_width_type="px" large_width_px="110" medium_custom_sizes="yes" medium_width_type="px" medium_width_px="58" small_custom_sizes="yes" small_width_type="px" small_width_px="40" extra_small_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15060720032845" large_width_type="calc" large_width_calc_px="220" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_px="116" small_custom_sizes="yes" small_width_type="calc" small_width_calc_px="80" extra_small_custom_sizes="yes" extra_small_width_type="calc" extra_small_width_calc_px="60"][ueldo_shortcode_heading class_name="ueldo_vc_element_15057264077597" heading_tag="h4" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15057264155166" heading_text="'. esc_html( __( 'Why you should visit this River?', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_icon_list class_name="ueldo_vc_element_15057265835463" icon_fontawesome="fa fa-check" icon_sizes="custom_settings" icon_height="27" icon_vertical_alignment="top" margin_bottom="60"]'. esc_html( __( 'beautiful views and clean Air,', 'ueldo' ) ) .'<br /><br /> '. esc_html( __( 'peaceful, pleasant river,', 'ueldo' ) ) .'<br /><br /> '. esc_html( __( 'amazing view of the bridge,', 'ueldo' ) ) .'<br /><br /> '. esc_html( __( 'great way to spend the weekend for the whole family,', 'ueldo' ) ) .'[/ueldo_shortcode_icon_list][ueldo_shortcode_progress_bar class_name="ueldo_vc_element_15057276298431" progress_bar_duration="2000" progress_bar_value="94%" progress_bar_title="'. esc_html( __( 'Customers recommendations:', 'ueldo' ) ) .'" progress_bar_title_position="above-progress-bar" custom_colors_enabled="custom_settings" inactive_background_color="#ded9c9"][ueldo_shortcode_icon class_name="ueldo_vc_element_83863026927483" icon_alignment="inline" icon_fontawesome="fa fa-yelp" custom_colors_enabled="custom_settings" icon_color="#e6491b"][ueldo_shortcode_heading class_name="ueldo_vc_element_150607184035" heading_tag="p" text_align="inline" display_heading_subtitle="no" heading_url="url:%23|title:'. rawurlencode( esc_html( __( 'Find out more on Yelp!', 'ueldo' ) ) ) .'||" custom_margins_enabled="custom_margins" custom_margin_bottom="0" custom_margin_left="20"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15060718889208" heading_text="'. esc_html( __( 'Find out more on Yelp!', 'ueldo' ) ) .'" font_family="general-font" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_15057271049295" large_height="155" medium_custom_sizes="yes" medium_height="80" extra_small_custom_sizes="yes" extra_small_height="0"][/vc_column][/vc_row][vc_row][vc_column offset="vc_hidden-lg vc_hidden-md vc_hidden-sm"][ueldo_shortcode_image class_name="ueldo_vc_element_15060768923318" border_width="8" large_height_px="0" extra_small_custom_sizes="yes" extra_small_height_px="380" margin_top="30" custom_colors_enabled="custom_settings" image_border_color="#ffffff" images_container_box_shadow_vertical_length="10" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(72,40,35,0.08)"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible" css=".vc_custom_1506082395509{margin-top: -118px !important;}"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15060822244629" large_height="0" medium_custom_sizes="yes" medium_height="13"][ueldo_shortcode_button class_name="ueldo_vc_element_15057253689549" button_text="'. esc_html( __( 'Find out more about Green River!', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'about-us%2F|title:'. rawurlencode( esc_html( __( 'About us', 'ueldo' ) ) ) .'||" button_alignment="center" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_6368091638960" large_height="120"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15057292321852" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15057292389939" heading_text="'. esc_html( __( 'Upcoming Tours', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Nunc metus orci, porttitor ac varius nec, efficitur vitae ex. Vestibulum pretium metus tempus porta tristique. Morbi suscipit id purus at rutrum. Quisque ullamcorper orci sem, a lacinia ligula congue at. Morbi dignissim feugiat elit, quis varius mi.</p>[/vc_column_text][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column width="1/6" offset="vc_col-lg-2 vc_col-md-1 vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-5 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_29868308380360" large_height="45"][ueldo_shortcode_card class_name="ueldo_vc_element_45514295979969" border_width="0" padding_top="30" custom_colors_enabled="custom_settings" box_shadow_color="rgba(255,255,255,0.01)" box_shadow_vertical_length_hover="0" box_shadow_blur_radius_hover="0" box_shadow_color_hover="rgba(255,255,255,0.01)" background_color="#faf9f7" background_color_hover="#f6f2e7"][ueldo_shortcode_info_box class_name="ueldo_vc_element_77056992885605" content_alignment="left" content_position="inline" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'guided-tours%2F|title:'. rawurlencode( esc_html( __( 'Guided tours', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'February 24 - 29, 2018', 'ueldo' ) ) .'" info_box_subtitle="'. esc_html( __( 'Number of kayaks limited!', 'ueldo' ) ) .'" info_box_title_heading_type="h5" info_element_width="44" info_element_height="44" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-canoe,flaticon-transport|url:https://www.flaticon.com/free-icon/canoe_390879|slug:info_element_icon_} info_element_icon_custom_size_enabled="custom_settings" info_element_icon_custom_size="44" custom_colors_enabled="custom_settings" info_element_background_color="rgba(255,255,255,0)" info_element_background_color_hover="rgba(255,255,255,0)" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_93516852054364" large_height="65" extra_small_custom_sizes="yes" extra_small_height="15"][/vc_column][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-5 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_89989635064029" large_height="45" extra_small_custom_sizes="yes" extra_small_height="0"][ueldo_shortcode_card class_name="ueldo_vc_element_39014248098454" border_width="0" padding_top="30" custom_colors_enabled="custom_settings" box_shadow_color="rgba(255,255,255,0.01)" box_shadow_vertical_length_hover="0" box_shadow_blur_radius_hover="0" box_shadow_color_hover="rgba(255,255,255,0.01)" background_color="#faf9f7" background_color_hover="#f6f2e7"][ueldo_shortcode_info_box class_name="ueldo_vc_element_58465465802388" content_alignment="left" content_position="inline" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'guided-tours%2F|title:'. rawurlencode( esc_html( __( 'Guided tours', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'March 12 - 16, 2018', 'ueldo' ) ) .'" info_box_subtitle="'. esc_html( __( 'Number of paddles limited!', 'ueldo' ) ) .'" info_box_title_heading_type="h5" info_element_width="44" info_element_height="44" info_element_border_radius="px" info_element_border_radius_px="0" {ueldopredefinedsections:icon|key:flaticon-paddle,flaticon-sports|url:https://www.flaticon.com/free-icon/paddle_178459|slug:info_element_icon_} info_element_icon_custom_size_enabled="custom_settings" info_element_icon_custom_size="44" custom_colors_enabled="custom_settings" info_element_background_color="rgba(255,255,255,0)" info_element_background_color_hover="rgba(255,255,255,0)" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][/ueldo_shortcode_info_box][/ueldo_shortcode_card][ueldo_shortcode_gap class_name="ueldo_vc_element_69972790739462"][/vc_column][vc_column width="1/6" offset="vc_col-lg-2 vc_col-md-1 vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_71124064350161" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_27619060275791" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_gap class_name="ueldo_vc_element_63998223496224" large_height="26"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15118595553804" layer_for_row_or_section="section" layer_z_index="0" color="#f6f2e7"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_62690170485783" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-map,flaticon-location|url:https://www.flaticon.com/free-icon/map_390897|slug:icon_} icon_size="200" icon_rotate="45deg" icon_alignment="right" icon_color="rgba(72,40,35,0.06)" large_width_type="px" large_width_px="300" large_height_type="px" large_height_px="300" large_layer_position="top_right" large_margin_right="-50"][ueldo_shortcode_gap class_name="ueldo_vc_element_58513704223187"][ueldo_shortcode_heading class_name="ueldo_vc_element_15057494502189" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15057494634917" heading_text="'. esc_html( __( 'Kayaks & Tours Gallery', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_filtered_masonry class_name="ueldo_vc_element_15057432801916" custom_filter_selector_settings="custom_settings" filter_selector_border_radius="25" margin_between_filter_selector_and_filtered_elements="60" filter_selector_element_padding_top="19" filter_selector_element_padding_right="25" filter_selector_element_padding_bottom="14" filter_selector_element_padding_left="25" custom_colors_enabled="custom_settings" container_background_color="rgba(246,242,231,0)" filter_selector_border_color="#e6491b" filter_selector_border_color_hover="#e6491b" filter_selector_title_color="#ffffff" filter_selector_inside_border_color="#da3a0b" filter_selector_background_color="#e6491b" filter_selector_box_shadow_color="rgba(255,255,255,0.01)" filter_selector_box_shadow_color_hover="rgba(230,73,27,0.25)" filter_selector_hover_element_title_color="#ffffff" filter_selector_hover_element_background_color="#dc3f11" filter_selector_active_element_title_color="#ffffff" filter_selector_active_element_background_color="#dc3f11"][ueldo_shortcode_filtered_masonry_cell class_name="ueldo_vc_element_47233517993998" filter_category="'. esc_html( __( 'Kayaking', 'ueldo' ) ) .'"][ueldo_shortcode_image class_name="ueldo_vc_element_19170862095955" additional="gallery_image" gallery_slug="gallery" border_width="8" margin_bottom="0" custom_colors_enabled="custom_settings" image_border_color="#ffffff" images_container_box_shadow_vertical_length="10" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(72,40,35,0.08)" gallery_buttons_border_color="#e6491b" gallery_buttons_background_color="#e6491b" gallery_buttons_icon_color="#ffffff" gallery_buttons_box_shadow_color="rgba(230,73,27,0.25)" gallery_buttons_border_color_hover="#ff701e" gallery_buttons_background_color_hover="#ff701e" gallery_buttons_icon_color_hover="#ffffff" gallery_buttons_box_shadow_color_hover="rgba(255,112,30,0.25)"][/ueldo_shortcode_filtered_masonry_cell][ueldo_shortcode_filtered_masonry_cell class_name="ueldo_vc_element_38262787122122" filter_category="Paddle"][ueldo_shortcode_image class_name="ueldo_vc_element_56071239912302" additional="gallery_image" gallery_slug="gallery" border_width="8" margin_bottom="0" custom_colors_enabled="custom_settings" image_border_color="#ffffff" images_container_box_shadow_vertical_length="10" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(72,40,35,0.08)" gallery_buttons_border_color="#e6491b" gallery_buttons_background_color="#e6491b" gallery_buttons_icon_color="#ffffff" gallery_buttons_box_shadow_color="rgba(230,73,27,0.25)" gallery_buttons_border_color_hover="#ff701e" gallery_buttons_background_color_hover="#ff701e" gallery_buttons_icon_color_hover="#ffffff" gallery_buttons_box_shadow_color_hover="rgba(255,112,30,0.25)"][/ueldo_shortcode_filtered_masonry_cell][ueldo_shortcode_filtered_masonry_cell class_name="ueldo_vc_element_61739489051596" filter_category="'. esc_html( __( 'Kayaking', 'ueldo' ) ) .'"][ueldo_shortcode_image class_name="ueldo_vc_element_68146316718794" additional="gallery_image" gallery_slug="gallery" border_width="8" margin_bottom="0" custom_colors_enabled="custom_settings" image_border_color="#ffffff" images_container_box_shadow_vertical_length="10" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(72,40,35,0.08)" gallery_buttons_border_color="#e6491b" gallery_buttons_background_color="#e6491b" gallery_buttons_icon_color="#ffffff" gallery_buttons_box_shadow_color="rgba(230,73,27,0.25)" gallery_buttons_border_color_hover="#ff701e" gallery_buttons_background_color_hover="#ff701e" gallery_buttons_icon_color_hover="#ffffff" gallery_buttons_box_shadow_color_hover="rgba(255,112,30,0.25)"][/ueldo_shortcode_filtered_masonry_cell][ueldo_shortcode_filtered_masonry_cell class_name="ueldo_vc_element_37831975599781" width="double" filter_category="Paddle"][ueldo_shortcode_image class_name="ueldo_vc_element_36785018648251" additional="gallery_image" gallery_slug="gallery" border_width="8" margin_bottom="0" custom_colors_enabled="custom_settings" image_border_color="#ffffff" images_container_box_shadow_vertical_length="10" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(72,40,35,0.08)" gallery_buttons_border_color="#e6491b" gallery_buttons_background_color="#e6491b" gallery_buttons_icon_color="#ffffff" gallery_buttons_box_shadow_color="rgba(230,73,27,0.25)" gallery_buttons_border_color_hover="#ff701e" gallery_buttons_background_color_hover="#ff701e" gallery_buttons_icon_color_hover="#ffffff" gallery_buttons_box_shadow_color_hover="rgba(255,112,30,0.25)"][/ueldo_shortcode_filtered_masonry_cell][ueldo_shortcode_filtered_masonry_cell class_name="ueldo_vc_element_78584097619999" filter_category="'. esc_html( __( 'Kayaking', 'ueldo' ) ) .'"][ueldo_shortcode_image class_name="ueldo_vc_element_12580672326487" additional="gallery_image" gallery_slug="gallery" border_width="8" margin_bottom="0" custom_colors_enabled="custom_settings" image_border_color="#ffffff" images_container_box_shadow_vertical_length="10" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(72,40,35,0.08)" gallery_buttons_border_color="#e6491b" gallery_buttons_background_color="#e6491b" gallery_buttons_icon_color="#ffffff" gallery_buttons_box_shadow_color="rgba(230,73,27,0.25)" gallery_buttons_border_color_hover="#ff701e" gallery_buttons_background_color_hover="#ff701e" gallery_buttons_icon_color_hover="#ffffff" gallery_buttons_box_shadow_color_hover="rgba(255,112,30,0.25)"][/ueldo_shortcode_filtered_masonry_cell][/ueldo_shortcode_filtered_masonry][ueldo_shortcode_gap class_name="ueldo_vc_element_15057505385776"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15118595553804" layer_for_row_or_section="section" layer_z_index="0" color="#f6f2e7"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_63330000659512" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-compass,flaticon-technology|url:https://www.flaticon.com/free-icon/compass_390848|slug:icon_} icon_size="200" icon_rotate="315deg" icon_alignment="left" icon_color="rgba(72,40,35,0.06)" large_width_type="px" large_width_px="300" large_height_type="px" large_height_px="300" large_layer_position="bottom_left" large_margin_bottom="-55" large_margin_left="-50"][/vc_column][/vc_row][vc_row][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15057505492376" text_align="center" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15057505545038" heading_text="'. esc_html( __( 'Opening hours', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Nunc metus orci, porttitor ac varius nec, efficitur vitae ex. Vestibulum pretium metus tempus porta tristique. Morbi suscipit id purus at rutrum. Quisque ullamcorper orci sem, a lacinia ligula congue at. Morbi dignissim feugiat elit, quis varius mi.</p>[/vc_column_text][ueldo_shortcode_heading class_name="ueldo_vc_element_15057510020518" heading_tag="h3" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="15"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_77293256112075" heading_text="08" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" custom_font_color_enabled="custom_settings"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_20773188364386" heading_text="00" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" font_size="24" custom_font_color_enabled="custom_settings" add_highlights="yes-underline" underline_height="2" underline_margin_bottom="3"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_78360948342649" heading_text="-" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" custom_font_color_enabled="custom_settings" additional_padding_left="10" additional_padding_right="10"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_79312620489579" heading_text="22" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" custom_font_color_enabled="custom_settings"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15555621569763" heading_text="00" font_family="headings-bold-font" custom_font_size_and_line_height_enabled="custom_settings" font_size="24" custom_font_color_enabled="custom_settings" add_highlights="yes-underline" underline_height="2" underline_margin_bottom="3"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_1505751278798" heading_tag="h6" text_align="center" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15057512989505" heading_text="'. esc_html( __( 'everyday between April and October', 'ueldo' ) ) .'" custom_font_color_enabled="custom_settings"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_77036112910336"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_91810130558089" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_50793952674334" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_gap class_name="ueldo_vc_element_32010733833638" large_height="26"][/vc_column][/vc_row][/vc_section]',

                'about-us' => '[vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_459374203230"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15058998962505" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-compass,flaticon-technology|url:https://www.flaticon.com/free-icon/compass_390848|slug:icon_} icon_size="200" icon_rotate="315deg" icon_alignment="left" icon_color="rgba(72,40,35,0.06)" large_width_type="px" large_width_px="300" large_height_type="px" large_height_px="300" large_layer_position="center_center" large_margin_top="-260" large_margin_left="-105" extra_small_layer_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="300" extra_small_height_type="px" extra_small_height_px="300" extra_small_layer_position="center_right" extra_small_margin_top="90" extra_small_margin_right="-125"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_heading class_name="ueldo_vc_element_56477220681268" heading_tag="h1" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_5696578320109" heading_text="'. esc_html( __( 'About us', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_heading class_name="ueldo_vc_element_51124844412775" heading_tag="h4" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_7645160122456" heading_text="Sed leo lacus, iaculis in sollicitudin tempus, lacinia id mi. Sed sit amet sapien ut mauris auctor malesuada at id nibh. Integer elementum diam vel tortor suscipit." custom_font_size_and_line_height_enabled="custom_settings" font_size="22" line_height="1.4"][/ueldo_shortcode_heading][vc_column_text]Duis lobortis enim sed elit suscipit dignissim. Suspendisse potenti. Ut consectetur quam sit amet dolor tempor, in maximus risus ullamcorper. Phasellus tempor leo ac ipsum aliquam, sit amet posuere lorem blandit. Donec a odio erat. Lorem ipsum dolor sit amet, consectetur adipiscing elit.[/vc_column_text][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15060837293414" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][ueldo_shortcode_image class_name="ueldo_vc_element_69793187962970" additional="gallery_image" gallery_slug="gallery" border_width="8" large_height_px="450" extra_small_custom_sizes="yes" extra_small_height_px="380" margin_bottom="0" custom_colors_enabled="custom_settings" image_border_color="#ffffff" images_container_box_shadow_vertical_length="10" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(72,40,35,0.08)" gallery_buttons_border_color="#ff701e" gallery_buttons_background_color="#ff701e" gallery_buttons_icon_color="#ffffff" gallery_buttons_icon_color_hover="#ffffff"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15058986749153"][/vc_column][/vc_row][vc_row][vc_column offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_info_box class_name="ueldo_vc_element_77801004172744" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( 'Kayaks & Paddles for rent', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h4" info_element_width="120" info_element_height="80" info_element_border_radius="px" info_element_type="counter" info_element_counter_value="94" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_font_family="headings-bold-font"][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_51967071846633" large_height="0" small_custom_sizes="yes" small_height="30"][/vc_column][vc_column offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_info_box class_name="ueldo_vc_element_43321985908361" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( 'Team members', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h4" info_element_width="120" info_element_height="80" info_element_border_radius="px" info_element_type="counter" info_element_counter_value="6" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_font_family="headings-bold-font"][/ueldo_shortcode_info_box][ueldo_shortcode_gap class_name="ueldo_vc_element_45406416965809" large_height="0" small_custom_sizes="yes" small_height="30"][/vc_column][vc_column offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_info_box class_name="ueldo_vc_element_44380876908557" content_alignment="left" content_position="inline" info_box_title="'. esc_html( __( 'Years of experience', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h4" info_element_width="120" info_element_height="80" info_element_border_radius="px" info_element_type="counter" info_element_counter_value="28" info_element_counter_custom_font_enabled="custom_settings" info_element_counter_font_family="headings-bold-font"][/ueldo_shortcode_info_box][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15059007771448"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_71124064350161" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_27619060275791" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_gap class_name="ueldo_vc_element_63998223496224" large_height="26"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15118602449739" layer_for_row_or_section="section" layer_z_index="0" color="#f6f2e7"][ueldo_shortcode_gap class_name="ueldo_vc_element_39279590318113"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_150591062711" layer_z_index="5" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-canoe,flaticon-transport|url:https://www.flaticon.com/free-icon/canoe_390879|slug:icon_} icon_size="150" large_width_type="px" large_width_px="150" large_height_type="px" large_height_px="152" large_layer_position="center_center" large_margin_top="-76" large_margin_left="-75" large_custom_row_border_radius="yes-same-for-corners" large_row_border_radius="4" extra_small_layer_custom_sizes="yes" extra_small_width_type="px" extra_small_width_px="150" extra_small_height_type="px" extra_small_height_px="152" extra_small_layer_position="center_right" extra_small_margin_top="-76" extra_small_margin_right="-75"][ueldo_shortcode_image class_name="ueldo_vc_element_68728490664458" additional="gallery_image" gallery_slug="gallery" border_width="8" large_height_px="450" margin_bottom="0" custom_colors_enabled="custom_settings" images_container_box_shadow_vertical_length="10" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(72,40,35,0.08)" gallery_buttons_border_color="#ff701e" gallery_buttons_background_color="#ff701e" gallery_buttons_icon_color="#ffffff" gallery_buttons_icon_color_hover="#ffffff"][ueldo_shortcode_gap class_name="ueldo_vc_element_10618944494057"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_47249453183179"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059111560556" large_width_type="px" large_width_px="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_58534493082125" large_width_type="calc" large_width_calc_px="60"][ueldo_shortcode_heading class_name="ueldo_vc_element_30867825026473" heading_tag="h4" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_88144644053116" heading_text="Vivamus eleifend nibh eget"][/ueldo_shortcode_heading][vc_column_text]Sed malesuada commodo sem et ornare. Quisque non mi sed magna venenatis consectetur. Maecenas rhoncus. Sed sit amet sapien ut mauris auctor malesuada at id nibh.[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_15059110533985" button_text="'. esc_html( __( 'Contact us!', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_19149983788900" large_height="30"][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15265115197021" large_height="30"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15036485716689"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059108484991" large_width_type="px" large_width_px="30"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_37780935847859" large_width_type="calc" large_width_calc_px="30"][ueldo_shortcode_heading class_name="ueldo_vc_element_55327163301412" heading_tag="h4" display_heading_subtitle="no"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_73043752607263" heading_text="Vivamus eleifend nibh eget"][/ueldo_shortcode_heading][vc_column_text]Donec lorem ante, placerat nec sem porttitor, pretium maximus massa. Nam sed pretium enim. Sed malesuada commodo sem et ornare. Quisque non mi sed magna venenatis consectetur. Maecenas rhoncus tempor diam, id dapibus erat auctor sed.[/vc_column_text][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_94182722236052"][ueldo_shortcode_image class_name="ueldo_vc_element_13562929900774" additional="gallery_image" gallery_slug="gallery" border_width="8" large_height_px="450" margin_bottom="0" custom_colors_enabled="custom_settings" images_container_box_shadow_vertical_length="10" images_container_box_shadow_blur_radius="25" images_container_box_shadow_color="rgba(72,40,35,0.08)" gallery_buttons_border_color="#ff701e" gallery_buttons_background_color="#ff701e" gallery_buttons_icon_color="#ffffff" gallery_buttons_icon_color_hover="#ffffff"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15118603634342" layer_for_row_or_section="section" layer_z_index="0" color="#f6f2e7"][ueldo_shortcode_gap class_name="ueldo_vc_element_15059106166382"][ueldo_shortcode_heading class_name="ueldo_vc_element_15059014607177" text_align="center" heading_subtitle_text="'. esc_html( __( 'Great reviews!', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="30"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15059014681838" heading_text="'. esc_html( __( 'Tourists References', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_full_width_testimonials class_name="ueldo_vc_element_15059026243042" type="persons" author_name_position="under-person-images" content_position="above" custom_colors_enabled="custom_settings" background_color="#f6f2e7" persons_images_box_shadow_color="rgba(255,255,255,0.01)" persons_images_box_shadow_color_hover="rgba(255,255,255,0.01)" active_person_image_box_shadow_color="rgba(255,255,255,0.01)" active_person_image_box_shadow_color_hover="rgba(255,255,255,0.01)" next_prev_arrow_color="#e6491b" next_prev_arrow_container_background="#f6f2e7" next_prev_arrow_container_background_hover="#f6f2e7" next_prev_arrow_container_box_shadow_color="rgba(255,255,255,0.01)" next_prev_arrow_container_box_shadow_color_hover="rgba(255,255,255,0.01)"][ueldo_shortcode_full_width_testimonials_single_testimonial class_name="ueldo_vc_element_29414971961845"][vc_column_text]Aliquam erat volutpat. Nullam tempus ligula eget tortor luctus, ac faucibus tellus suscipit. Nunc nulla tellus, pulvinar ut pellentesque in, iaculis at nulla. Curabitur a cursus elit. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Suspendisse risus risus, euismod et erat sed, hendrerit condimentum mi. Morbi fringilla, sapien sed placerat cursus, magna ligula suscipit odio, ut sollicitudin erat quam in ante.[/vc_column_text][/ueldo_shortcode_full_width_testimonials_single_testimonial][ueldo_shortcode_full_width_testimonials_single_testimonial class_name="ueldo_vc_element_91647214969097"][vc_column_text]Aliquam erat volutpat. Nullam tempus ligula eget tortor luctus, ac faucibus tellus suscipit. Nunc nulla tellus, pulvinar ut pellentesque in, iaculis at nulla. Curabitur a cursus elit. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Suspendisse risus risus, euismod et erat sed, hendrerit condimentum mi. Morbi fringilla, sapien sed placerat cursus, magna ligula suscipit odio, ut sollicitudin erat quam in ante.[/vc_column_text][/ueldo_shortcode_full_width_testimonials_single_testimonial][ueldo_shortcode_full_width_testimonials_single_testimonial class_name="ueldo_vc_element_61302073311433"][vc_column_text]Aliquam erat volutpat. Nullam tempus ligula eget tortor luctus, ac faucibus tellus suscipit. Nunc nulla tellus, pulvinar ut pellentesque in, iaculis at nulla. Curabitur a cursus elit. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Suspendisse risus risus, euismod et erat sed, hendrerit condimentum mi. Morbi fringilla, sapien sed placerat cursus, magna ligula suscipit odio, ut sollicitudin erat quam in ante.[/vc_column_text][/ueldo_shortcode_full_width_testimonials_single_testimonial][/ueldo_shortcode_full_width_testimonials][ueldo_shortcode_gap class_name="ueldo_vc_element_32209311091911"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_91810130558089" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_50793952674334" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_gap class_name="ueldo_vc_element_32010733833638" large_height="26"][/vc_column][/vc_row][/vc_section]',

                'contact' => '[vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15058215534979"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="5/12" offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15058215572033" heading_tag="h1" display_heading_subtitle="yes-under" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( '54321 Example Street, Westchester Township, IN 46304', 'ueldo' ) ) .'" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1505821564344" heading_text="'. esc_html( __( 'Contact us!', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/vc_column][vc_column width="7/12" offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15060841655349" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15058241787766"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_1505824181542" large_width_percentage="100%" large_content_alignment="right" extra_small_custom_sizes="yes"][ueldo_shortcode_button class_name="ueldo_vc_element_57130728270121" button_text="'. esc_html( __( 'Facebook', 'ueldo' ) ) .'" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Facebook', 'ueldo' ) ) ) .'||" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-facebook" custom_sizes_enabled="custom_settings" additional_margin_after="15"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_82368144253265" button_text="'. esc_html( __( 'Twitter', 'ueldo' ) ) .'" button_url="url:%23|title:'. rawurlencode( esc_html( __( 'Twitter', 'ueldo' ) ) ) .'||" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-twitter"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15058258304547"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_71124064350161" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_27619060275791" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_gap class_name="ueldo_vc_element_63998223496224" large_height="26"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15118609716876" layer_for_row_or_section="section" layer_z_index="0" color="#f6f2e7"][ueldo_shortcode_gap class_name="ueldo_vc_element_15118609906041" large_height="35"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15058262608266"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_1505826263977" large_width_type="calc" large_width_calc_px="15" extra_small_custom_sizes="yes"][ueldo_shortcode_google_map class_name="ueldo_vc_element_15058234535494" {ueldopredefinedsections:googlemap|context:kayaks} horizontal_alignment="center" border_width="8" large_height_px="550" extra_small_custom_sizes="yes" extra_small_height_px="380" margin_bottom="0" custom_colors_enabled="custom_settings" border_color="#ffffff" box_shadow_vertical_length="10" box_shadow_blur_radius="45" box_shadow_color="rgba(72,40,35,0.15)"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15058260496363" large_height="10" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15058262810815"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15058262839286" large_width_type="px" large_width_px="15" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_1505826289438" large_width_type="calc" large_width_calc_px="15" extra_small_custom_sizes="yes"][ueldo_shortcode_form class_name="ueldo_vc_element_15059149953666" form_shortcode="`{`contact-form-7 {ueldopredefinedsections:contactform7|context:kayaks|inside:true}`}`" custom_colors_enabled="custom_settings" form_field_border_color="#e4ddd0" form_field_border_color_focus="#aaaaaa" form_field_background_color="#f1ecde" form_field_placeholder_text_color="#888888" inside_field_icon_color="#dddddd" submit_button_text_color="#ffffff" submit_button_text_color_hover="#ffffff" submit_button_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15058285839275" large_height="35"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_91810130558089" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_50793952674334" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_gap class_name="ueldo_vc_element_32010733833638" large_height="26"][/vc_column][/vc_row][/vc_section]',

                'guided-tours' => '[vc_section full_width="stretch_row" css=".vc_custom_1505987652542{margin-top: -81px !important;}"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15059875965498" layer_for_row_or_section="section" layer_type="image"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_28811928735489" layer_for_row_or_section="section" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_38682702196003" layer_for_row_or_section="section" layer_opacity="65%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_gap class_name="ueldo_vc_element_15059876259691" large_height="450"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_88928824201361"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_heading class_name="ueldo_vc_element_15059882688936" heading_tag="h1" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Our services', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="30" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15059882766009" heading_text="'. esc_html( __( 'Guided tours', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15060862919424" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15060862716896"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15060862747792" large_width_percentage="100%" large_content_alignment="right" extra_small_custom_sizes="yes"][ueldo_shortcode_button class_name="ueldo_vc_element_15059886991198" button_text="'. esc_html( __( 'Reservation', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Make a reservation', 'ueldo' ) ) ) .'||" button_alignment="inline" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15059889802282"][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_column_text]Morbi cursus molestie dui, sed pulvinar justo fermentum in. Integer ac sagittis eros. Maecenas quis auctor arcu. Fusce tristique non tortor a pretium. Donec egestas blandit suscipit. Suspendisse magna nunc, cursus ac aliquam non, gravida commodo augue. Suspendisse potenti.<br /><br /> Nullam auctor erat eu ligula varius, eget dignissim augue congue. Suspendisse non rhoncus velit. Vivamus maximus nisl ut leo lobortis porta. Fusce mattis tristique nibh, a semper sem blandit eu. Praesent facilisis sapien libero, eget faucibus lacus euismod nec. Donec vitae congue quam, et blandit nulla.[/vc_column_text][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15060863349842" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][vc_column_text]Pellentesque non lorem enim. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Suspendisse sodales erat at orci consectetur aliquam. Quisque ligula felis, feugiat in ipsum cursus, lobortis blandit enim. Cras in est sit amet ex congue viverra.<br /><br /> Praesent vel diam in nisl consequat convallis. Aenean ornare augue nulla, vel ultrices arcu iaculis id. Suspendisse dapibus arcu orci. Etiam varius eget libero a sagittis. Quisque eget enim sed mauris rhoncus finibus. Mauris ac feugiat justo. Praesent et metus venenatis, hendrerit felis eget, feugiat massa.[/vc_column_text][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15059891304601"][ueldo_shortcode_tabs class_name="ueldo_vc_element_1505989169252" tabs_content_style="style-02" tabs_selector_style="style-03" circle_navigation_alignment="left" custom_colors_enabled="custom_settings" tabs_selector_border_color="#e6491b" tabs_selector_border_color_hover="#e6491b" tabs_selector_border_between_items_color="#da3a0b" tabs_selector_background_color="#e6491b" tabs_selector_active_element_background_color="#dc3f11" tabs_selector_box_shadow_color="rgba(255,255,255,0.01)" tabs_selector_box_shadow_color_hover="rgba(230,73,27,0.25)" tabs_selector_title_color="#ffffff" tabs_selector_title_color_hover="#ffffff" tabs_content_background_color="#ffffff"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_80930307908496" single_tab_title="'. esc_html( __( 'Rates', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_42077123071463" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_top="6"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_72943780708461" heading_text="'. esc_html( __( 'Rates', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15059901073839" vertical_alignment="top"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_66854631816681" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" small_custom_sizes="yes"][ueldo_shortcode_price_single class_name="ueldo_vc_element_23362031196235" title="'. esc_html( __( 'Per Adult', 'ueldo' ) ) .'" description="'. esc_html( __( 'For beginners and experienced swimmers', 'ueldo' ) ) .'" price="$80"][ueldo_shortcode_gap class_name="ueldo_vc_element_33824595491765" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_47720095085053" title="'. esc_html( __( 'Kids 12 years old and under', 'ueldo' ) ) .'" description="'. esc_html( __( 'For beginners and experienced swimmers', 'ueldo' ) ) .'" price="$49"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059901229343" large_width_type="px" large_width_px="30" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_38773963813633" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_40659504051484" large_height="0" small_custom_sizes="yes" small_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_85132681784525" title="'. esc_html( __( 'All family', 'ueldo' ) ) .'" description="'. esc_html( __( 'For experienced swimmers', 'ueldo' ) ) .'" price="$199"][ueldo_shortcode_gap class_name="ueldo_vc_element_44685965535983" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_69565098201448" title="'. esc_html( __( 'Per Senior', 'ueldo' ) ) .'" description="'. esc_html( __( 'For experienced swimmers', 'ueldo' ) ) .'" price="$49"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_5732662311369"][/ueldo_shortcode_tabs_single_tab][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_14124750535390" single_tab_title="'. esc_html( __( 'Dates & Times', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_71046362958027" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_top="6"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_36789162173781" heading_text="'. esc_html( __( 'Dates & Times', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]'. esc_html( __( 'Please note that all hours of operation are daylight and weather dependent.', 'ueldo' ) ) .' Aliquam at consectetur metus. Aliquam sit amet ante molestie, faucibus urna rhoncus, consequat massa. Morbi eu ex eu purus semper facilisis. Fusce congue lectus ut erat interdum suscipit.[/vc_column_text][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15059945104274" vertical_alignment="top"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059945146184" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" extra_small_custom_sizes="yes"][vc_column_text]<strong>'. esc_html( __( 'January - March', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'We\'re closed.', 'ueldo' ) ) .'<br /><br /> <strong>'. esc_html( __( 'April - May', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Open 7 days a week, 10:00am to dusk (around 7pm)', 'ueldo' ) ) .'[/vc_column_text][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059945250293" large_width_type="px" large_width_px="30" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059945316911" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15060863901657" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][vc_column_text]<strong>'. esc_html( __( 'June - August', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Open 7 days a week, 8:00am to 9:00pm', 'ueldo' ) ) .'<br /><br /> <strong>'. esc_html( __( 'September - December', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Open on weekends (weather permitting), 10:00am to dusk', 'ueldo' ) ) .'[/vc_column_text][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_6389874751363"][/ueldo_shortcode_tabs_single_tab][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_85223063794359" single_tab_title="'. esc_html( __( 'Extra Info', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_48312038135942" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_top="6"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_59725558200503" heading_text="'. esc_html( __( 'Extra Info', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_card class_name="ueldo_vc_element_15059947437813" margin_bottom="30" border_width="0" custom_colors_enabled="custom_settings" box_shadow_color="rgba(255,255,255,0.01)" box_shadow_vertical_length_hover="0" box_shadow_blur_radius_hover="0" box_shadow_color_hover="rgba(255,255,255,0.01)" background_color="#f6f2e7" background_color_hover="#f6f2e7"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15060860234908"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15060860269695" large_width_type="calc" large_width_calc_base="29%" large_width_calc_px="15" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_base="35%" medium_width_calc_px="15" small_custom_sizes="yes"][ueldo_shortcode_icon class_name="ueldo_vc_element_88470550430466" icon_alignment="inline" {ueldopredefinedsections:icon|key:flaticon-map,flaticon-location|url:https://www.flaticon.com/free-icon/map_390897|slug:icon_} custom_sizes_enabled="custom_settings" margin_right="25" custom_colors_enabled="custom_settings" icon_color="#e6491b"][ueldo_shortcode_heading class_name="ueldo_vc_element_67094326559930" heading_tag="h5" text_align="inline" display_heading_subtitle="no" heading_url="url:%23|title:title:'. rawurlencode( esc_html( __( 'What to bring?', 'ueldo' ) ) ) .'||" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_22088844102769" heading_text="'. esc_html( __( 'What to bring?', 'ueldo' ) ) .'" font_family="menu-font" custom_font_color_enabled="custom_settings" font_color="#482823"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15060860375006" large_width_type="px" large_width_px="30" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15060860452326" large_width_type="calc" large_width_calc_base="71%" large_width_calc_px="15" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_base="65%" medium_width_calc_px="15" small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15060862290643" large_height="0" small_custom_sizes="yes" small_height="30"][ueldo_shortcode_icon class_name="ueldo_vc_element_16642261917871" icon_alignment="inline" {ueldopredefinedsections:icon|key:flaticon-canoe,flaticon-transport|url:https://www.flaticon.com/free-icon/canoe_390879|slug:icon_} custom_sizes_enabled="custom_settings" margin_right="25" custom_colors_enabled="custom_settings" icon_color="#e6491b"][ueldo_shortcode_heading class_name="ueldo_vc_element_84504342261397" heading_tag="h5" text_align="inline" display_heading_subtitle="no" heading_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_27402212386304" heading_text="'. esc_html( __( 'Call us: 1-800-123-4567', 'ueldo' ) ) .'" font_family="menu-font" custom_font_color_enabled="custom_settings" font_color="#482823"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][vc_column_text]Vestibulum elementum scelerisque facilisis. Ut dui erat, tristique interdum diam sit amet, luctus feugiat nulla. Praesent laoreet, arcu vel bibendum scelerisque, dui dui mollis tellus, sit amet congue nunc nibh nec neque. Orci varius natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Nam in egestas massa. Suspendisse id nulla sed arcu iaculis cursus in vitae nisl. Nunc tellus lorem, commodo sit amet.<br /><br /> Commodo sit amet, dignissim quis dolor. Nullam blandit, sem non tempus ultrices, diam eros feugiat leo, a suscipit nisi erat nec nulla. Aenean non gravida risus. Cras molestie augue a sagittis lacinia. Pellentesque lacinia commodo placerat. Ut malesuada placerat elit quis placerat. Orci varius natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Nullam eu libero nisl. Sed suscipit lorem a tellus pretium, vel condimentum tortor fermentum.<br /><br /> Integer nec sapien in leo aliquam tincidunt. Morbi vitae auctor urna. Vivamus vel massa magna. Nunc lobortis tristique elementum. In condimentum porttitor urna id consequat. Aliquam erat volutpat. Mauris interdum porttitor massa, eget egestas dolor ultricies et. Curabitur scelerisque hendrerit condimentum. Duis eget venenatis tellus.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_7530535343789" large_height="25"][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][ueldo_shortcode_gap class_name="ueldo_vc_element_15059905521077"][/vc_column][/vc_row][/vc_section][vc_section el_class="ueldo-vc-row-overflow-visible"][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_71124064350161" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_27619060275791" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_gap class_name="ueldo_vc_element_63998223496224" large_height="26"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15118607904419" layer_for_row_or_section="section" layer_z_index="0" color="#f6f2e7"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_32467910961517" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-compass,flaticon-technology|url:https://www.flaticon.com/free-icon/compass_390848|slug:icon_} icon_size="200" icon_rotate="315deg" icon_alignment="left" icon_color="rgba(72,40,35,0.06)" large_width_type="px" large_width_px="300" large_height_type="px" large_height_px="300" large_layer_position="bottom_left" large_margin_bottom="-55" large_margin_left="-70"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_28823851110273" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-map,flaticon-location|url:https://www.flaticon.com/free-icon/map_390897|slug:icon_} icon_size="200" icon_rotate="45deg" icon_alignment="right" icon_color="rgba(72,40,35,0.06)" large_width_type="px" large_width_px="300" large_height_type="px" large_height_px="300" large_layer_position="top_right" large_margin_right="-70"][ueldo_shortcode_gap class_name="ueldo_vc_element_13454561836999"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15059847397071" text_align="center" heading_subtitle_text="'. esc_html( __( 'Spend unforgettable moments', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="30"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15059847864492" heading_text="'. esc_html( __( 'It\'s not just an adventure', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Aliquam volutpat dolor lectus, at malesuada quam suscipit at. Proin blandit tincidunt ligula, sed commodo nulla. Nunc id tempus diam, eu tincidunt quam. Duis sollicitudin, lacus eu faucibus imperdiet, mi urna pulvinar dolor, et mollis dui leo quis metus. Fusce tellus nibh, eleifend quis quam quis.</p>[/vc_column_text][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/6" offset="vc_col-lg-3 vc_col-md-3 vc_hidden-xs"][/vc_column][vc_column width="2/3" offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15059859919552"][ueldo_shortcode_card class_name="ueldo_vc_element_15059855045382" padding_bottom="25" custom_colors_enabled="custom_settings" box_shadow_vertical_length="10" box_shadow_blur_radius="35" box_shadow_color="rgba(228,222,204,0.25)" background_color="#f9f5eb" background_color_hover="#f9f5eb" border_color="#e4ddd0" border_color_hover="#e4ddd0"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15059859032045"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059859060656" large_width_percentage="100%" large_content_alignment="center"][ueldo_shortcode_form class_name="ueldo_vc_element_15059853021436" form_shortcode="`{`mc4wp_form {ueldopredefinedsections:mc4wp|context:kayaks|inside:true}`}`" custom_colors_enabled="custom_settings" form_field_border_color="#e4ddd0" form_field_border_color_focus="#aaaaaa" form_field_background_color="#f1ecde" form_field_placeholder_text_color="#888888" inside_field_icon_color="#dddddd" submit_button_text_color="#ffffff" submit_button_text_color_hover="#ffffff" submit_button_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][/vc_column][vc_column width="1/6" offset="vc_col-lg-3 vc_col-md-3 vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_59181369017229"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_91810130558089" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_50793952674334" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_gap class_name="ueldo_vc_element_32010733833638" large_height="26"][/vc_column][/vc_row][/vc_section]',

                'kayak-rental' => '[vc_section full_width="stretch_row" css=".vc_custom_1505987652542{margin-top: -81px !important;}"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15059875965498" layer_for_row_or_section="section" layer_type="image"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_28811928735489" layer_for_row_or_section="section" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_38682702196003" layer_for_row_or_section="section" layer_opacity="65%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_gap class_name="ueldo_vc_element_15059876259691" large_height="450"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_88928824201361"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_heading class_name="ueldo_vc_element_15059882688936" heading_tag="h1" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Our services', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="30" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15059882766009" heading_text="'. esc_html( __( 'Kayak Rental', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15060862919424" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15060862716896"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15060862747792" large_width_percentage="100%" large_content_alignment="right" extra_small_custom_sizes="yes"][ueldo_shortcode_button class_name="ueldo_vc_element_15059886991198" button_text="'. esc_html( __( 'Reservation', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Make a reservation', 'ueldo' ) ) ) .'||" button_alignment="inline" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15059889802282"][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_column_text]Morbi cursus molestie dui, sed pulvinar justo fermentum in. Integer ac sagittis eros. Maecenas quis auctor arcu. Fusce tristique non tortor a pretium. Donec egestas blandit suscipit. Suspendisse magna nunc, cursus ac aliquam non, gravida commodo augue. Suspendisse potenti.<br /><br /> Nullam auctor erat eu ligula varius, eget dignissim augue congue. Suspendisse non rhoncus velit. Vivamus maximus nisl ut leo lobortis porta. Fusce mattis tristique nibh, a semper sem blandit eu. Praesent facilisis sapien libero, eget faucibus lacus euismod nec. Donec vitae congue quam, et blandit nulla.[/vc_column_text][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15060863349842" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][vc_column_text]Pellentesque non lorem enim. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Suspendisse sodales erat at orci consectetur aliquam. Quisque ligula felis, feugiat in ipsum cursus, lobortis blandit enim. Cras in est sit amet ex congue viverra.<br /><br /> Praesent vel diam in nisl consequat convallis. Aenean ornare augue nulla, vel ultrices arcu iaculis id. Suspendisse dapibus arcu orci. Etiam varius eget libero a sagittis. Quisque eget enim sed mauris rhoncus finibus. Mauris ac feugiat justo. Praesent et metus venenatis, hendrerit felis eget, feugiat massa.[/vc_column_text][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15059891304601"][ueldo_shortcode_tabs class_name="ueldo_vc_element_1505989169252" tabs_content_style="style-02" tabs_selector_style="style-03" circle_navigation_alignment="left" custom_colors_enabled="custom_settings" tabs_selector_border_color="#e6491b" tabs_selector_border_color_hover="#e6491b" tabs_selector_border_between_items_color="#da3a0b" tabs_selector_background_color="#e6491b" tabs_selector_active_element_background_color="#dc3f11" tabs_selector_box_shadow_color="rgba(255,255,255,0.01)" tabs_selector_box_shadow_color_hover="rgba(230,73,27,0.25)" tabs_selector_title_color="#ffffff" tabs_selector_title_color_hover="#ffffff" tabs_content_background_color="#ffffff"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_80930307908496" single_tab_title="'. esc_html( __( 'Rates', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_42077123071463" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_top="6"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_72943780708461" heading_text="'. esc_html( __( 'Rates', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15059901073839" vertical_alignment="top"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_66854631816681" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" small_custom_sizes="yes"][ueldo_shortcode_price_single class_name="ueldo_vc_element_23362031196235" title="'. esc_html( __( 'Single kayak, 1 hour', 'ueldo' ) ) .'" description="'. esc_html( __( 'For experienced kayaker', 'ueldo' ) ) .'"][ueldo_shortcode_gap class_name="ueldo_vc_element_33824595491765" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_47720095085053" title="'. esc_html( __( 'Single kayak, 2 hours', 'ueldo' ) ) .'" description="'. esc_html( __( 'For experienced kayaker', 'ueldo' ) ) .'" price="$35"][ueldo_shortcode_gap class_name="ueldo_vc_element_53699421092157" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_69063981497295" title="'. esc_html( __( 'Single kayak, full day', 'ueldo' ) ) .'" description="'. esc_html( __( 'For experienced kayaker', 'ueldo' ) ) .'" price="$79"][ueldo_shortcode_gap class_name="ueldo_vc_element_97231110909642" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_26587160353486" title="'. esc_html( __( 'Single kayak, 2 full days', 'ueldo' ) ) .'" description="'. esc_html( __( 'For experienced kayaker', 'ueldo' ) ) .'" price="$149"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059901229343" large_width_type="px" large_width_px="30" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_38773963813633" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_40659504051484" large_height="0" small_custom_sizes="yes" small_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_85132681784525" title="'. esc_html( __( 'Double kayak, 1 hour', 'ueldo' ) ) .'" description="'. esc_html( __( 'For 1 experienced kayaker or 2 kayakers', 'ueldo' ) ) .'" price="$29"][ueldo_shortcode_gap class_name="ueldo_vc_element_44685965535983" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_69565098201448" title="'. esc_html( __( 'Double kayak, 2 hours', 'ueldo' ) ) .'" description="'. esc_html( __( 'For 1 experienced kayaker or 2 kayakers', 'ueldo' ) ) .'" price="$55"][ueldo_shortcode_gap class_name="ueldo_vc_element_63285190404959" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_28330569375277" title="'. esc_html( __( 'Double kayak, full day', 'ueldo' ) ) .'" description="'. esc_html( __( 'For 1 experienced kayaker or 2 kayakers', 'ueldo' ) ) .'" price="$109"][ueldo_shortcode_gap class_name="ueldo_vc_element_18230128776653" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_84242128865264" title="'. esc_html( __( 'Double kayak, 2 full days', 'ueldo' ) ) .'" description="'. esc_html( __( 'For 1 experienced kayaker or 2 kayakers', 'ueldo' ) ) .'" price="$199"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_5732662311369"][/ueldo_shortcode_tabs_single_tab][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_14124750535390" single_tab_title="'. esc_html( __( 'Dates & Times', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_71046362958027" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_top="6"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_36789162173781" heading_text="'. esc_html( __( 'Dates & Times', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]'. esc_html( __( 'Please note that all hours of operation are daylight and weather dependent.', 'ueldo' ) ) .' Aliquam at consectetur metus. Aliquam sit amet ante molestie, faucibus urna rhoncus, consequat massa. Morbi eu ex eu purus semper facilisis. Fusce congue lectus ut erat interdum suscipit.[/vc_column_text][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15059945104274" vertical_alignment="top"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059945146184" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" extra_small_custom_sizes="yes"][vc_column_text]<strong>'. esc_html( __( 'January - March', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'We\'re closed.', 'ueldo' ) ) .'<br /><br /> <strong>'. esc_html( __( 'April - May', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Open 7 days a week, 10:00am to dusk (around 7pm)', 'ueldo' ) ) .'[/vc_column_text][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059945250293" large_width_type="px" large_width_px="30" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059945316911" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15060863901657" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][vc_column_text]<strong>'. esc_html( __( 'June - August', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Open 7 days a week, 8:00am to 9:00pm', 'ueldo' ) ) .'<br /><br /> <strong>'. esc_html( __( 'September - December', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Open on weekends (weather permitting), 10:00am to dusk', 'ueldo' ) ) .'[/vc_column_text][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_6389874751363"][/ueldo_shortcode_tabs_single_tab][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_85223063794359" single_tab_title="'. esc_html( __( 'Extra Info', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_48312038135942" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_top="6"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_59725558200503" heading_text="'. esc_html( __( 'Extra Info', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_card class_name="ueldo_vc_element_15059947437813" margin_bottom="30" border_width="0" custom_colors_enabled="custom_settings" box_shadow_color="rgba(255,255,255,0.01)" box_shadow_vertical_length_hover="0" box_shadow_blur_radius_hover="0" box_shadow_color_hover="rgba(255,255,255,0.01)" background_color="#f6f2e7" background_color_hover="#f6f2e7"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15060860234908"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15060860269695" large_width_type="calc" large_width_calc_base="29%" large_width_calc_px="15" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_base="35%" medium_width_calc_px="15" small_custom_sizes="yes"][ueldo_shortcode_icon class_name="ueldo_vc_element_88470550430466" icon_alignment="inline" {ueldopredefinedsections:icon|key:flaticon-map,flaticon-location|url:https://www.flaticon.com/free-icon/map_390897|slug:icon_} custom_sizes_enabled="custom_settings" margin_right="25" custom_colors_enabled="custom_settings" icon_color="#e6491b"][ueldo_shortcode_heading class_name="ueldo_vc_element_67094326559930" heading_tag="h5" text_align="inline" display_heading_subtitle="no" heading_url="url:%23|title:title:'. rawurlencode( esc_html( __( 'What to bring?', 'ueldo' ) ) ) .'||" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_22088844102769" heading_text="'. esc_html( __( 'What to bring?', 'ueldo' ) ) .'" font_family="menu-font" custom_font_color_enabled="custom_settings" font_color="#482823"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15060860375006" large_width_type="px" large_width_px="30" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15060860452326" large_width_type="calc" large_width_calc_base="71%" large_width_calc_px="15" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_base="65%" medium_width_calc_px="15" small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15060862290643" large_height="0" small_custom_sizes="yes" small_height="30"][ueldo_shortcode_icon class_name="ueldo_vc_element_16642261917871" icon_alignment="inline" {ueldopredefinedsections:icon|key:flaticon-canoe,flaticon-transport|url:https://www.flaticon.com/free-icon/canoe_390879|slug:icon_} custom_sizes_enabled="custom_settings" margin_right="25" custom_colors_enabled="custom_settings" icon_color="#e6491b"][ueldo_shortcode_heading class_name="ueldo_vc_element_84504342261397" heading_tag="h5" text_align="inline" display_heading_subtitle="no" heading_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_27402212386304" heading_text="'. esc_html( __( 'Call us: 1-800-123-4567', 'ueldo' ) ) .'" font_family="menu-font" custom_font_color_enabled="custom_settings" font_color="#482823"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][vc_column_text]Vestibulum elementum scelerisque facilisis. Ut dui erat, tristique interdum diam sit amet, luctus feugiat nulla. Praesent laoreet, arcu vel bibendum scelerisque, dui dui mollis tellus, sit amet congue nunc nibh nec neque. Orci varius natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Nam in egestas massa. Suspendisse id nulla sed arcu iaculis cursus in vitae nisl. Nunc tellus lorem, commodo sit amet.<br /><br /> Commodo sit amet, dignissim quis dolor. Nullam blandit, sem non tempus ultrices, diam eros feugiat leo, a suscipit nisi erat nec nulla. Aenean non gravida risus. Cras molestie augue a sagittis lacinia. Pellentesque lacinia commodo placerat. Ut malesuada placerat elit quis placerat. Orci varius natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Nullam eu libero nisl. Sed suscipit lorem a tellus pretium, vel condimentum tortor fermentum.<br /><br /> Integer nec sapien in leo aliquam tincidunt. Morbi vitae auctor urna. Vivamus vel massa magna. Nunc lobortis tristique elementum. In condimentum porttitor urna id consequat. Aliquam erat volutpat. Mauris interdum porttitor massa, eget egestas dolor ultricies et. Curabitur scelerisque hendrerit condimentum. Duis eget venenatis tellus.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_7530535343789" large_height="25"][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][ueldo_shortcode_gap class_name="ueldo_vc_element_15059905521077"][/vc_column][/vc_row][/vc_section][vc_section el_class="ueldo-vc-row-overflow-visible"][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_71124064350161" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_27619060275791" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_gap class_name="ueldo_vc_element_63998223496224" large_height="26"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15118607904419" layer_for_row_or_section="section" layer_z_index="0" color="#f6f2e7"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_32467910961517" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-compass,flaticon-technology|url:https://www.flaticon.com/free-icon/compass_390848|slug:icon_} icon_size="200" icon_rotate="315deg" icon_alignment="left" icon_color="rgba(72,40,35,0.06)" large_width_type="px" large_width_px="300" large_height_type="px" large_height_px="300" large_layer_position="bottom_left" large_margin_bottom="-55" large_margin_left="-70"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_28823851110273" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-map,flaticon-location|url:https://www.flaticon.com/free-icon/map_390897|slug:icon_} icon_size="200" icon_rotate="45deg" icon_alignment="right" icon_color="rgba(72,40,35,0.06)" large_width_type="px" large_width_px="300" large_height_type="px" large_height_px="300" large_layer_position="top_right" large_margin_right="-70"][ueldo_shortcode_gap class_name="ueldo_vc_element_13454561836999"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15059847397071" text_align="center" heading_subtitle_text="'. esc_html( __( 'Spend unforgettable moments', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="30"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15059847864492" heading_text="'. esc_html( __( 'It\'s not just an adventure', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Aliquam volutpat dolor lectus, at malesuada quam suscipit at. Proin blandit tincidunt ligula, sed commodo nulla. Nunc id tempus diam, eu tincidunt quam. Duis sollicitudin, lacus eu faucibus imperdiet, mi urna pulvinar dolor, et mollis dui leo quis metus. Fusce tellus nibh, eleifend quis quam quis.</p>[/vc_column_text][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/6" offset="vc_col-lg-3 vc_col-md-3 vc_hidden-xs"][/vc_column][vc_column width="2/3" offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15059859919552"][ueldo_shortcode_card class_name="ueldo_vc_element_15059855045382" padding_bottom="25" custom_colors_enabled="custom_settings" box_shadow_vertical_length="10" box_shadow_blur_radius="35" box_shadow_color="rgba(228,222,204,0.25)" background_color="#f9f5eb" background_color_hover="#f9f5eb" border_color="#e4ddd0" border_color_hover="#e4ddd0"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15059859032045"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059859060656" large_width_percentage="100%" large_content_alignment="center"][ueldo_shortcode_form class_name="ueldo_vc_element_15059853021436" form_shortcode="`{`mc4wp_form {ueldopredefinedsections:mc4wp|context:kayaks|inside:true}`}`" custom_colors_enabled="custom_settings" form_field_border_color="#e4ddd0" form_field_border_color_focus="#aaaaaa" form_field_background_color="#f1ecde" form_field_placeholder_text_color="#888888" inside_field_icon_color="#dddddd" submit_button_text_color="#ffffff" submit_button_text_color_hover="#ffffff" submit_button_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][/vc_column][vc_column width="1/6" offset="vc_col-lg-3 vc_col-md-3 vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_59181369017229"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_91810130558089" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_50793952674334" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_gap class_name="ueldo_vc_element_32010733833638" large_height="26"][/vc_column][/vc_row][/vc_section]',

                'paddle-rental' => '[vc_section full_width="stretch_row" css=".vc_custom_1505987652542{margin-top: -81px !important;}"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15059875965498" layer_for_row_or_section="section" layer_type="image"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_28811928735489" layer_for_row_or_section="section" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_38682702196003" layer_for_row_or_section="section" layer_opacity="65%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_gap class_name="ueldo_vc_element_15059876259691" large_height="450"][/vc_column][/vc_row][/vc_section][vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_88928824201361"][/vc_column][/vc_row][vc_row content_placement="middle" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2"][ueldo_shortcode_heading class_name="ueldo_vc_element_15059882688936" heading_tag="h1" custom_margins_enabled="custom_margins" heading_subtitle_text="'. esc_html( __( 'Our services', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="30" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15059882766009" heading_text="'. esc_html( __( 'Paddle Rental', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15060862919424" large_height="0" extra_small_custom_sizes="yes" extra_small_height="45"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15060862716896"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15060862747792" large_width_percentage="100%" large_content_alignment="right" extra_small_custom_sizes="yes"][ueldo_shortcode_button class_name="ueldo_vc_element_15059886991198" button_text="'. esc_html( __( 'Reservation', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Make a reservation', 'ueldo' ) ) ) .'||" button_alignment="inline" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15059889802282"][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_column_text]Morbi cursus molestie dui, sed pulvinar justo fermentum in. Integer ac sagittis eros. Maecenas quis auctor arcu. Fusce tristique non tortor a pretium. Donec egestas blandit suscipit. Suspendisse magna nunc, cursus ac aliquam non, gravida commodo augue. Suspendisse potenti.<br /><br /> Nullam auctor erat eu ligula varius, eget dignissim augue congue. Suspendisse non rhoncus velit. Vivamus maximus nisl ut leo lobortis porta. Fusce mattis tristique nibh, a semper sem blandit eu. Praesent facilisis sapien libero, eget faucibus lacus euismod nec. Donec vitae congue quam, et blandit nulla.[/vc_column_text][/vc_column][vc_column width="1/2"][ueldo_shortcode_gap class_name="ueldo_vc_element_15060863349842" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][vc_column_text]Pellentesque non lorem enim. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Suspendisse sodales erat at orci consectetur aliquam. Quisque ligula felis, feugiat in ipsum cursus, lobortis blandit enim. Cras in est sit amet ex congue viverra.<br /><br /> Praesent vel diam in nisl consequat convallis. Aenean ornare augue nulla, vel ultrices arcu iaculis id. Suspendisse dapibus arcu orci. Etiam varius eget libero a sagittis. Quisque eget enim sed mauris rhoncus finibus. Mauris ac feugiat justo. Praesent et metus venenatis, hendrerit felis eget, feugiat massa.[/vc_column_text][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15059891304601"][ueldo_shortcode_tabs class_name="ueldo_vc_element_1505989169252" tabs_content_style="style-02" tabs_selector_style="style-03" circle_navigation_alignment="left" custom_colors_enabled="custom_settings" tabs_selector_border_color="#e6491b" tabs_selector_border_color_hover="#e6491b" tabs_selector_border_between_items_color="#da3a0b" tabs_selector_background_color="#e6491b" tabs_selector_active_element_background_color="#dc3f11" tabs_selector_box_shadow_color="rgba(255,255,255,0.01)" tabs_selector_box_shadow_color_hover="rgba(230,73,27,0.25)" tabs_selector_title_color="#ffffff" tabs_selector_title_color_hover="#ffffff" tabs_content_background_color="#ffffff"][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_80930307908496" single_tab_title="'. esc_html( __( 'Rates', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_42077123071463" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_top="6"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_72943780708461" heading_text="'. esc_html( __( 'Rates', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15059901073839" vertical_alignment="top"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_66854631816681" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" small_custom_sizes="yes"][ueldo_shortcode_price_single class_name="ueldo_vc_element_23362031196235" title="'. esc_html( __( 'Paddleboard, for 1 hour', 'ueldo' ) ) .'" description="'. esc_html( __( 'For beginners and experienced swimmers', 'ueldo' ) ) .'"][ueldo_shortcode_gap class_name="ueldo_vc_element_33824595491765" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_47720095085053" title="'. esc_html( __( 'Paddleboard, for 2 hours', 'ueldo' ) ) .'" description="'. esc_html( __( 'For beginners and experienced swimmers', 'ueldo' ) ) .'" price="$35"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059901229343" large_width_type="px" large_width_px="30" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_38773963813633" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_40659504051484" large_height="0" small_custom_sizes="yes" small_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_85132681784525" title="'. esc_html( __( 'Paddleboard, full day', 'ueldo' ) ) .'" description="'. esc_html( __( 'For experienced swimmers', 'ueldo' ) ) .'" price="$79"][ueldo_shortcode_gap class_name="ueldo_vc_element_44685965535983" large_height="30"][ueldo_shortcode_price_single class_name="ueldo_vc_element_69565098201448" title="'. esc_html( __( 'Paddleboard, 2 days', 'ueldo' ) ) .'" description="'. esc_html( __( 'For experienced swimmers', 'ueldo' ) ) .'" price="$149"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_5732662311369"][/ueldo_shortcode_tabs_single_tab][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_14124750535390" single_tab_title="'. esc_html( __( 'Dates & Times', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_71046362958027" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_top="6"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_36789162173781" heading_text="'. esc_html( __( 'Dates & Times', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]'. esc_html( __( 'Please note that all hours of operation are daylight and weather dependent.', 'ueldo' ) ) .' Aliquam at consectetur metus. Aliquam sit amet ante molestie, faucibus urna rhoncus, consequat massa. Morbi eu ex eu purus semper facilisis. Fusce congue lectus ut erat interdum suscipit.[/vc_column_text][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15059945104274" vertical_alignment="top"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059945146184" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" extra_small_custom_sizes="yes"][vc_column_text]<strong>'. esc_html( __( 'January - March', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'We\'re closed.', 'ueldo' ) ) .'<br /><br /> <strong>'. esc_html( __( 'April - May', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Open 7 days a week, 10:00am to dusk (around 7pm)', 'ueldo' ) ) .'[/vc_column_text][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059945250293" large_width_type="px" large_width_px="30" extra_small_custom_sizes="yes" extra_small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059945316911" large_width_type="calc" large_width_calc_base="50%" large_width_calc_px="15" extra_small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15060863901657" large_height="0" extra_small_custom_sizes="yes" extra_small_height="30"][vc_column_text]<strong>'. esc_html( __( 'June - August', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Open 7 days a week, 8:00am to 9:00pm', 'ueldo' ) ) .'<br /><br /> <strong>'. esc_html( __( 'September - December', 'ueldo' ) ) .'</strong><br /> '. esc_html( __( 'Open on weekends (weather permitting), 10:00am to dusk', 'ueldo' ) ) .'[/vc_column_text][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_6389874751363"][/ueldo_shortcode_tabs_single_tab][ueldo_shortcode_tabs_single_tab class_name="ueldo_vc_element_85223063794359" single_tab_title="'. esc_html( __( 'Extra Info', 'ueldo' ) ) .'"][ueldo_shortcode_heading class_name="ueldo_vc_element_48312038135942" display_heading_subtitle="no" custom_margins_enabled="custom_margins" custom_margin_top="6"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_59725558200503" heading_text="'. esc_html( __( 'Extra Info', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][ueldo_shortcode_card class_name="ueldo_vc_element_15059947437813" margin_bottom="30" border_width="0" custom_colors_enabled="custom_settings" box_shadow_color="rgba(255,255,255,0.01)" box_shadow_vertical_length_hover="0" box_shadow_blur_radius_hover="0" box_shadow_color_hover="rgba(255,255,255,0.01)" background_color="#f6f2e7" background_color_hover="#f6f2e7"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15060860234908"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15060860269695" large_width_type="calc" large_width_calc_base="29%" large_width_calc_px="15" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_base="35%" medium_width_calc_px="15" small_custom_sizes="yes"][ueldo_shortcode_icon class_name="ueldo_vc_element_88470550430466" icon_alignment="inline" {ueldopredefinedsections:icon|key:flaticon-map,flaticon-location|url:https://www.flaticon.com/free-icon/map_390897|slug:icon_} custom_sizes_enabled="custom_settings" margin_right="25" custom_colors_enabled="custom_settings" icon_color="#e6491b"][ueldo_shortcode_heading class_name="ueldo_vc_element_67094326559930" heading_tag="h5" text_align="inline" display_heading_subtitle="no" heading_url="url:%23|title:title:'. rawurlencode( esc_html( __( 'What to bring?', 'ueldo' ) ) ) .'||" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_22088844102769" heading_text="'. esc_html( __( 'What to bring?', 'ueldo' ) ) .'" font_family="menu-font" custom_font_color_enabled="custom_settings" font_color="#482823"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15060860375006" large_width_type="px" large_width_px="30" small_custom_sizes="yes" small_width_percentage="0%"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15060860452326" large_width_type="calc" large_width_calc_base="71%" large_width_calc_px="15" medium_custom_sizes="yes" medium_width_type="calc" medium_width_calc_base="65%" medium_width_calc_px="15" small_custom_sizes="yes"][ueldo_shortcode_gap class_name="ueldo_vc_element_15060862290643" large_height="0" small_custom_sizes="yes" small_height="30"][ueldo_shortcode_icon class_name="ueldo_vc_element_16642261917871" icon_alignment="inline" {ueldopredefinedsections:icon|key:flaticon-canoe,flaticon-transport|url:https://www.flaticon.com/free-icon/canoe_390879|slug:icon_} custom_sizes_enabled="custom_settings" margin_right="25" custom_colors_enabled="custom_settings" icon_color="#e6491b"][ueldo_shortcode_heading class_name="ueldo_vc_element_84504342261397" heading_tag="h5" text_align="inline" display_heading_subtitle="no" heading_url="url:tel%3A18001234567|title:'. rawurlencode( esc_html( __( 'Call us', 'ueldo' ) ) ) .'||" custom_margins_enabled="custom_margins" custom_margin_bottom="0"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_27402212386304" heading_text="'. esc_html( __( 'Call us: 1-800-123-4567', 'ueldo' ) ) .'" font_family="menu-font" custom_font_color_enabled="custom_settings" font_color="#482823"][/ueldo_shortcode_heading][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][vc_column_text]Vestibulum elementum scelerisque facilisis. Ut dui erat, tristique interdum diam sit amet, luctus feugiat nulla. Praesent laoreet, arcu vel bibendum scelerisque, dui dui mollis tellus, sit amet congue nunc nibh nec neque. Orci varius natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Nam in egestas massa. Suspendisse id nulla sed arcu iaculis cursus in vitae nisl. Nunc tellus lorem, commodo sit amet.<br /><br /> Commodo sit amet, dignissim quis dolor. Nullam blandit, sem non tempus ultrices, diam eros feugiat leo, a suscipit nisi erat nec nulla. Aenean non gravida risus. Cras molestie augue a sagittis lacinia. Pellentesque lacinia commodo placerat. Ut malesuada placerat elit quis placerat. Orci varius natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Nullam eu libero nisl. Sed suscipit lorem a tellus pretium, vel condimentum tortor fermentum.<br /><br /> Integer nec sapien in leo aliquam tincidunt. Morbi vitae auctor urna. Vivamus vel massa magna. Nunc lobortis tristique elementum. In condimentum porttitor urna id consequat. Aliquam erat volutpat. Mauris interdum porttitor massa, eget egestas dolor ultricies et. Curabitur scelerisque hendrerit condimentum. Duis eget venenatis tellus.[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_7530535343789" large_height="25"][/ueldo_shortcode_tabs_single_tab][/ueldo_shortcode_tabs][ueldo_shortcode_gap class_name="ueldo_vc_element_15059905521077"][/vc_column][/vc_row][/vc_section][vc_section el_class="ueldo-vc-row-overflow-visible"][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_71124064350161" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_27619060275791" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_gap class_name="ueldo_vc_element_63998223496224" large_height="26"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15118607904419" layer_for_row_or_section="section" layer_z_index="0" color="#f6f2e7"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_32467910961517" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-compass,flaticon-technology|url:https://www.flaticon.com/free-icon/compass_390848|slug:icon_} icon_size="200" icon_rotate="315deg" icon_alignment="left" icon_color="rgba(72,40,35,0.06)" large_width_type="px" large_width_px="300" large_height_type="px" large_height_px="300" large_layer_position="bottom_left" large_margin_bottom="-55" large_margin_left="-70"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_28823851110273" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-map,flaticon-location|url:https://www.flaticon.com/free-icon/map_390897|slug:icon_} icon_size="200" icon_rotate="45deg" icon_alignment="right" icon_color="rgba(72,40,35,0.06)" large_width_type="px" large_width_px="300" large_height_type="px" large_height_px="300" large_layer_position="top_right" large_margin_right="-70"][ueldo_shortcode_gap class_name="ueldo_vc_element_13454561836999"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15059847397071" text_align="center" heading_subtitle_text="'. esc_html( __( 'Spend unforgettable moments', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="30"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15059847864492" heading_text="'. esc_html( __( 'It\'s not just an adventure', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Aliquam volutpat dolor lectus, at malesuada quam suscipit at. Proin blandit tincidunt ligula, sed commodo nulla. Nunc id tempus diam, eu tincidunt quam. Duis sollicitudin, lacus eu faucibus imperdiet, mi urna pulvinar dolor, et mollis dui leo quis metus. Fusce tellus nibh, eleifend quis quam quis.</p>[/vc_column_text][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/6" offset="vc_col-lg-3 vc_col-md-3 vc_hidden-xs"][/vc_column][vc_column width="2/3" offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15059859919552"][ueldo_shortcode_card class_name="ueldo_vc_element_15059855045382" padding_bottom="25" custom_colors_enabled="custom_settings" box_shadow_vertical_length="10" box_shadow_blur_radius="35" box_shadow_color="rgba(228,222,204,0.25)" background_color="#f9f5eb" background_color_hover="#f9f5eb" border_color="#e4ddd0" border_color_hover="#e4ddd0"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15059859032045"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059859060656" large_width_percentage="100%" large_content_alignment="center"][ueldo_shortcode_form class_name="ueldo_vc_element_15059853021436" form_shortcode="`{`mc4wp_form {ueldopredefinedsections:mc4wp|context:kayaks|inside:true}`}`" custom_colors_enabled="custom_settings" form_field_border_color="#e4ddd0" form_field_border_color_focus="#aaaaaa" form_field_background_color="#f1ecde" form_field_placeholder_text_color="#888888" inside_field_icon_color="#dddddd" submit_button_text_color="#ffffff" submit_button_text_color_hover="#ffffff" submit_button_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][/vc_column][vc_column width="1/6" offset="vc_col-lg-3 vc_col-md-3 vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_59181369017229"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_91810130558089" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_50793952674334" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_gap class_name="ueldo_vc_element_32010733833638" large_height="26"][/vc_column][/vc_row][/vc_section]',

                '404-page' => '[vc_section][vc_row][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_77126362397974"][ueldo_shortcode_heading class_name="ueldo_vc_element_15058271731204" heading_tag="h1" text_align="center" heading_subtitle_text="'. esc_html( __( 'Nothing found here...', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="30"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_1505827187472" heading_text="'. esc_html( __( 'Oops... 404 page', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Nullam aliquam turpis quis nisi laoreet vehicula. Duis congue elementum est, id dictum tortor consectetur vitae. Mauris justo urna, euismod in blandit a, laoreet et magna. In ullamcorper imperdiet velit. Ut eu faucibus massa. Pellentesque habitant morbi tristique senectus et netus et malesuada.</p>[/vc_column_text][ueldo_shortcode_gap class_name="ueldo_vc_element_15058274162585" large_height="25"][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_71124064350161" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_27619060275791" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_gap class_name="ueldo_vc_element_63998223496224" large_height="26"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15118614249898" layer_for_row_or_section="section" layer_z_index="0" color="#f6f2e7"][ueldo_shortcode_gap class_name="ueldo_vc_element_15118614391363"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][ueldo_shortcode_info_box class_name="ueldo_vc_element_40012988677261" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'kayak-rental%2F|title:'. rawurlencode( esc_html( __( 'Kayak rental', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Kayak Rental', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h4" {ueldopredefinedsections:icon|key:flaticon-kayak,flaticon-transport|url:https://www.flaticon.com/free-icon/kayak_140476|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color_hover="#482823" info_element_border_color_hover="#482823" info_element_icon_color_hover="#efebe0" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][ueldo_shortcode_gap class_name="ueldo_vc_element_96521194125311" large_height="30"][vc_column_text]Nulla sit amet rutrum metus. In hac habitasse platea dictumst. Aenean aliquam, turpis eget congue.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][vc_column width="1/3"][ueldo_shortcode_info_box class_name="ueldo_vc_element_62346046707574" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'paddle-rental%2F|title:'. rawurlencode( esc_html( __( 'Paddle rental', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Paddle Rental', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h4" {ueldopredefinedsections:icon|key:flaticon-paddle,flaticon-beach|url:https://www.flaticon.com/free-icon/paddle_437151|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color_hover="#482823" info_element_border_color_hover="#482823" info_element_icon_color_hover="#efebe0" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][ueldo_shortcode_gap class_name="ueldo_vc_element_61734975934262" large_height="30"][vc_column_text]Suspendisse elementum bibendum leo, ac mollis ligula lobortis et. In lobortis dapibus ipsum, suspendisse.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][vc_column width="1/3"][ueldo_shortcode_info_box class_name="ueldo_vc_element_58458808113695" whole_box_link="yes" box_link_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'guided-tours%2F|title:'. rawurlencode( esc_html( __( 'Guided tours', 'ueldo' ) ) ) .'||" info_box_title="'. esc_html( __( 'Guided Tours', 'ueldo' ) ) .'" info_box_subtitle="" info_box_title_heading_type="h4" {ueldopredefinedsections:icon|key:flaticon-canoe,flaticon-transport|url:https://www.flaticon.com/free-icon/canoe_140767|slug:info_element_icon_} custom_colors_enabled="custom_settings" info_element_background_color_hover="#482823" info_element_border_color_hover="#482823" info_element_icon_color_hover="#efebe0" info_element_box_shadow_color="rgba(255,255,255,0.01)" info_element_box_shadow_color_hover="rgba(255,255,255,0.01)"][ueldo_shortcode_gap class_name="ueldo_vc_element_31593488797780" large_height="30"][vc_column_text]Vestibulum ac euismod orci. Nulla malesuada fringilla dignissim. Sed pulvinar finibus nunc, in auctor.[/vc_column_text][/ueldo_shortcode_info_box][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_91605544212416" large_height="90"][ueldo_shortcode_button class_name="ueldo_vc_element_15058277794065" button_text="'. esc_html( __( 'Go back to home page', 'ueldo' ) ) .'" button_text_alignment="center" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'|title:'. rawurlencode( esc_html( __( 'Home page', 'ueldo' ) ) ) .'||" button_alignment="center" hover_transform_enabled="yes"]'. esc_html( __( 'or', 'ueldo' ) ) .' <a href="/contact/">'. esc_html( __( 'contact us!', 'ueldo' ) ) .'</a>[/ueldo_shortcode_button][ueldo_shortcode_gap class_name="ueldo_vc_element_77036112910336"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_91810130558089" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_50793952674334" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_gap class_name="ueldo_vc_element_32010733833638" large_height="26"][/vc_column][/vc_row][/vc_section]',

                'footer' => '[vc_section][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_15058102170319"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2" offset="vc_col-lg-4 vc_col-md-4 vc_col-xs-12"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15058236805095"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15058236835171" large_width_type="calc" large_width_calc_px="30"][vc_column_text]<strong>'. esc_html( __( 'Green River Kayaks & Paddle rental', 'ueldo' ) ) .'</strong><br /><br /> '. esc_html( __( '54321 Example Street, Westchester Township, IN 46304 (near the Yellow Bay)', 'ueldo' ) ) .'[/vc_column_text][ueldo_shortcode_button class_name="ueldo_vc_element_15058114475494" button_text="'. esc_html( __( 'Contact us!', 'ueldo' ) ) .'" button_url="url:'. rawurlencode( ueldo_get_website_dir() ) .'contact%2F|title:'. rawurlencode( esc_html( __( 'Contact us', 'ueldo' ) ) ) .'||" show_button_icon="yes" button_icon_visibility="on_hover_only" hover_transform_enabled="yes"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_1506076524979" large_height="0" extra_small_custom_sizes="yes"][/vc_column][vc_column width="1/2" offset="vc_col-lg-3 vc_col-md-3 vc_col-xs-12"][vc_column_text]<strong>'. esc_html( __( 'E-mail us!', 'ueldo' ) ) .'</strong><br /> <a href="'. esc_url( __( 'mailto:contact@example.com', 'ueldo' ) ) .'">'. esc_html( __( 'contact@example.com', 'ueldo' ) ) .'</a><br /><br /> <strong>'. esc_html( __( 'Phone call:', 'ueldo' ) ) .'</strong><br /> <a href="tel:18001234567">1-800-123-4567</a>[/vc_column_text][ueldo_shortcode_social_media_feed class_name="ueldo_vc_element_15058113292881" type="facebook_like_button" facebook_like_button_layout="button_count" facebook_like_button_share="yes"][/ueldo_shortcode_social_media_feed][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][vc_column_text]<strong>'. esc_html( __( 'Other pages:', 'ueldo' ) ) .'</strong>[/vc_column_text][ueldo_shortcode_icon_list class_name="ueldo_vc_element_15870232397405" icon_fontawesome="fa fa-angle-right" list_elements_from="menu" {ueldopredefinedsections:menu|context:kayaks-pages-menu} margin_bottom="0"][/ueldo_shortcode_icon_list][/vc_column][vc_column width="1/4" offset="vc_hidden-sm vc_hidden-xs"][ueldo_shortcode_icon class_name="ueldo_vc_element_28608426738045" icon_alignment="center" {ueldopredefinedsections:icon|key:flaticon-kayak,flaticon-transport|url:https://www.flaticon.com/free-icon/kayak_140476|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_top="60" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#ece6db"][vc_column_text]<p style="text-align: center;">2017 - '. date( 'Y' ) .' &copy; <a href="'. esc_url( ueldo_get_external_url( 'ueldo-com' ) ) .'" target="_blank">'. esc_html( __( 'Ueldo WP theme', 'ueldo' ) ) .'</a></p>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_88877575986485" large_height="0" small_custom_sizes="yes"][/vc_column][/vc_row][vc_row content_placement="bottom" el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/2" offset="vc_hidden-lg vc_hidden-md vc_col-xs-12"][ueldo_shortcode_icon class_name="ueldo_vc_element_29164264978188" {ueldopredefinedsections:icon|key:flaticon-kayak,flaticon-transport|url:https://www.flaticon.com/free-icon/kayak_140476|slug:icon_} custom_sizes_enabled="custom_settings" icon_size="45" margin_bottom="30" custom_colors_enabled="custom_settings" icon_color="#ece6db"][vc_column_text]2017 - '. date( 'Y' ) .' &copy; <a href="'. esc_url( ueldo_get_external_url( 'ueldo-com' ) ) .'" target="_blank">'. esc_html( __( 'Ueldo WP theme', 'ueldo' ) ) .'</a>[/vc_column_text][/vc_column][vc_column width="1/2" offset="vc_hidden-lg vc_hidden-md vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15060765585936" large_height="0" extra_small_custom_sizes="yes"][vc_column_text]<strong>'. esc_html( __( 'Other pages:', 'ueldo' ) ) .'</strong>[/vc_column_text][ueldo_shortcode_icon_list class_name="ueldo_vc_element_50827147871310" icon_fontawesome="fa fa-angle-right" list_elements_from="menu" {ueldopredefinedsections:menu|context:kayaks-pages-menu} margin_bottom="0"][/ueldo_shortcode_icon_list][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_28146805196343"][/vc_column][/vc_row][/vc_section]',

                'header' => '[vc_section el_class="ueldo-vc-row-visible"][vc_row full_width="stretch_row_content_no_spaces" el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15060834832055" color="#ffffff"][vc_row full_width="stretch_row_content_no_spaces" el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_96752479202992" large_height="0" small_custom_sizes="yes" small_height="12"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_9570211914160"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_5936800098265" large_width_type="px" large_width_px="15"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_5274240506536" large_width_percentage="24%"][ueldo_shortcode_website_logo class_name="ueldo_vc_element_77133083305177" large_width_type="px" large_width_px="171" {ueldopredefinedsections:image|context:kayaks-logo}][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_49263318857361" large_width_type="calc" large_width_calc_base="52%" large_width_calc_px="30" large_content_alignment="center" small_custom_sizes="yes" small_width_percentage="0%"][ueldo_shortcode_header_menu class_name="ueldo_vc_element_83539645142143" menu_style="04" menu_links_alignment="center" custom_sizes_enabled="custom_settings"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_74124941866709" large_width_percentage="24%" large_content_alignment="right" small_custom_sizes="yes" small_width_type="calc" small_width_calc_base="76%" small_width_calc_px="30" small_content_alignment="right"][ueldo_shortcode_button class_name="ueldo_vc_element_15060741863631" button_visible_on_devices="small,extra-small" button_text="" action_after_click="show_hide_side_menu" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-bars" custom_sizes_enabled="custom_settings" additional_margin_after="15" standard_button_padding_top="17" standard_button_padding_bottom="17" standard_button_use_static_height="no" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="rgba(72,40,35,0.15)" standard_button_background_color_hover="#482823" standard_button_border_color="#482823" standard_button_border_color_hover="#482823" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_color_hover="rgba(72,40,35,0.25)" standard_button_text_color="#482823" standard_button_text_color_hover="#f6f2e7" standard_button_icon_color="#482823" standard_button_icon_color_hover="#f6f2e7"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_60779381523470" button_visible_on_devices="large,medium,small" button_text="'. esc_html( __( 'Call us: 1-800-123-4567', 'ueldo' ) ) .'" button_text_alignment="center" button_alignment="inline" custom_sizes_enabled="custom_settings" standard_button_padding_top="17" standard_button_padding_bottom="17" standard_button_use_static_height="no" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="rgba(72,40,35,0.15)" standard_button_background_color_hover="#482823" standard_button_border_color="#482823" standard_button_border_color_hover="#482823" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_color_hover="rgba(72,40,35,0.25)" standard_button_text_color="#482823" standard_button_text_color_hover="#f6f2e7" standard_button_icon_color="#482823" standard_button_icon_color_hover="#f6f2e7"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_20427449932126" button_visible_on_devices="extra-small" button_text="" button_text_alignment="center" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-phone" custom_sizes_enabled="custom_settings" standard_button_padding_top="17" standard_button_padding_bottom="17" standard_button_use_static_height="no" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="rgba(72,40,35,0.15)" standard_button_background_color_hover="#482823" standard_button_border_color="#482823" standard_button_border_color_hover="#482823" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_color_hover="rgba(72,40,35,0.25)" standard_button_text_color="#482823" standard_button_text_color_hover="#f6f2e7" standard_button_icon_color="#482823" standard_button_icon_color_hover="#f6f2e7"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_21461987674456" large_height="0" small_custom_sizes="yes" small_height="12"][ueldo_shortcode_delimiter class_name="ueldo_vc_element_26179866006527" large_height="1" margin_bottom="0" custom_colors_enabled="custom_settings" background_color="rgba(72,40,35,0.05)"][/vc_column][/vc_row][/vc_section]',

                'services-header' => '[vc_section el_class="ueldo-vc-row-visible"][vc_row full_width="stretch_row_content_no_spaces" el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_96752479202992" large_height="0" small_custom_sizes="yes" small_height="12"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_9570211914160"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_5936800098265" large_width_type="px" large_width_px="15"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_5274240506536" large_width_percentage="24%"][ueldo_shortcode_website_logo class_name="ueldo_vc_element_77133083305177" large_width_type="px" large_width_px="171" {ueldopredefinedsections:image|context:kayaks-logo}][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_49263318857361" large_width_type="calc" large_width_calc_base="52%" large_width_calc_px="30" large_content_alignment="center" small_custom_sizes="yes" small_width_percentage="0%"][ueldo_shortcode_header_menu class_name="ueldo_vc_element_83539645142143" menu_style="04" menu_links_alignment="center" custom_sizes_enabled="custom_settings"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_74124941866709" large_width_percentage="24%" large_content_alignment="right" small_custom_sizes="yes" small_width_type="calc" small_width_calc_base="76%" small_width_calc_px="30" small_content_alignment="right"][ueldo_shortcode_button class_name="ueldo_vc_element_15060741863631" button_visible_on_devices="small,extra-small" button_text="" action_after_click="show_hide_side_menu" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-bars" custom_sizes_enabled="custom_settings" additional_margin_after="15" standard_button_padding_top="17" standard_button_padding_bottom="17" standard_button_use_static_height="no" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="rgba(72,40,35,0.15)" standard_button_background_color_hover="#482823" standard_button_border_color="#482823" standard_button_border_color_hover="#482823" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_color_hover="rgba(72,40,35,0.25)" standard_button_text_color="#482823" standard_button_text_color_hover="#f6f2e7" standard_button_icon_color="#482823" standard_button_icon_color_hover="#f6f2e7"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_60779381523470" button_visible_on_devices="large,medium,small" button_text="'. esc_html( __( 'Call us: 1-800-123-4567', 'ueldo' ) ) .'" button_text_alignment="center" button_alignment="inline" custom_sizes_enabled="custom_settings" standard_button_padding_top="17" standard_button_padding_bottom="17" standard_button_use_static_height="no" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="rgba(72,40,35,0.15)" standard_button_background_color_hover="#482823" standard_button_border_color="#482823" standard_button_border_color_hover="#482823" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_color_hover="rgba(72,40,35,0.25)" standard_button_text_color="#482823" standard_button_text_color_hover="#f6f2e7" standard_button_icon_color="#482823" standard_button_icon_color_hover="#f6f2e7"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_20427449932126" button_visible_on_devices="extra-small" button_text="" button_text_alignment="center" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-phone" custom_sizes_enabled="custom_settings" standard_button_padding_top="17" standard_button_padding_bottom="17" standard_button_use_static_height="no" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="rgba(72,40,35,0.15)" standard_button_background_color_hover="#482823" standard_button_border_color="#482823" standard_button_border_color_hover="#482823" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_color_hover="rgba(72,40,35,0.25)" standard_button_text_color="#482823" standard_button_text_color_hover="#f6f2e7" standard_button_icon_color="#482823" standard_button_icon_color_hover="#f6f2e7"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_21461987674456" large_height="0" small_custom_sizes="yes" small_height="12"][ueldo_shortcode_delimiter class_name="ueldo_vc_element_26179866006527" large_height="1" margin_bottom="0" custom_colors_enabled="custom_settings" background_color="rgba(72,40,35,0.05)"][/vc_column][/vc_row][/vc_section]',

                'home-page-header' => '[vc_section el_class="ueldo-vc-row-visible"][vc_row full_width="stretch_row_content_no_spaces" el_class="ueldo-vc-row-overflow-visible"][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_96752479202992" large_height="0" small_custom_sizes="yes" small_height="12"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_9570211914160"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_5936800098265" large_width_type="px" large_width_px="15"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_5274240506536" large_width_percentage="24%"][ueldo_shortcode_website_logo class_name="ueldo_vc_element_77133083305177" large_width_type="px" large_width_px="171" {ueldopredefinedsections:image|context:kayaks-logo}][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_49263318857361" large_width_type="calc" large_width_calc_base="52%" large_width_calc_px="30" large_content_alignment="center" small_custom_sizes="yes" small_width_percentage="0%"][ueldo_shortcode_header_menu class_name="ueldo_vc_element_83539645142143" menu_style="04" menu_links_alignment="center" custom_sizes_enabled="custom_settings"][/ueldo_shortcode_inline_container_element][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_74124941866709" large_width_percentage="24%" large_content_alignment="right" small_custom_sizes="yes" small_width_type="calc" small_width_calc_base="76%" small_width_calc_px="30" small_content_alignment="right"][ueldo_shortcode_button class_name="ueldo_vc_element_15060741863631" button_visible_on_devices="small,extra-small" button_text="" action_after_click="show_hide_side_menu" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-bars" custom_sizes_enabled="custom_settings" additional_margin_after="15" standard_button_padding_top="17" standard_button_padding_bottom="17" standard_button_use_static_height="no" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="rgba(72,40,35,0.15)" standard_button_background_color_hover="#482823" standard_button_border_color="#482823" standard_button_border_color_hover="#482823" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_color_hover="rgba(72,40,35,0.25)" standard_button_text_color="#f6f2e7" standard_button_text_color_hover="#f6f2e7" standard_button_icon_color="#f6f2e7" standard_button_icon_color_hover="#f6f2e7"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_60779381523470" button_visible_on_devices="large,medium,small" button_text="'. esc_html( __( 'Call us: 1-800-123-4567', 'ueldo' ) ) .'" button_text_alignment="center" button_alignment="inline" custom_sizes_enabled="custom_settings" standard_button_padding_top="17" standard_button_padding_bottom="17" standard_button_use_static_height="no" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="rgba(72,40,35,0.15)" standard_button_background_color_hover="#482823" standard_button_border_color="#482823" standard_button_border_color_hover="#482823" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_color_hover="rgba(72,40,35,0.25)" standard_button_text_color="#f6f2e7" standard_button_text_color_hover="#f6f2e7" standard_button_icon_color="#f6f2e7" standard_button_icon_color_hover="#f6f2e7"][/ueldo_shortcode_button][ueldo_shortcode_button class_name="ueldo_vc_element_20427449932126" button_visible_on_devices="extra-small" button_text="" button_text_alignment="center" button_alignment="inline" show_button_icon="yes" button_icon_fontawesome="fa fa-phone" custom_sizes_enabled="custom_settings" standard_button_padding_top="17" standard_button_padding_bottom="17" standard_button_use_static_height="no" standard_button_border_width="0" custom_colors_enabled="custom_settings" standard_button_background_color="rgba(72,40,35,0.15)" standard_button_background_color_hover="#482823" standard_button_border_color="#482823" standard_button_border_color_hover="#482823" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_color_hover="rgba(72,40,35,0.25)" standard_button_text_color="#f6f2e7" standard_button_text_color_hover="#f6f2e7" standard_button_icon_color="#f6f2e7" standard_button_icon_color_hover="#f6f2e7"][/ueldo_shortcode_button][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][ueldo_shortcode_gap class_name="ueldo_vc_element_21461987674456" large_height="0" small_custom_sizes="yes" small_height="12"][ueldo_shortcode_delimiter class_name="ueldo_vc_element_26179866006527" large_height="1" margin_bottom="0" custom_colors_enabled="custom_settings" background_color="rgba(72,40,35,0.05)"][/vc_column][/vc_row][/vc_section]',

                'under-blog-section' => '[vc_section el_class="ueldo-vc-row-overflow-visible"][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_171124064350161" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_127619060275791" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" {ueldopredefinedsections:image|context:kayaks-wave-color-demo-like}][ueldo_shortcode_gap class_name="ueldo_vc_element_163998223496224" large_height="26"][/vc_column][/vc_row][/vc_section][vc_section full_width="stretch_row"][vc_row][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_15118607904419" layer_for_row_or_section="section" layer_z_index="0" color="#f6f2e7"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_32467910961517" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-compass,flaticon-technology|url:https://www.flaticon.com/free-icon/compass_390848|slug:icon_} icon_size="200" icon_rotate="315deg" icon_alignment="left" icon_color="rgba(72,40,35,0.06)" large_width_type="px" large_width_px="300" large_height_type="px" large_height_px="300" large_layer_position="bottom_left" large_margin_bottom="-55" large_margin_left="-70"][ueldo_shortcode_row_layer class_name="ueldo_vc_element_28823851110273" layer_for_row_or_section="section" custom_layer_sizes="custom_settings" layer_type="icon" {ueldopredefinedsections:icon|key:flaticon-map,flaticon-location|url:https://www.flaticon.com/free-icon/map_390897|slug:icon_} icon_size="200" icon_rotate="45deg" icon_alignment="right" icon_color="rgba(72,40,35,0.06)" large_width_type="px" large_width_px="300" large_height_type="px" large_height_px="300" large_layer_position="top_right" large_margin_right="-70"][ueldo_shortcode_gap class_name="ueldo_vc_element_13454561836999"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][vc_column offset="vc_col-lg-8 vc_col-md-8 vc_col-xs-12"][ueldo_shortcode_heading class_name="ueldo_vc_element_15059847397071" text_align="center" heading_subtitle_text="'. esc_html( __( 'Spend unforgettable moments', 'ueldo' ) ) .'" heading_subtitle_custom_margin_enabled="custom_settings" heading_subtitle_margin="30"][ueldo_shortcode_heading_text class_name="ueldo_vc_element_15059847864492" heading_text="'. esc_html( __( 'It\'s not just an adventure', 'ueldo' ) ) .'"][/ueldo_shortcode_heading][vc_column_text]<p style="text-align: center;">Aliquam volutpat dolor lectus, at malesuada quam suscipit at. Proin blandit tincidunt ligula, sed commodo nulla. Nunc id tempus diam, eu tincidunt quam. Duis sollicitudin, lacus eu faucibus imperdiet, mi urna pulvinar dolor, et mollis dui leo quis metus. Fusce tellus nibh, eleifend quis quam quis.</p>[/vc_column_text][/vc_column][vc_column width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column][/vc_row][vc_row el_class="ueldo-vc-row-overflow-visible"][vc_column width="1/6" offset="vc_col-lg-3 vc_col-md-3 vc_hidden-xs"][/vc_column][vc_column width="2/3" offset="vc_col-lg-6 vc_col-md-6 vc_col-xs-12"][ueldo_shortcode_gap class_name="ueldo_vc_element_15059859919552"][ueldo_shortcode_card class_name="ueldo_vc_element_15059855045382" padding_bottom="25" custom_colors_enabled="custom_settings" box_shadow_vertical_length="10" box_shadow_blur_radius="35" box_shadow_color="rgba(228,222,204,0.25)" background_color="#f9f5eb" background_color_hover="#f9f5eb" border_color="#e4ddd0" border_color_hover="#e4ddd0"][ueldo_shortcode_inline_container class_name="ueldo_vc_element_15059859032045"][ueldo_shortcode_inline_container_element class_name="ueldo_vc_element_15059859060656" large_width_percentage="100%" large_content_alignment="center"][ueldo_shortcode_form class_name="ueldo_vc_element_15059853021436" form_shortcode="`{`mc4wp_form {ueldopredefinedsections:mc4wp|context:kayaks|inside:true}`}`" custom_colors_enabled="custom_settings" form_field_border_color="#e4ddd0" form_field_border_color_focus="#aaaaaa" form_field_background_color="#f1ecde" form_field_placeholder_text_color="#888888" inside_field_icon_color="#dddddd" submit_button_text_color="#ffffff" submit_button_text_color_hover="#ffffff" submit_button_box_shadow_color="rgba(255,255,255,0.01)"][/ueldo_shortcode_inline_container_element][/ueldo_shortcode_inline_container][/ueldo_shortcode_card][/vc_column][vc_column width="1/6" offset="vc_col-lg-3 vc_col-md-3 vc_hidden-xs"][/vc_column][/vc_row][vc_row][vc_column][ueldo_shortcode_gap class_name="ueldo_vc_element_59181369017229"][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column][ueldo_shortcode_row_layer class_name="ueldo_vc_element_191810130558089" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_row_layer class_name="ueldo_vc_element_150793952674334" layer_opacity="45%" layer_z_index="15" custom_layer_sizes="custom_settings" layer_type="image" image_size="auto" image_repeat="repeat-x" large_width_type="calc" large_width_calc_operator="+" large_width_calc_px="200" large_height_type="px" large_height_px="26" large_layer_position="bottom_left" {ueldopredefinedsections:image|context:kayaks-wave-white}][ueldo_shortcode_gap class_name="ueldo_vc_element_132010733833638" large_height="26"][/vc_column][/vc_row][/vc_section]',

                'additional-before-side-menu' => '[vc_section][vc_row][vc_column][ueldo_shortcode_button class_name="ueldo_vc_element_15063198190026" button_text="'. esc_html( __( 'Close menu', 'ueldo' ) ) .'" button_text_alignment="center" action_after_click="show_hide_side_menu" button_alignment="center" show_button_icon="yes" button_icon_fontawesome="fa fa-times" custom_sizes_enabled="custom_settings" standard_button_use_static_height="no" custom_colors_enabled="custom_settings" standard_button_background_color="#f6f2e7" standard_button_background_color_hover="#e8e4da" standard_button_border_color="#f6f2e7" standard_button_border_color_hover="#e8e4da" standard_button_box_shadow_color="rgba(255,255,255,0.01)" standard_button_box_shadow_color_hover="rgba(232,228,218,0.25)" standard_button_text_color="#482823" standard_button_text_color_hover="#482823" standard_button_icon_color="rgba(72,40,35,0.1)" standard_button_icon_color_hover="rgba(72,40,35,0.1)"][/ueldo_shortcode_button][/vc_column][/vc_row][/vc_section]',

                'additional-after-side-menu' => ''
            );

            # return result
            return( $page_slug == false ? $contents : ( isset( $contents[esc_attr( $page_slug )] ) ? $contents[esc_attr( $page_slug )] : false ) );
        }

       /**
        *
        * end of class methods.
        *
        */
    }

   /**
    *
    * end of file.
    *
    */

?>