jQuery( document ).ready( function( $ ) {

   /**
    *
    * strict mode
    *
    */

    'use strict';

   /**
    *
    * global variables
    *
    */

    var ueldoPageWidth = 0;
    var ueldoIsFirstPageLoad = true;
    var ueldoNextIsotopeID = 1;
    var ueldoGoogleMapsCount = 0;
    var ueldoGoogleMaps = [];
    var ueldoIsotopes = [];
    var ueldoIntervals = [];

   /**
    *
    * mutation observer
    *
    */

    var ueldoMutationObserver = window.MutationObserver || window.WebKitMutationObserver || window.MozMutationObserver;
    var ueldoMutationObserverObject = new ueldoMutationObserver( function( mutations ) {

        mutations.forEach( function( mutation ) {

           /**
            *
            * hide container for hidden select field
            *
            */

            if( $( mutation.target ).is( 'span.ueldo-select-field' ) ) {

                var target = $( mutation.target );
                var select = target.children( 'select' );

                if( !select.is( ':visible' ) ) target.addClass( 'ueldo-select-field-hidden' );
                else target.removeClass( 'ueldo-select-field-hidden' );
            }

           /**
            *
            * end of observations
            *
            */

        });

    });

    ueldoMutationObserverObject.observe( document, { attributes: true, childList: true, subtree: true, characterData: true });

   /**
    *
    * fire background images configuration
    *
    */

    $.UeldoDoTheBackgroundImagesConfiguration = function( image, isLazyLoad ) {

        var imageLoader = image.siblings( '.ueldo-image-parent-loading' );

        if( isLazyLoad == true ) { $.UeldoConfigureBackgroundImages( image, imageLoader ); }
        else {

            image.one( 'load', function() {

                $.UeldoConfigureBackgroundImages( image, imageLoader );

            }).each( function() {

                if( this.complete ) $( this ).load();

            });
        }
    };

   /**
    *
    * configure background images
    *
    */

    $.UeldoConfigureBackgroundImages = function( image, imageLoader ) {

        var imageSrc = image.attr( 'src' );
        var imagePositionY = image.data( 'image-position-y' );
        var imagePositionX = image.data( 'image-position-x' );

        var class_names = image.attr( 'class' ).split( ' ' );
        $.each( class_names, function( id, class_name ) { if( class_name != 'ueldo-image-data-for-parent' ) image.parent().addClass( class_name ); });

        imagePositionY = typeof imagePositionY != 'undefined' && imagePositionY != '' && imagePositionY !== false && imagePositionY !== null ? imagePositionY : '50%';
        imagePositionX = typeof imagePositionX != 'undefined' && imagePositionX != '' && imagePositionX !== false && imagePositionX !== null ? imagePositionX : '50%';

        image.parent().css({ 'background-image': 'url('+ imageSrc +')' });
        image.parent().css({ 'background-position-y': imagePositionY, 'background-position-x': imagePositionX });

        if( ueldo_javascript_functions_l10n.retina_images_replacement_enabled == 'yes' ) {

            image.parent().data( 'rjs', '2' ).attr( 'data-rjs', '2' );
            retinajs( image.parent(), false );

            if( image.parent().hasClass( 'ueldo-image-repeat-repeat' ) || image.parent().hasClass( 'ueldo-image-repeat-repeat-x' ) || image.parent().hasClass( 'ueldo-image-repeat-repeat-y' ) || image.parent().hasClass( 'ueldo-widget-call-to-action' ) ) {

                image.parent().css({ 'background-size': image[0].naturalWidth +'px '+ image[0].naturalHeight +'px' });
            }
        }

        image.remove();
        setTimeout( function() {

            imageLoader.fadeOut( 300 );
            setTimeout( function() {

                imageLoader.remove();

            }, 350 );

        }, 100 );
    };

   /**
    *
    * lazy load images
    *
    */

    $( 'img.ueldo-image-data-for-parent' ).each( function() {

        var image = $( this );

        if( ueldo_javascript_functions_l10n.lazy_load_images_enabled == 'no' ) $.UeldoDoTheBackgroundImagesConfiguration( image, false );
        else {

            image.unveil( ueldo_javascript_functions_l10n.lazy_load_images_threshold, function() {

                $.UeldoDoTheBackgroundImagesConfiguration( image, true );

            });
        }

    });

   /**
    *
    * functions after window load
    *
    */

    $( window ).load( function() {

       /**
        *
        * page width
        *
        */

        ueldoPageWidth = $( 'body' ).width();

       /**
        *
        * reconfigure vc full-width rows
        *
        */

        $.UeldoReConfigureVCFullWidthRows();

       /**
        *
        * reconfigure vc sections with negative margin top (firefox issue fix)
        *
        */

        $.UeldoReConfigureVCSectionsAndRowsNegativeMarginTop();

       /**
        *
        * configure additional sidebar background sizes
        *
        */

        $.UeldoConfigureAdditionalSidebarBackgroundSizes();

       /**
        *
        * configure blog image width and position
        *
        */

        $.UeldoConfigureImagesSliderToBorder();

       /**
        *
        * reconfigure side menu visibility
        *
        */

        $.UeldoReConfigureSideMenuVisibility();

       /**
        *
        * configure selects
        *
        */

        $.UeldoConfigureSelects();

       /**
        *
        * configure checkbox fields
        *
        */

        $.UeldoConfigureCheckbox();

       /**
        *
        * configure radio elements
        *
        */

        $.UeldoConfigureRadioElements();

       /**
        *
        * configure date fields
        *
        */

        $.UeldoConfigureDateFields();

       /**
        *
        * configure inline fields sizes
        *
        */

        $.UeldoConfigureInlineFieldsSizes( false );

       /**
        *
        * configure range fields
        *
        */

        $.UeldoConfigureRangeFields();

       /**
        *
        * configure masonry posts list
        *
        */

        $.UeldoConfigureMasonryPostsList( true );

       /**
        *
        * configure masonry loop
        *
        */

        $.UeldoConfigureMasonryLoop();

       /**
        *
        * configure masonry selector
        *
        */

        $.UeldoConfigureMasonrySelector();

       /**
        *
        * remove "under content elements" container if empty
        *
        */

        $.UeldoRemoveUnderContentElementsContainerIfEmpty();

       /**
        *
        * configure images gallery - magnific popup
        *
        */

        $.UeldoConfigureImagesGalleries();

       /**
        *
        * configure google maps
        *
        */

        $.UeldoConfigureGoogleMaps();

       /**
        *
        * configure woocommerce tabs box clear line
        *
        */

        $.UeldoConfigureWooCommerceTabsBoxClearLine();

       /**
        *
        * configure tabs box
        *
        */

        $.UeldoConfigureTabsBox();

       /**
        *
        * configure "ueldo-shortcode-tabs" shortcode
        *
        */

        $.UeldoConfigureShortcodeTabs();

       /**
        *
        * configure numbers counter
        *
        */

        $.UeldoConfigureNumbersCounter();

       /**
        *
        * wrap card content to relative container
        *
        */

        $.UeldoWrapCardContent();

       /**
        *
        * configure full-width testimonials
        *
        */

        $.UeldoConfigureFullWidthTestimonials( false );

       /**
        *
        * configure loops
        *
        */

        $.UeldoConfigureLoops( false );

       /**
        *
        * configure presentations
        *
        */

        $.UeldoConfigurePresentations();

       /**
        *
        * configure timelines
        *
        */

        $.UeldoConfigureTimelines( false, false );

       /**
        *
        * add "data-animation-enabled" attribute for separated next/prev icons
        *
        */

        $.UeldoSetAnimationEnabledAttributeForSeparatedNextPrevIcons();

       /**
        *
        * configure tabs selector
        *
        */

        $.UeldoConfigureTabsSelector();

       /**
        *
        * all tabs selectors with the same height
        *
        */

        $.UeldoAllTabsSelectorsWithTheSameHeight();

       /**
        *
        * all filtered masonry selectors with the same height
        *
        */

        $.UeldoAllFilteredMasonrySelectorsWithTheSameHeight();

       /**
        *
        * configure rounded progress-bars
        *
        */

        $.UeldoConfigureProgressBarsRounded();

       /**
        *
        * flying sidebar on visual composer page
        *
        */

        $.UeldoFlyingSidebarOnVCPage();

       /**
        *
        * content and sidebar divider line
        *
        */

        $.UeldoContentAndSidebarDividerLine();

       /**
        *
        * configure accordion box
        *
        */

        $.UeldoConfigureAccordionBox();

       /**
        *
        * configure progress bars
        *
        */

        $.UeldoConfigureProgressBars();

       /**
        *
        * configure video layer sizes and positions
        *
        */

        $( '.vc_row' ).each( function() {

            var element = $( this );
            $.UeldoConfigureVideoLayerSizesAndPositions( element, true );

        });

       /**
        *
        * row layers
        *
        */

        $.UeldoMoveRowLayersToPosition();

       /**
        *
        * initialize parallax layer
        *
        */

        ueldoParallaxLayer.init( '.ueldo-shortcode-row-layer-parallax' );

       /**
        *
        * two-images difference
        *
        */

        $( '.ueldo-shortcode-two-images-difference' ).ueldoTwoImagesDifference();

       /**
        *
        * is datepicker field style set to theme defaults?
        *
        */

        $.UeldoConfigureDatepickerFieldStyle();

       /**
        *
        * configure opening hours status
        *
        */

        $.UeldoConfigureOpeningHoursStatus();

       /**
        *
        * configure custom footer with fixed position
        *
        */

        $.UeldoConfigureCustomFooterFixedPosition();

       /**
        *
        * update class name of column which container custom menu
        *
        */

        $.UeldoUpdateCustomMenuParentColumnClassName();

       /**
        *
        * update padding-top for website wrapper, depends on header height
        *
        */

        $.UeldoUpdateWebsiteWrapperPaddingTop();

       /**
        *
        * remove empty blog post data elements
        *
        */

        $.UeldoRemoveEmptyBlogPostDataElements();

       /**
        *
        * configure second header bar visibility
        *
        */

        $.UeldoConfigureSecondHeaderBarVisibility();

       /**
        *
        * configure header bar position in relation to wp admin bar on mobile devices
        *
        */

        $.UeldoConfigureHeaderBarPositionInRelationToAdminBar();

       /**
        *
        * configure side menu position in relation to wp admin bar on mobile devices
        *
        */

        $.UeldoConfigureSideMenuPositionInRelationToAdminBar();

       /**
        *
        * scroll to selected section (if possible)
        *
        */

        $.UeldoScrollToSectionIfPossible();

       /**
        *
        * configure sub-menus for side menu
        *
        */

        $.UeldoConfigureSideMenuSubmenus();

       /**
        *
        * configure side menu vertical alignments
        *
        */

        $.UeldoConfigureSideMenuVerticalAlignments( false, false );

       /**
        *
        * retina-ready images for revolution slider
        *
        */

        $.UeldoRevolutionSliderConfigureRetinaReadyImages();

       /**
        *
        * configure website background for retina screens
        *
        */

        $.UeldoConfigureWebsiteBackgroundForRetina();

       /**
        *
        * hide loader after all configuration is finished
        *
        */

        $.UeldoHideWebsiteLoader();

       /**
        *
        * end of functions.
        *
        */

    });

   /**
    *
    * resize functions
    *
    */

    $.UeldoResizeFunction = function() {

       /**
        *
        * page width
        *
        */

        var ueldoNewPageWidth = $( 'body' ).width();
        if( ueldoNewPageWidth != ueldoPageWidth ) {

           /**
            *
            * update current page width
            *
            */

            ueldoPageWidth = ueldoNewPageWidth;

           /**
            *
            * reconfigure vc full-width rows
            *
            */

            $.UeldoReConfigureVCFullWidthRows();

           /**
            *
            * configure additional sidebar background sizes
            *
            */

            $.UeldoConfigureAdditionalSidebarBackgroundSizes();

           /**
            *
            * reconfigure blog image width and position
            *
            */

            $.UeldoConfigureImagesSliderToBorder();

           /**
            *
            * reconfigure side menu visibility
            *
            */

            $.UeldoReConfigureSideMenuVisibility();

           /**
            *
            * reconfigure inline fields sizes
            *
            */

            $.UeldoConfigureInlineFieldsSizes( false );

           /**
            *
            * reconfigure masonry posts list
            *
            */

            $.UeldoConfigureMasonryPostsList( true );

           /**
            *
            * configure masonry loop
            *
            */

            $.UeldoConfigureMasonryLoop();

           /**
            *
            * configure masonry selector
            *
            */

            $.UeldoConfigureMasonrySelector();

           /**
            *
            * reconfigure "ueldo-shortcode-tabs" shortcode
            *
            */

            $.UeldoReConfigureShortcodeTabs();

           /**
            *
            * configure numbers counter
            *
            */

            $.UeldoConfigureNumbersCounter();

           /**
            *
            * configure tabs selector
            *
            */

            $.UeldoConfigureTabsSelector();

           /**
            *
            * all tabs selectors with the same height
            *
            */

            $.UeldoAllTabsSelectorsWithTheSameHeight();

           /**
            *
            * all filtered masonry selectors with the same height
            *
            */

            $.UeldoAllFilteredMasonrySelectorsWithTheSameHeight();

           /**
            *
            * configure rounded progress-bars
            *
            */

            $.UeldoConfigureProgressBarsRounded();

           /**
            *
            * flying sidebar on visual composer page
            *
            */

            $.UeldoFlyingSidebarOnVCPage();

           /**
            *
            * content and sidebar divider line
            *
            */

            $.UeldoContentAndSidebarDividerLine();

           /**
            *
            * configure progress bars
            *
            */

            $.UeldoConfigureProgressBars();

           /**
            *
            * configure full-width testimonials
            *
            */

            $.UeldoConfigureFullWidthTestimonials( false );

            $( '.ueldo-shortcode-full-width-testimonials-clients-logos' ).each( function() { $.UeldoChangeFullWidthTestimonialsTestimonial( $( this ).find( '.ueldo-shortcode-full-width-testimonials-clients-logos-single-client[data-active="yes"]' ), true ); });
            $( '.ueldo-shortcode-full-width-testimonials-clients-images' ).each( function() { $.UeldoChangeFullWidthTestimonialsTestimonial( $( this ).find( '.ueldo-shortcode-full-width-testimonials-clients-images-single-client[data-active="yes"]' ), true ); });

           /**
            *
            * configure loops
            *
            */

            $.UeldoConfigureLoops( true );

           /**
            *
            * configure presentations
            *
            */

            $.UeldoConfigurePresentations();

           /**
            *
            * configure timelines
            *
            */

            $.UeldoConfigureTimelines( false, false );

           /**
            *
            * re-configure "clear line" for tabs box
            *
            */

            $.UeldoReConfigureTabsBoxClearLine();

           /**
            *
            * configure video layer sizes and positions
            *
            */

            $( '.ueldo-shortcode-card, .vc_row' ).each( function() {

                var element = $( this );
                $.UeldoConfigureVideoLayerSizesAndPositions( element, element.hasClass( 'vc_row' ) );

            });

           /**
            *
            * full-width point of interest modal
            *
            */

            $( '.ueldo-shortcode-presentation-point-of-interest.ueldo-shortcode-presentation-point-of-interest-is-open' ).each( function() {

                var element = $( this );
                $.UeldoFullWidthPointOfInterestModal( element );

            });

           /**
            *
            * configure custom footer with fixed position
            *
            */

            $.UeldoConfigureCustomFooterFixedPosition();

           /**
            *
            * update padding-top for website wrapper, depends on header height
            *
            */

            $.UeldoUpdateWebsiteWrapperPaddingTop();

           /**
            *
            * configure second header bar visibility
            *
            */

            $.UeldoConfigureSecondHeaderBarVisibility();

           /**
            *
            * configure header bar position in relation to wp admin bar on mobile devices
            *
            */

            $.UeldoConfigureHeaderBarPositionInRelationToAdminBar();

           /**
            *
            * configure side menu position in relation to wp admin bar on mobile devices
            *
            */

            $.UeldoConfigureSideMenuPositionInRelationToAdminBar();

           /**
            *
            * hide responsive flying sidebar on bigger devices
            *
            */

            $.UeldoHideResponsiveFlyingSidebar( true );

           /**
            *
            * reconfigure side menu vertical alignments
            *
            */

            $.UeldoConfigureSideMenuVerticalAlignments( false, false );

           /**
            *
            * end of functions
            *
            */
        }

       /**
        *
        * clear variables
        *
        */

        ueldoNewPageWidth = false;

       /**
        *
        * trigger height change
        *
        */

        $( window ).trigger( 'ueldo-height-changed' );

       /**
        *
        * end of functions
        *
        */
    }

   /**
    *
    * catch resize actions
    *
    */

    $( window ).resize( function() { $.UeldoResizeFunction(); });
    $( window ).on( 'orientationchange', function() { $.UeldoResizeFunction(); });

   /**
    *
    * on scroll functions
    *
    */

    $( window ).scroll( function() {

       /**
        *
        * configure numbers counter
        *
        */

        $.UeldoConfigureNumbersCounter();

       /**
        *
        * configure rounded progress-bars
        *
        */

        $.UeldoConfigureProgressBarsRounded();

       /**
        *
        * configure progress bars
        *
        */

        $.UeldoConfigureProgressBars();

       /**
        *
        * configure second header bar visibility
        *
        */

        $.UeldoConfigureSecondHeaderBarVisibility();

       /**
        *
        * configure header bar position in relation to wp admin bar on mobile devices
        *
        */

        $.UeldoConfigureHeaderBarPositionInRelationToAdminBar();

       /**
        *
        * configure side menu position in relation to wp admin bar on mobile devices
        *
        */

        $.UeldoConfigureSideMenuPositionInRelationToAdminBar();

       /**
        *
        * fire all animations when the page end is reached
        *
        */

        $.UeldoFireAllAnimationsOnPageEnd();

       /**
        *
        * end of functions.
        *
        */

    });

   /**
    *
    * get device type, depends on screen and content sizes
    *
    */

    $.UeldoGetDeviceType = function() {

        if( ueldoPageWidth <= 767 ) return( 'mobile' );
        else {

            var contentWidth = parseInt( $( '.ueldo-content-container' ).css( 'width' ), 10 );

            if( contentWidth == parseInt( ueldo_javascript_functions_l10n.website_sizes_small_content_width, 10 ) ) return( 'tablet-vertical' );
            else return( contentWidth == parseInt( ueldo_javascript_functions_l10n.website_sizes_medium_content_width, 10 ) ? 'tablet-horizontal' : 'desktop' );
        }
    };

   /**
    *
    * configure selects
    *
    */

    $.UeldoConfigureSelects = function() {

        $( 'select:not(#billing_country):not(#billing_state)' ).each( function() {

            var element = $( this );
            var multiple = typeof element.attr( 'multiple' ) == 'undefined' ? false : ( element.attr( 'multiple' ) == 'multiple' );

            element.wrap( '<span class="ueldo-select-field'+ ( multiple == true ? ' ueldo-is-multiple-select' : '' ) +'"></span>' );

            if( element.hasClass( 'gfield_select' ) ) {

                var selectContainer = element.parent();
                selectContainer.addClass( element.attr( 'class' ) ).removeClass( 'gfield_select' );
            }

        });

    };

   /**
    *
    * configure checkbox fields
    *
    */

    $.UeldoConfigureCheckbox = function() {

        $( 'input[type="checkbox"]' ).each( function() {

            var checkbox = $( this );
            var checked = checkbox.is( ':checked' );

            checkbox.after( '<div class="ueldo-checkbox-box"><span class="ueldo-checkbox">'+ ( checked ? '<i class="fa fa-check"></i>' : '' ) +'</span></div>' );

        });

    };

   /**
    *
    * checkbox field change
    *
    */

    $( 'body' ).on( 'click touchstart', '.ueldo-checkbox-box', function( event ) {

        event.preventDefault();

        var checkboxBox = $( this );
        $.UeldoChangeCheckbox( checkboxBox );

    });

   /**
    *
    * action after click on checkbox label
    *
    */

    $( 'body' ).on( 'click touchstart', 'form label, .nf-form-wrap label, .gfield_checkbox label, .gfield_checkbox label .ginput_price', function( event ) {

        if( $( event.target ).is( 'a' ) ) return;
        else if( !$( event.target ).is( '.ueldo-checkbox-box' ) && !$( event.target ).is( 'span.ueldo-checkbox' ) && !$( event.target ).is( 'i.fa.fa-check' ) && !$( event.target ).is( 'span.ueldo-radio' ) && !$( event.target ).is( 'span.ueldo-radio-checked' ) ) {

            var label = $( this );
            var checkboxBox = label.find( '.ueldo-checkbox-box' );
            var radioBox = label.find( '.ueldo-radio-box' );

            if( checkboxBox.length == 1 ) {

                event.preventDefault();
                $.UeldoChangeCheckbox( checkboxBox );
            }

            else if( radioBox.length == 1 ) {

                event.preventDefault();
                $.UeldoChangeRadioElement( radioBox );
            }

            else if( label.hasClass( 'ginput_price' ) ) {

                event.preventDefault();
                $.UeldoChangeCheckbox( label.parents( 'label' ).siblings( '.ueldo-checkbox-box' ) );
            }

            else {

                if( $( event.target ).siblings( '.ueldo-checkbox-box' ).length === 1 ) {

                    event.preventDefault();
                    $.UeldoChangeCheckbox( $( event.target ).siblings( '.ueldo-checkbox-box' ) );
                }

                else if( $( event.target ).siblings( '.ueldo-radio-box' ).length === 1 ) {

                    event.preventDefault();
                    $.UeldoChangeRadioElement( $( event.target ).siblings( '.ueldo-radio-box' ) );
                }

                else {

                    var labelParent = label.parent().hasClass( 'nf-field-label' ) ? label.parent() : false;
                    if( labelParent != false ) {

                        var fieldElement = labelParent.siblings( '.nf-field-element' ).length === 1 ? labelParent.siblings( '.nf-field-element' ) : false;
                        if( fieldElement != false ) {

                            if( fieldElement.find( '.ueldo-checkbox-box' ).length === 1 ) {

                                event.preventDefault();
                                $.UeldoChangeCheckbox( fieldElement.find( '.ueldo-checkbox-box' ) );
                            }

                            else if( fieldElement.find( '.ueldo-radio-box' ).length === 1 ) {

                                event.preventDefault();
                                $.UeldoChangeRadioElement( fieldElement.find( '.ueldo-radio-box' ) );
                            }
                        }
                    }
                }
            }
        }

    });

   /**
    *
    * change checkbox value function
    *
    */

    $.UeldoChangeCheckbox = function( checkboxBox ) {

        var checkboxInput = checkboxBox.siblings( 'input[type="checkbox"]' );
        if( checkboxBox.parents( '.nf-field-element, .gfield_checkbox' ).length === 1 ) {

            checkboxInput.trigger( 'click' );

            if( checkboxInput.attr( 'checked' ) == 'checked' ) checkboxBox.children( '.ueldo-checkbox' ).html( '<i class="fa fa-check"></i>' );
            else checkboxBox.children( '.ueldo-checkbox' ).html( '' );
        }

        else {

            var checkboxInputName = checkboxInput.attr( 'name' );
            var isCheckboxMultiple = checkboxInputName.indexOf( '[]' ) == -1 ? false : true;

            if( checkboxInput.attr( 'checked' ) == 'checked' ) {

                checkboxInput.removeAttr( 'checked' ).attr( 'value', '0' ).val( '0' );
                checkboxBox.children( '.ueldo-checkbox' ).html( '' );
            }

            else {

                if( !isCheckboxMultiple ) $.UeldoUncheckAllCheckboxes( checkboxInputName, true );

                checkboxInput.attr( 'checked', 'checked' ).attr( 'value', '1' ).val( '1' );
                checkboxBox.children( '.ueldo-checkbox' ).html( '<i class="fa fa-check"></i>' );
            }

            if( checkboxInput.hasClass( 'wpcf7-acceptance' ) || checkboxInput.parents( '.wpcf7-acceptance' ).length !== 0 ) $.UeldoUpdateAcceptance( checkboxBox );
        }
    };

   /**
    *
    * uncheck all checkboxes
    *
    */

    $.UeldoUncheckAllCheckboxes = function( name, changeValue ) {

        $( 'input[type="checkbox"][name="'+ name +'"]' ).each( function() {

            var checkboxInput = $( this );
            var checkboxBox = checkboxInput.siblings( '.ueldo-checkbox-box' );

            if( changeValue == true ) checkboxInput.removeAttr( 'checked' );
            checkboxBox.children( '.ueldo-checkbox' ).html( '' );

        });

    };

   /**
    *
    * configure radio elements
    *
    */

    $.UeldoConfigureRadioElements = function() {

        $( 'input[type="radio"]' ).each( function() {

            var radio = $( this );
            var checked = radio.is( ':checked' );

            if( radio.siblings( 'input[type="radio"], .ueldo-radio-field' ).length == 0 ) {

                var holder = radio.parent();

                radio.after( '<div class="ueldo-radio-box"><span class="ueldo-radio">'+ ( checked ? '<span class="ueldo-radio-checked"></span>' : '' ) +'</span></div>' );
                holder.addClass( 'ueldo-radio-field' );

                if( radio.parents( 'label' ).length !== 0 ) radio.parents( 'label' ).addClass( 'ueldo-radio-label' );
                else {

                    holder.wrapInner( '<span class="ueldo-radio-label"></span>' );
                    holder.children( 'span.ueldo-radio-label' ).before( holder.find( 'span.wpcf7-form-control-wrap' ) );
                }
            }

            else {

                if( radio.parents( '.starrating-container' ).length == 0 ) {

                    radio.wrap( '<span class="ueldo-radio-field"><span class="ueldo-radio-label"></span></span>' );
                    radio.parents( '.ueldo-radio-label' ).append( '<div class="ueldo-radio-box"><span class="ueldo-radio">'+ ( checked ? '<span class="ueldo-radio-checked"></span>' : '' ) +'</span></div>' );
                }
            }

        });

    };

   /**
    *
    * radio field change
    *
    */

    $( 'body' ).on( 'click touchstart', '.ueldo-radio-box', function( event ) {

        event.preventDefault();

        var element = $( this );
        $.UeldoChangeRadioElement( element );

    });

   /**
    *
    * change checkbox value function
    *
    */

    $.UeldoChangeRadioElement = function( radioBox ) {

        var radioInput = radioBox.siblings( 'input[type="radio"]' );

        if( radioBox.parents( '.nf-field-element' ).length === 1 ) {

            $.UeldoUncheckAllRadioElements( radioInput.attr( 'name' ), false );

            radioInput.trigger( 'click' );
            radioBox.children( '.ueldo-radio' ).html( '<span class="ueldo-radio-checked"></span>' );
        }

        else {

            $.UeldoUncheckAllRadioElements( radioInput.attr( 'name' ), true );

            radioInput.attr( 'checked', 'checked' ).attr( 'value', '1' ).val( '1' );
            radioBox.children( '.ueldo-radio' ).html( '<span class="ueldo-radio-checked"></span>' );
        }
    };

   /**
    *
    * uncheck all radio elements
    *
    */

    $.UeldoUncheckAllRadioElements = function( name, changeValue ) {

        $( 'input[type="radio"][name="'+ name +'"]' ).each( function() {

            var radioInput = $( this );
            var radioBox = radioInput.siblings( '.ueldo-radio-box' );

            if( changeValue == true ) radioInput.removeAttr( 'checked' ).attr( 'value', '0' ).val( '0' );
            radioBox.children( '.ueldo-radio' ).html( '' );

        });

    };

   /**
    *
    * acceptance field
    *
    */

    $.UeldoUpdateAcceptance = function( checkboxBox ) {

        var form = checkboxBox.parents( 'form.wpcf7-form' );
        var button = form.find( 'input[type="submit"].wpcf7-submit' );
        var isError = false;

        form.find( '.wpcf7-acceptance' ).each( function() {

            var field = $( this ).is( 'input[type="checkbox"]' ) ? $( this ) : $( this ).find( 'input[type="checkbox"]' );
            var isInvert = field.hasClass( 'wpcf7-invert' );
            var isCorrect = isInvert ? ( field.is( ':checked' ) ? false : true ) : ( field.is( ':checked' ) ? true : false );

            if( isCorrect == false ) isError = true;

        });

        if( isError == true ) button.attr( 'disabled', 'disabled' );
        else button.removeAttr( 'disabled' );

    };

   /**
    *
    * configure date fields
    *
    */

    $.UeldoConfigureDateFields = function() {

        $( 'input[type="date"]' ).each( function() {

            var field = $( this );

            field.wrap( '<span class="ueldo-date-field"></span>' );
            field.parents( '.ueldo-date-field' ).prepend( '<span class="ueldo-date-field-icon"><i class="fa fa-calendar"></i></span>' );

        });
    };

   /**
    *
    * configure range fields
    *
    */

    $.UeldoConfigureRangeFields = function() {

        $( 'input[type="range"]' ).each( function() {

            var field = $( this );

            field.wrap( '<span class="ueldo-range-field"></span>' );
            $( '<span class="ueldo-range-field-value">'+ field.val() +'</span>' ).insertBefore( field.parents( '.ueldo-range-field' ) );

        });
    };

   /**
    *
    * update range field value on change
    *
    */

    $( 'body' ).on( 'change', 'input[type="range"]', function() {

        var field = $( this );
        field.parents( '.ueldo-range-field' ).siblings( '.ueldo-range-field-value' ).text( field.val() );

    });

   /**
    *
    * update range field value on input
    *
    */

    $( 'body' ).on( 'input', 'input[type="range"]', function() {

        var field = $( this );
        field.parents( '.ueldo-range-field' ).siblings( '.ueldo-range-field-value' ).text( field.val() );

    });

   /**
    *
    * add error class to select container in Contact Form 7 plugin
    *
    */

    $( 'body' ).on( 'wpcf7:invalid', function() {

        $( 'body' ).find( 'select' ).each( function() {

            var select = $( this );

            if( select.hasClass( 'wpcf7-not-valid' ) ) select.parent().addClass( 'wpcf7-not-valid' );
            else select.parent().removeClass( 'wpcf7-not-valid' );

        });

    });

   /**
    *
    * get center width
    *
    */

    $.UeldoGetCenterWidth = function() {

        var contentContainer = $( 'body' ).find( '.ueldo-content-default .ueldo-content-container' );
        return( parseInt( contentContainer.width(), 10 ) );
    };

   /**
    *
    * get website wrapper width
    *
    */

    $.UeldoGetWebsiteWrapperWidth = function() {

        var websiteWrapper = $( 'body' ).find( '.ueldo-website-wrapper' );
        return( websiteWrapper.hasClass( 'ueldo-website-wrapper-boxed' ) ? websiteWrapper.width() : ueldoPageWidth );
    };

   /**
    *
    * configure "images slider to border" width and position
    *
    */

    $.UeldoConfigureImagesSliderToBorder = function() {

        var contentContainer = $( '.ueldo-content-default .ueldo-content-wrapper article.ueldo-blog-post, .ueldo-content-default .ueldo-content-wrapper article.ueldo-page, .ueldo-content-default.ueldo-content-default-vc-page .ueldo-row-with-sidebar-content-column' );
        contentContainer.find( '.ueldo-slider-area-close-to-border' ).each( function() {

            var imagesSlider = $( this );
            var borderSide = 'left';
            var maxHeight = imagesSlider.data( 'max-height' );
            var contentDefaultContainer = contentContainer.parents( '.ueldo-content-default' );

            if( contentDefaultContainer.length !== 0 && typeof contentDefaultContainer.attr( 'data-ueldo-content-default-sidebar-side' ) !== 'undefined' ) { if( contentDefaultContainer.attr( 'data-ueldo-content-default-sidebar-side' ) == 'left' ) borderSide = 'right'; }
            if( contentDefaultContainer.hasClass( 'ueldo-content-default-vc-page' ) ) {

                var contentColumn = imagesSlider.parents( '.ueldo-row-with-sidebar-content-column' );
                var contentRow = contentColumn.parents( '.vc_row' );

                if( contentRow.hasClass( 'ueldo-row-with-sidebar-on-left' ) ) borderSide = 'right';
            }

            var centerWidth = $.UeldoGetCenterWidth();
            var websiteWrapperWidth = $.UeldoGetWebsiteWrapperWidth();
            var parentArticle = imagesSlider.parents( 'article.ueldo-page, article.ueldo-blog-post, .ueldo-row-with-sidebar-content-column > .vc_column-inner > .wpb_wrapper' );

            if( parentArticle.length == 0 ) return;
            else {

                var articleWidth = parentArticle[0].getBoundingClientRect().width;
                var imageWidth = 0;
                var imageMargin = 0;

                if( ( contentDefaultContainer.length !== 0 && !contentDefaultContainer.hasClass( 'ueldo-content-default-vc-page' ) && contentDefaultContainer.find( '.ueldo-content-container' ).hasClass( 'ueldo-content-wrapper' ) ) || $.UeldoGetDeviceType() == 'mobile' ) {

                    if( parentArticle.hasClass( 'ueldo-page' ) || $.UeldoGetDeviceType() == 'mobile' ) {

                        // full width page

                        imageWidth = ( websiteWrapperWidth / 2 ) + ( centerWidth / 2 );
                        imageMargin = - ( websiteWrapperWidth - centerWidth ) / 2;
                    }

                    else {

                        // full width blog post

                        var articleMargin = parseInt( parentArticle.css( 'margin-left' ), 10 ) + parseInt( parentArticle.css( 'margin-right' ), 10 );

                        imageWidth = ( websiteWrapperWidth / 2 ) + ( centerWidth / 2 );
                        imageMargin = - ( ( websiteWrapperWidth - ( centerWidth - articleMargin ) ) / 2 );
                    }
                }

                else {

                    // article with sidebar

                    imageWidth = ( ( websiteWrapperWidth - centerWidth ) / 2 ) + articleWidth;
                    imageMargin = - ( imageWidth - articleWidth );
                }

                switch( borderSide ) {

                    case 'left': imagesSlider.css({ 'width': imageWidth, 'margin-left': imageMargin }); break;
                    case 'right': imagesSlider.css({ 'width': imageWidth, 'margin-right': imageMargin }); break;
                }

                if( maxHeight != 'none' ) imagesSlider.css({ 'max-height': maxHeight +'px' });
            }

        });

        if( ueldoIsFirstPageLoad == true ) {

            $( window ).trigger( 'resize' );
            ueldoIsFirstPageLoad = false;
        }

        $( window ).trigger( 'ueldo-height-changed' );
    };

   /**
    *
    * configure masonry posts list
    *
    */

    $.UeldoConfigureMasonryPostsList = function( refresh ) {

        $( '.ueldo-posts-list-masonry' ).each( function() {

            var container = $( this );
            container.masonry({
                itemSelector: '.ueldo-short-post-box',
                gutter: 40
            });

            $.UeldoConfigureAdditionalSidebarBackgroundSizes();

        });

        if( refresh == true ) {

            setTimeout( function() {

                $.UeldoConfigureMasonryPostsList( false );

            }, 300 );
        }
    };

   /**
    *
    * remove "under content elements" container if empty
    *
    */

    $.UeldoRemoveUnderContentElementsContainerIfEmpty = function() {

        $( '.ueldo-elements-under-content-elements' ).each( function() {

            var element = $( this );
            if( element.children().length == 0 ) element.remove();

        });

    };

   /**
    *
    * configure "ueldo-shortcode-tabs" shortcode
    *
    */

    $.UeldoConfigureShortcodeTabs = function() {

        $( '.ueldo-shortcode-tabs' ).each( function() {

            var shortcode = $( this );
            var tabsContainer = shortcode.find( '.ueldo-shortcode-tabs-single-tabs-contents' );
            var first = true;

            shortcode.find( '.ueldo-shortcode-tabs-single-tab' ).each( function() {

                var element = $( this );

                if( shortcode.hasClass( 'ueldo-shortcode-tabs-style-05' ) ) {

                    if( first == true ) {

                        element.addClass( 'ueldo-shortcode-tabs-single-tab-active' );
                        first = false;
                    }
                }

                else {

                    if( first == false ) element.css({ 'display': 'none' });
                    else {

                        var elementHeight = element.height();

                        tabsContainer.css({ 'height': elementHeight });
                        element.addClass( 'ueldo-shortcode-tabs-single-tab-active' );

                        $.UeldoSwitchSingleTabImageContent( shortcode, element.data( 'tab-slug' ) );

                        first = false;
                    }
                }

            });

            if( shortcode.data( 'autochange-enabled' ) == 'yes' ) $.UeldoAutochangeForTabs( shortcode );

        });

        $.UeldoUpdateImagesContainerHeight( true );
        $( window ).trigger( 'ueldo-height-changed' );
    };

   /**
    *
    * reconfigure "ueldo-shortcode-tabs" shortcode
    *
    */

    $.UeldoReConfigureShortcodeTabs = function() {

        $( '.ueldo-shortcode-tabs' ).each( function() {

            var shortcode = $( this );
            var tabsContainer = shortcode.find( '.ueldo-shortcode-tabs-single-tabs-contents' );

            tabsContainer.css({ 'height': tabsContainer.find( '.ueldo-shortcode-tabs-single-tab-active' ).height() });
            setTimeout( function() {

                tabsContainer.css({ 'height': tabsContainer.find( '.ueldo-shortcode-tabs-single-tab-active' ).height() });

            }, 300 );

        });

        $.UeldoUpdateImagesContainerHeight( true );
        $( window ).trigger( 'ueldo-height-changed' );
    };

   /**
    *
    * update images container height for mobile devices
    *
    */

    $.UeldoUpdateImagesContainerHeight = function( repeat ) {

        $( '.ueldo-shortcode-tabs' ).each( function() {

            var shortcode = $( this );
            var deviceType = $.UeldoGetDeviceType();
            var element = shortcode.find( '.ueldo-shortcode-tabs-single-tabs-images-container' );
            var middleHelper = shortcode.find( '.ueldo-shortcode-tabs-single-tabs-content-middle-helper' );
            var baseHeight = parseInt( shortcode.data( 'base-height' ), 10 );
            var baseWidth = parseInt( shortcode.data( 'base-width' ), 10 );
            var currentElementWidth = element.width();
            var resultHeight = parseInt( currentElementWidth > baseWidth ? baseHeight : ( currentElementWidth * ( baseHeight / baseWidth ) ), 10 );

            if( deviceType == 'desktop' || deviceType == 'tablet-horizontal' ) {

                element.css({ 'height': resultHeight, 'max-height': resultHeight, 'margin-top': '-'+ ( resultHeight / 2 ) +'px' });
                middleHelper.css({ 'height': resultHeight });
            }

            else {

                element.css({ 'height': resultHeight, 'max-height': resultHeight, 'margin-top': '' });
                middleHelper.css({ 'height': '' });
            }

        });

        if( repeat == true ) {

            setTimeout( function() {

                $.UeldoUpdateImagesContainerHeight( false );

            }, 300 );
        }

        $( window ).trigger( 'ueldo-height-changed' );
    };

   /**
    *
    * switch tab in "ueldo-shortcode-tabs" element
    *
    */

    $.UeldoSwitchSingleTab = function( element, allowAutoChange ) {

        var shortcode = element.parents( '.ueldo-shortcode-tabs' );
        var slug = element.data( 'tab-slug' );

        if( !shortcode.hasClass( 'ueldo-shortcode-tabs-style-05' ) ) {

            shortcode.addClass( 'ueldo-animation-proceed' );
            $.UeldoSwitchSingleTabImageContent( shortcode, slug );

            var oldTab = shortcode.find( '.ueldo-shortcode-tabs-single-tab.ueldo-shortcode-tabs-single-tab-active' );
            var newTab = shortcode.find( '.ueldo-shortcode-tabs-single-tab[data-tab-slug="'+ slug +'"]' );
            var newHeight = newTab.height();

            shortcode.find( '.ueldo-shortcode-tabs-selector li.ueldo-shortcode-tabs-selector-single-tab-active' ).removeClass( 'ueldo-shortcode-tabs-selector-single-tab-active' );
            shortcode.find( '.ueldo-shortcode-tabs-selector li[data-tab-slug="'+ slug +'"]' ).addClass( 'ueldo-shortcode-tabs-selector-single-tab-active' );

            shortcode.find( '.ueldo-circle-navigation li .ueldo-circle-navigation-element.ueldo-circle-navigation-element-active' ).removeClass( 'ueldo-circle-navigation-element-active' );
            shortcode.find( '.ueldo-circle-navigation li .ueldo-circle-navigation-element[data-tab-slug="'+ slug +'"]' ).addClass( 'ueldo-circle-navigation-element-active' );

            newTab.fadeIn( 300 );
            oldTab.fadeOut( 300 );

            shortcode.find( '.ueldo-shortcode-tabs-single-tabs-contents' ).animate({ 'height': newHeight }, { duration: 300, progress: function() { $( window ).trigger( 'ueldo-height-changed' ); } });

            setTimeout( function() {

                newTab.addClass( 'ueldo-shortcode-tabs-single-tab-active' );
                oldTab.removeClass( 'ueldo-shortcode-tabs-single-tab-active' ).css({ 'height': '', 'display': 'none' });

                shortcode.removeClass( 'ueldo-animation-proceed' );

            }, 300 );
        }

        else {

            shortcode.find( '.ueldo-shortcode-tabs-single-tab.ueldo-shortcode-tabs-single-tab-active' ).removeClass( 'ueldo-shortcode-tabs-single-tab-active' );
            element.addClass( 'ueldo-shortcode-tabs-single-tab-active' );

            $.UeldoSwitchSingleTabImageContent( shortcode, slug );
        }

        shortcode.find( '.ueldo-shortcode-tabs-single-tabs-images-single-tab-image-content' ).data( 'visible', '' ).removeAttr( 'data-visible' );
        if( shortcode.data( 'autochange-enabled' ) == 'yes' && allowAutoChange == true ) $.UeldoAutochangeForTabs( shortcode );

        $.UeldoRefreshGoogleMapsOnDemand();
        $( window ).trigger( 'ueldo-height-changed' );
    };

    $( 'body' ).on( 'click', '.ueldo-shortcode-tabs:not(.ueldo-shortcode-tabs-style-05):not(.ueldo-animation-proceed) .ueldo-shortcode-tabs-selector li:not(.ueldo-shortcode-tabs-selector-single-tab-active)', function() { $.UeldoSwitchSingleTab( $( this ), false ); });
    $( 'body' ).on( 'click touchstart', '.ueldo-shortcode-tabs:not(.ueldo-shortcode-tabs-style-05):not(.ueldo-animation-proceed) .ueldo-circle-navigation li span:not(.ueldo-circle-navigation-element-active)', function( event ) { event.preventDefault(); $.UeldoSwitchSingleTab( $( this ), false ); });
    $( 'body' ).on( 'click', '.ueldo-shortcode-tabs.ueldo-shortcode-tabs-style-05 .ueldo-shortcode-tabs-single-tab:not(.ueldo-shortcode-tabs-single-tab-active)', function() { $.UeldoSwitchSingleTab( $( this ), false ); });

   /**
    *
    * switch single tab image content
    *
    */

    $.UeldoSwitchSingleTabImageContent = function( shortcode, slug ) {

        var imagesContainer = shortcode.find( '.ueldo-shortcode-tabs-single-tabs-images-container' );
        if( imagesContainer.length == 0 || imagesContainer.data( 'custom-tab-image' ) == 'no' ) return;

        imagesContainer.find( '.ueldo-shortcode-tabs-single-tabs-images-single-tab-image-content' ).each( function() {

            var element = $( this );

            if( element.data( 'tab-slug' ) != slug ) element.fadeOut( 300 );
            else {

                element.fadeIn( 300 );
                $.UeldoRefreshRevSlider( element );
            }

        });

    };

   /**
    *
    * play revolution slider from begin on tab change
    *
    */

    $.UeldoRefreshRevSlider = function( element ) {

        var revSlider = element.find( '.rev_slider' );
        if( revSlider.length !== 0 ) {

            var slider = eval( 'revapi' + revSlider.attr( 'id' ).split( 'rev_slider_' )[1].split( '_' )[0] );
            if( slider.revcurrentslide() > 1 ) {

                slider.revpause();
                slider.revredraw();
                slider.revshowslide( 1 );

                setTimeout( function() {

                    slider.revresume();

                }, 300 );
            }
        }

    };

   /**
    *
    * autochange for tabs shortcode
    *
    */

    $.UeldoAutochangeForTabs = function( shortcode ) {

        var shortcodeClass = shortcode.attr( 'class' );
        var interval = shortcode.data( 'autochange-interval' );
        var uniqueClass = shortcodeClass.substring( shortcodeClass.indexOf( 'ueldo_vc_element_' ), shortcodeClass.length ).trim();

        if( uniqueClass.indexOf( ' ' ) > 0 ) uniqueClass = uniqueClass.substring( 0, uniqueClass.indexOf( ' ' ) ).trim();
        if( typeof ueldoIntervals[uniqueClass] != 'undefined' ) clearInterval( ueldoIntervals[uniqueClass] );

        ueldoIntervals[uniqueClass] = setInterval( function() {

            if( !shortcode.hasClass( 'ueldo-shortcode-tabs-style-05' ) ) {

                var firstTab = false;
                var currentActiveTab = false;
                var elementAfterCurrentActiveTab = false;
                var tabsSelector = shortcode.find( '.ueldo-shortcode-tabs-selector' );

                tabsSelector.find( 'li' ).each( function() {

                    var element = $( this );

                    if( firstTab == false ) firstTab = element;
                    if( element.hasClass( 'ueldo-shortcode-tabs-selector-single-tab-active' ) ) currentActiveTab = element;
                    else if( currentActiveTab != false && elementAfterCurrentActiveTab == false ) elementAfterCurrentActiveTab = element;

                });

                $.UeldoSwitchSingleTab( elementAfterCurrentActiveTab != false ? elementAfterCurrentActiveTab : firstTab, true );
            }

            else {

                var firstTab = false;
                var currentActiveTab = false;
                var elementAfterCurrentActiveTab = false;
                var tabsSelector = shortcode.find( '.ueldo-shortcode-tabs-single-tabs-content-container' );

                tabsSelector.find( '.ueldo-shortcode-tabs-single-tab' ).each( function() {

                    var element = $( this );

                    if( firstTab == false ) firstTab = element;
                    if( element.hasClass( 'ueldo-shortcode-tabs-single-tab-active' ) ) currentActiveTab = element;
                    else if( currentActiveTab != false && elementAfterCurrentActiveTab == false ) elementAfterCurrentActiveTab = element;

                });

                $.UeldoSwitchSingleTab( elementAfterCurrentActiveTab != false ? elementAfterCurrentActiveTab : firstTab, true );
            }

        }, interval );

    };

   /**
    *
    * stop tabs interval on mouse in
    *
    */

    $( 'body' ).on( 'mouseenter', '.ueldo-shortcode-tabs', function() {

        var shortcode = $( this );
        var shortcodeClass = shortcode.attr( 'class' );
        var uniqueClass = shortcodeClass.substring( shortcodeClass.indexOf( 'ueldo_vc_element_' ), shortcodeClass.length ).trim();

        if( uniqueClass.indexOf( ' ' ) > 0 ) uniqueClass = uniqueClass.substring( 0, uniqueClass.indexOf( ' ' ) ).trim();
        if( typeof ueldoIntervals[uniqueClass] != 'undefined' ) clearInterval( ueldoIntervals[uniqueClass] );

    });

    $( 'body' ).on( 'mouseleave', '.ueldo-shortcode-tabs', function() {

        var shortcode = $( this );
        if( shortcode.data( 'autochange-enabled' ) == 'yes' ) $.UeldoAutochangeForTabs( shortcode );

    });

   /**
    *
    * configure tabs selector
    *
    */

    $.UeldoConfigureTabsSelector = function() {

        $( '.ueldo-shortcode-tabs' ).each( function() {

            var minTabWidth = 150;
            var maxPerRow = 5;
            var tabsContainer = $( this );
            var tabsSelector = tabsContainer.find( '.ueldo-shortcode-tabs-selector' );
            var tabsSelectorWidth = tabsSelector.width() + parseInt( tabsSelector.css( 'border-left-width' ), 10 ) + parseInt( tabsSelector.css( 'border-right-width' ), 10 );
            var tabsCount = tabsSelector.children( 'li' ).length;

            if( tabsSelector.length == 0 || tabsContainer.hasClass( 'ueldo-shortcode-tabs-style-02' ) ) return;

            var tabsSelectorContainer = tabsSelector.parents( '.ueldo-shortcode-tabs-selector-container' );
            if( tabsSelector.hasClass( 'ueldo-shortcode-tabs-selector-03' ) ) {

                if( tabsSelectorWidth < tabsSelectorContainer.width() ) tabsSelector.removeClass( 'ueldo-shortcode-tabs-selector-as-table' ).data( 'tabs-per-row', '' ).removeAttr( 'data-tabs-per-row' );
                else {

                    tabsSelector.addClass( 'ueldo-shortcode-tabs-selector-as-table' );
                    for( var i = maxPerRow; i > 0; i-- ) {

                        if( ( tabsSelectorWidth / i ) >= minTabWidth ) {

                            tabsSelector.data( 'tabs-per-row', i ).attr( 'data-tabs-per-row', i );
                            break;
                        }
                    }
                }
            }

            else {

                if( tabsSelectorWidth / tabsCount >= minTabWidth ) tabsSelector.removeClass( 'ueldo-shortcode-tabs-selector-as-table' ).data( 'tabs-per-row', '' ).removeAttr( 'data-tabs-per-row' );
                else {

                    tabsSelector.addClass( 'ueldo-shortcode-tabs-selector-as-table' );
                    for( var i = maxPerRow; i > 0; i-- ) {

                        if( ( tabsSelectorWidth / i ) >= minTabWidth ) {

                            tabsSelector.data( 'tabs-per-row', i ).attr( 'data-tabs-per-row', i );
                            break;
                        }
                    }
                }
            }

        });
    };

   /**
    *
    * all tabs selectors with the same height
    *
    */

    $.UeldoAllTabsSelectorsWithTheSameHeight = function() {

        $( '.ueldo-shortcode-tabs' ).each( function() {

            var tabsContainer = $( this );
            var tabsSelector = tabsContainer.find( '.ueldo-shortcode-tabs-selector' );

            if( tabsSelector.length == 0 || tabsContainer.hasClass( 'ueldo-shortcode-tabs-style-02' ) ) return;
            tabsSelector.find( 'li .ueldo-shortcode-tabs-selector-single-tab-middle-helper' ).remove();

            var maxHeight = 0;
            var isDifferentHeight = false;

            tabsSelector.find( 'li' ).each( function() {

                var element = $( this );
                var elementHeight = element.height();

                if( elementHeight != maxHeight ) {

                    if( maxHeight > 0 ) isDifferentHeight = true;
                    maxHeight = elementHeight > maxHeight ? elementHeight : maxHeight;
                }

            });

            if( isDifferentHeight == true ) {

                var middleHelpers = tabsSelector.find( 'li .ueldo-shortcode-tabs-selector-single-tab-middle-helper' );
                if( middleHelpers.length == 0 ) tabsSelector.find( 'li' ).prepend( '<span class="ueldo-shortcode-tabs-selector-single-tab-middle-helper"></span>' );

                tabsSelector.find( 'li .ueldo-shortcode-tabs-selector-single-tab-middle-helper' ).css({ 'height': maxHeight });
            }

        });

        $( window ).trigger( 'ueldo-height-changed' );
    };

   /**
    *
    * play the video - magnific popup
    *
    */

    $( 'body' ).on( 'click', '.ueldo-play-video-button', function() {

        var button = $( this );
        var videoURL = button.data( 'video-url' );

        $.magnificPopup.open({ type: 'iframe', items: { src: videoURL } });

    });

   /**
    *
    * configure images gallery - magnific popup
    *
    */

    $.UeldoConfigureImagesGalleries = function() {

        var elements = $( 'body' ).find( '*[class^="ueldo-shortcode-image-gallery-"], div[class*=" ueldo-shortcode-image-gallery-"]' );
        var outsideGallerySlugs = [];
        var insideGallerySlugs = [];

        elements.each( function() {

            var element = $( this );
            if( element.parents( '.ueldo-shortcode-filtered-masonry' ).length == 0 ) {

                var class_names = element.attr( 'class' ).split( ' ' );
                var gallery_slug = false;

                $.each( class_names, function( id, class_name ) { if( class_name.indexOf( 'ueldo-shortcode-image-gallery-' ) !== -1 ) { gallery_slug = class_name; } });

                if( outsideGallerySlugs.indexOf( gallery_slug ) === -1 ) {

                    outsideGallerySlugs.push( gallery_slug );
                    var selectors = $( 'body' ).find( '*:not(.ueldo-shortcode-filtered-masonry-cell-inner) > .'+ gallery_slug +':not(.ueldo-gallery-image-inside-filtered-masonry) .ueldo-image-caption-icon-show' );

                    if( ueldo_javascript_functions_l10n.retina_images_replacement_enabled == 'yes' && $.UeldoIsRetina() == true ) {

                        selectors.magnificPopup({
                            type: 'image',
                            gallery: { enabled: true },
                            retina: { ratio: 2 },
                            callbacks: {
                                open: function() { $.UeldoFixMagnificPopupRetinaImagesDimensions( true ); },
                                resize: function() { $.UeldoFixMagnificPopupRetinaImagesDimensions( true ); },
                                change: function() { $.UeldoFixMagnificPopupRetinaImagesDimensions( true ); }
                            }
                        });
                    }

                    else selectors.magnificPopup({ type: 'image', gallery: { enabled: true } });
                }
            }

            else {

                element.addClass( 'ueldo-gallery-image-inside-filtered-masonry' );

                var filteredMasonryContainer = element.parents( '.ueldo-shortcode-filtered-masonry' );
                filteredMasonryContainer.find( '*[class^="ueldo-shortcode-image-gallery-"], div[class*=" ueldo-shortcode-image-gallery-"]' ).each( function() {

                    var filteredGalleryElement = $( this );
                    var class_names = filteredGalleryElement.attr( 'class' ).split( ' ' );
                    var gallery_slug = false;

                    $.each( class_names, function( id, class_name ) { if( class_name.indexOf( 'ueldo-shortcode-image-gallery-' ) !== -1 ) { gallery_slug = class_name; } });

                    if( !filteredMasonryContainer.hasClass( 'ueldo-shortcode-filtered-masonry-gallery-for-'+ gallery_slug +'-created' ) ) {

                        filteredMasonryContainer.addClass( 'ueldo-shortcode-filtered-masonry-gallery-for-'+ gallery_slug +'-created' );
                        var selectors = filteredMasonryContainer.find( '.'+ gallery_slug +'.ueldo-gallery-image-inside-filtered-masonry .ueldo-image-caption-icon-show.ueldo-isotope-element-visible' );

                        if( ueldo_javascript_functions_l10n.retina_images_replacement_enabled == 'yes' && $.UeldoIsRetina() == true ) {

                            selectors.magnificPopup({
                                type: 'image',
                                gallery: { enabled: true },
                                retina: { ratio: 2 },
                                callbacks: {
                                    open: function() { $.UeldoFixMagnificPopupRetinaImagesDimensions( true ); },
                                    resize: function() { $.UeldoFixMagnificPopupRetinaImagesDimensions( true ); },
                                    change: function() { $.UeldoFixMagnificPopupRetinaImagesDimensions( true ); }
                                }
                            });
                        }

                        else selectors.magnificPopup({ type: 'image', gallery: { enabled: true } });
                        insideGallerySlugs.push( gallery_slug );
                    }

                });

            }

        });

        for( var i = 0; i < insideGallerySlugs.length; i++ ) {

            $( 'body' ).find( '.ueldo-shortcode-filtered-masonry' ).removeClass( 'ueldo-shortcode-filtered-masonry-gallery-for-'+ insideGallerySlugs[i] +'-created' );
        }
    };

   /**
    *
    * actions after click on image caption
    *
    */

    $( 'body' ).on( 'click', '.ueldo-shortcode-image .ueldo-image-caption', function( event ) {

        var element = $( this ).parents( '.ueldo-shortcode-image' );
        if( $( event.target ).hasClass( 'ueldo-image-caption' ) || $( event.target ).hasClass( 'ueldo-image-caption-middle' ) ) {

            var imagePopup = element.find( '.ueldo-image-caption-icon-show' );

            if( imagePopup.length !== 0 ) imagePopup.trigger( 'click' );
            else {

                var imageLink = element.find( '.ueldo-image-caption-icon-link' );
                if( imageLink.length !== 0 ) imageLink[0].click();
            }
        }

    });

   /**
    *
    * fix retina images dimensions for magnific popup
    *
    */

    $.UeldoFixMagnificPopupRetinaImagesDimensions = function( repeat ) {

        var item = $.magnificPopup.instance.currItem;
        var imageElement = $( item.img[0] );
        var naturalHeight = item.img[0].naturalHeight;
        var element = $( '.mfp-wrap img.mfp-img' );
        var is2x = imageElement.attr( 'src' ).indexOf( '@2x' ) !== false;
        var windowHeight = $( window ).height();
        var maxHeight = 0;

        if( is2x && ueldo_javascript_functions_l10n.retina_images_replacement_enabled == 'yes' && $.UeldoIsRetina() == true ) {

            element.css({ 'max-width': '', 'max-height': '', 'width': '' });

            if( windowHeight >= ( naturalHeight / 2 ) ) maxHeight = Math.floor( naturalHeight / 2 );
            else maxHeight = windowHeight;

            element.css({ 'max-width': '', 'max-height': maxHeight +'px', 'width': '' });

            if( repeat == true ) setTimeout( function() { $.UeldoFixMagnificPopupRetinaImagesDimensions( false ); }, 1 );
        }

    };

   /**
    *
    * configure google maps
    *
    */

    $.UeldoConfigureGoogleMaps = function() {

        if( ueldo_javascript_functions_l10n.is_google_maps_available == 'no' ) return;

        var mapID = 1;
        $( '.ueldo-google-map-data' ).each( function() {

            var mapBox = $( this );
            var lat = mapBox.data( 'lat' );
            var lng = mapBox.data( 'lng' );
            var zoom = mapBox.data( 'zoom-level' );
            var mapStylesBox = mapBox.siblings( '.ueldo-google-map-custom-style-data' );

            mapBox.attr( 'id', 'google-map-'+ mapID );

            var map = new google.maps.Map( document.getElementById( 'google-map-'+ mapID ), {
                zoom: zoom,
                center: new google.maps.LatLng( lat, lng ),
                mapTypeId: google.maps.MapTypeId.ROADMAP,
                scrollwheel: false,
                styles: ( mapStylesBox.length == 1 ? $.parseJSON( mapStylesBox.html() ) : '' )
            });

            ueldoGoogleMaps['google-map-'+ mapID] = map;
            ueldoGoogleMapsCount++;

            mapBox.siblings( '.ueldo-google-map-marker-data' ).each( function() {

                var marker = $( this );
                var customMarker = marker.data( 'use-custom-marker' );

                switch( customMarker ) {

                    case 'yes-icon':

                        new RichMarker({
                            position: new google.maps.LatLng( marker.data( 'lat' ), marker.data( 'lng' ) ),
                            map: map,
                            draggable: false,
                            flat: true,
                            content: marker.html()
                        });

                    break;

                    case 'yes-image':

                        if( ueldo_javascript_functions_l10n.retina_images_replacement_enabled == 'yes' ) {

                            var imageObj = marker.find( 'img' );
                            var noRetinaImage = {
                                'src': imageObj.attr( 'src' ),
                                'width': imageObj[0].naturalWidth,
                                'height': imageObj[0].naturalHeight
                            };

                            var noRetinaMarker = new google.maps.Marker({
                                position: new google.maps.LatLng( marker.data( 'lat' ), marker.data( 'lng' ) ),
                                icon: new google.maps.MarkerImage( noRetinaImage.src, null, null, null, new google.maps.Size( noRetinaImage.width, noRetinaImage.height ) ),
                                map: map
                            });

                            if( $.UeldoIsRetina() == true ) {

                                imageObj.on( 'load', function() {

                                    noRetinaMarker.setMap( null );

                                    var newImageObj = $( this );
                                    var retinaMarker = new google.maps.Marker({
                                        position: new google.maps.LatLng( marker.data( 'lat' ), marker.data( 'lng' ) ),
                                        icon: new google.maps.MarkerImage( newImageObj.attr( 'src' ), null, null, null, new google.maps.Size( noRetinaImage.width, noRetinaImage.height ) ),
                                        map: map
                                    });

                                });
                            }
                        }

                        else {

                            new google.maps.Marker({
                                position: new google.maps.LatLng( marker.data( 'lat' ), marker.data( 'lng' ) ),
                                icon: marker.find( 'img' ).attr( 'src' ),
                                map: map
                            });
                        }

                    break;

                    default:

                        new google.maps.Marker({
                            position: new google.maps.LatLng( marker.data( 'lat' ), marker.data( 'lng' ) ),
                            map: map
                        });

                    break;
                }

            });

            google.maps.event.addDomListener( window, 'resize', function() {

                var mapCenter = map.getCenter();

                google.maps.event.trigger( map, 'resize' );
                map.setCenter( mapCenter );

            });

            mapID++;

        });
    };

   /**
    *
    * is retina / high resolution screen?
    *
    */

    $.UeldoIsRetina = function() {

        return( Math.round( typeof window !== 'undefined' ? window.devicePixelRatio || 1 : 1 ) > 1 );
    };

   /**
    *
    * refresh google maps on demand
    *
    */

    $.UeldoRefreshGoogleMapsOnDemand = function() {

        for( var i = 1; i < ( ueldoGoogleMapsCount + 1 ); i++ ) {

            var map = ueldoGoogleMaps['google-map-'+ i];
            var mapCenter = map.getCenter();

            google.maps.event.trigger( map, 'resize' );
            map.setCenter( mapCenter );
        }
    };

   /**
    *
    * counter
    *
    */

    $.UeldoConfigureNumbersCounter = function() {

        $( '.ueldo-shortcode-info-box-element-counter[data-animation-done="no"], .ueldo-shortcode-info-box-additional-element-counter[data-animation-done="no"], .ueldo-shortcode-heading-text-counter[data-animation-done="no"]' ).each( function() {

            var element = $( this );
            var visible = ( element.offset().top + element.height() ) >= $( window ).scrollTop() && element.offset().top <= ( $( window ).scrollTop() + $( window ).height() );

            if( visible == true ) {

                element.data( 'animation-done', 'yes' ).attr( 'data-animation-done', 'yes' );
                element.prop( 'Counter', 0 ).animate({ Counter: element.text() }, {

                    duration: element.data( 'counter-duration' ),
                    easing: 'swing',
                    step: function( now ) { $( this ).text( Math.ceil( now ) ); }

                });
            }

        });

    };

   /**
    *
    * change pricing list group
    *
    */

    $( 'body' ).on( 'change', '.ueldo-shortcode-pricing-list select[name="ueldo-shortcode-pricing-list-group-selector"]', function() {

        var selector = $( this );
        var newGroupSlug = selector.val();
        var pricingList = selector.parents( '.ueldo-shortcode-pricing-list' );

        pricingList.find( '.ueldo-shortcode-pricing-list-background-icon[data-visible="yes"], .ueldo-shortcode-pricing-list-groups-selector-descriptions-single-description[data-visible="yes"], .ueldo-shortcode-pricing-list-groups-content-group-attributes[data-visible="yes"]' ).data( 'visible', 'no' ).attr( 'data-visible', 'no' );
        pricingList.find( '.ueldo-shortcode-pricing-list-background-icon[data-group-slug="'+ newGroupSlug +'"], .ueldo-shortcode-pricing-list-groups-selector-descriptions-single-description[data-group-slug="'+ newGroupSlug +'"], .ueldo-shortcode-pricing-list-groups-content-group-attributes[data-group-slug="'+ newGroupSlug +'"]' ).data( 'visible', 'yes' ).attr( 'data-visible', 'yes' );

    });

   /**
    *
    * wrap card content to relative container
    *
    */

    $.UeldoWrapCardContent = function() {

        $( '.ueldo-shortcode-card' ).each( function() {

            var card = $( this );
            var cardLayers = card.find( '.ueldo-shortcode-card-layer-container' );

            card.prepend( cardLayers );
            $.UeldoConfigureVideoLayerSizesAndPositions( card, false );

        });

    };

   /**
    *
    * configure video layer sizes and positions
    *
    */

    $.UeldoConfigureVideoLayerSizesAndPositions = function( element, is_row_layer ) {

        var class_name = is_row_layer ? '.ueldo-shortcode-row-layer[data-layer-type="youtube_video"]' : '.ueldo-shortcode-card-layer[data-layer-type="youtube_video"]';
        element.find( class_name ).each( function() {

            var layer = $( this );
            var iframe = layer.find( 'iframe' );
            var heightCalculated = false;

            var newIframeHeight = element.height() + parseInt( element.css( 'padding-top' ), 10 ) + parseInt( element.css( 'padding-bottom' ), 10 );
            var elementWidth = element.width() + parseInt( element.css( 'padding-left' ), 10 ) + parseInt( element.css( 'padding-right' ), 10 );
            var elementHeight = element.height() + parseInt( element.css( 'padding-top' ), 10 ) + parseInt( element.css( 'padding-bottom' ), 10 );
            var newIframeWidth = ( newIframeHeight / 9 ) * 16;

            if( newIframeWidth < elementWidth ) {

                newIframeWidth = elementWidth;
                newIframeHeight = ( newIframeWidth / 16 ) * 9;
                heightCalculated = true;
            }

            iframe.css({ 'height': newIframeHeight, 'width': newIframeWidth });
            iframe.css({ 'margin-left': '-'+ ( ( iframe.width() - elementWidth ) / 2 ) +'px' });

            if( heightCalculated == true ) {

                iframe.css({ 'margin-top': '-'+ ( ( iframe.height() - elementHeight ) / 2 ) +'px' });
            }

        });

        $( window ).trigger( 'ueldo-height-changed' );
    };

   /**
    *
    * move row layers to correct position
    *
    */

    $.UeldoMoveRowLayersToPosition = function() {

        $( '.ueldo-shortcode-row-layer' ).each( function() {

            var layer = $( this );
            var layerFor = layer.data( 'layer-for' );

            switch( layerFor ) {

                case 'row': if( !layer.parent().hasClass( 'vc_row' ) ) layer.insertBefore( layer.parents( '.vc_row' ).children( '.wpb_column' ).first() ); break;
                case 'section': if( !layer.parent().hasClass( 'vc_section' ) ) layer.insertBefore( layer.parents( '.vc_section' ).children( '.vc_row' ).first() ); break;
            }

        });
    };

   /**
    *
    * configure full-width testimonials
    *
    */

    $.UeldoConfigureFullWidthTestimonials = function( is_repeated ) {

        $( '.ueldo-shortcode-full-width-testimonials' ).each( function() {

            var section = $( this );
            var loopType = section.data( 'loop-type' );
            var widths = 0;
            var imagesContainerWidth = 0;

            if( loopType == 'logos' ) {

                var selectors = section.find( '.ueldo-shortcode-full-width-testimonials-clients-logos' );
                var loop = section.find( '.ueldo-shortcode-full-width-testimonials-clients-logos-loop' );

                section.find( '.ueldo-shortcode-full-width-testimonials-clients-logos-single-client' ).each( function() {

                    var imagesContainer = $( this );
                    var image = imagesContainer.find( '.ueldo-shortcode-full-width-testimonials-clients-logos-single-client-image' );
                    var imageHover = imagesContainer.find( '.ueldo-shortcode-full-width-testimonials-clients-logos-single-client-image-hover' );

                    if( $.UeldoGetDeviceType() == 'mobile' ) imagesContainer.css({ 'width': section.width(), 'margin': '' });
                    else imagesContainer.css({ 'width': '' });

                    var height = image.find( 'img' ).height();
                    if( imageHover.find( 'img' ).height() > height ) height = imageHover.find( 'img' ).height();

                    imagesContainer.css({ 'height': height });
                    image.css({ 'height': height });
                    image.find( '.ueldo-shortcode-full-width-testimonials-clients-logos-single-client-image-middle-helper' ).css({ 'height': height });
                    imageHover.css({ 'height': height });
                    imageHover.find( '.ueldo-shortcode-full-width-testimonials-clients-logos-single-client-image-middle-helper' ).css({ 'height': height });

                    imagesContainerWidth = imagesContainer.width() + parseInt( imagesContainer.css( 'margin-left' ), 10 ) + parseInt( imagesContainer.css( 'margin-right' ), 10 );
                    widths += imagesContainerWidth;

                    if( $.UeldoGetDeviceType() == 'mobile' ) {

                        var imageWidth = image.width();

                        if( ueldo_javascript_functions_l10n.is_rtl == 'yes' ) {

                            image.css({ 'margin-right': '-'+ ( imageWidth / 2 ) +'px', 'right': '50%' });
                            imageHover.css({ 'margin-right': '-'+ ( imageWidth / 2 ) +'px', 'right': '50%' });
                        }

                        else {

                            image.css({ 'margin-left': '-'+ ( imageWidth / 2 ) +'px', 'left': '50%' });
                            imageHover.css({ 'margin-left': '-'+ ( imageWidth / 2 ) +'px', 'left': '50%' });
                        }
                    }

                    else {

                        image.css({ 'margin-left': '', 'margin-right': '', 'left': '', 'right': '' });
                        imageHover.css({ 'margin-left': '', 'margin-right': '', 'left': '', 'right': '' });
                    }

                    if( imagesContainer.data( 'active' ) == 'yes' ) {

                        var contentsContainer = section.find( '.ueldo-shortcode-full-width-testimonials-single-testimonial-contents' );
                        var activeContent = contentsContainer.find( '.ueldo-shortcode-full-width-testimonials-single-testimonial-content[data-active="yes"]' );

                        contentsContainer.css({ 'height': activeContent.height() });
                    }

                });

                if( selectors.data( 'loop-style' ) == 'on_center' && $.UeldoGetDeviceType() != 'mobile' ) widths += imagesContainerWidth * ( section.width() == parseInt( ueldo_javascript_functions_l10n.website_sizes_small_content_width, 10 ) ? 2 : 4 );
                loop.css({ 'width': widths });
            }

            else {

                var selectors = section.find( '.ueldo-shortcode-full-width-testimonials-clients-images' );
                var loop = section.find( '.ueldo-shortcode-full-width-testimonials-clients-images-loop' );
                var biggerElementHeight = 0;

                section.find( '.ueldo-shortcode-full-width-testimonials-clients-images-single-client-container' ).each( function() {

                    var imagesContainer = $( this );
                    var image = imagesContainer.find( '.ueldo-shortcode-full-width-testimonials-clients-logos-single-client-image' );
                    var imageHover = imagesContainer.find( '.ueldo-shortcode-full-width-testimonials-clients-logos-single-client-image-hover' );

                    if( $.UeldoGetDeviceType() == 'mobile' ) imagesContainer.css({ 'width': section.width(), 'margin': '' });
                    else imagesContainer.css({ 'width': '' });

                    imagesContainerWidth = imagesContainer.width() + parseInt( imagesContainer.css( 'margin-left' ), 10 ) + parseInt( imagesContainer.css( 'margin-right' ), 10 );
                    widths += imagesContainerWidth;

                    if( imagesContainer.height() > biggerElementHeight ) biggerElementHeight = imagesContainer.height();

                    if( imagesContainer.children( '.ueldo-shortcode-full-width-testimonials-clients-images-single-client' ).data( 'active' ) == 'yes' ) {

                        var contentsContainer = section.find( '.ueldo-shortcode-full-width-testimonials-single-testimonial-contents' );
                        var activeContent = contentsContainer.find( '.ueldo-shortcode-full-width-testimonials-single-testimonial-content[data-active="yes"]' );

                        contentsContainer.css({ 'height': activeContent.height() });
                    }

                });

                loop.css({ 'width': widths + 100, 'height': biggerElementHeight + parseInt( loop.css( 'padding-top' ), 10 ) + parseInt( loop.css( 'padding-bottom' ), 10 ) });
                loop.find( '.ueldo-shortcode-full-width-testimonials-clients-images-loop-middle-helper' ).css({ 'height': biggerElementHeight });

                var testimonialAuthors = section.find( '.ueldo-shortcode-full-width-testimonials-single-testimonial-authors' );
                testimonialAuthors.find( '.ueldo-shortcode-full-width-testimonials-single-testimonial-author' ).each( function() {

                    var testimonialAuthor = $( this );

                    if( testimonialAuthor.data( 'active' ) == 'yes' ) testimonialAuthors.css({ 'height': testimonialAuthor.height() + parseInt( testimonialAuthor.css( 'margin-top' ), 10 ) + parseInt( testimonialAuthor.css( 'margin-bottom' ), 10 ) });
                    else testimonialAuthor.css({ 'display': 'none' });

                });
            }

        });

        if( is_repeated == false ) {

            setTimeout( function() {

                $.UeldoConfigureFullWidthTestimonials( true );

            }, 100 );
        }

        $( window ).trigger( 'ueldo-height-changed' );
    };

   /**
    *
    * change full-width testimonials testimonial
    *
    */

    $.UeldoChangeFullWidthTestimonialsTestimonial = function( selector, refresh ) {

        var testimonialID = selector.data( 'testimonial-id' );
        var section = selector.parents( '.ueldo-shortcode-full-width-testimonials' );
        var loopType = section.data( 'loop-type' );
        var animationSpeed = 300;
        var animationClassSpeed = 170;

        if( section.hasClass( 'ueldo-animation-proceed' ) ) return;
        else section.addClass( 'ueldo-animation-proceed' );

        if( loopType == 'logos' ) {

            var loop = section.find( '.ueldo-shortcode-full-width-testimonials-clients-logos-loop' );
            var loopStyle = section.find( '.ueldo-shortcode-full-width-testimonials-clients-logos' ).data( 'loop-style' );
            var testimonialsCount = section.find( '.ueldo-shortcode-full-width-testimonials-clients-logos-single-client' ).length;
            var firstTestimonialImage = section.find( '.ueldo-shortcode-full-width-testimonials-clients-logos-single-client[data-testimonial-id="1"]' );
            var css_styles = {};
            var marginLeft = selector.offset().left - firstTestimonialImage.offset().left;
                marginLeft = marginLeft.toString().replace( '-', '' );

            if( loopStyle == 'standard' && ( ( $.UeldoGetDeviceType() == 'tablet-vertical' && testimonialsCount <= 3 ) || ( ( $.UeldoGetDeviceType() == 'tablet-horizontal' || $.UeldoGetDeviceType() == 'desktop' ) && testimonialsCount <= 5 ) ) ) {

                css_styles[( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ) )] = 'auto';
            }

            else {

                if( loopStyle == 'on_center' ) {

                    css_styles[( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ) )] = '-'+ marginLeft +'px';
                }

                else {

                    if( ( $.UeldoGetDeviceType() == 'tablet-horizontal' || $.UeldoGetDeviceType() == 'desktop' ) ) {

                        if( testimonialID <= 3 ) {

                            css_styles[( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ) )] = '';
                        }

                        else {

                            var logosToEnd = ( testimonialsCount + 1 ) - testimonialID;

                            if( logosToEnd == 1 ) {

                                marginLeft = ( testimonialID - 5 ) * ( firstTestimonialImage.width() + parseInt( firstTestimonialImage.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'left' : 'right' ) ), 10 ) );
                                css_styles[( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ) )] = '-'+ marginLeft +'px';
                            }

                            else if( logosToEnd == 2 ) {

                                marginLeft = ( testimonialID - 4 ) * ( firstTestimonialImage.width() + parseInt( firstTestimonialImage.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'left' : 'right' ) ), 10 ) );
                                css_styles[( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ) )] = '-'+ marginLeft +'px';
                            }

                            else if( logosToEnd > 2 ) {

                                marginLeft = ( testimonialID - 3 ) * ( firstTestimonialImage.width() + parseInt( firstTestimonialImage.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'left' : 'right' ) ), 10 ) );
                                css_styles[( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ) )] = '-'+ marginLeft +'px';
                            }
                        }
                    }

                    else if( $.UeldoGetDeviceType() == 'tablet-vertical' ) {

                        if( testimonialID <= 2 ) {

                            css_styles[( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ) )] = '';
                        }

                        else {

                            var logosToEnd = ( testimonialsCount + 1 ) - testimonialID;

                            if( logosToEnd == 1 ) {

                                marginLeft = ( testimonialID - 3 ) * ( firstTestimonialImage.width() + parseInt( firstTestimonialImage.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'left' : 'right' ) ), 10 ) );
                                css_styles[( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ) )] = '-'+ marginLeft +'px';
                            }

                            else if( logosToEnd > 1 ) {

                                marginLeft = ( testimonialID - 2 ) * ( firstTestimonialImage.width() + parseInt( firstTestimonialImage.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'left' : 'right' ) ), 10 ) );
                                css_styles[( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ) )] = '-'+ marginLeft +'px';
                            }
                        }
                    }

                    else {

                        if( testimonialID == 1 ) {

                            css_styles[( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ) )] = '';
                        }

                        else {

                            marginLeft = ( testimonialID - 1 ) * ( firstTestimonialImage.width() + parseInt( firstTestimonialImage.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'left' : 'right' ) ), 10 ) );
                            css_styles[( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ) )] = '-'+ marginLeft +'px';
                        }
                    }
                }
            }

            if( refresh == true ) loop.css( css_styles );
            else loop.animate( css_styles, animationSpeed );
        }

        else {

            var loop = section.find( '.ueldo-shortcode-full-width-testimonials-clients-images-loop' );
            var testimonialAuthors = section.find( '.ueldo-shortcode-full-width-testimonials-single-testimonial-authors' );
            var oldTestimonialAuthor = testimonialAuthors.find( '.ueldo-shortcode-full-width-testimonials-single-testimonial-author[data-active="yes"]' );
            var newTestimonialAuthor = testimonialAuthors.find( '.ueldo-shortcode-full-width-testimonials-single-testimonial-author[data-testimonial-id="'+ testimonialID +'"]' );
            var animationType = parseInt( oldTestimonialAuthor.data( 'testimonial-id' ), 10 ) < parseInt( testimonialID, 10 ) ? 'next' : 'prev';

            if( $.UeldoGetDeviceType() != 'mobile' ) loop.css({ 'margin': '0 auto' });
            else {

                var activeElement = loop.find( '.ueldo-shortcode-full-width-testimonials-clients-images-single-client[data-active="yes"]' );
                var activeElementContainer = activeElement.parent();
                var marginLeft = '-'+ ( activeElementContainer.width() + parseInt( activeElementContainer.css( 'margin-left' ), 10 ) + parseInt( activeElementContainer.css( 'margin-right' ), 10 ) ) * ( testimonialID - 1 );

                if( refresh == true ) loop.css({ 'margin': ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? '0 '+ marginLeft +'px 0 0' : '0 0 0 '+ marginLeft +'px' ) });
                else loop.animate({ 'margin': ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? '0 '+ marginLeft +'px 0 0' : '0 0 0 '+ marginLeft +'px' ) }, animationSpeed );
            }

            var testimonialAuthor = testimonialAuthors.find( '.ueldo-shortcode-full-width-testimonials-single-testimonial-author[data-testimonial-id="'+ testimonialID +'"]' );
            testimonialAuthors.css({ 'height': testimonialAuthor.height() + parseInt( testimonialAuthor.css( 'margin-top' ), 10 ) + parseInt( testimonialAuthor.css( 'margin-bottom' ), 10 ) });

            if( refresh == false ) {

                if( animationType == 'next' ) oldTestimonialAuthor.addClass( 'animated ueldo-animated-fast ueldoFadeOut'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Right' : 'Left' ) +'Small' );
                else oldTestimonialAuthor.addClass( 'animated ueldo-animated-fast ueldoFadeOut'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Left' : 'Right' ) +'Small' );

                setTimeout( function() {

                    if( animationType == 'next' ) {

                        oldTestimonialAuthor.css({ 'display': 'none' }).removeClass( 'animated ueldo-animated-fast ueldoFadeOut'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Right' : 'Left' ) +'Small' );
                        newTestimonialAuthor.css({ 'display': 'block' }).addClass( 'animated ueldo-animated-fast ueldoFadeIn'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Left' : 'Right' ) +'Small' );
                    }

                    else {

                        oldTestimonialAuthor.css({ 'display': 'none' }).removeClass( 'animated ueldo-animated-fast ueldoFadeOut'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Left' : 'Right' ) +'Small' );
                        newTestimonialAuthor.css({ 'display': 'block' }).addClass( 'animated ueldo-animated-fast ueldoFadeIn'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Right' : 'Left' ) +'Small' );
                    }

                    setTimeout( function() {

                        if( animationType == 'next' ) newTestimonialAuthor.removeClass( 'animated ueldo-animated-fast ueldoFadeIn'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Left' : 'Right' ) +'Small' );
                        else newTestimonialAuthor.removeClass( 'animated ueldo-animated-fast ueldoFadeIn'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Right' : 'Left' ) +'Small' );

                        oldTestimonialAuthor.data( 'active', 'no' ).attr( 'data-active', 'no' );
                        newTestimonialAuthor.data( 'active', 'yes' ).attr( 'data-active', 'yes' );

                    }, animationClassSpeed );

                }, animationClassSpeed );
            }
        }

        if( refresh != false ) section.removeClass( 'ueldo-animation-proceed' );
        else {

            var oldContentElement = section.find( '.ueldo-shortcode-full-width-testimonials-single-testimonial-content[data-active="yes"]' );
            var newContentElement = section.find( '.ueldo-shortcode-full-width-testimonials-single-testimonial-content[data-testimonial-id="'+ testimonialID +'"]' );
            var animationType = parseInt( oldContentElement.data( 'testimonial-id' ), 10 ) < parseInt( testimonialID, 10 ) ? 'next' : 'prev';

            if( loopType == 'logos' ) section.find( '.ueldo-shortcode-full-width-testimonials-clients-logos-single-client[data-active="yes"]' ).data( 'active', 'no' ).attr( 'data-active', 'no' );
            else section.find( '.ueldo-shortcode-full-width-testimonials-clients-images-single-client[data-active="yes"]' ).data( 'active', 'no' ).attr( 'data-active', 'no' );

            selector.data( 'active', 'yes' ).attr( 'data-active', 'yes' );
            section.find( '.ueldo-shortcode-full-width-testimonials-single-testimonial-contents' ).animate({ 'height': newContentElement.height() }, { duration: animationSpeed, progress: function() { $( window ).trigger( 'ueldo-height-changed' ); } });

            if( animationType == 'next' ) oldContentElement.addClass( 'animated ueldo-animated-fast ueldoFadeOut'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Right' : 'Left' ) +'Small' );
            else oldContentElement.addClass( 'animated ueldo-animated-fast ueldoFadeOut'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Left' : 'Right' ) +'Small' );

            setTimeout( function() {

                if( animationType == 'next' ) {

                    oldContentElement.css({ 'display': 'none' }).removeClass( 'animated ueldo-animated-fast ueldoFadeOut'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Right' : 'Left' ) +'Small' );
                    newContentElement.css({ 'display': 'block' }).addClass( 'animated ueldo-animated-fast ueldoFadeIn'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Left' : 'Right' ) +'Small' );
                }

                else {

                    oldContentElement.css({ 'display': 'none' }).removeClass( 'animated ueldo-animated-fast ueldoFadeOut'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Left' : 'Right' ) +'Small' );
                    newContentElement.css({ 'display': 'block' }).addClass( 'animated ueldo-animated-fast ueldoFadeIn'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Right' : 'Left' ) +'Small' );
                }

                setTimeout( function() {

                    if( animationType == 'next' ) newContentElement.removeClass( 'animated ueldo-animated-fast ueldoFadeIn'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Left' : 'Right' ) +'Small' );
                    else newContentElement.removeClass( 'animated ueldo-animated-fast ueldoFadeIn'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'Right' : 'Left' ) +'Small' );

                    oldContentElement.data( 'active', 'no' ).attr( 'data-active', 'no' );
                    newContentElement.data( 'active', 'yes' ).attr( 'data-active', 'yes' );

                    section.removeClass( 'ueldo-animation-proceed' );

                }, animationClassSpeed );

            }, animationClassSpeed );
        }

        $( window ).trigger( 'ueldo-height-changed' );
    };

   /**
    *
    * change full-width testimonial after click on "next" icon
    *
    */

    $.UeldoMoveToNextFullWidthTestimonialsTestimonial = function( container ) {

        var loopType = container.data( 'loop-type' );
        var logosContainer = loopType == 'logos' ? container.find( '.ueldo-shortcode-full-width-testimonials-clients-logos' ) : container.find( '.ueldo-shortcode-full-width-testimonials-clients-images' );
        var activeElement = loopType == 'logos' ? container.find( '.ueldo-shortcode-full-width-testimonials-clients-logos-single-client[data-active="yes"]' ) : container.find( '.ueldo-shortcode-full-width-testimonials-clients-images-single-client[data-active="yes"]' ).parent();
        var nextElement = activeElement.next();

        if( nextElement.length == 1 ) $.UeldoChangeFullWidthTestimonialsTestimonial( ( loopType == 'logos' ? nextElement : nextElement.children( '.ueldo-shortcode-full-width-testimonials-clients-images-single-client' ) ), false );
        else {

            if( logosContainer.data( 'loop-first-after-last' ) == 'yes' ) {

                nextElement = activeElement.siblings( '*:not(.ueldo-shortcode-full-width-testimonials-clients-images-loop-middle-helper)' ).first();
                $.UeldoChangeFullWidthTestimonialsTestimonial( ( loopType == 'logos' ? nextElement : nextElement.children( '.ueldo-shortcode-full-width-testimonials-clients-images-single-client' ) ), false );
            }
        }

    };

   /**
    *
    * change full-width testimonial after click on "prev" icon
    *
    */

    $.UeldoMoveToPrevFullWidthTestimonialsTestimonial = function( container ) {

        var loopType = container.data( 'loop-type' );
        var logosContainer = loopType == 'logos' ? container.find( '.ueldo-shortcode-full-width-testimonials-clients-logos' ) : container.find( '.ueldo-shortcode-full-width-testimonials-clients-images' );
        var activeElement = loopType == 'logos' ? container.find( '.ueldo-shortcode-full-width-testimonials-clients-logos-single-client[data-active="yes"]' ) : container.find( '.ueldo-shortcode-full-width-testimonials-clients-images-single-client[data-active="yes"]' ).parent();
        var prevElement = activeElement.prev();

        if( prevElement.length == 1 && !prevElement.hasClass( 'ueldo-shortcode-full-width-testimonials-clients-images-loop-middle-helper' ) ) $.UeldoChangeFullWidthTestimonialsTestimonial( ( loopType == 'logos' ? prevElement : prevElement.children( '.ueldo-shortcode-full-width-testimonials-clients-images-single-client' ) ), false );
        else {

            if( logosContainer.data( 'loop-first-after-last' ) == 'yes' ) {

                prevElement = activeElement.siblings( '*:not(.ueldo-shortcode-full-width-testimonials-clients-images-loop-middle-helper)' ).last();
                $.UeldoChangeFullWidthTestimonialsTestimonial( ( loopType == 'logos' ? prevElement : prevElement.children( '.ueldo-shortcode-full-width-testimonials-clients-images-single-client' ) ), false );
            }
        }

    };

   /**
    *
    * change full-width testimonial after click on logo / image / next icon / prev icon
    *
    */

    $( 'body' ).on( 'click', '.ueldo-shortcode-full-width-testimonials-clients-logos .ueldo-shortcode-full-width-testimonials-clients-logos-single-client[data-active="no"]', function() { $.UeldoChangeFullWidthTestimonialsTestimonial( $( this ), false ); });
    $( 'body' ).on( 'click', '.ueldo-shortcode-full-width-testimonials-clients-images .ueldo-shortcode-full-width-testimonials-clients-images-single-client[data-active="no"]', function() { $.UeldoChangeFullWidthTestimonialsTestimonial( $( this ), false ); });
    $( 'body' ).on( 'click', '.ueldo-shortcode-full-width-testimonials .ueldo-shortcode-full-width-testimonials-next-prev-icon[data-next-prev-icon-type="next"]', function() { $.UeldoMoveToNextFullWidthTestimonialsTestimonial( $( this ).parents( '.ueldo-shortcode-full-width-testimonials' ) ); });
    $( 'body' ).on( 'click', '.ueldo-shortcode-full-width-testimonials .ueldo-shortcode-full-width-testimonials-next-prev-icon[data-next-prev-icon-type="prev"]', function() { $.UeldoMoveToPrevFullWidthTestimonialsTestimonial( $( this ).parents( '.ueldo-shortcode-full-width-testimonials' ) ); });

   /**
    *
    * touchswipe event in full-width testimonials
    *
    */

    $( '.ueldo-shortcode-full-width-testimonials' ).swipe({

        threshold: 20,
        swipe: function( event, direction, distance, duration, fingerCount, fingerData ) {

            var container = $( event.target ).hasClass( 'ueldo-shortcode-full-width-testimonials' ) ? $( event.target ) : $( event.target ).parents( '.ueldo-shortcode-full-width-testimonials' );

            if( direction == ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'left' : 'right' ) ) $.UeldoMoveToPrevFullWidthTestimonialsTestimonial( container );
            else if( direction == ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ) ) $.UeldoMoveToNextFullWidthTestimonialsTestimonial( container );
        }

    });

   /**
    *
    * add "data-animation-enabled" attribute for separated next/prev icons
    *
    */

    $.UeldoSetAnimationEnabledAttributeForSeparatedNextPrevIcons = function() {

        $( 'body' ).find( '.ueldo-shortcode-loop-separate-next-prev-icons' ).each( function() {

            var icons = $( this );
            var loopID = icons.data( 'loop-id' );

            var container = $( 'body' ).find( '.ueldo_vc_element_'+ loopID );
            if( container.length !== 0 ) {

                var animationEnabled = container.data( 'separated-next-prev-icons-animation-enabled' );
                icons.find( '.ueldo-shortcode-loop-next-prev-icon' ).data( 'animation-enabled', animationEnabled ).attr( 'data-animation-enabled', animationEnabled );
            }

        });

        $( 'body' ).find( '.ueldo-shortcode-timeline-separate-next-prev-icons' ).each( function() {

            var icons = $( this );
            var timelineID = icons.data( 'timeline-id' );

            var container = $( 'body' ).find( '.ueldo_vc_element_'+ timelineID );
            if( container.length !== 0 ) {

                var animationEnabled = container.data( 'next-prev-icons-animation-enabled' );
                icons.find( '.ueldo-shortcode-timeline-next-prev-icon' ).data( 'animation-enabled', animationEnabled ).attr( 'data-animation-enabled', animationEnabled );
            }

        });

    };

   /**
    *
    * animation for next/prev icons
    *
    */

    $( 'body' ).on( 'mouseenter', '.ueldo-shortcode-full-width-testimonials-next-prev-icon[data-animation-enabled="yes"], .ueldo-shortcode-loop-next-prev-icon[data-animation-enabled="yes"], .ueldo-shortcode-timeline-next-prev-icon[data-animation-enabled="yes"], .ueldo-shortcode-presentation-elements-switcher-prev-images[data-animation-enabled="yes"], .ueldo-shortcode-presentation-elements-switcher-next-images[data-animation-enabled="yes"]', function() {

        var element = $( this );
        var icon = element.find( 'i' );

        if( element.hasClass( 'ueldo-animation-proceed' ) ) return;
        element.addClass( 'ueldo-animation-proceed' );

        if( icon.hasClass( 'fa-long-arrow-left' ) ) icon.addClass( 'animated ueldo-animated-fast ueldoFadeOutLeftSuperSmall' );
        else if( icon.hasClass( 'fa-long-arrow-right' ) ) icon.addClass( 'animated ueldo-animated-fast ueldoFadeOutRightSuperSmall' );
        else if( icon.hasClass( 'fa-long-arrow-up' ) ) icon.addClass( 'animated ueldo-animated-fast ueldoFadeOutUpSuperSmall' );
        else if( icon.hasClass( 'fa-long-arrow-down' ) ) icon.addClass( 'animated ueldo-animated-fast ueldoFadeOutDownSuperSmall' );

        setTimeout( function() {

            if( icon.hasClass( 'fa-long-arrow-left' ) ) {

                icon.removeClass( 'ueldoFadeOutLeftSuperSmall' );
                icon.addClass( 'ueldoFadeInRightSuperSmall' );
            }

            else if( icon.hasClass( 'fa-long-arrow-right' ) ) {

                icon.removeClass( 'ueldoFadeOutRightSuperSmall' );
                icon.addClass( 'ueldoFadeInLeftSuperSmall' );
            }

            else if( icon.hasClass( 'fa-long-arrow-up' ) ) {

                icon.removeClass( 'ueldoFadeOutUpSuperSmall' );
                icon.addClass( 'ueldoFadeInUpSuperSmall' );
            }

            else if( icon.hasClass( 'fa-long-arrow-down' ) ) {

                icon.removeClass( 'ueldoFadeOutDownSuperSmall' );
                icon.addClass( 'ueldoFadeInDownSuperSmall' );
            }

            setTimeout( function() {

                if( icon.hasClass( 'fa-long-arrow-left' ) ) icon.removeClass( 'animated ueldo-animated-fast ueldoFadeInRightSuperSmall' );
                else if( icon.hasClass( 'fa-long-arrow-right' ) ) icon.removeClass( 'animated ueldo-animated-fast ueldoFadeInLeftSuperSmall' );
                else if( icon.hasClass( 'fa-long-arrow-up' ) ) icon.removeClass( 'animated ueldo-animated-fast ueldoFadeInUpSuperSmall' );
                else if( icon.hasClass( 'fa-long-arrow-down' ) ) icon.removeClass( 'animated ueldo-animated-fast ueldoFadeInDownSuperSmall' );

                element.removeClass( 'ueldo-animation-proceed' );

            }, 200 );

        }, 200 );

    });

   /**
    *
    * configure loops
    *
    */

    $.UeldoConfigureLoops = function( repeat ) {

        $( '.ueldo-shortcode-loop' ).each( function() {

            var container = $( this );
            container.addClass( 'ueldo-animation-proceed' );

            var loop = container.find( '.ueldo-shortcode-loop-container-inner' );
            var visibleRowGroupID = loop.data( 'row-group-visible-id' );
            var rowGroups = loop.find( '.ueldo-shortcode-loop-row-group' );
            var rowGroupWidth = parseInt( loop.parents( '.ueldo-shortcode-loop' ).css( 'width' ), 10 );
            var rowGroupsCounter = rowGroups.length;
            var innerWidth = rowGroupsCounter * rowGroupWidth;

            rowGroups.css({ 'width': rowGroupWidth });

            loop.css({ 'width': innerWidth });
            loop.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ), '-'+ ( ( visibleRowGroupID - 1 ) * rowGroupWidth ) +'px' );

            setTimeout( function() {

                loop.parents( '.ueldo-shortcode-loop-container' ).css({ 'height': parseInt( loop.find( '.ueldo-shortcode-loop-row-group[data-loop-row-group-id="'+ visibleRowGroupID +'"]' ).css( 'height' ), 10 ) });

            }, 300 );

            container.removeClass( 'ueldo-animation-proceed' );
            if( container.data( 'autochange-enabled' ) == 'yes' ) $.UeldoLoopAutoChange( container );

        });

        if( repeat == true ) setTimeout( function() { $.UeldoConfigureLoops( false ); }, 150 );
        $( window ).trigger( 'ueldo-height-changed' );
    };

   /**
    *
    * animate loop (next/prev)
    *
    */

    $.UeldoAnimateLoop = function( loop, type ) {

        if( loop.hasClass( 'ueldo-animation-proceed' ) ) return;
        loop.addClass( 'ueldo-animation-proceed' );

        var loopInner = loop.find( '.ueldo-shortcode-loop-container-inner' );
        var currentLoopVisibleGroupID = parseInt( loopInner.data( 'row-group-visible-id' ), 10 );
        var loopGroupsCount = loopInner.find( '.ueldo-shortcode-loop-row-group' ).length;
        var rowGroupWidth = parseInt( loop.css( 'width' ), 10 );
        var animationSpeed = 300;
        var newLoopGroupID;

        switch( type ) {

            case 'next':

                if( currentLoopVisibleGroupID == loopGroupsCount ) newLoopGroupID = 1;
                else newLoopGroupID = currentLoopVisibleGroupID + 1;

            break;

            case 'prev':

                if( currentLoopVisibleGroupID === 1 ) newLoopGroupID = loopGroupsCount;
                else newLoopGroupID = currentLoopVisibleGroupID - 1;

            break;
        }

        var css_style = {};
            css_style['margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' )] = '-'+ ( ( newLoopGroupID - 1 ) * rowGroupWidth ) +'px';

        loopInner.data( 'row-group-visible-id', newLoopGroupID ).attr( 'data-row-group-visible-id', newLoopGroupID );
        loopInner.animate( css_style, animationSpeed );

        setTimeout( function() {

            loopInner.parents( '.ueldo-shortcode-loop-container' ).animate({ 'height': parseInt( loopInner.find( '.ueldo-shortcode-loop-row-group[data-loop-row-group-id="'+ newLoopGroupID +'"]' ).css( 'height' ), 10 ) }, { duration: animationSpeed, progress: function() { $( window ).trigger( 'ueldo-height-changed' ); } });
            loop.removeClass( 'ueldo-animation-proceed' );

            if( loop.data( 'autochange-enabled' ) == 'yes' ) $.UeldoLoopAutoChange( loop );

        }, ( animationSpeed / 2 ) );

        $( window ).trigger( 'ueldo-height-changed' );
    };

   /**
    *
    * switch loop elements
    *
    */

    $( 'body' ).on( 'click', '.ueldo-shortcode-loop .ueldo-shortcode-loop-next-prev-icon[data-next-prev-icon-type="next"]', function() { $.UeldoAnimateLoop( $( this ).parents( '.ueldo-shortcode-loop' ), 'next' ); });
    $( 'body' ).on( 'click', '.ueldo-shortcode-loop .ueldo-shortcode-loop-next-prev-icon[data-next-prev-icon-type="prev"]', function() { $.UeldoAnimateLoop( $( this ).parents( '.ueldo-shortcode-loop' ), 'prev' ); });
    $( 'body' ).on( 'click', '.ueldo-shortcode-loop-separate-next-prev-icons .ueldo-shortcode-loop-next-prev-icon[data-next-prev-icon-type="next"]', function() { $.UeldoAnimateLoop( $( '.ueldo-shortcode-loop.ueldo_vc_element_'+ $( this ).parents( '.ueldo-shortcode-loop-separate-next-prev-icons' ).data( 'loop-id' ) ), 'next' ); });
    $( 'body' ).on( 'click', '.ueldo-shortcode-loop-separate-next-prev-icons .ueldo-shortcode-loop-next-prev-icon[data-next-prev-icon-type="prev"]', function() { $.UeldoAnimateLoop( $( '.ueldo-shortcode-loop.ueldo_vc_element_'+ $( this ).parents( '.ueldo-shortcode-loop-separate-next-prev-icons' ).data( 'loop-id' ) ), 'prev' ); });

   /**
    *
    * touchswipe event in loop elements
    *
    */

    $( '.ueldo-shortcode-loop' ).swipe({

        threshold: 20,
        swipe: function( event, direction, distance, duration, fingerCount, fingerData ) {

            var container = $( event.target ).hasClass( 'ueldo-shortcode-loop' ) ? $( event.target ) : $( event.target ).parents( '.ueldo-shortcode-loop' );

            if( direction == ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'left' : 'right' ) ) $.UeldoAnimateLoop( container, 'prev' );
            else if( direction == ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ) ) $.UeldoAnimateLoop( container, 'next' );
        }

    });

   /**
    *
    * auto-change for loops
    *
    */

    $.UeldoLoopAutoChange = function( shortcode ) {

        var shortcodeClass = shortcode.attr( 'class' );
        var interval = shortcode.data( 'autochange-interval' );
        var uniqueClass = shortcodeClass.substring( shortcodeClass.indexOf( 'ueldo_vc_element_' ), shortcodeClass.length ).trim();

        if( uniqueClass.indexOf( ' ' ) > 0 ) uniqueClass = uniqueClass.substring( 0, uniqueClass.indexOf( ' ' ) ).trim();
        if( typeof ueldoIntervals[uniqueClass] != 'undefined' ) clearInterval( ueldoIntervals[uniqueClass] );

        ueldoIntervals[uniqueClass] = setInterval( function() {

            var nextIcon = shortcode.find( '.ueldo-shortcode-loop-next-prev-icon[data-next-prev-icon-type="next"]' );
            if( nextIcon.length === 0 ) {

                var nextIconContainer = $( 'body' ).find( '.ueldo-shortcode-loop-separate-next-prev-icons[data-loop-id="'+ uniqueClass.replace( 'ueldo_vc_element_', '' ) +'"]' );
                if( nextIconContainer.length !== 0 ) nextIcon = nextIconContainer.find( '.ueldo-shortcode-loop-next-prev-icon[data-next-prev-icon-type="next"]' );
            }

            if( nextIcon.length !== 0 ) {

                nextIcon.trigger( 'click' );
            }

        }, interval );

    };

   /**
    *
    * get rounded progress bar levels
    *
    */

    $.UeldoGetRoundedProgressBarLevels = function() {

        var levels = {
            '0': { 'from': '90deg', 'to': '90deg' },
            '1': { 'from': '90deg', 'to': '93.6deg' },
            '2': { 'from': '90deg', 'to': '97.2deg' },
            '3': { 'from': '90deg', 'to': '100.8deg' },
            '4': { 'from': '90deg', 'to': '104.4deg' },
            '5': { 'from': '90deg', 'to': '108deg' },
            '6': { 'from': '90deg', 'to': '111.6deg' },
            '7': { 'from': '90deg', 'to': '115.2deg' },
            '8': { 'from': '90deg', 'to': '118.8deg' },
            '9': { 'from': '90deg', 'to': '122.4deg' },
            '10': { 'from': '90deg', 'to': '126deg' },
            '11': { 'from': '90deg', 'to': '129.6deg' },
            '12': { 'from': '90deg', 'to': '133.2deg' },
            '13': { 'from': '90deg', 'to': '136.8deg' },
            '14': { 'from': '90deg', 'to': '140.4deg' },
            '15': { 'from': '90deg', 'to': '144deg' },
            '16': { 'from': '90deg', 'to': '147.6deg' },
            '17': { 'from': '90deg', 'to': '151.2deg' },
            '18': { 'from': '90deg', 'to': '154.8deg' },
            '19': { 'from': '90deg', 'to': '158.4deg' },
            '20': { 'from': '90deg', 'to': '162deg' },
            '21': { 'from': '90deg', 'to': '165.6deg' },
            '22': { 'from': '90deg', 'to': '169.2deg' },
            '23': { 'from': '90deg', 'to': '172.8deg' },
            '24': { 'from': '90deg', 'to': '176.4deg' },
            '25': { 'from': '90deg', 'to': '180deg' },
            '26': { 'from': '90deg', 'to': '183.6deg' },
            '27': { 'from': '90deg', 'to': '187.2deg' },
            '28': { 'from': '90deg', 'to': '190.8deg' },
            '29': { 'from': '90deg', 'to': '194.4deg' },
            '30': { 'from': '90deg', 'to': '198deg' },
            '31': { 'from': '90deg', 'to': '201.6deg' },
            '32': { 'from': '90deg', 'to': '205.2deg' },
            '33': { 'from': '90deg', 'to': '208.8deg' },
            '34': { 'from': '90deg', 'to': '212.4deg' },
            '35': { 'from': '90deg', 'to': '216deg' },
            '36': { 'from': '90deg', 'to': '219.6deg' },
            '37': { 'from': '90deg', 'to': '223.2deg' },
            '38': { 'from': '90deg', 'to': '226.8deg' },
            '39': { 'from': '90deg', 'to': '230.4deg' },
            '40': { 'from': '90deg', 'to': '234deg' },
            '41': { 'from': '90deg', 'to': '237.6deg' },
            '42': { 'from': '90deg', 'to': '241.2deg' },
            '43': { 'from': '90deg', 'to': '244.8deg' },
            '44': { 'from': '90deg', 'to': '248.4deg' },
            '45': { 'from': '90deg', 'to': '252deg' },
            '46': { 'from': '90deg', 'to': '255.6deg' },
            '47': { 'from': '90deg', 'to': '259.2deg' },
            '48': { 'from': '90deg', 'to': '262.8deg' },
            '49': { 'from': '90deg', 'to': '266.4deg' },
            '50': { 'from': '-90deg', 'to': '270deg' },
            '51': { 'from': '-86.4deg', 'to': '270deg' },
            '52': { 'from': '-82.6deg', 'to': '270deg' },
            '53': { 'from': '-79.2deg', 'to': '270deg' },
            '54': { 'from': '-75.6deg', 'to': '270deg' },
            '55': { 'from': '-72deg', 'to': '270deg' },
            '56': { 'from': '-68.4deg', 'to': '270deg' },
            '57': { 'from': '-64.8deg', 'to': '270deg' },
            '58': { 'from': '-61.2deg', 'to': '270deg' },
            '59': { 'from': '-57.6deg', 'to': '270deg' },
            '60': { 'from': '-54deg', 'to': '270deg' },
            '61': { 'from': '-50.4deg', 'to': '270deg' },
            '62': { 'from': '-46.8deg', 'to': '270deg' },
            '63': { 'from': '-43.2deg', 'to': '270deg' },
            '64': { 'from': '-39.6deg', 'to': '270deg' },
            '65': { 'from': '-36deg', 'to': '270deg' },
            '66': { 'from': '-32.4deg', 'to': '270deg' },
            '67': { 'from': '-28.8deg', 'to': '270deg' },
            '68': { 'from': '-25.2deg', 'to': '270deg' },
            '69': { 'from': '-21.6deg', 'to': '270deg' },
            '70': { 'from': '-18deg', 'to': '270deg' },
            '71': { 'from': '-14.4deg', 'to': '270deg' },
            '72': { 'from': '-10.8deg', 'to': '270deg' },
            '73': { 'from': '-7.2deg', 'to': '270deg' },
            '74': { 'from': '-3.6deg', 'to': '270deg' },
            '75': { 'from': '0deg', 'to': '270deg' },
            '76': { 'from': '3.6deg', 'to': '270deg' },
            '77': { 'from': '7.2deg', 'to': '270deg' },
            '78': { 'from': '10.8deg', 'to': '270deg' },
            '79': { 'from': '14.4deg', 'to': '270deg' },
            '80': { 'from': '18deg', 'to': '270deg' },
            '81': { 'from': '21.6deg', 'to': '270deg' },
            '82': { 'from': '25.2deg', 'to': '270deg' },
            '83': { 'from': '28.8deg', 'to': '270deg' },
            '84': { 'from': '32.4deg', 'to': '270deg' },
            '85': { 'from': '36deg', 'to': '270deg' },
            '86': { 'from': '39.2deg', 'to': '270deg' },
            '87': { 'from': '43.2deg', 'to': '270deg' },
            '88': { 'from': '46.8deg', 'to': '270deg' },
            '89': { 'from': '50.4deg', 'to': '270deg' },
            '90': { 'from': '54deg', 'to': '270deg' },
            '91': { 'from': '57.6deg', 'to': '270deg' },
            '92': { 'from': '61.2deg', 'to': '270deg' },
            '93': { 'from': '64.8deg', 'to': '270deg' },
            '94': { 'from': '68.4deg', 'to': '270deg' },
            '95': { 'from': '72deg', 'to': '270deg' },
            '96': { 'from': '75.6deg', 'to': '270deg' },
            '97': { 'from': '79.2deg', 'to': '270deg' },
            '98': { 'from': '82.8deg', 'to': '270deg' },
            '99': { 'from': '86.4deg', 'to': '270deg' },
            '100': { 'from': '90deg', 'to': '270deg' }
        };

        return( levels );
    };

   /**
    *
    * configure rounded progress bars
    *
    */

    $.UeldoConfigureProgressBarsRounded = function() {

        var progressBarsRounded = $( '.ueldo-progress-bar-rounded' );
        if( progressBarsRounded.length > 0 ) {

            progressBarsRounded.each( function() {

                var progressBar = $( this );
                var visible = ( progressBar.offset().top + progressBar.height() ) >= $( window ).scrollTop() && progressBar.offset().top <= ( $( window ).scrollTop() + $( window ).height() );

                if( visible == true && !progressBar.hasClass( 'ueldo-animation-done' ) ) {

                    progressBar.addClass( 'ueldo-animation-done' );

                    var settings = {
                        'elementWidth': progressBar.width(),
                        'elementHeight': progressBar.height(),
                        'value': progressBar.data( 'progress-bar-value' ),
                        'color': progressBar.data( 'progress-bar-color' ),
                        'indicatorColor': progressBar.data( 'progress-bar-indicator-color' ),
                        'colorHover': progressBar.data( 'progress-bar-color-hover' ),
                        'indicatorColorHover': progressBar.data( 'progress-bar-indicator-color-hover' ),
                        'borderRadius': progressBar.data( 'progress-bar-border-radius' ),
                        'borderWidth': parseInt( progressBar.data( 'progress-bar-border-width' ), 10 ),
                        'duration': parseInt( progressBar.data( 'progress-bar-duration' ), 10 ),
                        'differentColorsOnHover': progressBar.data( 'progress-bar-color' ) != progressBar.data( 'progress-bar-color-hover' ) || progressBar.data( 'progress-bar-indicator-color' ) != progressBar.data( 'progress-bar-indicator-color-hover' )
                    };

                    progressBar.append( '<div class="ueldo-progress-bar-container"><div class="ueldo-progress-bar-rounded-line"></div><div class="ueldo-progress-bar-rounded-inner"></div></div>' );
                    progressBar.find( '.ueldo-progress-bar-rounded-inner' ).css({ 'background': settings.color });

                    if( settings.differentColorsOnHover == true ) {

                        progressBar.append( '<div class="ueldo-progress-bar-container-hover"><div class="ueldo-progress-bar-rounded-line-hover"></div><div class="ueldo-progress-bar-rounded-inner-hover"></div></div>' );
                        progressBar.find( '.ueldo-progress-bar-rounded-inner-hover' ).css({ 'background': settings.colorHover });
                    }

                    $.UeldoAnimateProgressBarRounded( progressBar, settings.value, settings, settings.duration );
                }

            });

            $( window ).trigger( 'ueldo-height-changed' );
        }
    };

   /**
    *
    * animate rounded progress bar
    *
    */

    $.UeldoAnimateProgressBarRounded = function( progressBar, progressBarMaxValue, settings, progressBarAnimationDuration ) {

        function ueldoAnimateProgressBarRoundedDoAnimation( animationLevel, levels, settings, speed ) {

            var animation = setInterval( function() {

                progressBar.find( '.ueldo-progress-bar-rounded-line' ).css({ 'background-image': 'linear-gradient( '+ levels[animationLevel].from +', '+ ( animationLevel < 50 ? settings.color : settings.indicatorColor ) +' 50%, transparent 50%, transparent ), linear-gradient( '+ levels[animationLevel].to +', '+ settings.indicatorColor +' 50%, '+ settings.color +' 50%, '+ settings.color +' )' });
                if( settings.differentColorsOnHover == true ) progressBar.find( '.ueldo-progress-bar-rounded-line-hover' ).css({ 'background-image': 'linear-gradient( '+ levels[animationLevel].from +', '+ ( animationLevel < 50 ? settings.colorHover : settings.indicatorColorHover ) +' 50%, transparent 50%, transparent ), linear-gradient( '+ levels[animationLevel].to +', '+ settings.indicatorColorHover +' 50%, '+ settings.colorHover +' 50%, '+ settings.colorHover +' )' });

                clearInterval( animation );

                if( animationLevel != progressBarMaxValue ) {

                    animationLevel += 1;
                    ueldoAnimateProgressBarRoundedDoAnimation( animationLevel, levels, settings, $.UeldoGetAnimatedProgressBarRoundedSpeed( animationLevel, progressBarMaxValue, progressBarAnimationDuration ) );
                }

            }, speed );

        };

        var animationLevel = 0;
        ueldoAnimateProgressBarRoundedDoAnimation( animationLevel, $.UeldoGetRoundedProgressBarLevels(), settings, $.UeldoGetAnimatedProgressBarRoundedSpeed( animationLevel, progressBarMaxValue, progressBarAnimationDuration ) );

    };

   /**
    *
    * get animation speed for rounded progress-bar
    *
    */

    $.UeldoGetAnimatedProgressBarRoundedSpeed = function( currentLevel, maxLevel, duration ) {

        var wat = 1290 * ( maxLevel / 100 );

        var speed = 0;
        var speedPerStep = Math.floor( duration / wat );
        var step = Math.floor( ( currentLevel / maxLevel ) * 100 );

        if( step <= 10 ) speed = speedPerStep * Math.floor( wat * 0.00465116 );
        else if( step > 10 && step <= 25 ) speed = speedPerStep * Math.floor( wat * 0.00697674 );
        else if( step > 25 && step <= 75 ) speed = speedPerStep * Math.floor( wat * 0.01395348 );
        else if( step > 75 && step <= 90 ) speed = speedPerStep * Math.floor( wat * 0.00697674 );
        else speed = speedPerStep * Math.floor( wat * 0.00465116 );

        return( speed );
    };

   /**
    *
    * content and sidebar divider line
    *
    */

    $.UeldoContentAndSidebarDividerLine = function() {

        $( '.vc_row.ueldo-row-with-sidebar-on-left, .vc_row.ueldo-row-with-sidebar-on-right' ).each( function() {

            var row = $( this );
            var content = row.find( '.vc_column_container.ueldo-row-with-sidebar-content-column' );
            var sidebar = row.find( '.vc_column_container.ueldo-row-with-sidebar-sidebar-column' );
            var dividerLine = row.find( '.ueldo-row-with-sidebar-divider-line' );

            if( content.length !== 0 && sidebar.length !== 0 && ( $.UeldoGetDeviceType() == 'desktop' || $.UeldoGetDeviceType() == 'tablet-horizontal' ) ) {

                var sidebarWidth = sidebar[0].getBoundingClientRect().width;
                var contentWidth = content[0].getBoundingClientRect().width;
                var sidebarPosition = row.hasClass( 'ueldo-row-with-sidebar-on-left' ) ? 'left' : 'right';
                var dividerPosition = sidebarPosition == 'left' ? ( sidebarWidth + 30 ) : ( contentWidth - 30 );

                if( dividerLine.length === 0 ) {

                    row.prepend( '<span class="ueldo-row-with-sidebar-divider-line"></span>' );
                    dividerLine = row.find( '.ueldo-row-with-sidebar-divider-line' );
                }

                dividerLine.css({ 'left': dividerPosition });
            }

            else {

                if( dividerLine.length !== 0 ) dividerLine.remove();
            }

        });
    };

   /**
    *
    * flying sidebar on visual composer page
    *
    */

    $.UeldoFlyingSidebarOnVCPage = function() {

        var content = $( '.ueldo-content-default' );
        var flyingSidebar = content.find( '.ueldo-sidebar-flying' );

        if( content.hasClass( 'ueldo-content-default-vc-page' ) && ueldo_javascript_functions_l10n.responsive_sidebar_style == 'flying' ) {

            if( $.UeldoGetDeviceType() == 'desktop' || $.UeldoGetDeviceType() == 'tablet-horizontal' ) {

                if( flyingSidebar.length !== 0 ) flyingSidebar.remove();
                content.find( '.ueldo-row-with-sidebar-sidebar-column' ).css({ 'display': '' });
            }

            else {

                if( flyingSidebar.length === 0 ) {

                    var html = '';
                    var sidebarPosition = false;

                    content.find( '.ueldo-row-with-sidebar-sidebar-column' ).each( function() {

                        var sidebar = $( this );
                        sidebar.css({ 'display': 'none' });

                        html = html + sidebar.html();
                        if( sidebarPosition == false ) sidebarPosition = sidebar.parents( '.vc_row' ).hasClass( 'ueldo-row-with-sidebar-on-left' ) ? 'left' : 'right';

                    });

                    if( html != '' ) content.prepend( '<div class="ueldo-sidebar-flying" data-flying-sidebar-side="'+ sidebarPosition +'">'+ html +'</div>' );
                }
            }
        }

    };

   /**
    *
    * configure accordion box
    *
    */

    $.UeldoConfigureAccordionBox = function() {

        $( '.ueldo-shortcode-accordion' ).each( function() {

            var accordionBox = $( this );
            var startWith = accordionBox.data( 'start-with' );

            if( startWith == 'first_opened' ) {

                accordionBox.find( '.ueldo-shortcode-accordion-single-element' ).first().removeClass( 'ueldo-shortcode-accordion-single-element-inactive' );
            }

        });

    };

   /**
    *
    * switch accordion box single element
    *
    */

    $( 'body' ).on( 'click', '.ueldo-shortcode-accordion-single-element .ueldo-shortcode-accordion-single-element-title', function() {

        var element = $( this ).parents( '.ueldo-shortcode-accordion-single-element' );
        var accordionBox = element.parents( '.ueldo-shortcode-accordion' );
        var animationType = accordionBox.data( 'animation-type' );

        if( accordionBox.hasClass( 'ueldo-animation-proceed' ) ) return;
        accordionBox.addClass( 'ueldo-animation-proceed' );

        if( animationType == 'one_per_time' ) {

            if( !element.hasClass( 'ueldo-shortcode-accordion-single-element-inactive' ) ) {

                accordionBox.removeClass( 'ueldo-animation-proceed' );
                return;
            }

            var currentActiveElement = accordionBox.find( '.ueldo-shortcode-accordion-single-element:not(.ueldo-shortcode-accordion-single-element-inactive)' );

            currentActiveElement.children( '.ueldo-shortcode-accordion-single-element-content' ).slideToggle({ duration: 200, progress: function() { $( window ).trigger( 'ueldo-height-changed' ); } });
            element.children( '.ueldo-shortcode-accordion-single-element-content' ).slideToggle({ duration: 200, progress: function() { $( window ).trigger( 'ueldo-height-changed' ); } });

            setTimeout( function() {

                currentActiveElement.addClass( 'ueldo-shortcode-accordion-single-element-inactive' );
                element.removeClass( 'ueldo-shortcode-accordion-single-element-inactive' );

                accordionBox.removeClass( 'ueldo-animation-proceed' );

            }, 200 );
        }

        else {

            if( element.hasClass( 'ueldo-shortcode-accordion-single-element-inactive' ) ) {

                element.children( '.ueldo-shortcode-accordion-single-element-content' ).slideToggle({ duration: 200, progress: function() { $( window ).trigger( 'ueldo-height-changed' ); } });
                setTimeout( function() {

                    element.removeClass( 'ueldo-shortcode-accordion-single-element-inactive' );
                    accordionBox.removeClass( 'ueldo-animation-proceed' );

                }, 200 );
            }

            else {

                element.children( '.ueldo-shortcode-accordion-single-element-content' ).slideToggle({ duration: 200, progress: function() { $( window ).trigger( 'ueldo-height-changed' ); } });
                setTimeout( function() {

                    element.addClass( 'ueldo-shortcode-accordion-single-element-inactive' );
                    accordionBox.removeClass( 'ueldo-animation-proceed' );

                }, 200 );
            }
        }

    });

   /**
    *
    * two images difference function
    *
    */

    $.fn.ueldoTwoImagesDifference = function() {

        return this.each( function() {

            var element = $( this );
            var options = {
                'orientation': element.data( 'orientation' ),
                'defaultOffset': parseInt( element.data( 'default-offset' ).replace( '%', '' ), 10 ) / 100,
                'beforeText': element.data( 'before-text' ),
                'afterText': element.data( 'after-text' )
            };

            var sliderPct = options.defaultOffset;
            var container = element.find( '.ueldo-shortcode-two-images-difference-container' );
            var sliderOrientation = options.orientation;
            var beforeDirection = ( sliderOrientation === 'vertical' ) ? 'down' : 'left';
            var afterDirection = ( sliderOrientation === 'vertical' ) ? 'up' : 'right';

            container.wrap( '<div class="ueldo-shortcode-two-images-difference-wrapper ueldo-shortcode-two-images-difference-'+ sliderOrientation +'"></div>' );
            container.append( '<div class="ueldo-shortcode-two-images-difference-overlay"></div>' );

            var beforeImg = container.find( 'img:first' );
            var afterImg = container.find( 'img:last' );

            container.append( '<div class="ueldo-shortcode-two-images-difference-handle"></div>' );
            var slider = container.find( '.ueldo-shortcode-two-images-difference-handle' );

            slider.append( '<span class="ueldo-shortcode-two-images-difference-'+ beforeDirection +'-arrow"></span>' );
            slider.append( '<span class="ueldo-shortcode-two-images-difference-'+ afterDirection +'-arrow"></span>' );

            beforeImg.addClass( 'ueldo-shortcode-two-images-difference-before' );
            afterImg.addClass( 'ueldo-shortcode-two-images-difference-after' );

            var overlay = container.find( '.ueldo-shortcode-two-images-difference-overlay' );

            overlay.append( '<div class="ueldo-shortcode-two-images-difference-before-label" data-content="'+ options.beforeText +'"></div>' );
            overlay.append( '<div class="ueldo-shortcode-two-images-difference-after-label" data-content="'+ options.afterText +'"></div>' );

            var calcOffset = function( dimensionPct ) {

                var w = beforeImg.width();
                var h = beforeImg.height();

                return {
                    w: w +'px',
                    h: h +'px',
                    cw: ( dimensionPct * w ) +'px',
                    ch: ( dimensionPct * h ) +'px'
                };
            };

            var adjustContainer = function( offset ) {

                if( sliderOrientation === 'vertical' ) beforeImg.css( 'clip', 'rect( 0, '+ offset.w +', '+ offset.ch +', 0 )' );
               	else beforeImg.css( 'clip', 'rect( 0, '+ offset.cw +', '+ offset.h +', 0 )' );

                container.css( 'height', offset.h );
            };

            var adjustSlider = function( pct ) {

                var offset = calcOffset( pct );

                slider.css( ( sliderOrientation === 'vertical' ) ? 'top' : 'left', ( sliderOrientation === 'vertical' ) ? offset.ch : offset.cw );
                adjustContainer( offset );
            }

            $( window ).on( 'resize.ueldoTwoImagesDifference', function( e ) { adjustSlider( sliderPct ); });

            var offsetX = 0;
            var offsetY = 0;
            var imgWidth = 0;
            var imgHeight = 0;

            slider.on( 'movestart', function( e ) {

                if( ( ( e.distX > e.distY && e.distX < -e.distY ) || ( e.distX < e.distY && e.distX > -e.distY ) ) && sliderOrientation !== 'vertical' ) e.preventDefault();
                else if( ( ( e.distX < e.distY && e.distX < -e.distY ) || ( e.distX > e.distY && e.distX > -e.distY ) ) && sliderOrientation === 'vertical' ) e.preventDefault();

                container.addClass( 'ueldo-animation-proceed' );

                offsetX = container.offset().left;
                offsetY = container.offset().top;
                imgWidth = beforeImg.width();
                imgHeight = beforeImg.height();

            });

            slider.on( 'moveend', function( e ) { container.removeClass( 'ueldo-animation-proceed' ); });
            slider.on( 'move', function( e ) {

                if( container.hasClass( 'ueldo-animation-proceed' ) ) {

                    sliderPct = ( sliderOrientation === 'vertical' ) ? ( e.pageY - offsetY ) / imgHeight : ( e.pageX - offsetX ) / imgWidth;

                    if( sliderPct < 0 ) sliderPct = 0;
                    if( sliderPct > 1 ) sliderPct = 1;

                    adjustSlider( sliderPct );
                }

            });

            container.find( 'img' ).on( 'mousedown', function( event ) { event.preventDefault(); });

            $( window ).trigger( 'resize.ueldoTwoImagesDifference' );
            $( window ).trigger( 'ueldo-height-changed' );

        });
    };

   /**
    *
    * configure progress bars
    *
    */

    $.UeldoConfigureProgressBars = function() {

        $( '.ueldo-shortcode-progress-bar' ).each( function() {

            var progressBar = $( this );
            var visible = ( progressBar.offset().top + progressBar.height() ) >= $( window ).scrollTop() && progressBar.offset().top <= ( $( window ).scrollTop() + $( window ).height() );

            if( visible == true && !progressBar.hasClass( 'ueldo-animation-done' ) ) {

                progressBar.addClass( 'ueldo-animation-done' );

                var progressBarLine = progressBar.find( '.ueldo-shortcode-progress-bar-line' );
                var progressBarLineValue = progressBarLine.find( '.ueldo-shortcode-progress-bar-line-value' );
                var progressBarValue = progressBar.find( '.ueldo-shortcode-progress-bar-value' );

                if( progressBarValue.hasClass( 'ueldo-shortcode-progress-bar-value-on-progress-bar-on-right-side-of-progress-line' ) ) progressBarValue.css({ 'width': progressBarLine.data( 'progress-bar-value' ) });
                progressBarLineValue.animate({ 'width': progressBarLine.data( 'progress-bar-value' ) }, { 'duration': progressBarLine.data( 'progress-bar-animation-duration' ), 'step': function( now, fx ) { progressBar.find( '.ueldo-shortcode-progress-bar-value' ).text( Math.floor( now ) +'%' ); }, 'complete': function() { progressBarLine.addClass( 'ueldo-shortcode-progress-bar-line-animation-done' ); } });
            }

        });
    };

   /**
    *
    * configure masonry loop
    *
    */

    $.UeldoConfigureMasonryLoop = function() {

        setTimeout( function() {

            $( '.ueldo-shortcode-loop .ueldo-shortcode-loop-row-group' ).each( function() {

                var container = $( this );
                var masonryModeEnabled = container.parents( '.ueldo-shortcode-loop' ).data( 'masonry-mode-enabled' );

                if( masonryModeEnabled == 'yes' ) container.masonry({ itemSelector: '.ueldo-shortcode-loop-row-group-single-row-single-cell', gutter: 0, columnWidth: '.ueldo-shortcode-loop-row-group-single-row-single-cell:not(.ueldo-shortcode-loop-row-group-single-row-single-cell-double-width)', percentPosition: true });

            });

            $( '.ueldo-shortcode-filtered-masonry .ueldo-shortcode-filtered-masonry-container' ).each( function() {

                var container = $( this );
                var masonryModeEnabled = container.parents( '.ueldo-shortcode-filtered-masonry' ).data( 'masonry-mode-enabled' );

                if( masonryModeEnabled == 'yes' ) {

                    ueldoIsotopes[ueldoNextIsotopeID] = container.isotope({
                        itemSelector: '.ueldo-shortcode-filtered-masonry-cell',
                        gutter: 0,
                        columnWidth: '.ueldo-shortcode-filtered-masonry-cell:not(.ueldo-shortcode-filtered-masonry-cell-double-width)',
                        percentPosition: true
                    });

                    container.find( '.ueldo-shortcode-image .ueldo-image-caption-icon-show' ).addClass( 'ueldo-isotope-element-visible' );
                    container.data( 'isotope-id', ueldoNextIsotopeID ).attr( 'data-isotope-id', ueldoNextIsotopeID );

                    ueldoNextIsotopeID += 1;
                }

            });

            $.UeldoConfigureImagesGalleries();

        }, 300 );
    };

   /**
    *
    * filter isotope elements on click
    *
    */

    $( 'body' ).on( 'click', '.ueldo-shortcode-filtered-masonry .ueldo-shortcode-filtered-masonry-filter-list li', function( event ) {

        event.preventDefault();

        var element = $( this );
        var isotopeContainer = element.parents( '.ueldo-shortcode-filtered-masonry' ).find( '.ueldo-shortcode-filtered-masonry-container' );
        var isotopeFilter = element.parents( '.ueldo-shortcode-filtered-masonry-filter-list' );
        var isotopeID = parseInt( isotopeContainer.data( 'isotope-id' ), 10 );
        var filterClass = element.data( 'filter-category' );

        isotopeFilter.find( 'li' ).removeClass( 'ueldo-shortcode-filtered-masonry-filter-active' );
        element.addClass( 'ueldo-shortcode-filtered-masonry-filter-active' );

        ueldoIsotopes[isotopeID].isotope({ filter: ( filterClass == '*' ? '*' : '.'+ filterClass ) });
        isotopeContainer.find( '.ueldo-shortcode-image .ueldo-image-caption-icon-show' ).removeClass( 'ueldo-isotope-element-visible' );

        var filteredElements = isotopeContainer.data( 'isotope' ).filteredItems;
        for( var i = 0; i < filteredElements.length; i++ ) {

            var filteredElement = $( filteredElements[i].element ).find( '.ueldo-shortcode-image .ueldo-image-caption-icon-show' );
            filteredElement.addClass( 'ueldo-isotope-element-visible' );

            $.UeldoConfigureImagesGalleries();
        };

    });

   /**
    *
    * configure masonry selector
    *
    */

    $.UeldoConfigureMasonrySelector = function() {

        $( '.ueldo-shortcode-filtered-masonry-filter-list' ).each( function() {

            var minTabWidth = 150;
            var maxPerRow = 5;
            var tabsSelector = $( this );
            var tabsSelectorWidth = tabsSelector.width() + parseInt( tabsSelector.css( 'border-left-width' ), 10 ) + parseInt( tabsSelector.css( 'border-right-width' ), 10 );
            var tabsCount = tabsSelector.children( 'li' ).length;

            if( tabsCount.length < 2 ) return;
            var tabsSelectorContainer = tabsSelector.parents( '.ueldo-shortcode-filtered-masonry-filter-list-container' );

            if( tabsSelectorWidth < tabsSelectorContainer.width() ) tabsSelector.removeClass( 'ueldo-shortcode-filtered-masonry-filter-list-as-table' ).data( 'tabs-per-row', '' ).removeAttr( 'data-tabs-per-row' );
            else {

                tabsSelector.addClass( 'ueldo-shortcode-filtered-masonry-filter-list-as-table' );
                for( var i = maxPerRow; i > 0; i-- ) {

                    if( ( tabsSelectorWidth / i ) >= minTabWidth ) {

                        tabsSelector.data( 'tabs-per-row', i ).attr( 'data-tabs-per-row', i );
                        break;
                    }
                }
            }
        });
    };

   /**
    *
    * all filtered masonry selectors with the same height
    *
    */

    $.UeldoAllFilteredMasonrySelectorsWithTheSameHeight = function() {

        $( '.ueldo-shortcode-filtered-masonry' ).each( function() {

            var tabsContainer = $( this );
            var tabsSelector = tabsContainer.find( '.ueldo-shortcode-filtered-masonry-filter-list' );

            if( tabsSelector.length == 0 ) return;
            tabsSelector.find( 'li .ueldo-shortcode-filtered-masonry-filter-middle-helper' ).remove();

            var maxHeight = 0;
            var isDifferentHeight = false;

            tabsSelector.find( 'li' ).each( function() {

                var element = $( this );
                var elementHeight = element.height();

                if( elementHeight != maxHeight ) {

                    if( maxHeight > 0 ) isDifferentHeight = true;
                    maxHeight = elementHeight > maxHeight ? elementHeight : maxHeight;
                }

            });

            if( isDifferentHeight == true ) {

                var middleHelpers = tabsSelector.find( 'li .ueldo-shortcode-filtered-masonry-filter-middle-helper' );
                if( middleHelpers.length == 0 ) tabsSelector.find( 'li' ).prepend( '<span class="ueldo-shortcode-filtered-masonry-filter-middle-helper"></span>' );

                tabsSelector.find( 'li .ueldo-shortcode-filtered-masonry-filter-middle-helper' ).css({ 'height': maxHeight });
            }

        });

        $( window ).trigger( 'ueldo-height-changed' );
    };

   /**
    *
    * get header bar height
    *
    */

    $.UeldoGetHeaderBarHeight = function() {

        var result = 0;
        var header = $( 'body' ).find( 'header.ueldo-header-bar.ueldo-header-bar-main.ueldo-header-bar-position-flying' );
        var wpAdminBar = $( 'body' ).find( '#wpadminbar' );

        if( header.length != 0 ) result += header.height();
        else {

            var header = $( 'header.ueldo-header-bar.ueldo-header-bar-additional' );
            if( header.length != 0 ) result += header.height();
        }

        if( wpAdminBar.length != 0 ) result += wpAdminBar.height();
        return( result );
    };

   /**
    *
    * parallax class
    *
    */

    window.ueldoParallaxLayer = ( function() {

       /**
        *
        * images array
        *
        */

        var images;

       /**
        *
        * init function
        *
        */

        function init( classSelector ) {

            images = [].slice.call( document.querySelectorAll( classSelector ) );
            if( !images.length ) return;

            jQuery( window ).on( 'load', doParallax );
            jQuery( window ).on( 'scroll', doParallax );
            jQuery( window ).on( 'resize', doParallax );

            onElementHeightChange( document.body, doParallax );
            doParallax();
        }

       /**
        *
        * get viewport height
        *
        */

        function getViewportHeight() {

            var a = document.documentElement.clientHeight, b = window.innerHeight;
            return a < b ? b : a;
        }

       /**
        *
        * get viewport scroll position
        *
        */

        function getViewportScroll() {

            if( typeof window.scrollY != 'undefined' ) return window.scrollY;
            if( typeof pageYOffset != 'undefined' ) return pageYOffset;

            var doc = document.documentElement;
            doc = doc.clientHeight ? doc : document.body;

            return doc.scrollTop;
        }

       /**
        *
        * get header bar height
        *
        */

        function getHeaderHeight() {

            return( $.UeldoGetHeaderBarHeight() );
        }

       /**
        *
        * do an action if element height is changed
        *
        */

        function onElementHeightChange( elm, callback ) {

            var lastHeight = elm.clientHeight, newHeight;
            ( function run() {

                newHeight = elm.clientHeight;

                if( lastHeight != newHeight ) callback();
                lastHeight = newHeight;

                if( elm.onElementHeightChangeTimer ) clearTimeout( elm.onElementHeightChangeTimer );
                elm.onElementHeightChangeTimer = setTimeout( run, 200 );

            })();
        }

       /**
        *
        * main function - parallax for images
        *
        */

        function doParallax() {

            var offset = getViewportScroll();
            var vHeight = getViewportHeight();
            var headerHeight = getHeaderHeight();

            for( var i in images ) {

                var image = jQuery( images[i] );
                var imageParent = image.parent();
                var layerFor = imageParent.data( 'layer-for' ) == 'row' ? '.vc_row' : '.vc_section';
                var parentHeight = imageParent.height();
                var parentOffset = imageParent.offset().top;
                var visibleFrom = parentOffset - vHeight;
                var visibleTo = parentOffset + parentHeight - headerHeight;

                if( offset < visibleFrom || offset >= visibleTo ) continue;
                else {

                    var percent = ( offset - visibleFrom ) / ( visibleTo - visibleFrom ) * 100;
                    var imageSizeRatio = parseInt( image.data( 'parallax-original-height' ), 10 ) / parseInt( image.data( 'parallax-original-width' ), 10 );
                    var maxImagePos = Math.floor( image.parents( layerFor ).width() * imageSizeRatio ) - image.height();
                    var newImagePos = 0;

                    var from = - Math.floor( maxImagePos * ( parseInt( image.data( 'parallax-initial-vertical-position' ), 10 ) / 100 ) );
                    var to = Math.floor( from + ( maxImagePos * ( parseInt( image.data( 'parallax-speed' ), 10 ) / 100 ) ) );
                    if( to > maxImagePos ) to = maxImagePos;

                    newImagePos = from - ( ( to / 100 ) * percent );
                    image.css({ 'backgroundPosition': '50% '+ newImagePos +'px' });
                }
            }
        }

       /**
        *
        * self initialize
        *
        */

        return { init: init }

       /**
        *
        * end of class
        *
        */

    })();

   /**
    *
    * is datepicker field style set to theme defaults?
    *
    */

    $.UeldoConfigureDatepickerFieldStyle = function() {

        var uiThemeCss = $( document ).find( '#jquery-ui-theme-css' );
        var gravityFormsDatepickerCss = $( document ).find( '#gforms_datepicker_css-css' );

        if( uiThemeCss.length == 1 && gravityFormsDatepickerCss.length == 0 ) {

            var cssHref = uiThemeCss.attr( 'href' );
            if( cssHref.indexOf( '_assets/_css/datepicker-theme.css' ) !== -1 ) {

                var datepicker = $( 'body' ).find( '#ui-datepicker-div' );
                if( datepicker.length !== 0 ) {

                    datepicker.addClass( 'ueldo-custom-datepicker-theme' );
                }
            }
        }

    };

   /**
    *
    * configure inline fields sizes
    *
    */

    $.UeldoConfigureInlineFieldsSizes = function( is_repeated ) {

        $( '.ueldo-fields-inline' ).each( function() {

            var container = $( this );
            var containerWidth = container[0].getBoundingClientRect().width;
            var button = container.find( 'input[type="submit"]' );

            if( button.length == 0 ) button = container.find( '.ueldo-button' );

            container.find( 'input[type="text"], input[type="email"], input[type="password"], input[type="url"], input[type="tel"], input[type="number"], input[type="date"]' ).each( function() {

                var field = $( this );
                if( field.parent().hasClass( 'wpcf7-form-control-wrap' ) ) field = field.parent();

                field.addClass( 'ueldo-fields-inline-temp-field-container' );

            });

            var fields = container.find( '.ueldo-fields-inline-temp-field-container' );
            container.find( '*' ).removeClass( 'ueldo-fields-inline-temp-field-container' );

            if( button.length == 1 ) {

                var buttonWidth = button[0].getBoundingClientRect().width;
                var singleFieldWidth = ( ( containerWidth - buttonWidth ) / fields.length ) - 10;

                if( singleFieldWidth >= 150 ) fields.css({ 'width': singleFieldWidth, 'display': 'inline-block', 'vertical-align': 'top', 'margin': ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? '0 0 0 10px' : '0 10px 0 0' ) });
                else {

                    fields.css({ 'width': '', 'margin': '0 0 10px 0', 'display': 'block' });
                }
            }

            else {

                var singleFieldWidth = ( containerWidth / fields.length ) - ( ( ( fields.length - 1 ) * 10 ) / fields.length );

                if( singleFieldWidth >= 150 ) {

                    fields.css({ 'width': singleFieldWidth, 'display': 'inline-block', 'vertical-align': 'top', 'margin': '0 10px 0 0' });
                    fields.last().css({ 'margin': '0' });
                }

                else {

                    fields.css({ 'width': '', 'margin': '0 0 10px 0', 'display': 'block' });
                }
            }

        });

        if( is_repeated == false ) {

            setTimeout( function() {

                $.UeldoConfigureInlineFieldsSizes( true );

            }, 100 );
        }

        $( window ).trigger( 'ueldo-height-changed' );
    };

   /**
    *
    * configure woocommerce tabs box clear line
    *
    */

    $.UeldoConfigureWooCommerceTabsBoxClearLine = function() {

        $( '.woocommerce div.product .woocommerce-tabs' ).each( function() {

            var tabs = $( this );
            tabs.prepend( '<div class="ueldo-woocommerce-tabs-clear-line"></div>' );

            tabs.children( '.panel.wc-tab' ).each( function() {

                var panel = $( this );
                panel.wrapInner( '<div class="ueldo-woocommerce-tabs-panel-inner"></div>' );

            });

        });
    };

   /**
    *
    * configure tabs box
    *
    */

    $.UeldoConfigureTabsBox = function() {

        $( '.ueldo-shortcode-tabs-box' ).each( function() {

            var tabsBox = $( this );

            tabsBox.find( 'ul.ueldo-shortcode-tabs-box-tabs-selector li[data-tab-id="1"]' ).addClass( 'ueldo-shortcode-tabs-box-active-tab' );
            tabsBox.find( '.ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab[data-tab-id="1"]' ).addClass( 'ueldo-shortcode-tabs-box-active-tab' );

            var clearLine = tabsBox.find( '.ueldo-shortcode-tabs-box-tabs-contents-clear-line' );
            var tabsSelectorHeight = tabsBox.find( '.ueldo-shortcode-tabs-box-tabs-selector' )[0].getBoundingClientRect().height;
            var borderWidth = parseInt( tabsBox.find( '.ueldo-shortcode-tabs-box-tabs-contents' ).css( 'border-width' ), 10 );

            clearLine.css({ 'top': tabsSelectorHeight, 'height': 'calc( 100% - '+ ( tabsSelectorHeight + borderWidth ) +'px )' });

        });

        $( window ).trigger( 'ueldo-height-changed' );
        $.UeldoConfigureAdditionalSidebarBackgroundSizes();
    };

   /**
    *
    * re-configure "clear line" for tabs box
    *
    */

    $.UeldoReConfigureTabsBoxClearLine = function() {

        $( '.ueldo-shortcode-tabs-box' ).each( function() {

            var tabsBox = $( this );
            var clearLine = tabsBox.find( '.ueldo-shortcode-tabs-box-tabs-contents-clear-line' );
            var tabsSelectorHeight = tabsBox.find( '.ueldo-shortcode-tabs-box-tabs-selector' )[0].getBoundingClientRect().height;
            var borderWidth = parseInt( tabsBox.find( '.ueldo-shortcode-tabs-box-tabs-contents' ).css( 'border-width' ), 10 );

            clearLine.css({ 'top': tabsSelectorHeight, 'height': 'calc( 100% - '+ ( tabsSelectorHeight + borderWidth ) +'px )' });

        });
    };

   /**
    *
    * switch single tab in tabs box (in default mode)
    *
    */

    $( 'body' ).on( 'click touchstart', '.ueldo-shortcode-tabs-box ul.ueldo-shortcode-tabs-box-tabs-selector li:not(.ueldo-shortcode-tabs-box-active-tab)', function( event ) {

        event.preventDefault();

        var selector = $( this );
        var tabsBox = selector.parents( '.ueldo-shortcode-tabs-box' );
        var newTabId = selector.data( 'tab-id' );

        tabsBox.find( 'ul.ueldo-shortcode-tabs-box-tabs-selector li' ).removeClass( 'ueldo-shortcode-tabs-box-active-tab' );
        selector.addClass( 'ueldo-shortcode-tabs-box-active-tab' );

        tabsBox.find( '.ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab' ).removeClass( 'ueldo-shortcode-tabs-box-active-tab' );
        tabsBox.find( '.ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab[data-tab-id="'+ newTabId +'"]' ).addClass( 'ueldo-shortcode-tabs-box-active-tab' );

        if( tabsBox.parents( '.ueldo-shortcode-tabs' ).length != 0 ) $.UeldoReConfigureShortcodeTabs();

        $( window ).trigger( 'ueldo-height-changed' );
        $.UeldoConfigureAdditionalSidebarBackgroundSizes();

    });

   /**
    *
    * switch single tab in tabs box (in accordion mode)
    *
    */

    $( 'body' ).on( 'click touchstart', '.ueldo-shortcode-tabs-box .ueldo-shortcode-tabs-box-single-tab:not(.ueldo-shortcode-tabs-box-active-tab) .ueldo-shortcode-tabs-box-single-tab-title', function( event ) {

        event.preventDefault();

        var selector = $( this );
        var tabsBox = selector.parents( '.ueldo-shortcode-tabs-box' );
        var newTabId = selector.parents( '.ueldo-shortcode-tabs-box-single-tab' ).data( 'tab-id' );

        tabsBox.find( 'ul.ueldo-shortcode-tabs-box-tabs-selector li' ).removeClass( 'ueldo-shortcode-tabs-box-active-tab' );
        tabsBox.find( 'ul.ueldo-shortcode-tabs-box-tabs-selector li[data-tab-id="'+ newTabId +'"]' ).addClass( 'ueldo-shortcode-tabs-box-active-tab' );

        tabsBox.find( '.ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab.ueldo-shortcode-tabs-box-active-tab .ueldo-shortcode-tabs-box-single-tab-content, .ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab[data-tab-id="'+ newTabId +'"] .ueldo-shortcode-tabs-box-single-tab-content' ).slideToggle({ duration: 200, progress: function() { $( window ).trigger( 'ueldo-height-changed' ); } });
        setTimeout( function() {

            tabsBox.find( '.ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab' ).removeClass( 'ueldo-shortcode-tabs-box-active-tab' );
            tabsBox.find( '.ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab[data-tab-id="'+ newTabId +'"]' ).addClass( 'ueldo-shortcode-tabs-box-active-tab' );

            if( tabsBox.parents( '.ueldo-shortcode-tabs' ).length != 0 ) $.UeldoReConfigureShortcodeTabs();

            setTimeout( function() {

                tabsBox.find( '.ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab .ueldo-shortcode-tabs-box-single-tab-content' ).css({ 'display': '' });

            }, 100 );

        }, 200 );

        $( window ).trigger( 'ueldo-height-changed' );
        $.UeldoConfigureAdditionalSidebarBackgroundSizes();

    });

   /**
    *
    * configure timelines
    *
    */

    $.UeldoConfigureTimelines = function( container, animate ) {

        if( container != false ) $.UeldoConfigureTimeline( container, animate, false );
        else {

            $( '.ueldo-shortcode-timeline' ).each( function() {

                $.UeldoConfigureTimeline( $( this ), animate, false );

            });
        }

    };

   /**
    *
    * configure single timeline
    *
    */

    $.UeldoConfigureTimeline = function( container, animate, is_repeated ) {

        container.addClass( 'ueldo-animation-proceed' );

        var elementsPerScreen = container.data( 'elements-per-screen' );
        var elementsCount = container.find( '.ueldo-shortcode-timeline-element' ).length;
        var currentPosition = parseInt( container.data( 'current-position' ), 10 );
        var loopContainer = container.find( '.ueldo-shortcode-timeline-loop-container' );
        var loopContainerElements = container.find( '.ueldo-shortcode-timeline-loop-container-elements' );
        var elementID = currentPosition * elementsPerScreen;
        var animationSpeed = 300;

        if( container.hasClass( 'ueldo-shortcode-timeline-display-as-card' ) ) {

            var loopContainerHeight = 0;
            var loopContainerElementsMarginTop = 0;

            for( var i = elementID; i < ( elementID + elementsPerScreen ); i++ ) {

                if( $( container.find( '.ueldo-shortcode-timeline-element' )[i] ).length == 1 ) {

                    loopContainerHeight += container.find( '.ueldo-shortcode-timeline-element' )[i].getBoundingClientRect().height;
                }
            }

            if( currentPosition !== 0 ) {

                for( var i = 0; i < ( elementID ); i++ ) {

                    if( $( container.find( '.ueldo-shortcode-timeline-element' )[i] ).length == 1 ) {

                        loopContainerElementsMarginTop += container.find( '.ueldo-shortcode-timeline-element' )[i].getBoundingClientRect().height;
                    }
                }
            }

            if( animate == false ) {

                loopContainer.css({ 'height': loopContainerHeight +'px' });
                loopContainerElements.css({ 'margin-top': '-'+ loopContainerElementsMarginTop +'px' });
            }

            else {

                loopContainer.animate({ 'height': loopContainerHeight +'px' }, { duration: animationSpeed, progress: function() { $( window ).trigger( 'ueldo-height-changed' ); } });
                loopContainerElements.animate({ 'margin-top': '-'+ loopContainerElementsMarginTop +'px' }, { duration: animationSpeed, progress: function() { $( window ).trigger( 'ueldo-height-changed' ); } });
            }

            if( is_repeated == false ) {

                setTimeout( function() {

                    $.UeldoConfigureTimeline( container, animate, true );

                }, 100 );
            }
        }

        else {

            var loopContainerElementsHeight = parseInt( Math.ceil( parseFloat( loopContainerElements.css( 'padding-top' ) ) ), 10 );
            var loopContainerElementsMarginLeft = 0;
            var loopContainerElementsMarginTop = 0;
            var loopContainerElementsWidth = 0;

            if( $.UeldoGetDeviceType() == 'mobile' ) {

                loopContainerElementsWidth = ueldoPageWidth - 30;

                if( animate == false ) { loopContainerElements.css({ 'width': loopContainerElementsWidth +'px' }); }

                var currentElementID = 0;
                var elementsArray = [];

                container.find( '.ueldo-shortcode-timeline-element' ).each( function() {

                    var element = $( this );

                    elementsArray[currentElementID] = { 'height': element[0].getBoundingClientRect().height };
                    currentElementID += 1;

                });

                for( var i = elementID; i < ( elementID + elementsPerScreen ); i++ ) { loopContainerElementsHeight += elementsArray[i].height; }

                if( currentPosition !== 0 ) {

                    loopContainerElementsHeight -= parseInt( container.find( '.ueldo-shortcode-timeline-element:last-child' ).css( 'padding-top' ), 10 );
                    loopContainerElementsMarginTop += parseInt( container.find( '.ueldo-shortcode-timeline-element:last-child' ).css( 'padding-top' ), 10 );

                    for( var i = 0; i < ( elementID ); i++ ) { loopContainerElementsMarginTop += elementsArray[i].height; }
                }

                if( animate == false ) {

                    loopContainer.css({ 'height': loopContainerElementsHeight +'px' });

                    loopContainerElements.css({ 'margin-top': '-'+ loopContainerElementsMarginTop +'px', 'height': '' });
                    loopContainerElements.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ), '' );
                }

                else {

                    loopContainerElements.css({ 'height': '' });
                    loopContainerElements.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ), '' );

                    loopContainer.animate({ 'height': loopContainerElementsHeight +'px' }, { duration: animationSpeed, progress: function() { $( window ).trigger( 'ueldo-height-changed' ); } });
                    loopContainerElements.animate({ 'width': loopContainerElementsWidth +'px', 'margin-top': '-'+ loopContainerElementsMarginTop +'px' }, { duration: animationSpeed, progress: function() { $( window ).trigger( 'ueldo-height-changed' ); } });
                }
            }

            else {

                container.find( '.ueldo-shortcode-timeline-element' ).each( function() {

                    loopContainerElementsWidth += $( this )[0].getBoundingClientRect().width;

                });

                if( animate == false ) { loopContainerElements.css({ 'width': loopContainerElementsWidth +'px' }); }

                for( var i = elementID; i < ( elementID + elementsPerScreen ); i++ ) {

                    if( $( container.find( '.ueldo-shortcode-timeline-element' )[i] ).length == 1 ) {

                        var elementHeight = container.find( '.ueldo-shortcode-timeline-element' )[i].getBoundingClientRect().height;
                        if( elementHeight > loopContainerElementsHeight ) loopContainerElementsHeight = elementHeight;
                    }
                }

                loopContainerElementsHeight += parseInt( Math.ceil( parseFloat( loopContainerElements.css( 'padding-top' ) ) ), 10 );
                if( currentPosition !== 0 ) {

                    for( var i = 0; i < ( elementID ); i++ ) {

                        if( $( container.find( '.ueldo-shortcode-timeline-element' )[i] ).length == 1 ) {

                            loopContainerElementsMarginLeft += container.find( '.ueldo-shortcode-timeline-element' )[i].getBoundingClientRect().width;
                        }
                    }
                }

                if( animate == false ) {

                    loopContainer.css({ 'height': '' });

                    loopContainerElements.css({ 'margin-top': '', 'height': loopContainerElementsHeight });
                    loopContainerElements.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ), '-'+ loopContainerElementsMarginLeft +'px' );
                }

                else {

                    loopContainer.css({ 'height': '' });
                    loopContainerElements.css({ 'margin-top': '' }, animationSpeed );

                    var css_styles = {};

                    css_styles['width'] = loopContainerElementsWidth +'px';
                    css_styles['margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' )] = '-'+ loopContainerElementsMarginLeft +'px';
                    css_styles['height'] = loopContainerElementsHeight;

                    loopContainerElements.animate( css_styles, { duration: animationSpeed, progress: function() { $( window ).trigger( 'ueldo-height-changed' ); } });
                }
            }
        }

        container.removeClass( 'ueldo-animation-proceed' );
        if( container.data( 'autochange-enabled' ) == 'yes' ) $.UeldoTimelineAutoChange( container );

        $( window ).trigger( 'ueldo-height-changed' );
    };

   /**
    *
    * switch timeline (next / prev)
    *
    */

    $.UeldoSwitchTimeline = function( container, type ) {

        if( container.hasClass( 'ueldo-animation-proceed' ) ) return;
        container.addClass( 'ueldo-animation-proceed' );

        var elementsPerScreen = container.data( 'elements-per-screen' );
        var elementsCount = container.find( '.ueldo-shortcode-timeline-element' ).length;
        var currentPosition = parseInt( container.data( 'current-position' ), 10 );
        var maxPositionValue = Math.ceil( elementsCount / elementsPerScreen ) - 1;

        switch( type ) {

            case 'next':

                if( currentPosition == maxPositionValue ) currentPosition = 0;
                else currentPosition += 1;

            break;

            case 'prev':

                if( currentPosition == 0 ) currentPosition = maxPositionValue;
                else currentPosition -= 1;

            break;
        }

        container.data( 'current-position', currentPosition ).attr( 'data-current-position', currentPosition );
        $.UeldoConfigureTimeline( container, true, false );
    };

   /**
    *
    * switch timeline elements hooks
    *
    */

    $( 'body' ).on( 'click', '.ueldo-shortcode-timeline .ueldo-shortcode-timeline-next-prev-icon[data-next-prev-icon-type="next"]', function() { $.UeldoSwitchTimeline( $( this ).parents( '.ueldo-shortcode-timeline' ), 'next' ); });
    $( 'body' ).on( 'click', '.ueldo-shortcode-timeline .ueldo-shortcode-timeline-next-prev-icon[data-next-prev-icon-type="prev"]', function() { $.UeldoSwitchTimeline( $( this ).parents( '.ueldo-shortcode-timeline' ), 'prev' ); });
    $( 'body' ).on( 'click', '.ueldo-shortcode-timeline-separate-next-prev-icons .ueldo-shortcode-timeline-next-prev-icon[data-next-prev-icon-type="next"]', function() { $.UeldoSwitchTimeline( $( '.ueldo-shortcode-timeline.ueldo_vc_element_'+ $( this ).parents( '.ueldo-shortcode-timeline-separate-next-prev-icons' ).data( 'timeline-id' ) ), 'next' ); });
    $( 'body' ).on( 'click', '.ueldo-shortcode-timeline-separate-next-prev-icons .ueldo-shortcode-timeline-next-prev-icon[data-next-prev-icon-type="prev"]', function() { $.UeldoSwitchTimeline( $( '.ueldo-shortcode-timeline.ueldo_vc_element_'+ $( this ).parents( '.ueldo-shortcode-timeline-separate-next-prev-icons' ).data( 'timeline-id' ) ), 'prev' ); });

   /**
    *
    * touchswipe event in timeline elements
    *
    */

    $( '.ueldo-shortcode-timeline' ).swipe({

        threshold: 20,
        swipe: function( event, direction, distance, duration, fingerCount, fingerData ) {

            var container = $( event.target ).hasClass( 'ueldo-shortcode-timeline' ) ? $( event.target ) : $( event.target ).parents( '.ueldo-shortcode-timeline' );

            if( container.hasClass( 'ueldo-shortcode-timeline-display-as-card' ) ) {

                if( direction == 'down' ) $.UeldoSwitchTimeline( container, 'prev' );
                else if( direction == 'up' ) $.UeldoSwitchTimeline( container, 'next' );
            }

            else {

                if( direction == ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'left' : 'right' ) ) $.UeldoSwitchTimeline( container, 'prev' );
                else if( direction == ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ) ) $.UeldoSwitchTimeline( container, 'next' );
            }
        }

    });

   /**
    *
    * auto-change for timelines
    *
    */

    $.UeldoTimelineAutoChange = function( shortcode ) {

        var shortcodeClass = shortcode.attr( 'class' );
        var interval = shortcode.data( 'autochange-interval' );
        var uniqueClass = shortcodeClass.substring( shortcodeClass.indexOf( 'ueldo_vc_element_' ), shortcodeClass.length ).trim();

        if( uniqueClass.indexOf( ' ' ) > 0 ) uniqueClass = uniqueClass.substring( 0, uniqueClass.indexOf( ' ' ) ).trim();
        if( typeof ueldoIntervals[uniqueClass] != 'undefined' ) clearInterval( ueldoIntervals[uniqueClass] );

        ueldoIntervals[uniqueClass] = setInterval( function() {

            var nextIcon = shortcode.find( '.ueldo-shortcode-timeline-next-prev-icon[data-next-prev-icon-type="next"]' );
            if( nextIcon.length === 0 ) {

                var nextIconContainer = $( 'body' ).find( '.ueldo-shortcode-timeline-separate-next-prev-icons[data-timeline-id="'+ uniqueClass.replace( 'ueldo_vc_element_', '' ) +'"]' );
                if( nextIconContainer.length !== 0 ) nextIcon = nextIconContainer.find( '.ueldo-shortcode-timeline-next-prev-icon[data-next-prev-icon-type="next"]' );
            }

            if( nextIcon.length !== 0 ) {

                nextIcon.trigger( 'click' );
            }

        }, interval );

    };

   /**
    *
    * configure presentations
    *
    */

    $.UeldoConfigurePresentations = function() {

        $( '.ueldo-shortcode-presentation' ).each( function() {

            var presentation = $( this );
            var switcher = presentation.find( '.ueldo-shortcode-presentation-elements-switcher' );
            var switcherImagesInner = switcher.find( '.ueldo-shortcode-presentation-elements-switcher-images-list-inner' );
            var switcherImagesCount = switcherImagesInner.find( '.ueldo-shortcode-presentation-elements-switcher-images-list-single-image' ).length;
            var singleSwitcherImageWidth, elementsPerScreen;

            if( switcherImagesInner.length == 1 ) singleSwitcherImageWidth = switcherImagesInner.find( '.ueldo-shortcode-presentation-elements-switcher-images-list-single-image.ueldo-shortcode-presentation-elements-switcher-images-list-single-image-active' )[0].getBoundingClientRect().width;

            switch( $.UeldoGetDeviceType() ) {

                case 'desktop': elementsPerScreen = 6; break;
                case 'tablet-horizontal': elementsPerScreen = 5; break;
                case 'tablet-vertical': elementsPerScreen = 3; break;
                case 'mobile': elementsPerScreen = 3; break;
            }

            if( !presentation.hasClass( 'ueldo-shortcode-presentation-configured' ) ) {

                presentation.find( '.ueldo-shortcode-presentation-element' ).each( function() {

                    var element = $( this );
                    var elementID = parseInt( element.data( 'element-id' ), 10 );

                    if( elementID !== 1 ) element.css({ 'display': 'none' });

                });

                if( switcher.length == 1 ) {

                    var switcherImages = switcher.find( '.ueldo-shortcode-presentation-elements-switcher-images-list' );

                    switcherImagesInner.css({ 'width': ( switcherImagesCount * ( singleSwitcherImageWidth + 4 ) ) +'px' });
                    presentation.addClass( 'ueldo-shortcode-presentation-configured' );
                }
            }

            else {

                if( switcher.length == 1 ) {

                    var activeSwitcherImage = switcher.find( '.ueldo-shortcode-presentation-elements-switcher-images-list-single-image.ueldo-shortcode-presentation-elements-switcher-images-list-single-image-active' );
                    var activeSwitcherImageID = activeSwitcherImage.data( 'element-id' );
                    var switcherImagesCount = switcher.find( '.ueldo-shortcode-presentation-elements-switcher-images-list-single-image' ).length;
                    var firstScreenElementID;
                    var switcherPosition = Math.ceil( activeSwitcherImageID / elementsPerScreen );
                    var switcherPositionsCount = Math.ceil( switcherImagesCount / elementsPerScreen );

                    if( switcherPosition != switcherPositionsCount ) firstScreenElementID = ( ( switcherPosition - 1 ) * elementsPerScreen );
                    else {

                        firstScreenElementID = ( switcherImagesCount - ( switcherPosition * elementsPerScreen ) < elementsPerScreen ) ? ( switcherImagesCount - elementsPerScreen ) : ( switcherPosition * elementsPerScreen );
                    }

                    switcher.data( 'current-switcher-position', switcherPosition ).attr( 'data-current-switcher-position', switcherPosition );
                    switcherImagesInner.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ), '-'+ ( firstScreenElementID * ( singleSwitcherImageWidth + 4 ) ) +'px' );
                }
            }

            if( switcher.length == 1 ) {

                var next_prev_buttons = switcher.find( '.ueldo-shortcode-presentation-elements-switcher-prev-images, .ueldo-shortcode-presentation-elements-switcher-next-images' );
                if( switcherImagesCount <= elementsPerScreen ) {

                    if( $.UeldoGetDeviceType() != 'mobile' ) {

                        next_prev_buttons.css({ 'display': 'none' });

                        switcherImagesInner.css({ 'margin': '0 auto' });
                        switcherImagesInner.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ), '' );
                        switcherImagesInner.parent().css({ 'width': switcherImagesInner.width(), 'margin': '0 2px' });

                        switcher.css({ 'width': ( switcherImagesInner.width() + 4 ), 'height': '' });
                        switcher.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ), '-'+ ( ( switcherImagesInner.width() + 4 ) / 2 ) +'px' );
                    }

                    else {

                        next_prev_buttons.css({ 'display': 'none' });

                        switcherImagesInner.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ), '' );
                        switcherImagesInner.css({ 'margin': '0 auto' });
                        switcherImagesInner.parent().css({ 'width': switcherImagesInner.width(), 'margin': '' });
                        switcherImagesInner.parent().css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ), '-'+ ( ( switcherImagesInner.width() + 4 ) / 2 ) +'px' );

                        switcher.css({ 'width': '', 'height': '88px' });
                        switcher.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ), '' );
                    }
                }

                else {

                    next_prev_buttons.css({ 'display': '' });
                    switcherImagesInner.parent().css({ 'width': '', 'margin': '' });

                    switcher.css({ 'width': '', 'height': '' });
                    switcher.css( 'margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' ), '' );
                }
            }

        });

        $( window ).trigger( 'ueldo-height-changed' );
    };

   /**
    *
    * next / prev presentation element
    *
    */

    $( 'body' ).on( 'click', '.ueldo-shortcode-presentation .ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-prev-images, .ueldo-shortcode-presentation .ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-next-images', function() {

        var element = $( this );
        var presentation = element.parents( '.ueldo-shortcode-presentation' );
        var switcher = presentation.find( '.ueldo-shortcode-presentation-elements-switcher' );
        var switcherImagesInner = switcher.find( '.ueldo-shortcode-presentation-elements-switcher-images-list-inner' );
        var switcherPosition = parseInt( switcher.data( 'current-switcher-position' ), 10 );
        var switcherImagesCount = switcher.find( '.ueldo-shortcode-presentation-elements-switcher-images-list-single-image' ).length;
        var singleSwitcherImageWidth = switcherImagesInner.find( '.ueldo-shortcode-presentation-elements-switcher-images-list-single-image.ueldo-shortcode-presentation-elements-switcher-images-list-single-image-active' )[0].getBoundingClientRect().width;
        var type = element.hasClass( 'ueldo-shortcode-presentation-elements-switcher-prev-images' ) ? 'prev' : 'next';
        var animationSpeed = 300;
        var elementsPerScreen, switcherPositionsCount, firstScreenElementID;

        switch( $.UeldoGetDeviceType() ) {

            case 'desktop': elementsPerScreen = 6; break;
            case 'tablet-horizontal': elementsPerScreen = 5; break;
            case 'tablet-vertical': elementsPerScreen = 3; break;
            case 'mobile': elementsPerScreen = 3; break;
        }

        switcherPositionsCount = Math.ceil( switcherImagesCount / elementsPerScreen );
        switch( type ) {

            case 'next':

                if( ( switcherPosition + 1 ) == switcherPositionsCount ) {

                    firstScreenElementID = ( switcherImagesCount - ( ( switcherPosition * elementsPerScreen ) + 1 ) < elementsPerScreen ) ? ( switcherImagesCount - elementsPerScreen + 1 ) : ( switcherPosition * elementsPerScreen ) + 1;
                    switcherPosition += 1;
                }

                else if( switcherPosition == switcherPositionsCount ) {

                    firstScreenElementID = 1;
                    switcherPosition = 1;
                }

                else {

                    firstScreenElementID = ( switcherPosition * elementsPerScreen ) + 1;
                    switcherPosition += 1;
                }

            break;

            case 'prev':

                if( switcherPosition == 1 ) {

                    firstScreenElementID = switcherImagesCount - elementsPerScreen + 1;
                    switcherPosition = switcherPositionsCount;
                }

                else {

                    firstScreenElementID = ( switcherPosition - 1 == 1 ) ? 1 : ( ( ( switcherPosition - 1 ) * elementsPerScreen ) - ( elementsPerScreen - 1 ) );
                    switcherPosition -= 1;
                }

            break;
        }

        var css_style = {};
            css_style['margin-'+ ( ueldo_javascript_functions_l10n.is_rtl == 'yes' ? 'right' : 'left' )] = '-'+ ( firstScreenElementID - 1 ) * ( singleSwitcherImageWidth + 4 ) +'px';

        switcher.data( 'current-switcher-position', switcherPosition ).attr( 'data-current-switcher-position', switcherPosition );
        switcherImagesInner.animate( css_style, animationSpeed );

    });

   /**
    *
    * change single presentation element
    *
    */

    $( 'body' ).on( 'click', '.ueldo-shortcode-presentation-elements-switcher-images-list-single-image:not(.ueldo-shortcode-presentation-elements-switcher-images-list-single-image-active)', function() {

        var element = $( this );
        var elementID = element.data( 'element-id' );
        var presentation = element.parents( '.ueldo-shortcode-presentation' );
        var animationSpeed = 300;

        presentation.find( '.ueldo-shortcode-presentation-elements-switcher-images-list-single-image.ueldo-shortcode-presentation-elements-switcher-images-list-single-image-active' ).removeClass( 'ueldo-shortcode-presentation-elements-switcher-images-list-single-image-active' );
        element.addClass( 'ueldo-shortcode-presentation-elements-switcher-images-list-single-image-active' );

        presentation.find( '.ueldo-shortcode-presentation-point-of-interest' ).removeClass( 'ueldo-shortcode-presentation-point-of-interest-is-open' );

        var newPresentationElement = presentation.find( '.ueldo-shortcode-presentation-element[data-element-id="'+ elementID +'"]' );
        var oldPresentationElement = presentation.find( '.ueldo-shortcode-presentation-element:not([data-element-id="'+ elementID +'"])' );

        newPresentationElement.css({ 'display': 'block', 'z-index': '-1' });
        oldPresentationElement.fadeOut( animationSpeed );

        setTimeout( function() {

            oldPresentationElement.css({ 'display': 'none' });
            newPresentationElement.css({ 'display': '', 'z-index': '' });

        }, animationSpeed );

    });

   /**
    *
    * open / close point of interest
    *
    */

    $( 'body' ).on( 'click', '.ueldo-shortcode-presentation-point-of-interest', function( event ) {

        if( ( $( event.target ).hasClass( 'ueldo-shortcode-presentation-point-of-interest-content' ) || $( event.target ).parents( '.ueldo-shortcode-presentation-point-of-interest-content' ).length == 1 ) && ( !$( event.target ).hasClass( 'ueldo-shortcode-presentation-point-of-interest-content-modal-close' ) && !$( event.target ).hasClass( 'ueldo-shortcode-presentation-point-of-interest-content-modal-close-inner' ) ) ) return;

        var element = $( this );
        var fullWidthFrom = element.data( 'full-width-from' );
        var presentation = element.parents( '.ueldo-shortcode-presentation' );
        var modal = element.find( '.ueldo-shortcode-presentation-point-of-interest-content' );

        if( $( event.target ).hasClass( 'ueldo-shortcode-presentation-point-of-interest-content-modal-close' ) || $( event.target ).hasClass( 'ueldo-shortcode-presentation-point-of-interest-content-modal-close-inner' ) ) {

            element.removeClass( 'ueldo-shortcode-presentation-point-of-interest-is-open' );
            element.find( '.ueldo-shortcode-presentation-point-of-interest-content' ).fadeOut( 300 );
            presentation.find( '.ueldo-shortcode-presentation-point-of-interest:not(.ueldo-shortcode-presentation-point-of-interest-is-open)' ).css({ 'display': '' });

            setTimeout( function() {

                modal.removeClass( 'ueldo-shortcode-presentation-point-of-interest-content-without-arrow' ).css({ 'width': '', 'height': '', 'top': '', 'left': '', 'right': '', 'bottom': '', 'margin-top': '', 'margin-right': '', 'margin-bottom': '', 'margin-left': '' });
                modal.find( '.ueldo-shortcode-presentation-point-of-interest-content-inner' ).css({ 'height': '' });

            }, 300 );
        }

        else {

            if( element.hasClass( 'ueldo-shortcode-presentation-point-of-interest-is-open' ) ) {

                element.removeClass( 'ueldo-shortcode-presentation-point-of-interest-is-open' );
                element.find( '.ueldo-shortcode-presentation-point-of-interest-content' ).fadeOut( 200 );
            }

            else {

                presentation.find( '.ueldo-shortcode-presentation-point-of-interest .ueldo-shortcode-presentation-point-of-interest-content' ).fadeOut( 200 );
                presentation.find( '.ueldo-shortcode-presentation-point-of-interest' ).removeClass( 'ueldo-shortcode-presentation-point-of-interest-is-open' );

                element.addClass( 'ueldo-shortcode-presentation-point-of-interest-is-open' );
                element.find( '.ueldo-shortcode-presentation-point-of-interest-content' ).fadeIn( 200 );
            }

            $.UeldoFullWidthPointOfInterestModal( element );
        }

    });

   /**
    *
    * display full-width point-of-interest modal
    *
    */

    $.UeldoFullWidthPointOfInterestModal = function( element ) {

        var presentation = element.parents( '.ueldo-shortcode-presentation' );
        var shortcodeClass = presentation.attr( 'class' );
        var uniqueClass = shortcodeClass.substring( shortcodeClass.indexOf( 'ueldo_vc_element_' ), shortcodeClass.length ).trim();

        if( uniqueClass.indexOf( ' ' ) > 0 ) uniqueClass = uniqueClass.substring( 0, uniqueClass.indexOf( ' ' ) ).trim();
        if( typeof ueldoIntervals[uniqueClass] != 'undefined' ) clearInterval( ueldoIntervals[uniqueClass] );

        var fullWidthFrom = element.data( 'full-width-from' );
        var modal = element.find( '.ueldo-shortcode-presentation-point-of-interest-content' );
        var executePossible = false;

        switch( $.UeldoGetDeviceType() ) {

            case 'desktop': if( fullWidthFrom == 'large' ) { executePossible = true; } break;
            case 'tablet-horizontal': if( fullWidthFrom == 'medium' || fullWidthFrom == 'large' ) { executePossible = true; } break;
            case 'tablet-vertical': if( fullWidthFrom == 'small' || fullWidthFrom == 'medium' || fullWidthFrom == 'large' ) { executePossible = true; } break;
            case 'mobile': executePossible = true; break;
        }

        if( executePossible == true ) {

            $.UeldoUpdateFullWidthPointOfInterestModalSizes( presentation, element, modal );

            var intervalCount = 0;
            ueldoIntervals[uniqueClass] = setInterval( function() {

                $.UeldoUpdateFullWidthPointOfInterestModalSizes( presentation, element, modal );

                intervalCount += 1;
                if( intervalCount == 10 ) clearInterval( ueldoIntervals[uniqueClass] );

            }, 50 );
        }

        else {

            presentation.find( '.ueldo-shortcode-presentation-point-of-interest:not(.ueldo-shortcode-presentation-point-of-interest-is-open)' ).css({ 'display': '' });
            modal.removeClass( 'ueldo-shortcode-presentation-point-of-interest-content-without-arrow' ).css({ 'width': '', 'height': '', 'top': '', 'left': '', 'right': '', 'bottom': '', 'margin-top': '', 'margin-right': '', 'margin-bottom': '', 'margin-left': '' });
            modal.find( '.ueldo-shortcode-presentation-point-of-interest-content-inner' ).css({ 'height': '' });
        }
    };

   /**
    *
    * update modal sizes
    *
    */

    $.UeldoUpdateFullWidthPointOfInterestModalSizes = function( presentation, element, modal ) {

        var presentationWidth = presentation[0].getBoundingClientRect().width;
        var presentationHeight = presentation[0].getBoundingClientRect().height;

        presentation.find( '.ueldo-shortcode-presentation-point-of-interest:not(.ueldo-shortcode-presentation-point-of-interest-is-open)' ).css({ 'display': 'none' });
        modal.addClass( 'ueldo-shortcode-presentation-point-of-interest-content-without-arrow' ).css({
            'width': presentationWidth,
            'height': presentationHeight,
            'top': '-'+ element.position().top +'px',
            'left': '-'+ element.position().left +'px',
            'right': 'auto',
            'bottom': 'auto',
            'margin-top': '0',
            'margin-right': '0',
            'margin-bottom': '0',
            'margin-left': '0'
        });

        modal.find( '.ueldo-shortcode-presentation-point-of-interest-content-inner' ).css({ 'height': '100%' });
    };

   /**
    *
    * configure opening hours status
    *
    */

    $.UeldoConfigureOpeningHoursStatus = function() {

        $( '.ueldo-shortcode-opening-hours-status' ).each( function() {

            var status = $( this );
            var dateTime = $.UeldoGetCurrentDateAndTimeValuesForOpeningHoursStatus( status );
            var useRule = $.UeldoGetOpeningHoursStatusRule( status, dateTime );

            if( useRule == false ) return;

            var isOpenToday = useRule.data( 'type' ) == 'open';
            if( isOpenToday == true ) {

                var currentTime = parseInt( dateTime.hour + dateTime.minutes, 10 );
                var isOpenNow = false;

                useRule.find( '.ueldo-shortcode-opening-hours-status-rule-opening-hours-set' ).each( function() {

                    var openingHoursSet = $( this );
                    var from = parseInt( openingHoursSet.data( 'from-hour' ) + openingHoursSet.data( 'from-minutes' ), 10 );
                    var to = parseInt( openingHoursSet.data( 'to-hour' ) + openingHoursSet.data( 'to-minutes' ), 10 );

                    if( from <= currentTime && to >= currentTime ) isOpenNow = true;

                });

                if( isOpenNow == true ) status.find( '.ueldo-shortcode-opening-hours-status-content[data-for-status="open"]' ).addClass( 'ueldo-shortcode-opening-hours-status-content-active' );
            }

            if( isOpenToday == false || isOpenNow == false ) status.find( '.ueldo-shortcode-opening-hours-status-content[data-for-status="closed"]' ).addClass( 'ueldo-shortcode-opening-hours-status-content-active' );

        });
    };

   /**
    *
    * get current date and time values
    *
    */

    $.UeldoGetCurrentDateAndTimeValuesForOpeningHoursStatus = function( status ) {

        var useBrowserTime = status.find( '.ueldo-shortcode-opening-hours-status-timezone' ).data( 'use-browser-time' );
        var hour, minutes, weekday, date;

        if( useBrowserTime == 'no' ) {

            var time = status.find( '.ueldo-shortcode-opening-hours-status-time' );

            hour = time.data( 'hour' );
            minutes = time.data( 'minutes' );
            weekday = time.data( 'weekday' );
            date = time.data( 'date' );
        }

        else {

            var dateObject = new Date();
            var weekdays = [ 'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday', 'sunday' ];
            var month = dateObject.getMonth() + 1;
            var day = dateObject.getDate();

            hour = dateObject.getHours();
            minutes = dateObject.getMinutes();
            weekday = weekdays[ dateObject.getDay() - 1 ];
            date = dateObject.getFullYear() +'-'+ ( month < 10 ? '0'+ month : month ) +'-'+ ( day < 10 ? '0'+ day : day );

            if( hour < 10 ) hour = '0'+ hour;
            if( minutes < 10 ) minutes = '0'+ minutes;
        }

        return({ 'hour': hour.toString(), 'minutes': minutes.toString(), 'weekday': weekday, 'date': date, 'dateInt': parseInt( date.split( '-' ).join( '' ), 10 ) });
    };

   /**
    *
    * get rule for opening hours status
    *
    */

    $.UeldoGetOpeningHoursStatusRule = function( status, dateTime ) {

        var useRule = false;
        status.find( '.ueldo-shortcode-opening-hours-status-exception' ).each( function() {

            var exception = $( this );
            var applyFrom = parseInt( exception.data( 'apply-from' ).split( '-' ).join( '' ), 10 );
            var applyTo = parseInt( exception.data( 'apply-to' ).split( '-' ).join( '' ), 10 );

            if( applyFrom <= dateTime.dateInt && applyTo >= dateTime.dateInt ) useRule = exception;

        });

        if( useRule == false ) {

            status.find( '.ueldo-shortcode-opening-hours-status-rule' ).each( function() {

                if( useRule == false ) {

                    var rule = $( this );
                    if( rule.data( 'apply-for-'+ dateTime.weekday ) == 'yes' ) useRule = rule;
                }

            });
        }

        return( useRule );
    };

   /**
    *
    * reconfigure vc full-width rows
    *
    */

    $.UeldoReConfigureVCFullWidthRows = function() {

        var websiteWidth = $.UeldoGetWebsiteWidth();
        var spaceWidth = $.UeldoGetDeviceType() == 'mobile' ? 15 : ( ( websiteWidth - $.UeldoGetContentWidth() - 30 ) / 2 );
        var isRTL = ueldo_javascript_functions_l10n.is_rtl == 'yes';
        var sideMenu = $( '#ueldo-side-menu' );
        var isSideMenuStatic = sideMenu.hasClass( 'ueldo-side-menu-style-static' );

        if( isRTL == true || isSideMenuStatic == true || $( '.ueldo-website-wrapper' ).hasClass( 'ueldo-website-wrapper-boxed' ) ) {

            if( isSideMenuStatic == true && ( $.UeldoGetDeviceType() == 'desktop' || $.UeldoGetDeviceType() == 'tablet-horizontal' ) ) {

                websiteWidth = websiteWidth - sideMenu[0].getBoundingClientRect().width;
                spaceWidth = $.UeldoGetDeviceType() == 'mobile' ? 15 : ( ( websiteWidth - $.UeldoGetContentWidth() - 30 ) / 2 );
            }

            $( '*[data-vc-full-width="true"], .ueldo-full-width-vc-element' ).each( function() {

                var element = $( this );
                var stretchContent = ( typeof element.data( 'vc-stretch-content' ) == 'undefined' ? element.hasClass( 'ueldo-full-width-vc-element-stretch-content' ) : element.data( 'vc-stretch-content' ) ) == true;
                var type = element.is( 'section' ) ? 'section' : 'row';

                element.removeAttr( 'data-vc-full-width' );
                element.removeAttr( 'data-vc-full-width-init' );
                element.removeAttr( 'data-vc-stretch-content' );

                element.addClass( 'ueldo-full-width-vc-element' );
                element.css({ 'left': '', 'right': '', 'width': '', 'padding-left': '', 'padding-right': '' });

                if( stretchContent == true ) element.addClass( 'ueldo-full-width-vc-element-stretch-content' );

               /**
                *
                * section
                *
                */

                if( type == 'section' ) {

                    if( stretchContent == true ) {

                        element.css({ 'width': websiteWidth +'px' });

                        if( isRTL == true ) element.css( 'right', '-'+ spaceWidth +'px' );
                        else element.css( 'left', '-'+ spaceWidth +'px' );
                    }

                    else {

                        element.css({ 'width': websiteWidth +'px', 'padding-left': spaceWidth +'px', 'padding-right': spaceWidth +'px' });

                        if( isRTL == true ) element.css( 'right', '-'+ spaceWidth +'px' );
                        else element.css( 'left', '-'+ spaceWidth +'px' );
                    }
                }

               /**
                *
                * row
                *
                */

                else {

                    var section = element.parents( 'section.vc_section' );
                    var isSectionStretchContent = section.length === 1 ? ( typeof section.data( 'vc-stretch-content' ) != 'undefined' ? true : section.hasClass( 'ueldo-full-width-vc-element-stretch-content' ) ) : false;

                    if( stretchContent == true ) {

                        if( isSectionStretchContent == true ) {

                            element.css({ 'width': websiteWidth +'px' });

                            if( isRTL == true ) element.css( 'right', '0' );
                            else element.css( 'left', '0' );
                        }

                        else {

                            element.css({ 'width': websiteWidth +'px' });

                            if( isRTL == true ) element.css( 'right', '-'+ spaceWidth +'px' );
                            else element.css( 'left', '-'+ spaceWidth +'px' );
                        }
                    }

                    else {

                        if( isSectionStretchContent == true ) {

                            element.css({ 'width': websiteWidth +'px', 'padding-left': '0', 'padding-right': '0' });

                            if( isRTL == true ) element.css( 'right', '0' );
                            else element.css( 'left', '0' );
                        }

                        else {

                            element.css({ 'width': websiteWidth +'px', 'padding-left': spaceWidth +'px', 'padding-right': spaceWidth +'px' });

                            if( isRTL == true ) element.css( 'right', '-'+ spaceWidth +'px' );
                            else element.css( 'left', '-'+ spaceWidth +'px' );
                        }
                    }
                }

               /**
                *
                * end of function.
                *
                */

            });

           /**
            *
            * fixed footer width
            *
            */

            var fixedFooter = $( 'footer[data-is-footer-position-fixed="yes"]' );
            if( fixedFooter.length === 1 ) {

                fixedFooter.css({ 'width': websiteWidth +'px' });
            }
        }
    };

   /**
    *
    * reconfigure vc sections with negative margin top (firefox issue fix)
    *
    */

    $.UeldoReConfigureVCSectionsAndRowsNegativeMarginTop = function() {

        $( '.vc_section' ).each( function() {

            var element = $( this );
            if( element.is( '[class*="vc_custom_"]' ) ) {

                var marginTop = parseInt( element.css( 'margin-top' ), 10 );
                var marginBottom = parseInt( element.css( 'margin-bottom' ), 10 );

                if( marginTop < 0 ) {

                    var newMarginBottom = marginBottom + marginTop;

                    element.css({ 'top': marginTop, 'margin-bottom': newMarginBottom });
                    element.css( 'cssText', element.attr( 'style' ) +'margin-top: 0 !important' );
                }
            }

        });
    };

   /**
    *
    * get the content width
    *
    */

    $.UeldoGetContentWidth = function() {

        switch( $.UeldoGetDeviceType() ) {

            case 'desktop': return( parseInt( ueldo_javascript_functions_l10n.website_sizes_large_content_width, 10 ) );
            case 'tablet-horizontal': return( parseInt( ueldo_javascript_functions_l10n.website_sizes_medium_content_width, 10 ) );
            case 'tablet-vertical': return( parseInt( ueldo_javascript_functions_l10n.website_sizes_small_content_width, 10 ) );
            case 'mobile': return( ueldoPageWidth );
        }
    };

   /**
    *
    * get website container width
    *
    */

    $.UeldoGetWebsiteWidth = function() {

        if( $( '.ueldo-website-wrapper' ).hasClass( 'ueldo-website-wrapper-boxed' ) == false ) return( ueldoPageWidth );
        else {

            switch( $.UeldoGetDeviceType() ) {

                case 'desktop': return( parseInt( ueldo_javascript_functions_l10n.website_sizes_large_content_width, 10 ) + ( parseInt( ueldo_javascript_functions_l10n.website_sizes_large_content_space, 10 ) * 2 ) );
                case 'tablet-horizontal': return( parseInt( ueldo_javascript_functions_l10n.website_sizes_medium_content_width, 10 ) + ( parseInt( ueldo_javascript_functions_l10n.website_sizes_medium_content_space, 10 ) * 2 ) );
                case 'tablet-vertical': return( parseInt( ueldo_javascript_functions_l10n.website_sizes_small_content_width, 10 ) + ( parseInt( ueldo_javascript_functions_l10n.website_sizes_small_content_space, 10 ) * 2 ) );
                case 'mobile': return( ueldoPageWidth );
            }
        }
    };

   /**
    *
    * configure custom footer with fixed position
    *
    */

    $.UeldoConfigureCustomFooterFixedPosition = function() {

        var footer = $( 'footer[data-is-footer-position-fixed="yes"]' );
        if( footer.length !== 1 ) return;

        footer.css({ 'height': '', 'overflow-y': '', 'bottom': '', 'top': '' });

        var websiteContentWrapper = $( '#ueldo-website-content-wrapper' );
        var websiteWrapper = $( '.ueldo-website-wrapper' );
        var footerHeight = footer[0].getBoundingClientRect().height;
        var websiteWrapperHeight = websiteWrapper[0].getBoundingClientRect().height;
        var windowHeight = $( window ).height();
        var deviceType = $.UeldoGetDeviceType();

        if( deviceType == 'desktop' || deviceType == 'tablet-horizontal' ) {

            if( windowHeight <= footerHeight ) {

                websiteContentWrapper.css({ 'margin-bottom': windowHeight });
                footer.css({ 'height': windowHeight, 'overflow-y': 'scroll', 'bottom': '', 'top': '' });
            }

            else {

                var adminBar = $( '#wpadminbar' );
                if( adminBar.length === 1 ) websiteWrapperHeight += adminBar[0].getBoundingClientRect().height;

                if( ( websiteWrapperHeight + footerHeight ) < windowHeight ) {

                    websiteContentWrapper.css({ 'margin-bottom': '' });
                    footer.css({ 'height': '', 'overflow-y': 'hidden', 'bottom': 'auto', 'top': websiteWrapperHeight });
                }

                else {

                    websiteContentWrapper.css({ 'margin-bottom': footerHeight });
                    footer.css({ 'height': '', 'overflow-y': 'hidden', 'bottom': '', 'top': '' });
                }
            }
        }

        else {

            websiteContentWrapper.css({ 'margin-bottom': '' });
            footer.css({ 'height': '', 'overflow-y': '', 'bottom': '', 'top': '' });
        }
    };

   /**
    *
    * update class name of column which container custom menu
    *
    */

    $.UeldoUpdateCustomMenuParentColumnClassName = function() {

        var columnID = 0;
        $( '.ueldo-shortcode-header-menu, .ubermenu' ).each( function() {

            var headerMenu = $( this );
            var column = headerMenu.parents( '.vc_column-inner' );

            if( column.length > 0 ) {

                column.addClass( 'ueldo-column-container-for-shortcode-header-menu' ).css({ 'z-index': ( 1500 - columnID ) });
                columnID++;
            }

        });
    };

   /**
    *
    * update padding-top for website wrapper, depends on header height
    *
    */

    $.UeldoUpdateWebsiteWrapperPaddingTop = function() {

        var websiteWrapper = $( '.ueldo-website-wrapper' );
        var header = $( 'header.ueldo-header-bar.ueldo-header-bar-main.ueldo-header-bar-position-flying' );

        if( header.length === 0 ) websiteWrapper.css({ 'padding-top': '' });
        else {

            var headerHeight = header[0].getBoundingClientRect().height;

            websiteWrapper.css({ 'padding-top': headerHeight });
            setTimeout( function() {

                var reCheckHeaderHeight = header[0].getBoundingClientRect().height;
                if( headerHeight != reCheckHeaderHeight ) {

                    headerHeight = reCheckHeaderHeight;
                    websiteWrapper.css({ 'padding-top': headerHeight });

                    setTimeout( function() {

                        var reCheckHeaderHeight = header[0].getBoundingClientRect().height;
                        if( headerHeight != reCheckHeaderHeight ) {

                            headerHeight = reCheckHeaderHeight;
                            websiteWrapper.css({ 'padding-top': headerHeight });
                        }

                    }, 100 );
                }

            }, 100 );
        }

        $( window ).trigger( 'ueldo-height-changed' );
    };

   /**
    *
    * remove empty blog post data elements
    *
    */

    $.UeldoRemoveEmptyBlogPostDataElements = function() {

        $( '.ueldo-blog-post-data' ).each( function() {

            var container = $( this );
            container.find( 'li' ).each( function() {

                var element = $( this );
                var elementText = element.text();

                if( elementText.length == 0 || element.is( ':empty' ) ) element.remove();
                else {

                    elementText = elementText.replace( /\s/g, '' );
                    if( elementText.length == 0 ) element.remove();
                }

            });

        });
    };

   /**
    *
    * configure second header bar visibility
    *
    */

    $.UeldoConfigureSecondHeaderBarVisibility = function() {

        var element = $( 'header.ueldo-header-bar.ueldo-header-bar-additional' );
        if( element.length !== 1 ) return;

        if( $( window ).scrollTop() >= parseInt( element.data( 'visible-from' ), 10 ) ) element.addClass( 'ueldo-header-bar-additional-visible' );
        else element.removeClass( 'ueldo-header-bar-additional-visible' );

    };

   /**
    *
    * show / hide flying sidebar after click on button
    *
    */

    $( 'body' ).on( 'click', 'a[href="#ueldo-show-hide-flying-sidebar"]', function( event ) {

        event.preventDefault();

        var button = $( this );

        if( button.hasClass( 'ueldo-animation-proceed' ) ) return;
        button.addClass( 'ueldo-animation-proceed' );

        var deviceType = $.UeldoGetDeviceType();
        var sidebar = $( '.ueldo-content-default .ueldo-sidebar-wrapper[data-sidebar-responsive-style="flying"], .ueldo-content-default.ueldo-content-default-vc-page .ueldo-sidebar-flying' );

        if( sidebar.length === 0 ) {

            button.removeClass( 'ueldo-animation-proceed' );
            return;
        }

        var sidebarLine = sidebar.find( '.ueldo-flying-sidebar-line' );
        var sidebarBackground = sidebar.find( '.ueldo-custom-sidebar-background' );
        var sidebarSide = sidebar.parents( '.ueldo-content-default' ).data( 'ueldo-content-default-sidebar-side' );

        if( deviceType != 'mobile' && deviceType != 'tablet-vertical' ) {

            button.removeClass( 'ueldo-animation-proceed' );
            $.UeldoHideResponsiveFlyingSidebar( false );

            return;
        }

        else {

            if( sidebar.hasClass( 'ueldo-sidebar-flying-visible' ) ) {

                if( sidebarSide == 'left' ) {

                    sidebar.animate({ 'left': '-300px' }, { duration: 300, complete: function() { sidebar.removeClass( 'ueldo-sidebar-flying-visible' ); button.removeClass( 'ueldo-animation-proceed' ); }});
                    sidebarLine.animate({ 'left': '-1px' }, 300 );
                    sidebarBackground.animate({ 'left': '-300px' }, 300 );
                }

                else {

                    sidebar.animate({ 'right': '-300px' }, { duration: 300, complete: function() { sidebar.removeClass( 'ueldo-sidebar-flying-visible' ); button.removeClass( 'ueldo-animation-proceed' ); }});
                    sidebarLine.animate({ 'right': '-1px' }, 300 );
                    sidebarBackground.animate({ 'right': '-300px' }, 300 );
                }
            }

            else {

                if( sidebarSide == 'left' ) {

                    sidebar.addClass( 'ueldo-sidebar-flying-visible' ).animate({ 'left': '0px' }, { duration: 300, complete: function() { button.removeClass( 'ueldo-animation-proceed' ); }});
                    sidebarLine.animate({ 'left': '299px' }, 300 );
                    sidebarBackground.animate({ 'left': '0px' }, 300 );
                }

                else {

                    sidebar.addClass( 'ueldo-sidebar-flying-visible' ).animate({ 'right': '0px' }, { duration: 300, complete: function() { button.removeClass( 'ueldo-animation-proceed' ); }});
                    sidebarLine.animate({ 'right': '299px' }, 300 );
                    sidebarBackground.animate({ 'right': '0px' }, 300 );
                }
            }
        }

    });

   /**
    *
    * hide responsive flying sidebar on bigger devices
    *
    */

    $.UeldoHideResponsiveFlyingSidebar = function( find ) {

        var sidebar = $( '.ueldo-content-default .ueldo-sidebar-wrapper[data-sidebar-responsive-style="flying"], .ueldo-content-default.ueldo-content-default-vc-page .ueldo-sidebar-flying' );
        if( sidebar.length === 0 ) return;

        var sidebarLine = sidebar.find( '.ueldo-flying-sidebar-line' );
        var remove = find == false;

        if( find == true ) {

            var deviceType = $.UeldoGetDeviceType();
            remove = deviceType != 'mobile' && deviceType != 'tablet-vertical';
        }

        if( remove == true ) {

            sidebar.removeClass( 'ueldo-sidebar-flying-visible' ).css({ 'left': '', 'right': '' });
            sidebarLine.css({ 'left': '', 'right': '' });
        }
    };

   /**
    *
    * search field animation
    *
    */

    $( 'body' ).on( 'click', '.ueldo-shortcode-search-field.ueldo-shortcode-search-field-type-animated.ueldo-shortcode-search-field-type-animated-hidden .ueldo-animated-search-field button[type="submit"]', function( event ) {

        event.preventDefault();
        $.UeldoHideAnimatedSearchFields( $( '.ueldo-shortcode-search-field.ueldo-shortcode-search-field-type-animated:not(.ueldo-shortcode-search-field-type-animated-hidden)' ) );

        var button = $( this );
        var field = button.parents( '.ueldo-shortcode-search-field' );

        field.removeClass( 'ueldo-shortcode-search-field-type-animated-hidden' );
        setTimeout( function() {

            button.addClass( 'ueldo-animated-search-field-button-left-pos' );

        }, 26 );

        $( window ).trigger( 'ueldo-height-changed' );

    });

   /**
    *
    * hide animated search field
    *
    */

    $.UeldoHideAnimatedSearchFields = function( fields ) {

        if( fields.length === 0 ) return;
        fields.each( function() {

            var field = $( this );
            if( !field.hasClass( 'ueldo-animation-proceed' ) ) {

                field.addClass( 'ueldo-animation-proceed' );

                var input = field.find( 'input[type="text"]' );
                var button = field.find( 'button[type="submit"]' );

                field.animate({ 'width': '14px' }, 200 );
                input.animate({ 'opacity': '0' }, { duration: 400, complete: function() {

                    field.addClass( 'ueldo-shortcode-search-field-type-animated-hidden' ).css({ 'width': '' });
                    setTimeout( function() {

                        button.removeClass( 'ueldo-animated-search-field-button-left-pos' );
                        setTimeout( function() {

                            input.css({ 'opacity': '' });
                            field.removeClass( 'ueldo-animation-proceed' );

                        }, 400 );

                    }, 90 );

                }});
            }

        });
    };

   /**
    *
    * hide animated search field
    *
    */

    $( document ).on( 'click', function( event ) {

        if( !$( event.target ).closest( '.ueldo-shortcode-search-field.ueldo-shortcode-search-field-type-animated' ).length ) {

            $.UeldoHideAnimatedSearchFields( $( '.ueldo-shortcode-search-field.ueldo-shortcode-search-field-type-animated:not(.ueldo-shortcode-search-field-type-animated-hidden)' ) );
        }

    });

   /**
    *
    * keep search field hover when mouse is on search button
    *
    */

    $( 'body' ).on( 'mouseenter', '.ueldo-shortcode-search-field button[type="submit"], .ueldo-search-field button[type="submit"]', function() {

        var button = $( this );
        var input = button.siblings( 'input[type="text"]' );

        if( input.is( ':focus' ) ) return;
        else input.addClass( 'ueldo-search-field-hover' );

    });

    $( 'body' ).on( 'mouseleave', '.ueldo-shortcode-search-field button[type="submit"], .ueldo-search-field button[type="submit"]', function() {

        var button = $( this );
        var input = button.siblings( 'input[type="text"]' );

        if( input.is( ':focus' ) ) return;
        else input.removeClass( 'ueldo-search-field-hover' );

    });

   /**
    *
    * link with hash?
    *
    */

    $( 'body' ).on( 'click', 'a', function() {

        if( ueldo_javascript_functions_l10n.local_scrolling_links_animation_enabled == 'yes' && location.pathname.replace( /^\//, '' ) == this.pathname.replace( /^\//, '' ) && location.hostname == this.hostname ) {

            var hash = this.hash;
            var target = $( hash );

            target = target.length ? target : $( '[id="'+ this.hash.slice( 1 ) +'"]' );
            if( target.length ) {

                var position = Math.ceil( target.offset().top ) - $.UeldoGetHeaderBarHeight();
                $( 'html, body' ).animate({ scrollTop: position }, { duration: parseInt( ueldo_javascript_functions_l10n.local_scrolling_links_animation_speed, 10 ), complete: function() {

                    window.location.hash = hash;
                    $( 'html, body' ).scrollTop( position );

                }});

                return false;
            }
        }

    });

   /**
    *
    * scroll to section on page load, if possible
    *
    */

    $.UeldoScrollToSectionIfPossible = function() {

        var hash = location.hash;
        if( hash !== '' && ueldo_javascript_functions_l10n.local_scrolling_links_animation_enabled == 'yes' ) {

            var target = $( hash );
            target = target.length ? target : $( '[id="'+ hash.slice( 1 ) +'"]' );

            if( target.length ) {

                var position = Math.ceil( target.offset().top ) - $.UeldoGetHeaderBarHeight();

                $( 'html, body' ).animate({ scrollTop: position }, 1 );
                return false;
            }
        }
    };

   /**
    *
    * configure sub-menus for side menu
    *
    */

    $.UeldoConfigureSideMenuSubmenus = function() {

        var sideMenu = $( '#ueldo-side-menu' );
        var nav = sideMenu.find( 'nav.ueldo-side-menu-submenu-links-visible-on-click-as-new-layer' );

        if( nav.length == 0 ) return;

        nav.find( 'ul.sub-menu' ).each( function() {

            var subMenu = $( this );

            subMenu.prepend( '<li><a href="#" class="ueldo-side-menu-submenu-back-link"><span>'+ ueldo_javascript_functions_l10n.back +'</span></a></li>' );

        });
    };

   /**
    *
    * open sub-menu item on side menu
    *
    */

    $( 'body' ).on( 'click', '#ueldo-side-menu nav.ueldo-side-menu-submenu-links-visible-on-click-under-parent li.menu-item-has-children > a, #ueldo-side-menu nav.ueldo-side-menu-submenu-links-visible-on-click-as-new-layer li.menu-item-has-children > a', function( event ) {

        var link = $( this );
        var nav = link.parents( '.ueldo-side-menu-inner nav' );

        if( nav.hasClass( 'ueldo-side-menu-submenu-links-visible-on-click-under-parent' ) ) {

            if( !link.hasClass( 'ueldo-link-allowed' ) ) {

                event.preventDefault();
                link.addClass( 'ueldo-link-allowed' );

                var submenu = link.siblings( 'ul.sub-menu' );
                var submenuHeight = 0;

                submenu.children( 'li' ).each( function() {

                    var li = $( this );
                    var a = li.children( 'a' );

                    submenuHeight += parseInt( a.css( 'line-height' ), 10 ) + parseInt( a.css( 'padding-top' ), 10 ) + parseInt( a.css( 'padding-bottom' ), 10 ) + parseInt( a.css( 'margin-top' ), 10 ) + parseInt( a.css( 'border-bottom-width' ), 10 );

                });

                submenu.css({ 'display': 'block' });
                submenu.animate({ 'height': submenuHeight }, { duration: 200, progress: function() {

                    $.UeldoConfigureSideMenuVerticalAlignments( false, false );

                } });

                submenu.parents( 'ul.sub-menu' ).each( function() {

                    var parent = $( this );
                    parent.animate({ 'height': ( parseInt( parent.css( 'height' ), 10 ) + submenuHeight ) }, { duration: 200, progress: function() {

                        $.UeldoConfigureSideMenuVerticalAlignments( false, false );

                    } });

                });
            }
        }

        else if( nav.hasClass( 'ueldo-side-menu-submenu-links-visible-on-click-as-new-layer' ) ) {

            event.preventDefault();

            var submenu = link.siblings( 'ul.sub-menu' );
            var parents = link.parent().siblings( 'li' ).andSelf();

            parents.children( 'a' ).addClass( 'animated ueldo-animated-fast ueldoFadeOutLeftSuperSmall' );
            setTimeout( function() {

                submenu.css({ 'display': 'block' }).addClass( 'animated ueldo-animated-fast ueldoFadeInRightSuperSmall' );
                nav.css({ 'height': submenu[0].getBoundingClientRect().height });

                setTimeout( function() {

                    parents.children( 'a' ).css({ 'visibility': 'hidden' });

                }, 300 );

                $.UeldoConfigureSideMenuVerticalAlignments( submenu[0].getBoundingClientRect().height, true );

            }, 200 );
        }

    });

   /**
    *
    * close sub-menu item on side menu
    *
    */

    $( 'body' ).on( 'click', '#ueldo-side-menu nav.ueldo-side-menu-submenu-links-visible-on-click-as-new-layer a.ueldo-side-menu-submenu-back-link', function( event ) {

        event.preventDefault();

        var link = $( this );
        var nav = link.parents( '.ueldo-side-menu-inner nav' );
        var submenu = link.closest( 'ul.sub-menu' );
        var parents = submenu.parent().siblings( 'li' ).andSelf();
        var parentsUl = parents.parent();

        submenu.removeClass( 'ueldoFadeInRightSuperSmall' ).addClass( 'ueldoFadeOutRightSuperSmall' );
        setTimeout( function() {

            var parentHeight = parentsUl.hasClass( 'sub-menu' ) ? parentsUl[0].getBoundingClientRect().height : ( parentsUl[0].getBoundingClientRect().height + ( parseInt( parentsUl.children( 'li' ).first().children( 'a' ).first().css( 'margin-top' ), 10 ) * 2 ) );

            parents.children( 'a' ).removeClass( 'ueldoFadeOutLeftSuperSmall' ).addClass( 'ueldoFadeInLeftSuperSmall' ).css({ 'visibility': '' });
            nav.css({ 'height': parentHeight });

            setTimeout( function() {

                submenu.removeClass( 'animated ueldo-animated-fast ueldoFadeOutRightSuperSmall' ).css({ 'display': '' });
                setTimeout( function() {

                    parents.children( 'a' ).removeClass( 'animated ueldo-animated-fast ueldoFadeInLeftSuperSmall' );

                }, 200 );

            }, 300 );

            $.UeldoConfigureSideMenuVerticalAlignments( parentHeight, true );

        }, 200 );

    });

   /**
    *
    * configure side menu vertical alignments
    *
    */

    $.UeldoConfigureSideMenuVerticalAlignments = function( b, animation ) {

        var sideMenu = $( '#ueldo-side-menu' );
        var sideMenuInner = sideMenu.find( '.ueldo-side-menu-inner' );
        var menuNav = sideMenu.find( '.ueldo-side-menu-inner nav' );
        var verticalAlignment = sideMenu.data( 'menu-vertical-alignment' );
        var beforeMenuContent = sideMenu.find( '.ueldo-side-menu-content-before-menu' );
        var afterMenuContent = sideMenu.find( '.ueldo-side-menu-content-after-menu' );

        if( menuNav.length !== 1 ) return;

        var a = beforeMenuContent.length == 1 ? beforeMenuContent[0].getBoundingClientRect().height : 0;
        if( b == false ) b = menuNav[0].getBoundingClientRect().height;
        var c = afterMenuContent.length == 1 ? afterMenuContent[0].getBoundingClientRect().height : 0;
        var d = sideMenu[0].getBoundingClientRect().height;

        switch( verticalAlignment ) {

            case 'top':

                if( ( a + b + c ) >= d ) {

                    if( animation == true ) sideMenuInner.animate({ 'height': ( a + b + c ) +'px' }, 200 );
                    else sideMenuInner.css({ 'height': ( a + b + c ) +'px' });
                }

                else {

                    if( animation == true ) sideMenuInner.animate({ 'height': d }, 200 );
                    else sideMenuInner.css({ 'height': d });
                }

            break;

            case 'middle':

                if( ( a + b + c ) >= d ) {

                    menuNav.css({ 'top': '' });

                    if( animation == true ) sideMenuInner.animate({ 'height': ( a + b + c ) +'px' }, 200 );
                    else sideMenuInner.css({ 'height': ( a + b + c ) +'px' });
                }

                else {

                    menuNav.css({ 'top': ( a + ( ( d - ( a + b + c ) ) / 2 ) ) +'px' });

                    if( animation == true ) sideMenuInner.animate({ 'height': d }, 200 );
                    else sideMenuInner.css({ 'height': d });
                }

            break;

            case 'bottom':

                if( ( a + b + c ) >= d ) {

                    menuNav.css({ 'top': '' });

                    if( animation == true ) sideMenuInner.animate({ 'height': ( a + b + c ) +'px' }, 200 );
                    else sideMenuInner.css({ 'height': ( a + b + c ) +'px' });
                }

                else {

                    menuNav.css({ 'top': ( d - c - b ) +'px' });

                    if( animation == true ) sideMenuInner.animate({ 'height': d }, 200 );
                    else sideMenuInner.css({ 'height': d });
                }

            break;
        }
    };

   /**
    *
    * show / hide side menu after click on button
    *
    */

    $( 'body' ).on( 'click', 'a[href="#ueldo-show-hide-side-menu"]', function( event ) {

        event.preventDefault();
        $.UeldoShowHideSideMenu( true );

    });

   /**
    *
    * alternative rules for hide side menu
    *
    */

    $( document ).mouseup( function( event ) {

        var sideMenu = $( '#ueldo-side-menu' );

       /**
        *
        * hide side menua fter click anywhere outside of it
        *
        */

        if( ueldo_javascript_functions_l10n.side_menu_closing_rules_anywhere_outside == 'yes' ) {

            if( !sideMenu.is( event.target ) && sideMenu.has( event.target ).length === 0 ) {

                if( sideMenu.data( 'is-menu-visible' ) == 'yes' ) $.UeldoShowHideSideMenu( false );
            }
        }

       /**
        *
        * hide side menu after click on any link inside
        *
        */

        if( ueldo_javascript_functions_l10n.side_menu_closing_rules_any_link_inside == 'yes' ) {

            var link = $( '#ueldo-side-menu a' );
            if( link.is( event.target ) || link.has( event.target ).length === 1 ) {

                if( sideMenu.data( 'is-menu-visible' ) == 'yes' ) $.UeldoShowHideSideMenu( false );
            }
        }

       /**
        *
        * end of rules.
        *
        */

    });

   /**
    *
    * show / hide side menu
    *
    */

    $.UeldoShowHideSideMenu = function( showAllowed ) {

        var sideMenu = $( '#ueldo-side-menu' );
        var deviceType = $.UeldoGetDeviceType();

        if( sideMenu.hasClass( 'ueldo-animation-proceed' ) ) return;
        sideMenu.addClass( 'ueldo-animation-proceed' );

        if( sideMenu.hasClass( 'ueldo-side-menu-style-static' ) && ( deviceType == 'desktop' || deviceType == 'tablet-horizontal' ) ) {

            sideMenu.removeClass( 'ueldo-animation-proceed' );
            return;
        }

        var leftOrRight = sideMenu.hasClass( 'ueldo-side-menu-container-position-left' ) ? 'left' : 'right';
        var isVisible = sideMenu.data( 'is-menu-visible' );
        var opacityAnimationEnabled = sideMenu.data( 'opacity-animation-enabled' );

        if( isVisible == 'no' ) {

            if( showAllowed == false ) {

                sideMenu.removeClass( 'ueldo-animation-proceed' );
                return;
            }

            else {

                if( opacityAnimationEnabled == 'yes' ) {

                    sideMenu.css({ 'visibility': 'visible' }).data( 'is-menu-visible', 'yes' ).attr( 'data-is-menu-visible', 'yes' );

                    if( leftOrRight == 'left' ) sideMenu.animate({ 'left': '0', 'opacity': '1' }, { duration: 300, complete: function() { sideMenu.removeClass( 'ueldo-animation-proceed' ); }});
                    else sideMenu.animate({ 'right': '0', 'opacity': '1' }, { duration: 300, complete: function() { sideMenu.removeClass( 'ueldo-animation-proceed' ); }});
                }

                else {

                    sideMenu.css({ 'visibility': 'visible', 'opacity': '1' }).data( 'is-menu-visible', 'yes' ).attr( 'data-is-menu-visible', 'yes' );

                    if( leftOrRight == 'left' ) sideMenu.animate({ 'left': '0' }, { duration: 300, complete: function() { sideMenu.removeClass( 'ueldo-animation-proceed' ); }});
                    else sideMenu.animate({ 'right': '0' }, { duration: 300, complete: function() { sideMenu.removeClass( 'ueldo-animation-proceed' ); }});
                }
            }
        }

        else {

            var sideMenuWidth = sideMenu[0].getBoundingClientRect().width;
            if( opacityAnimationEnabled == 'yes' ) {

                if( leftOrRight == 'left' ) sideMenu.animate({ 'left': '-'+ sideMenuWidth +'px', 'opacity': '0' }, { duration: 300, complete: function() { sideMenu.css({ 'visibility': 'hidden' }).data( 'is-menu-visible', 'no' ).attr( 'data-is-menu-visible', 'no' ); sideMenu.removeClass( 'ueldo-animation-proceed' ); }});
                else sideMenu.animate({ 'right': '-'+ sideMenuWidth +'px', 'opacity': '0' }, { duration: 300, complete: function() { sideMenu.css({ 'visibility': 'hidden' }).data( 'is-menu-visible', 'no' ).attr( 'data-is-menu-visible', 'no' ); sideMenu.removeClass( 'ueldo-animation-proceed' ); }});
            }

            else {

                if( leftOrRight == 'left' ) sideMenu.animate({ 'left': '-'+ sideMenuWidth +'px' }, { duration: 300, complete: function() { sideMenu.css({ 'visibility': 'hidden', 'opacity': '0' }).data( 'is-menu-visible', 'no' ).attr( 'data-is-menu-visible', 'no' ); sideMenu.removeClass( 'ueldo-animation-proceed' ); }});
                else sideMenu.animate({ 'right': '-'+ sideMenuWidth +'px' }, { duration: 300, complete: function() { sideMenu.css({ 'visibility': 'hidden', 'opacity': '0' }).data( 'is-menu-visible', 'no' ).attr( 'data-is-menu-visible', 'no' ); sideMenu.removeClass( 'ueldo-animation-proceed' ); }});
            }
        }
    };

   /**
    *
    * hide loader after all configuration is finished
    *
    */

    $.UeldoHideWebsiteLoader = function() {

        var loader = $( '#ueldo-website-loader' );
        if( loader.length == 1 ) {

            loader.animate({ 'opacity': '0' }, { duration: 300, complete: function() {

                loader.remove();

            }});
        }
    };

   /**
    *
    * configure header bar position in relation to wp admin bar on mobile devices
    *
    */

    $.UeldoConfigureHeaderBarPositionInRelationToAdminBar = function() {

        var wpadminbar = $( '#wpadminbar' );
        var headerBar = $( 'header.ueldo-header-bar.ueldo-header-bar-main.ueldo-header-bar-position-flying' );

        if( headerBar.length !== 1 ) headerBar = $( 'header.ueldo-header-bar.ueldo-header-bar-additional' );
        if( headerBar.length !== 1 ) return;

        if( $.UeldoGetDeviceType() != 'mobile' || wpadminbar.length !== 1 || wpadminbar.css( 'position' ) != 'absolute' ) {

            headerBar.css({ 'top': '' });
            return;
        }

        else {

            var wpadminbar_height = wpadminbar[0].getBoundingClientRect().height;
            var position = wpadminbar_height - $( window ).scrollTop() < 0 ? 0 : wpadminbar_height - $( window ).scrollTop();

            headerBar.css({ 'top': position });
            return;
        }
    };

   /**
    *
    * configure side menu position in relation to wp admin bar on mobile devices
    *
    */

    $.UeldoConfigureSideMenuPositionInRelationToAdminBar = function() {

        var wpadminbar = $( '#wpadminbar' );
        var sidemenu = $( '#ueldo-side-menu' );

        if( sidemenu.length !== 1 ) return;
        if( $.UeldoGetDeviceType() != 'mobile' || wpadminbar.length !== 1 || wpadminbar.css( 'position' ) != 'absolute' ) {

            sidemenu.css({ 'top': '', 'height': '' });
            return;
        }

        else {

            var wpadminbar_height = wpadminbar[0].getBoundingClientRect().height;
            var position = wpadminbar_height - $( window ).scrollTop() < 0 ? 0 : wpadminbar_height - $( window ).scrollTop();

            sidemenu.css({ 'top': position, 'height': 'calc( 100% - '+ position +'px )' });
            return;
        }
    };

   /**
    *
    * reconfigure side menu visibility
    *
    */

    $.UeldoReConfigureSideMenuVisibility = function() {

        var sidemenu = $( '#ueldo-side-menu' );
        var isStatic = sidemenu.hasClass( 'ueldo-side-menu-style-static' );

        if( isStatic == false ) return;

        var deviceType = $.UeldoGetDeviceType();
        var sidemenuWidth = sidemenu[0].getBoundingClientRect().width;
        var leftOrRight = sidemenu.hasClass( 'ueldo-side-menu-container-position-left' ) ? 'left' : 'right';

        if( deviceType == 'desktop' || deviceType == 'tablet-horizontal' ) {

            sidemenu.css({ 'visibility': 'visible', 'opacity': '1' }).data( 'is-menu-visible', 'yes' ).attr( 'data-is-menu-visible', 'yes' );
            sidemenu.css( leftOrRight, '0' );
        }

        else {

            sidemenu.css({ 'visibility': 'hidden', 'opacity': '0' }).data( 'is-menu-visible', 'no' ).attr( 'data-is-menu-visible', 'no' );
            sidemenu.css( leftOrRight, '-'+ sidemenuWidth +'px' );
        }
    };

   /**
    *
    * configure additional sidebar background sizes
    *
    */

    $.UeldoConfigureAdditionalSidebarBackgroundSizes = function() {

        var background = $( '.ueldo-sidebar-wrapper .ueldo-custom-sidebar-background' );
        if( background.length !== 1 ) return;

        var deviceType = $.UeldoGetDeviceType();
        var sidebarWrapper = background.parents( '.ueldo-sidebar-wrapper' );

        switch( deviceType ) {

            case 'desktop':
            case 'tablet-horizontal':

                var sidebarWrapperWidth = sidebarWrapper[0].getBoundingClientRect().width;
                var height = background.parents( '.ueldo-content-container' )[0].getBoundingClientRect().height;
                var width = ( ( $.UeldoGetWebsiteWidth() / 2 ) - ( $.UeldoGetContentWidth() / 2 ) ) + sidebarWrapperWidth + 45;

                background.css({ 'height': height, 'width': width, 'left': '', 'right': '' });

                setTimeout( function() {

                    var newHeight = background.parents( '.ueldo-content-container' )[0].getBoundingClientRect().height;
                    if( newHeight != height ) background.css({ 'height': newHeight });

                }, 50 );

            break;

            case 'tablet-vertical':
            case 'mobile':

                if( sidebarWrapper.data( 'sidebar-responsive-style' ) == 'flying' ) background.css({ 'height': '', 'width': '', 'left': '', 'right': '' });
                else {

                    var height = sidebarWrapper[0].getBoundingClientRect().height - 1;
                    var margin = ( $.UeldoGetWebsiteWidth() - $.UeldoGetContentWidth() ) / 2;
                    var width = $.UeldoGetWebsiteWidth();

                    if( margin == 0 ) margin = 30;

                    background.css({ 'height': height, 'width': width, 'left': '', 'right': '' });

                    if( ueldo_javascript_functions_l10n.is_rtl == 'yes' ) background.css({ 'right': '-'+ margin +'px' });
                    else background.css({ 'left': '-'+ margin +'px' });
                }

            break;
        }
    };

   /**
    *
    * reconfigure sidebar background size after click on comment reply link
    *
    */

    $( 'body' ).on( 'click', '.reply a.comment-reply-link, #cancel-comment-reply-link', function() {

        $.UeldoConfigureAdditionalSidebarBackgroundSizes();

        var intervalCounter = 0;
        ueldoIntervals['reconfigure-sidebar-background-size'] = setInterval( function() {

            if( intervalCounter >= 10 ) clearInterval( ueldoIntervals['reconfigure-sidebar-background-size'] );

            $.UeldoConfigureAdditionalSidebarBackgroundSizes();
            intervalCounter++;

        }, 100 );

        $( window ).trigger( 'ueldo-height-changed' );

    });

   /**
    *
    * fire all animations when the page end is reached
    *
    */

    $.UeldoFireAllAnimationsOnPageEnd = function() {

        if( ( window.innerHeight + window.scrollY ) >= document.body.offsetHeight ) {

            $( '.wpb_animate_when_almost_visible:not(.wpb_start_animation)' ).each( function() {

                var element = $( this );
                element.addClass( 'wpb_start_animation' );

            });
        }

    };

   /**
    *
    * retina-ready images for revolution slider
    *
    */

    $.UeldoRevolutionSliderConfigureRetinaReadyImages = function() {

        $( '.rev_slider .tp-bgimg, .rev_slider img' ).each( function() {

            if( ueldo_javascript_functions_l10n.retina_images_replacement_enabled == 'yes' ) {

                var image = $( this );

                image.data( 'rjs', '2' ).attr( 'data-rjs', '2' );
                retinajs( image, true );
            }

        });
    };

   /**
    *
    * configure website background for retina screens
    *
    */

    $.UeldoConfigureWebsiteBackgroundForRetina = function() {

        var body = $( 'body' );
        if( ueldo_javascript_functions_l10n.retina_images_replacement_enabled == 'yes' && $.UeldoIsRetina() == true && body.hasClass( 'custom-background' ) ) {

            var imageSrc = body.css( 'background-image' );
            var repeat = body.css( 'background-repeat' );

            if( imageSrc != false && imageSrc != null && imageSrc != '' ) {

                body.data( 'rjs', '2' ).attr( 'data-rjs', '2' ).css({ 'background-image': imageSrc });
                retinajs( body, false );

                imageSrc = imageSrc.replace( 'url(', '' ).replace( ')', '' ).replace( /\"/gi, "" );
                if( repeat == 'repeat' || repeat == 'repeat-x' || repeat == 'repeat-y' ) {

                    var image = document.createElement( 'img' );

                    image.setAttribute( 'src', imageSrc );
                    image.addEventListener('load', function () {

                        body.css({ 'background-size': image.naturalWidth +'px '+ image.naturalHeight +'px' });

                    });
                }
            }
        }
    };

   /**
    *
    * add placeholder to search field in woocommerce select2 field
    *
    */

    $( 'body' ).on( 'select2:open', 'select#billing_country, select#billing_state', function( event ) {

        var container = $( '.select2-container' );
        var input = container.find( 'input.select2-search__field' );

        if( input.length > 0 ) input.attr( 'placeholder', ueldo_javascript_functions_l10n.search );

    });

   /**
    *
    * function triggered on height change
    *
    */

    $( window ).on( 'ueldo-height-changed', function() {

       /**
        *
        * update custom footer fixed position on website height change
        *
        */

        $.UeldoConfigureCustomFooterFixedPosition();

       /**
        *
        * end of functions fired on height change
        *
        */

    });

   /**
    *
    * end of jquery functions.
    *
    */

});

var ueldoYouTubePlayers = [];

var ueldoYouTubeScriptTag = document.createElement( 'script' );
ueldoYouTubeScriptTag.src = 'https://www.youtube.com/iframe_api';

var ueldoYouTubeScriptFirstTag = document.getElementsByTagName( 'script' )[0];
ueldoYouTubeScriptFirstTag.parentNode.insertBefore( ueldoYouTubeScriptTag, ueldoYouTubeScriptFirstTag );

function onYouTubeIframeAPIReady() {

    var youtube_video_containers = document.querySelectorAll( '.ueldo-shortcode-card-layer-youtube-video-container, .ueldo-shortcode-row-layer-youtube-video-container' );
    var videoID;

    for( var i = 0; i < youtube_video_containers.length; i++ ) {

        videoID = youtube_video_containers[i].getAttribute( 'data-video-id' );
        ueldoYouTubePlayers[youtube_video_containers[i].id] = new YT.Player( youtube_video_containers[i].id, {
            height: '360',
            width: '640',
            videoId: videoID,
            playerVars: {
                'autoplay': 1,
                'controls': 0,
                'loop': 1,
                'playlist': videoID,
                'iv_load_policy': 3,
                'modestbranding': 1,
                'showinfo': 0,
                'branding': 0,
                'autohide': 0,
                'disablekb': 1,
                'enablejsapi': 1
            },
            events: {
                'onReady': onPlayerReady,
                'onStateChange': onStateChange
            }
        });
    }
}

function onPlayerReady( event ) {

    var player_id = event.target.a.id;

    ueldoYouTubePlayers[player_id].playVideo();
    ueldoYouTubePlayers[player_id].mute();
}

function onStateChange( event ) {

    if( event.data == YT.PlayerState.ENDED ) {

        var player_id = event.target.a.id;
        ueldoYouTubePlayers[player_id].seekTo( 0 );
    }
}