<?php

   /**
    *
    * get styles css
    *
    */

    function ueldo_customizer_get_styles_css() {

        # do we have ueldo plugin activated?
        if( ueldo_plugins::is_active_plugin( 'ueldo' ) ) {

            # we should get styles from cache?
            if( ueldo_dynamic_theme_styles_cache::can_generate() == false ) {

                # do we have styles for this page?
                if( ueldo_dynamic_theme_styles_cache::are_styles_cached() == true ) {

                    # end of the function.
                    return( true );
                }
            }
        }

        # global variables
        global $ueldo_styles_cache;

        # create object of styles cache class
        $styles = new ueldo_shortcodes_styles_cache();

        # get the styles rules array
        $rules = ueldo_customizer_get_styles_rules();

        # walk for each rule
        foreach( $rules as $rule ) {

            # style enabled flag
            $style_enabled = true;

            # do we have dependency settings?
            if( isset( $rule['dependency'] ) ) {

                # walk for each dependency rule
                foreach( $rule['dependency'] as $key => $value ) {

                    # compare
                    if( $ueldo_styles_cache -> get_style( $key ) != $value ) $style_enabled = false;
                }
            }

            # do we have style enabled?
            if( $style_enabled == false ) continue;
            else {

                # prepare rule styles array
                $rule_styles = array();

                # walk for each rule styles
                foreach( $rule['styles'] as $rule_style_key => $rule_style_value ) {

                    # is rule value an array?
                    if( is_array( $rule_style_value ) ) {

                        # responsive rules
                        if( in_array( $rule_style_key, array( '1200_more', '992_1199', '768_991', 'less_767', 'less_991' ), true ) ) {

                            # prepare rule substyles array
                            $rule_substyles = array();

                            # walk for each rule style values
                            foreach( $rule_style_value as $rule_substyle_key => $rule_substyle_value ) {

                                # update rule substyles array
                                $rule_substyles[esc_attr( $rule_substyle_key )] = esc_attr( $ueldo_styles_cache -> get_style( $rule_substyle_value ) );
                            }

                            # add rule only for selected device
                            $rule_styles[esc_attr( $rule_style_key )] = $rule_substyles;

                            # remove temporary variables
                            unset( $rule_substyles, $rule_substyle_key, $rule_substyle_value );
                        }

                        # patterns
                        else {

                            # walk for each pattern values
                            foreach( $rule_style_value['values'] as $pattern_key => $pattern_value ) {

                                # update pattern value
                                $rule_style_value['pattern'] = str_replace( '{'. esc_attr( $pattern_key ) .'}', $ueldo_styles_cache -> get_style( $pattern_value['color'], $pattern_value ), $rule_style_value['pattern'] );
                            }

                            # remove temporary variables
                            unset( $pattern_key, $pattern_value );

                            # box shadow?
                            if( $rule_style_key == 'box-shadow' ) {

                                # update rule styles array for webkit
                                $rule_styles['-webkit-'. esc_attr( $rule_style_key )] = esc_attr( $rule_style_value['pattern'] );

                                # update rule styles array for moz
                                $rule_styles['-moz-'. esc_attr( $rule_style_key )] = esc_attr( $rule_style_value['pattern'] );
                            }

                            # do we have math?
                            if( strpos( $rule_style_value['pattern'], 'math[' ) !== false ) {

                                # find the math begin
                                $math = substr( $rule_style_value['pattern'], strpos( $rule_style_value['pattern'], 'math[' ) );

                                # find the math end
                                $math = substr( $math, 0, ( strpos( $math, ']' ) + 1 ) );

                                # update pattern value
                                $rule_style_value['pattern'] = str_replace( $math, ueldo_parse_math_expression( trim( str_replace( 'math[', '', str_replace( ']', '', $math ) ) ) ), $rule_style_value['pattern'] );

                                # remove temporary variable
                                unset( $math );
                            }

                            # update rule styles array
                            $rule_styles[esc_attr( $rule_style_key )] = esc_attr( $rule_style_value['pattern'] );
                        }
                    }

                    # global value
                    else {

                        # update rule styles array
                        $rule_styles[esc_attr( $rule_style_key )] = esc_attr( $ueldo_styles_cache -> get_style( $rule_style_value ) );
                    }
                }

                # update css styles
                $styles -> update_style(
                    str_replace( '\"', '"', join( $rule['elements'], ', ' ) ),
                    $rule_styles
                );
            }

            # remove temporary variables
            unset( $rules, $rule_styles, $rule_style_key, $rule_style_value, $style_enabled );
        }

        # save css style
        $styles -> save_styles( false );

        # do we have ueldo plugin activated?
        if( ueldo_plugins::is_active_plugin( 'ueldo' ) ) {

            # can we save styles in cache?
            if( ueldo_dynamic_theme_styles_cache::can_save() == true ) {

                # save styles in cache
                ueldo_dynamic_theme_styles_cache::save_style_in_cache( 'customizer', ueldo_minify_css( $styles -> get_css() ) );

                # end of the function
                return( true );
            }
        }

        # cache disabled - display inline styles
        wp_add_inline_style( 'ueldo-stylesheet', ueldo_minify_css( $styles -> get_css() ) );
    }

   /**
    *
    * get an array of colors and styles rules
    *
    */

    function ueldo_customizer_get_styles_rules() {

        # return result array
        return( array(

           /**
            *
            * register style rules
            *
            */

            array(
                'elements' => array(
                    '.ueldo-website-wrapper',
                    '.ueldo-content-default',
                    'footer.ueldo-footer',
                    '.ueldo-shortcode-tabs:not(.ueldo-shortcode-tabs-style-05) .ueldo-shortcode-tabs-single-tabs-container .ueldo-shortcode-tabs-single-tab',
                    '.ueldo-shortcode-tabs.ueldo-shortcode-tabs-style-05 .ueldo-shortcode-tabs-single-tabs-content-container .ueldo-shortcode-tabs-single-tab',
                    '.ueldo-shortcode-tabs.ueldo-shortcode-tabs-style-04 .ueldo-shortcode-tabs-single-tabs-content-container',
                    'section.ueldo-sidebar .widget .tagcloud a',
                    '.wpb_content_element .widget .tagcloud a',
                    '.ueldo-content-default .ueldo-content-wrapper .ueldo-tags-and-categories p a.element',
                    '.ueldo-content-default .ueldo-content-wrapper .ueldo-single-news-page-switcher a .ueldo-single-news-page',
                    'section.ueldo-comments .ueldo-comments-pagination a.page-numbers',
                    'section.ueldo-comments ul.ueldo-comments-list li.comment .comment-respond',
                    '.ueldo-content-woocommerce nav.woocommerce-pagination ul.page-numbers li a',
                    'section.ueldo-sidebar .ueldo-widget-call-to-action:before',
                    '.wpb_content_element .ueldo-widget-call-to-action:before',
                    '.ueldo-shortcode-card',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector',
                    '.ueldo-shortcode-pulsating-circles .ueldo-shortcode-pulsating-circles-circle-central',
                    '.ueldo-shortcode-pricing-table.ueldo-shortcode-pricing-table-style-01 ul.ueldo-shortcode-pricing-table-attributes',
                    '.ueldo-shortcode-pricing-table.ueldo-shortcode-pricing-table-style-02 ul.ueldo-shortcode-pricing-table-attributes',
                    '.ueldo-shortcode-pricing-table.ueldo-shortcode-pricing-table-style-03',
                    '.ueldo-shortcode-pricing-list',
                    '.ueldo-shortcode-pricing-list .ueldo-shortcode-pricing-list-background-icons:after',
                    '.ueldo-shortcode-pricing-list .ueldo-shortcode-pricing-list-groups-selector',
                    '.ueldo-shortcode-pricing-list .ueldo-shortcode-pricing-list-groups-content',
                    '.ueldo-shortcode-price-single.ueldo-shortcode-price-single-with-delimiter .ueldo-shortcode-price-single-content .ueldo-shortcode-price-single-title-text',
                    '.ueldo-shortcode-price-single.ueldo-shortcode-price-single-with-delimiter .ueldo-shortcode-price-single-content .ueldo-shortcode-price-single-price-text',
                    '.ueldo-shortcode-full-width-testimonials .ueldo-shortcode-full-width-testimonials-single-testimonial-content',
                    '.ueldo-shortcode-full-width-testimonials .ueldo-shortcode-full-width-testimonials-clients-logos .ueldo-shortcode-full-width-testimonials-clients-logos-single-client .ueldo-shortcode-full-width-testimonials-clients-logos-single-client-image',
                    '.ueldo-shortcode-full-width-testimonials .ueldo-shortcode-full-width-testimonials-clients-logos .ueldo-shortcode-full-width-testimonials-clients-logos-single-client .ueldo-shortcode-full-width-testimonials-clients-logos-single-client-image-hover',
                    '.ueldo-shortcode-full-width-testimonials-next-prev-icon',
                    '.ueldo-shortcode-loop-next-prev-icon',
                    '.ueldo-shortcode-timeline-next-prev-icon',
                    '.ueldo-shortcode-announcement.ueldo-shortcode-announcement-type-custom',
                    '.ueldo-shortcode-loop',
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-box',
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-box .ueldo-shortcode-quote-box-inner',
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-box:before',
                    '.ueldo-shortcode-tabs-box ul.ueldo-shortcode-tabs-box-tabs-selector',
                    '.ueldo-shortcode-tabs-box ul.ueldo-shortcode-tabs-box-tabs-selector li.ueldo-shortcode-tabs-box-active-tab',
                    '.ueldo-shortcode-tabs-box .ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-tabs-contents-clear-line',
                    '.ueldo-shortcode-tabs-box .ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab .ueldo-shortcode-tabs-box-single-tab-content',
                    '.woocommerce div.product .woocommerce-tabs.wc-tabs-wrapper > ul.tabs.wc-tabs li.active',
                    '.woocommerce div.product .woocommerce-tabs.wc-tabs-wrapper .panel',
                    '.woocommerce div.product .woocommerce-tabs .ueldo-woocommerce-tabs-clear-line',
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-card',
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-card .ueldo-shortcode-timeline-element:before',
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-full-width .ueldo-shortcode-timeline-element:before',
                    '.ueldo-shortcode-presentation-elements-switcher',
                    '.ueldo-shortcode-presentation-point-of-interest .ueldo-shortcode-presentation-point-of-interest-content',
                    '.ueldo-shortcode-presentation-point-of-interest .ueldo-shortcode-presentation-point-of-interest-content:before',
                    '.ueldo-shortcode-presentation-point-of-interest .ueldo-shortcode-presentation-point-of-interest-inner::after',
                    '.ueldo-shortcode-presentation-point-of-interest .ueldo-shortcode-presentation-point-of-interest-inner::before',
                    '.ueldo-shortcode-presentation-point-of-interest-content-modal-close-inner::after',
                    '.ueldo-shortcode-presentation-point-of-interest-content-modal-close-inner::before',
                    '.ueldo-shortcode-opening-hours-box',
                    '.ueldo-shortcode-attributes-box .ueldo-shortcode-attributes-box-elements',
                    '.ueldo-shortcode-two-line-button'
                ),
                'styles' => array(
                    'background' => 'general-colors-website-background'
                )
            ),

            array(
                'elements' => array(
                    'h1',
                    'h1 a',
                    'a',
                    'section.ueldo-sidebar .widget ul:not(.ueldo-posts-list) > li > a:hover',
                    'section.ueldo-sidebar .widget ul:not(.ueldo-posts-list) > li > span.comment-author-link > a:hover',
                    '.wpb_content_element .widget ul:not(.ueldo-posts-list) > li > a:hover',
                    '.wpb_content_element .widget ul:not(.ueldo-posts-list) > li > span.comment-author-link > a:hover',
                    'section.ueldo-sidebar .widget ul.ueldo-posts-list li a:hover span.ueldo-posts-list-single-post-title',
                    '.wpb_content_element .widget ul.ueldo-posts-list li a:hover span.ueldo-posts-list-single-post-title',
                    'section.ueldo-sidebar .widget .tagcloud a:hover',
                    '.wpb_content_element .widget .tagcloud a:hover',
                    '.ueldo-content-default .ueldo-content-wrapper .ueldo-tags-and-categories p a.element:hover',
                    '.ueldo-content-default .ueldo-content-wrapper .ueldo-single-news-page-switcher a:hover .ueldo-single-news-page',
                    'section.ueldo-comments .ueldo-comments-pagination a.page-numbers:hover',
                    '.ueldo-content-woocommerce nav.woocommerce-pagination ul.page-numbers li a:hover',
                    '.ueldo-content-woocommerce nav.woocommerce-pagination ul.page-numbers li a:focus',
                    'section.ueldo-sidebar .ueldo-widget-call-to-action .ueldo-widget-call-to-action-offer',
                    '.wpb_content_element .ueldo-widget-call-to-action .ueldo-widget-call-to-action-offer',
                    'section.ueldo-sidebar .ueldo-widget-call-to-action .ueldo-widget-call-to-action-offer i:before',
                    '.wpb_content_element .ueldo-widget-call-to-action .ueldo-widget-call-to-action-offer i:before',
                    '.ueldo-content-default .ueldo-switch-page i.ueldo-switch-page-icon',
                    '.ueldo-content-default .ueldo-switch-page a:hover span.ueldo-switch-page-content-title',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector li:hover i',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector li:hover i:before',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector li.ueldo-shortcode-tabs-selector-single-tab-active i',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector li.ueldo-shortcode-tabs-selector-single-tab-active i:before',
                    '.ueldo-shortcode-pulsating-circles .ueldo-shortcode-pulsating-circles-circle-central i',
                    '.ueldo-shortcode-pulsating-circles .ueldo-shortcode-pulsating-circles-circle-central i:before',
                    '.ueldo-shortcode-attributes-box .ueldo-shortcode-attributes-box-elements ul li i',
                    '.ueldo-shortcode-attributes-box .ueldo-shortcode-attributes-box-elements ul li i:before',
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-element i',
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-element i:before',
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-element .ueldo-shortcode-info-box-element-text',
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-element .ueldo-shortcode-info-box-element-counter',
                    '.ueldo-shortcode-pricing-table .ueldo-shortcode-pricing-table-ribbon',
                    '.ueldo-shortcode-pricing-table .ueldo-shortcode-pricing-table-content-price .ueldo-shortcode-pricing-table-content-price-value',
                    '.ueldo-shortcode-pricing-table .ueldo-shortcode-pricing-table-content-price .ueldo-shortcode-pricing-table-content-price-currency',
                    '.ueldo-shortcode-pricing-table .ueldo-shortcode-pricing-table-content-price .ueldo-shortcode-pricing-table-content-price-after-value',
                    '.ueldo-shortcode-full-width-testimonials-next-prev-icon:hover i',
                    '.ueldo-shortcode-loop-next-prev-icon:hover i',
                    '.ueldo-shortcode-timeline-next-prev-icon:hover i',
                    '.ueldo-shortcode-accordion .ueldo-shortcode-accordion-single-element:not(.ueldo-shortcode-accordion-single-element-inactive) .ueldo-shortcode-accordion-single-element-title h1',
                    '.ueldo-shortcode-accordion .ueldo-shortcode-accordion-single-element.ueldo-shortcode-accordion-single-element-inactive .ueldo-shortcode-accordion-single-element-title:hover h1',
                    '.ueldo-shortcode-accordion .ueldo-shortcode-accordion-single-element:not(.ueldo-shortcode-accordion-single-element-inactive) .ueldo-shortcode-accordion-single-element-title h2',
                    '.ueldo-shortcode-accordion .ueldo-shortcode-accordion-single-element.ueldo-shortcode-accordion-single-element-inactive .ueldo-shortcode-accordion-single-element-title:hover h2',
                    '.ueldo-shortcode-accordion .ueldo-shortcode-accordion-single-element:not(.ueldo-shortcode-accordion-single-element-inactive) .ueldo-shortcode-accordion-single-element-title h3',
                    '.ueldo-shortcode-accordion .ueldo-shortcode-accordion-single-element.ueldo-shortcode-accordion-single-element-inactive .ueldo-shortcode-accordion-single-element-title:hover h3',
                    '.ueldo-shortcode-accordion .ueldo-shortcode-accordion-single-element:not(.ueldo-shortcode-accordion-single-element-inactive) .ueldo-shortcode-accordion-single-element-title h4',
                    '.ueldo-shortcode-accordion .ueldo-shortcode-accordion-single-element.ueldo-shortcode-accordion-single-element-inactive .ueldo-shortcode-accordion-single-element-title:hover h4',
                    '.ueldo-shortcode-accordion .ueldo-shortcode-accordion-single-element:not(.ueldo-shortcode-accordion-single-element-inactive) .ueldo-shortcode-accordion-single-element-title h5',
                    '.ueldo-shortcode-accordion .ueldo-shortcode-accordion-single-element.ueldo-shortcode-accordion-single-element-inactive .ueldo-shortcode-accordion-single-element-title:hover h5',
                    '.ueldo-shortcode-accordion .ueldo-shortcode-accordion-single-element:not(.ueldo-shortcode-accordion-single-element-inactive) .ueldo-shortcode-accordion-single-element-title h6',
                    '.ueldo-shortcode-accordion .ueldo-shortcode-accordion-single-element.ueldo-shortcode-accordion-single-element-inactive .ueldo-shortcode-accordion-single-element-title:hover h6',
                    '.ueldo-shortcode-icon-list .ueldo-shortcode-icon-list-single-element .ueldo-shortcode-icon-list-single-element-icon i',
                    '.ueldo-shortcode-icon-list .ueldo-shortcode-icon-list-single-element .ueldo-shortcode-icon-list-single-element-icon i:before',
                    '.ueldo-shortcode-icon-list .ueldo-shortcode-icon-list-single-element .ueldo-shortcode-icon-list-single-element-number span.ueldo-shortcode-icon-list-single-element-number-value',
                    '.ueldo-shortcode-tabs-box ul.ueldo-shortcode-tabs-box-tabs-selector li.ueldo-shortcode-tabs-box-active-tab i',
                    '.ueldo-shortcode-tabs-box ul.ueldo-shortcode-tabs-box-tabs-selector li:not(.ueldo-shortcode-tabs-box-active-tab):hover i',
                    '.ueldo-shortcode-tabs-box .ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab.ueldo-shortcode-tabs-box-active-tab .ueldo-shortcode-tabs-box-single-tab-title i',
                    '.ueldo-shortcode-tabs-box .ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab:not(.ueldo-shortcode-tabs-box-active-tab):hover .ueldo-shortcode-tabs-box-single-tab-title i',
                    '.ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-prev-images i',
                    '.ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-next-images i',
                    '.ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-prev-images:hover span.ueldo-shortcode-presentation-elements-switcher-prev-images-content',
                    '.ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-next-images:hover span.ueldo-shortcode-presentation-elements-switcher-next-images-content',
                    '.ueldo-shortcode-opening-hours-box .ueldo-shortcode-opening-hours-box-heading .ueldo-shortcode-opening-hours-box-heading-title'
                ),
                'styles' => array(
                    'color' => 'general-colors-main-color'
                )
            ),

            array(
                'elements' => array(
                    'h2',
                    'h3',
                    'h4',
                    'h5',
                    'h6',
                    'h2 a',
                    'h3 a',
                    'h4 a',
                    'h5 a',
                    'h6 a',
                    'p strong',
                    'li strong',
                    'b',
                    'strong',
                    'dt',
                    '.ueldo-content-default .ueldo-content-wrapper table:not(.highlight) th',
                    'section.ueldo-sidebar .widget ul:not(.ueldo-posts-list) li a',
                    '.wpb_content_element .widget ul:not(.ueldo-posts-list) li a',
                    '.ueldo-content-default .ueldo-content-wrapper .ueldo-tags-and-categories p span.ueldo-tags-and-categories-title',
                    'section.ueldo-comments ul.ueldo-comments-list li .comment-author cite.fn a',
                    'section.ueldo-comments .ueldo-comments-pagination span.page-numbers.current',
                    '.ueldo-content-default .ueldo-content-wrapper .ueldo-single-news-page-switcher span.ueldo-single-news-page',
                    '.ueldo-content-woocommerce nav.woocommerce-pagination ul.page-numbers li span.page-numbers.current',
                    'section.ueldo-sidebar .widget ul.ueldo-posts-list li a',
                    'section.ueldo-sidebar .widget ul.ueldo-posts-list li a span.ueldo-posts-list-single-post-title',
                    '.wpb_content_element .widget ul.ueldo-posts-list li a',
                    '.wpb_content_element .widget ul.ueldo-posts-list li a span.ueldo-posts-list-single-post-title',
                    '.ueldo-content-default .ueldo-switch-page span.ueldo-switch-page-content-title',
                    '.ueldo-content-default .ueldo-blog-post-title',
                    '.ueldo-content-default .ueldo-blog-post-title a',
                    '.ueldo-content-default .ueldo-content-wrapper h1:not(.ueldo-blog-post-title)',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector li:hover .ueldo-shortcode-tabs-selector-single-tab-title',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector li.ueldo-shortcode-tabs-selector-single-tab-active .ueldo-shortcode-tabs-selector-single-tab-title',
                    '.ueldo-shortcode-attributes-box .ueldo-shortcode-attributes-box-elements ul li .ueldo-shortcode-attributes-box-element-title',
                    '.ueldo-shortcode-pricing-list ul.ueldo-shortcode-pricing-list-groups-content-group-attributes-list li span.ueldo-shortcode-pricing-list-attribute-price',
                    '.ueldo-shortcode-price-single .ueldo-shortcode-price-single-column .ueldo-shortcode-price-single-content .ueldo-shortcode-price-single-title',
                    '.ueldo-shortcode-price-single .ueldo-shortcode-price-single-column .ueldo-shortcode-price-single-content .ueldo-shortcode-price-single-price',
                    '.ueldo-shortcode-full-width-testimonials .ueldo-shortcode-full-width-testimonials-single-testimonial-author p.ueldo-shortcode-full-width-testimonials-single-testimonial-author-name',
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-box .ueldo-shortcode-quote-box-inner p',
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-author .ueldo-shortcode-quote-author-content p.ueldo-shortcode-quote-author-content-author-name',
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list li.ueldo-shortcode-filtered-masonry-filter-active',
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list li:hover',
                    '.ueldo-shortcode-tabs-box ul.ueldo-shortcode-tabs-box-tabs-selector li',
                    '.ueldo-shortcode-tabs-box .ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab .ueldo-shortcode-tabs-box-single-tab-title',
                    '.woocommerce div.product .woocommerce-tabs.wc-tabs-wrapper > ul.tabs.wc-tabs li a',
                    '.ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-prev-images span.ueldo-shortcode-presentation-elements-switcher-prev-images-content',
                    '.ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-next-images span.ueldo-shortcode-presentation-elements-switcher-next-images-content',
                    '.ueldo-shortcode-opening-hours-box .ueldo-shortcode-opening-hours-box-elements .ueldo-shortcode-opening-hours-box-element .ueldo-shortcode-opening-hours-box-element-title',
                    '.ueldo-shortcode-two-line-button .ueldo-shortcode-two-line-button-content-title',
                    '.woocommerce div.product div.product_meta span.posted_in',
                    '.woocommerce div.product div.product_meta span.tagged_as'
                ),
                'styles' => array(
                    'color' => 'general-colors-headings-color'
                )
            ),

            array(
                'elements' => array(
                    'h1 span.ueldo-heading-subtitle',
                    'h2 span.ueldo-heading-subtitle',
                    'h3 span.ueldo-heading-subtitle',
                    'h4 span.ueldo-heading-subtitle',
                    'h5 span.ueldo-heading-subtitle',
                    'h6 span.ueldo-heading-subtitle',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector li .ueldo-shortcode-tabs-selector-single-tab-title',
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list li'
                ),
                'styles' => array(
                    'color' => 'general-colors-headings-subtitle-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-content-default article.ueldo-blog-post .ueldo-blog-post-data ul li',
                    '.ueldo-content-default article.ueldo-blog-post .ueldo-blog-post-data ul li span',
                    '.ueldo-content-default article.ueldo-blog-post .ueldo-blog-post-data ul li a:not(:hover)'
                ),
                'styles' => array(
                    'color' => 'general-colors-blog-post-data-color'
                )
            ),

            array(
                'elements' => array(
                    'p',
                    'ul li',
                    'ol li',
                    '.ueldo-content-default .ueldo-content-wrapper table:not(.highlight) td',
                    '.ueldo-content-default .ueldo-content-wrapper dl:not(.gallery-item) dd',
                    '.ueldo-content-default .ueldo-content-wrapper address',
                    'section.ueldo-sidebar .widget .tagcloud a',
                    '.wpb_content_element .widget .tagcloud a',
                    '.ueldo-content-default .ueldo-content-wrapper .ueldo-tags-and-categories p a.element',
                    '.ueldo-content-default .ueldo-content-wrapper .ueldo-single-news-page-switcher a .ueldo-single-news-page',
                    'section.ueldo-comments .ueldo-comments-pagination a.page-numbers',
                    'section.ueldo-comments ul.ueldo-comments-list li .comment-meta a',
                    '.ueldo-content-woocommerce nav.woocommerce-pagination ul.page-numbers li a',
                    '.ueldo-content-default .ueldo-switch-page span.ueldo-switch-page-content-highlight',
                    '.ueldo-shortcode-info-box p.ueldo-shortcode-info-box-subtitle a',
                    '.ueldo-shortcode-announcement.ueldo-shortcode-announcement-type-custom *',
                    '.ueldo-shortcode-opening-hours-box .ueldo-shortcode-opening-hours-box-elements .ueldo-shortcode-opening-hours-box-element .ueldo-shortcode-opening-hours-box-element-value',
                    '.ueldo-shortcode-two-line-button .ueldo-shortcode-two-line-button-content-subtitle'
                ),
                'styles' => array(
                    'color' => 'general-colors-content-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-content-default .ueldo-content-wrapper code',
                    '.ueldo-content-default .ueldo-content-wrapper kbd',
                    '.ueldo-content-default .ueldo-content-wrapper pre',
                    '.ueldo-website-wrapper pre'
                ),
                'styles' => array(
                    'color' => 'general-colors-preformatted-text-color'
                )
            ),

            array(
                'elements' => array(
                    'blockquote',
                    'blockquote p'
                ),
                'styles' => array(
                    'color' => 'general-colors-blockquote-color'
                )
            ),

            array(
                'elements' => array(
                    'section.ueldo-sidebar .widget .tagcloud a',
                    '.wpb_content_element .widget .tagcloud a',
                    '.ueldo-content-default .ueldo-content-wrapper .ueldo-tags-and-categories p a.element',
                    '.ueldo-content-default .ueldo-content-wrapper .ueldo-single-news-page-switcher a .ueldo-single-news-page',
                    'section.ueldo-comments .ueldo-comments-pagination a.page-numbers',
                    'section.ueldo-comments ul.ueldo-comments-list li.comment .comment-respond',
                    '.ueldo-content-woocommerce nav.woocommerce-pagination ul.page-numbers li a',
                    '.ueldo-content-default section.ueldo-author-box',
                    '.ueldo-short-post-box',
                    'section.ueldo-sidebar .ueldo-widget-call-to-action',
                    '.wpb_content_element .ueldo-widget-call-to-action',
                    'section.ueldo-sidebar .ueldo-widget-call-to-action:before',
                    '.wpb_content_element .ueldo-widget-call-to-action:before',
                    'footer.ueldo-footer',
                    '.ueldo-content-default .ueldo-content-wrapper table:not(.highlight) tr',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h1',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h2',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h3',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h4',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h5',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h6',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector.ueldo-shortcode-tabs-selector-01',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector.ueldo-shortcode-tabs-selector-03',
                    '.ueldo-shortcode-pricing-table',
                    '.ueldo-shortcode-pricing-table.ueldo-shortcode-pricing-table-style-01 .ueldo-shortcode-pricing-table-content',
                    '.ueldo-shortcode-pricing-table.ueldo-shortcode-pricing-table-style-02 .ueldo-shortcode-pricing-table-heading',
                    '.ueldo-shortcode-pricing-list',
                    '.ueldo-shortcode-pricing-list:before',
                    '.ueldo-shortcode-pricing-list ul.ueldo-shortcode-pricing-list-groups-content-group-attributes-list.ueldo-shortcode-pricing-list-groups-content-group-attributes-list-left',
                    '.ueldo-shortcode-pricing-list ul.ueldo-shortcode-pricing-list-groups-content-group-attributes-list li',
                    '.ueldo-shortcode-card',
                    '.ueldo-shortcode-accordion',
                    '.ueldo-shortcode-accordion .ueldo-shortcode-accordion-single-element',
                    '.ueldo-shortcode-icon-list .ueldo-shortcode-icon-list-single-element .ueldo-shortcode-icon-list-single-element-icon',
                    '.ueldo-shortcode-icon-list .ueldo-shortcode-icon-list-single-element .ueldo-shortcode-icon-list-single-element-number',
                    '.ueldo-shortcode-announcement.ueldo-shortcode-announcement-type-custom',
                    '.ueldo-shortcode-loop .ueldo-shortcode-loop-row-group .ueldo-shortcode-loop-row-group-single-row-single-cell .ueldo-shortcode-loop-cell',
                    '.ueldo-shortcode-filtered-masonry .ueldo-shortcode-filtered-masonry-cell .ueldo-shortcode-filtered-masonry-cell-inner',
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-box',
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-box:before',
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list',
                    '.ueldo-shortcode-tabs-box ul.ueldo-shortcode-tabs-box-tabs-selector',
                    '.ueldo-shortcode-tabs-box ul.ueldo-shortcode-tabs-box-tabs-selector li',
                    '.ueldo-shortcode-tabs-box .ueldo-shortcode-tabs-box-tabs-contents',
                    '.ueldo-shortcode-tabs-box .ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab .ueldo-shortcode-tabs-box-single-tab-title',
                    '.ueldo-shortcode-tabs-box .ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab .ueldo-shortcode-tabs-box-single-tab-content',
                    '.woocommerce div.product .woocommerce-tabs.wc-tabs-wrapper > ul.tabs.wc-tabs',
                    '.woocommerce div.product .woocommerce-tabs.wc-tabs-wrapper > ul.tabs.wc-tabs li',
                    '.woocommerce div.product .woocommerce-tabs.wc-tabs-wrapper .panel',
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-card',
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-card .ueldo-shortcode-timeline-element:before',
                    '.ueldo-shortcode-timeline-next-prev-icon',
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-full-width .ueldo-shortcode-timeline-element:before',
                    '.ueldo-shortcode-presentation .ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-prev-images',
                    '.ueldo-shortcode-presentation .ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-next-images',
                    '.ueldo-shortcode-opening-hours-status .ueldo-shortcode-opening-hours-status-container',
                    '.ueldo-shortcode-opening-hours-box',
                    '.ueldo-shortcode-opening-hours-box .ueldo-shortcode-opening-hours-box-elements .ueldo-shortcode-opening-hours-box-element',
                    '.ueldo-shortcode-opening-hours-box .ueldo-shortcode-opening-hours-box-heading',
                    '.ueldo-shortcode-post-page-box .ueldo-shortcode-post-page-box-card',
                    '.ueldo-shortcode-attributes-box .ueldo-shortcode-attributes-box-elements',
                    '.ueldo-content-default .ueldo-content-wrapper code',
                    '.ueldo-content-default .ueldo-content-wrapper kbd',
                    '.ueldo-content-default .ueldo-content-wrapper pre',
                    '.ueldo-website-wrapper pre',
                    '.ueldo-shortcode-two-line-button',
                    '.ueldo-shortcode-loop-separate-next-prev-icons .ueldo-shortcode-loop-next-prev-icon',
                    '.ueldo-content-default article.ueldo-blog-post.sticky'
                ),
                'styles' => array(
                    'border-color' => 'general-colors-elements-border-color'
                )
            ),

            array(
                'elements' => array(
                    'section.ueldo-sidebar .widget > ul:not(.ueldo-posts-list) > li:after',
                    'section.ueldo-sidebar .widget ul.menu > li:after',
                    '.wpb_content_element .widget > ul:not(.ueldo-posts-list) > li:after',
                    '.wpb_content_element .widget ul.menu > li:after',
                    '.ueldo-content-default .ueldo-content-wrapper hr'
                ),
                'styles' => array(
                    'background' => 'general-colors-elements-border-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-sidebar-wrapper .ueldo-custom-sidebar-background'
                ),
                'styles' => array(
                    'background' => 'sidebar-background-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-content-default[data-ueldo-content-default-sidebar-side=\"left\"] .ueldo-sidebar-wrapper[data-sidebar-responsive-style=\"flying\"] .ueldo-widget-call-to-action',
                    '.ueldo-sidebar-flying[data-flying-sidebar-side=\"left\"] .ueldo-widget-call-to-action'
                ),
                'styles' => array(
                    'border-right-color' => 'flying-sidebar-border-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-content-default[data-ueldo-content-default-sidebar-side=\"right\"] .ueldo-sidebar-wrapper[data-sidebar-responsive-style=\"flying\"] .ueldo-widget-call-to-action',
                    '.ueldo-sidebar-flying[data-flying-sidebar-side=\"right\"] .ueldo-widget-call-to-action'
                ),
                'styles' => array(
                    'border-left-color' => 'flying-sidebar-border-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list li',
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list li:last-child'
                ),
                'styles' => array(
                    '768_991' => array(
                        'border-color' => 'general-colors-elements-inset-border-color'
                    )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list.ueldo-shortcode-filtered-masonry-filter-list-as-table[data-tabs-per-row=\"5\"] li:nth-child( 5n+1 ):before',
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list.ueldo-shortcode-filtered-masonry-filter-list-as-table[data-tabs-per-row=\"4\"] li:nth-child( 4n+1 ):before',
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list.ueldo-shortcode-filtered-masonry-filter-list-as-table[data-tabs-per-row=\"3\"] li:nth-child( 3n+1 ):before',
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list.ueldo-shortcode-filtered-masonry-filter-list-as-table[data-tabs-per-row=\"2\"] li:nth-child( 2n+1 ):before',
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list.ueldo-shortcode-filtered-masonry-filter-list-as-table[data-tabs-per-row=\"1\"] li:before'
                ),
                'styles' => array(
                    'background' => 'general-colors-elements-inset-border-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-content-default article.ueldo-blog-post.sticky'
                ),
                'styles' => array(
                    'border-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) .'-color' => 'general-colors-main-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-pricing-list .ueldo-shortcode-pricing-list-groups-content'
                ),
                'styles' => array(
                    'less_767' => array(
                        'border-color' => 'general-colors-elements-border-color'
                    )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list li',
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list li:last-child'
                ),
                'styles' => array(
                    'less_767' => array(
                        'border-color' => 'general-colors-elements-inset-border-color'
                    )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-pricing-table .ueldo-shortcode-pricing-table-ribbon',
                    '.ueldo-shortcode-pricing-table.ueldo-shortcode-pricing-table-style-03 .ueldo-shortcode-pricing-table-content-title-line',
                    '.ueldo-shortcode-pricing-list:after',
                    '.ueldo-shortcode-price-single.ueldo-shortcode-price-single-with-delimiter .ueldo-shortcode-price-single-content:before',
                    '.ueldo-shortcode-delimiter',
                    '.ueldo-shortcode-progress-bar .ueldo-shortcode-progress-bar-line',
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-card:before',
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-full-width:before'
                ),
                'styles' => array(
                    'background' => 'general-colors-elements-border-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-content-default .ueldo-content-container:before',
                    '.vc_row.ueldo-row-with-sidebar-on-left .ueldo-row-with-sidebar-divider-line',
                    '.vc_row.ueldo-row-with-sidebar-on-right .ueldo-row-with-sidebar-divider-line'
                ),
                'styles' => array(
                    'background' => esc_attr( ueldo_get_theme_options_value( 'styles', false, 'sidebar-border-line-custom-color-enabled' ) == 'yes' ? 'sidebar-border-line-custom-color' : 'general-colors-elements-border-color' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector.ueldo-shortcode-tabs-selector-as-table[data-tabs-per-row=\"5\"] li:nth-child( 5n+1 ):before',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector.ueldo-shortcode-tabs-selector-as-table[data-tabs-per-row=\"4\"] li:nth-child( 4n+1 ):before',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector.ueldo-shortcode-tabs-selector-as-table[data-tabs-per-row=\"3\"] li:nth-child( 3n+1 ):before',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector.ueldo-shortcode-tabs-selector-as-table[data-tabs-per-row=\"2\"] li:nth-child( 2n+1 ):before',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector.ueldo-shortcode-tabs-selector-as-table[data-tabs-per-row=\"1\"] li:before'
                ),
                'styles' => array(
                    'background' => 'general-colors-elements-inset-border-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-circle-navigation li .ueldo-circle-navigation-element'
                ),
                'styles' => array(
                    'background' => 'general-colors-circle-navigation-background-color',
                    'border-color' => 'general-colors-website-background'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-circle-navigation li:hover .ueldo-circle-navigation-element',
                    '.ueldo-circle-navigation li .ueldo-circle-navigation-element.ueldo-circle-navigation-element-active',
                    'section.ueldo-sidebar .ueldo-widget-call-to-action:hover:before',
                    '.wpb_content_element .ueldo-widget-call-to-action:hover:before',
                    '.ueldo-play-video-button:hover .ueldo-play-video-button-icon',
                    '.ueldo-image-caption .ueldo-image-caption-icon:hover',
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-card .ueldo-shortcode-timeline-element .ueldo-shortcode-timeline-element-date'
                ),
                'styles' => array(
                    'background' => 'general-colors-main-color',
                    'border-color' => 'general-colors-main-color'
                )
            ),

            array(
                'elements' => array(
                    'section.ueldo-sidebar .widget .tagcloud a',
                    '.wpb_content_element .widget .tagcloud a',
                    '.ueldo-content-default .ueldo-content-wrapper .ueldo-tags-and-categories p a.element',
                    '.ueldo-content-default .ueldo-content-wrapper .ueldo-single-news-page-switcher a .ueldo-single-news-page',
                    'section.ueldo-comments .ueldo-comments-pagination a.page-numbers',
                    'section.ueldo-comments ul.ueldo-comments-list li.comment .comment-respond',
                    '.ueldo-content-woocommerce nav.woocommerce-pagination ul.page-numbers li a',
                    'section.ueldo-sidebar .ueldo-widget-call-to-action',
                    '.wpb_content_element .ueldo-widget-call-to-action',
                    '.ueldo-content-default section.ueldo-author-box',
                    '.ueldo-short-post-box',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector.ueldo-shortcode-tabs-selector-01',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector.ueldo-shortcode-tabs-selector-03',
                    '.ueldo-shortcode-attributes-box .ueldo-shortcode-attributes-box-elements',
                    '.ueldo-shortcode-pricing-table',
                    '.ueldo-shortcode-pricing-list',
                    '.ueldo-shortcode-card',
                    '.ueldo-shortcode-accordion',
                    '.ueldo-shortcode-announcement.ueldo-shortcode-announcement-type-custom',
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-box',
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list',
                    '.ueldo-shortcode-tabs-box ul.ueldo-shortcode-tabs-box-tabs-selector',
                    '.ueldo-shortcode-tabs-box .ueldo-shortcode-tabs-box-tabs-contents',
                    '.woocommerce div.product .woocommerce-tabs.wc-tabs-wrapper > ul.tabs.wc-tabs',
                    '.woocommerce div.product .woocommerce-tabs.wc-tabs-wrapper .panel',
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-card',
                    '.ueldo-shortcode-opening-hours-box',
                    '.ueldo-shortcode-post-page-box .ueldo-shortcode-post-page-box-card',
                    '.ueldo-shortcode-two-line-button'
                ),
                'styles' => array(
                    '-webkit-box-shadow' => 'general-colors-elements-box-shadow',
                    '-moz-box-shadow' => 'general-colors-elements-box-shadow',
                    'box-shadow' => 'general-colors-elements-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    'section.ueldo-sidebar .widget .tagcloud a:hover',
                    '.wpb_content_element .widget .tagcloud a:hover',
                    '.ueldo-content-default .ueldo-content-wrapper .ueldo-tags-and-categories p a.element:hover',
                    '.ueldo-content-default .ueldo-content-wrapper .ueldo-single-news-page-switcher a:hover .ueldo-single-news-page',
                    'section.ueldo-comments .ueldo-comments-pagination a.page-numbers:hover',
                    'section.ueldo-comments ul.ueldo-comments-list li.comment .comment-respond:hover',
                    '.ueldo-content-woocommerce nav.woocommerce-pagination ul.page-numbers li a:hover',
                    '.ueldo-content-woocommerce nav.woocommerce-pagination ul.page-numbers li a:focus',
                    'section.ueldo-sidebar .ueldo-widget-call-to-action:hover',
                    '.wpb_content_element .ueldo-widget-call-to-action:hover',
                    '.ueldo-content-default section.ueldo-author-box:hover',
                    '.ueldo-short-post-box:hover',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector.ueldo-shortcode-tabs-selector-01:hover',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector.ueldo-shortcode-tabs-selector-03:hover',
                    '.ueldo-shortcode-attributes-box .ueldo-shortcode-attributes-box-elements:hover',
                    '.ueldo-shortcode-pricing-table:hover',
                    '.ueldo-shortcode-pricing-list:hover',
                    '.ueldo-shortcode-card:hover',
                    '.ueldo-shortcode-accordion:hover',
                    '.ueldo-shortcode-announcement.ueldo-shortcode-announcement-type-custom:hover',
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-box:hover',
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list:hover',
                    '.ueldo-shortcode-tabs-box:hover ul.ueldo-shortcode-tabs-box-tabs-selector',
                    '.ueldo-shortcode-tabs-box:hover .ueldo-shortcode-tabs-box-tabs-contents',
                    '.woocommerce div.product .woocommerce-tabs.wc-tabs-wrapper:hover > ul.tabs.wc-tabs',
                    '.woocommerce div.product .woocommerce-tabs.wc-tabs-wrapper:hover .panel',
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-card:hover',
                    '.ueldo-shortcode-opening-hours-box:hover',
                    '.ueldo-shortcode-post-page-box .ueldo-shortcode-post-page-box-card:hover',
                    '.ueldo-shortcode-two-line-button:hover'
                ),
                'styles' => array(
                    'border-color' => 'general-colors-elements-hover-border-color',
                    '-webkit-box-shadow' => 'general-colors-elements-hover-box-shadow',
                    '-moz-box-shadow' => 'general-colors-elements-hover-box-shadow',
                    'box-shadow' => 'general-colors-elements-hover-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-box:hover:before',
                    '.ueldo-shortcode-timeline-next-prev-icon:hover',
                    '.ueldo-shortcode-loop-separate-next-prev-icons .ueldo-shortcode-loop-next-prev-icon:hover'
                ),
                'styles' => array(
                    'border-color' => 'general-colors-elements-hover-border-color',
                )
            ),

            array(
                'elements' => array(
                    'section.ueldo-comments .ueldo-comments-pagination i.fa.fa-long-arrow-left',
                    'section.ueldo-comments .ueldo-comments-pagination i.fa.fa-long-arrow-right',
                    'section.ueldo-comments ul.ueldo-comments-list li.comment .ueldo-comments-reply-link i',
                    '.ueldo-shortcode-full-width-testimonials-next-prev-icon i',
                    '.ueldo-shortcode-loop-next-prev-icon i',
                    '.ueldo-shortcode-timeline-next-prev-icon i',
                    '.ueldo-shortcode-tabs-box ul.ueldo-shortcode-tabs-box-tabs-selector li i',
                    '.ueldo-shortcode-tabs-box .ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab .ueldo-shortcode-tabs-box-single-tab-title i',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector li i',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector li i:before',
                    '.ueldo-shortcode-two-line-button i',
                    '.ueldo-shortcode-icon i'
                ),
                'styles' => array(
                    'color' => 'general-colors-icon-color'
                )
            ),

            array(
                'elements' => array(
                    'section.ueldo-comments ul.ueldo-comments-list li.comment.bypostauthor .ueldo-comment-by-post-author',
                    '.ueldo-shortcode-pulsating-circles .ueldo-shortcode-pulsating-circles-circle-central .ueldo-shortcode-pulsating-circles-tip',
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-additional-element',
                    '.ueldo-shortcode-progress-bar .ueldo-shortcode-progress-bar-line .ueldo-shortcode-progress-bar-line-value',
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-full-width .ueldo-shortcode-timeline-element .ueldo-shortcode-timeline-element-date',
                    '.select2-container--default .select2-results__option[aria-selected=true], .select2-container--default .select2-results__option[data-selected=true]'
                ),
                'styles' => array(
                    'background' => 'general-colors-main-color',
                    'color' => 'general-colors-main-color-contrast-text-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-pulsating-circles .ueldo-shortcode-pulsating-circles-circle-central .ueldo-shortcode-pulsating-circles-tip',
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-additional-element'
                ),
                'styles' => array(
                    'box-shadow' => ueldo_get_color_pattern_options( 'pulsating-circles-tip-and-info-box-additional-element-box-shadow' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-image',
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-additional-element',
                    '.ueldo-shortcode-two-images-difference',
                    '.ueldo-shortcode-google-map.ueldo-google-map-container',
                    '.ueldo-shortcode-presentation-point-of-interest .ueldo-shortcode-presentation-point-of-interest-content',
                    '.ueldo-shortcode-presentation-point-of-interest .ueldo-shortcode-presentation-point-of-interest-content:not(.ueldo-shortcode-presentation-point-of-interest-content-without-arrow):before'
                ),
                'styles' => array(
                    'border-color' => 'general-colors-website-background'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-tabs-box ul.ueldo-shortcode-tabs-box-tabs-selector li.ueldo-shortcode-tabs-box-active-tab',
                    '.woocommerce div.product .woocommerce-tabs.wc-tabs-wrapper > ul.tabs.wc-tabs li.active'
                ),
                'styles' => array(
                    'border-bottom-color' => 'general-colors-website-background'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-pulsating-circles .ueldo-shortcode-pulsating-circles-circle-central .ueldo-shortcode-pulsating-circles-tip *',
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-additional-element i',
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-additional-element i:before',
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-additional-element .ueldo-shortcode-info-box-additional-element-text',
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-additional-element .ueldo-shortcode-info-box-additional-element-counter',
                    '.ueldo-shortcode-progress-bar .ueldo-shortcode-progress-bar-line h6',
                    '.ueldo-shortcode-progress-bar .ueldo-shortcode-progress-bar-line h6 *',
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-card .ueldo-shortcode-timeline-element .ueldo-shortcode-timeline-element-date'
                ),
                'styles' => array(
                    'color' => 'general-colors-main-color-contrast-text-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-pulsating-circles .ueldo-shortcode-pulsating-circles-circle-central .ueldo-shortcode-pulsating-circles-tip:before',
                    '.ueldo-shortcode-presentation-point-of-interest'
                ),
                'styles' => array(
                    'background' => 'general-colors-main-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-pulsating-circles .ueldo-shortcode-pulsating-circles-circle-central'
                ),
                'styles' => array(
                    '-webkit-box-shadow' => 'general-colors-pulsating-circles-central-circle-box-shadow',
                    '-moz-box-shadow' => 'general-colors-pulsating-circles-central-circle-box-shadow',
                    'box-shadow' => 'general-colors-pulsating-circles-central-circle-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-content-default article.ueldo-blog-post .ueldo-blog-post-data img',
                    '.ueldo-content-default .ueldo-content-wrapper img',
                    '.ueldo-content-default article.ueldo-blog-post .ueldo-blog-post-featured-image',
                    '.ueldo-shortcode-post-page-box .ueldo-post-page-featured-image',
                    '.ueldo-content-default article.ueldo-page .ueldo-page-featured-image',
                    '.ueldo-slider-area-close-to-border',
                    '.ueldo-shortcode-tabs .ueldo-shortcode-tabs-single-tabs-images-container',
                    '.ueldo-shortcode-image',
                    '.ueldo-shortcode-google-map.ueldo-google-map-container',
                    '.ueldo-shortcode-full-width-testimonials .ueldo-shortcode-full-width-testimonials-clients-images .ueldo-shortcode-full-width-testimonials-clients-images-single-client[data-active=\"yes\"]',
                    '.ueldo-shortcode-two-images-difference',
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-author .ueldo-shortcode-quote-author-image',
                    '.ueldo-shortcode-presentation',
                    '.ueldo-shortcode-presentation-point-of-interest .ueldo-shortcode-presentation-point-of-interest-content'
                ),
                'styles' => array(
                    '-webkit-box-shadow' => 'general-colors-image-box-shadow',
                    '-moz-box-shadow' => 'general-colors-image-box-shadow',
                    'box-shadow' => 'general-colors-image-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-content-default .ueldo-content-wrapper li.comment img.avatar'
                ),
                'styles' => array(
                    '-webkit-box-shadow' => 'general-colors-comment-author-avatar-box-shadow',
                    '-moz-box-shadow' => 'general-colors-comment-author-avatar-box-shadow',
                    'box-shadow' => 'general-colors-comment-author-avatar-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector.ueldo-shortcode-tabs-selector-01 li',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector.ueldo-shortcode-tabs-selector-03 li',
                    '.ueldo-shortcode-attributes-box .ueldo-shortcode-attributes-box-elements ul li',
                    '.ueldo-shortcode-pricing-table.ueldo-shortcode-pricing-table-style-02 ul.ueldo-shortcode-pricing-table-attributes li',
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list li'
                ),
                'styles' => array(
                    'border-color' => 'general-colors-elements-inset-border-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector.ueldo-shortcode-tabs-selector-01 li.ueldo-shortcode-tabs-selector-single-tab-active',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector.ueldo-shortcode-tabs-selector-03 li.ueldo-shortcode-tabs-selector-single-tab-active',
                    '.ueldo-shortcode-tabs.ueldo-shortcode-tabs-style-05 .ueldo-shortcode-tabs-single-tabs-content-container .ueldo-shortcode-tabs-single-tab.ueldo-shortcode-tabs-single-tab-active',
                    '.ueldo-shortcode-pricing-table.ueldo-shortcode-pricing-table-style-01 .ueldo-shortcode-pricing-table-content',
                    '.ueldo-shortcode-pricing-table.ueldo-shortcode-pricing-table-style-02 .ueldo-shortcode-pricing-table-heading',
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list li.ueldo-shortcode-filtered-masonry-filter-active',
                    '.ueldo-shortcode-tabs-box ul.ueldo-shortcode-tabs-box-tabs-selector li',
                    '.ueldo-shortcode-tabs-box .ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab .ueldo-shortcode-tabs-box-single-tab-title',
                    '.woocommerce div.product .woocommerce-tabs.wc-tabs-wrapper > ul.tabs.wc-tabs li:not(.active)',
                    '.ueldo-shortcode-opening-hours-box .ueldo-shortcode-opening-hours-box-heading',
                    '.ueldo-content-default .ueldo-content-wrapper code',
                    '.ueldo-content-default .ueldo-content-wrapper kbd',
                    '.ueldo-content-default .ueldo-content-wrapper pre',
                    '.ueldo-website-wrapper pre'
                ),
                'styles' => array(
                    'background' => 'general-colors-elements-heading-or-active-tab-background-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-tabs.ueldo-shortcode-tabs-style-05 .ueldo-shortcode-tabs-single-tab-icon i',
                    '.ueldo-shortcode-tabs.ueldo-shortcode-tabs-style-05 .ueldo-shortcode-tabs-single-tab-icon i:before',
                    '.ueldo-shortcode-attributes-box i.ueldo-shortcode-attributes-box-icon',
                    '.ueldo-shortcode-attributes-box i.ueldo-shortcode-attributes-box-icon:before',
                    '.ueldo-shortcode-pricing-table.ueldo-shortcode-pricing-table-style-02 .ueldo-shortcode-pricing-table-level-icons i',
                    '.ueldo-shortcode-pricing-table.ueldo-shortcode-pricing-table-style-02 .ueldo-shortcode-pricing-table-level-icons i:before',
                    '.ueldo-shortcode-pricing-list .ueldo-shortcode-pricing-list-background-icons .ueldo-shortcode-pricing-list-background-icon',
                    '.ueldo-shortcode-pricing-list .ueldo-shortcode-pricing-list-background-icons .ueldo-shortcode-pricing-list-background-icon:before',
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-box .ueldo-shortcode-quote-box-inner i.ueldo-shortcode-quote-box-icon',
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-box .ueldo-shortcode-quote-box-inner i.ueldo-shortcode-quote-box-icon:before'
                ),
                'styles' => array(
                    'color' => 'general-colors-elements-background-icon-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-play-video-button .ueldo-play-video-button-icon'
                ),
                'styles' => array(
                    'border-color' => 'play-video-button-color',
                    '-webkit-box-shadow' => 'play-video-button-box-shadow',
                    '-moz-box-shadow' => 'play-video-button-box-shadow',
                    'box-shadow' => 'play-video-button-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-play-video-button .ueldo-play-video-button-icon i'
                ),
                'styles' => array(
                    'color' => 'play-video-button-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-image-caption .ueldo-image-caption-icon'
                ),
                'styles' => array(
                    'border-color' => 'gallery-image-buttons-color',
                    '-webkit-box-shadow' => 'gallery-image-buttons-box-shadow',
                    '-moz-box-shadow' => 'gallery-image-buttons-box-shadow',
                    'box-shadow' => 'gallery-image-buttons-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-image-caption .ueldo-image-caption-icon i'
                ),
                'styles' => array(
                    'color' => 'gallery-image-buttons-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-play-video-button .ueldo-play-video-button-title'
                ),
                'styles' => array(
                    'color' => 'play-video-button-title-text-color',
                    'background' => 'play-video-button-title-background-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-play-video-button .ueldo-play-video-button-title:before'
                ),
                'styles' => array(
                    'border-color' => 'play-video-button-title-background-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-pulsating-circles .ueldo-shortcode-pulsating-circles-circle-first'
                ),
                'styles' => array(
                    'background' => ueldo_get_color_pattern_options( 'pulsating-circles-first-circle-background-color' ),
                    'border-color' => ueldo_get_color_pattern_options( 'website-background-transparent' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-pulsating-circles .ueldo-shortcode-pulsating-circles-circle-second'
                ),
                'styles' => array(
                    'background' => ueldo_get_color_pattern_options( 'pulsating-circles-second-circle-background-color' ),
                    'border-color' => ueldo_get_color_pattern_options( 'website-background-transparent' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-pulsating-circles .ueldo-shortcode-pulsating-circles-circle-third'
                ),
                'styles' => array(
                    'background' => ueldo_get_color_pattern_options( 'pulsating-circles-third-circle-background-color' ),
                    'border-color' => ueldo_get_color_pattern_options( 'website-background-transparent' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-pulsating-circles .ueldo-shortcode-pulsating-circles-circle-fourth'
                ),
                'styles' => array(
                    'background' => ueldo_get_color_pattern_options( 'pulsating-circles-fourth-circle-background-color' ),
                    'border-color' => ueldo_get_color_pattern_options( 'website-background-transparent' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-element'
                ),
                'styles' => array(
                    'background' => 'info-box-element-background-color',
                    'border-color' => 'info-box-element-border-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-pricing-table.ueldo-shortcode-pricing-table-style-03 .ueldo-shortcode-pricing-table-content:before'
                ),
                'styles' => array(
                    'background' => ueldo_get_color_pattern_options( 'pricing-table-03-image-overlay-background-color' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-pricing-list:before'
                ),
                'styles' => array(
                    '-webkit-box-shadow' => 'general-colors-pricing-list-inset-box-shadow',
                    '-moz-box-shadow' => 'general-colors-pricing-list-inset-box-shadow',
                    'box-shadow' => 'general-colors-pricing-list-inset-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-google-map.ueldo-google-map-container.ueldo-shortcode-google-map-shadow-inset:before'
                ),
                'styles' => array(
                    '-webkit-box-shadow' => 'general-colors-full-width-elements-inset-box-shadow-top',
                    '-moz-box-shadow' => 'general-colors-full-width-elements-inset-box-shadow-top',
                    'box-shadow' => 'general-colors-full-width-elements-inset-box-shadow-top'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-google-map.ueldo-google-map-container.ueldo-shortcode-google-map-shadow-inset:after'
                ),
                'styles' => array(
                    '-webkit-box-shadow' => 'general-colors-full-width-elements-inset-box-shadow-bottom',
                    '-moz-box-shadow' => 'general-colors-full-width-elements-inset-box-shadow-bottom',
                    'box-shadow' => 'general-colors-full-width-elements-inset-box-shadow-bottom',
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-image-caption'
                ),
                'styles' => array(
                    'background' => 'gallery-image-overlay-background-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-full-width .ueldo-shortcode-timeline-element:after'
                ),
                'styles' => array(
                    '-o-background-image' => ueldo_get_color_pattern_options( 'full-width-timeline-element-gradient-o' ),
                    '-moz-background-image' => ueldo_get_color_pattern_options( 'full-width-timeline-element-gradient-moz' ),
                    '-webkit-background-image' => ueldo_get_color_pattern_options( 'full-width-timeline-element-gradient-webkit' ),
                    '-ms-background-image' => ueldo_get_color_pattern_options( 'full-width-timeline-element-gradient-ms' ),
                    'background-image' => ueldo_get_color_pattern_options( 'full-width-timeline-element-gradient' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-images-list .ueldo-shortcode-presentation-elements-switcher-images-list-single-image:not(.ueldo-shortcode-presentation-elements-switcher-images-list-single-image-active):before'
                ),
                'styles' => array(
                    'background' => ueldo_get_color_pattern_options( 'presentation-elements-switcher-inactive-elements-overlay' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-presentation .ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-images-list .ueldo-shortcode-presentation-elements-switcher-images-list-single-image.ueldo-shortcode-presentation-elements-switcher-images-list-single-image-active:after'
                ),
                'styles' => array(
                    'border-color' => 'general-colors-main-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-presentation-point-of-interest',
                    '.ueldo-shortcode-presentation-point-of-interest-content-modal-close'
                ),
                'styles' => array(
                    '-webkit-box-shadow' => 'point-of-interest-box-shadow',
                    '-moz-box-shadow' => 'point-of-interest-box-shadow',
                    'box-shadow' => 'point-of-interest-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-presentation-point-of-interest::after'
                ),
                'styles' => array(
                    'box-shadow' => ueldo_get_color_pattern_options( 'presentation-point-of-interest-pulse-box-shadow' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-presentation-point-of-interest.ueldo-shortcode-presentation-point-of-interest-is-open',
                    '.ueldo-shortcode-presentation-point-of-interest-content-modal-close'
                ),
                'styles' => array(
                    'background-color' => 'point-of-interest-close-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-opening-hours-status .ueldo-shortcode-opening-hours-status-content[data-for-status=\"open\"]:before'
                ),
                'styles' => array(
                    'background' => 'opening-hours-status-color-when-open'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-opening-hours-status .ueldo-shortcode-opening-hours-status-content[data-for-status=\"closed\"]:before'
                ),
                'styles' => array(
                    'background' => 'opening-hours-status-color-when-closed'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-content-default .ueldo-sidebar-wrapper[data-sidebar-responsive-style=\"flying\"]',
                    '.ueldo-content-default.ueldo-content-default-vc-page .ueldo-sidebar-flying'
                ),
                'styles' => array(
                    'less_991' => array(
                        'background' => 'general-colors-website-background',
                        '-webkit-box-shadow' => 'flying-sidebar-box-shadow',
                        '-moz-box-shadow' => 'flying-sidebar-box-shadow',
                        'box-shadow' => 'flying-sidebar-box-shadow'
                    )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-content-default .ueldo-sidebar-wrapper[data-sidebar-responsive-style=\"flying\"] .ueldo-flying-sidebar-line',
                    '.ueldo-content-default.ueldo-content-default-vc-page .ueldo-sidebar-flying .ueldo-flying-sidebar-line'
                ),
                'styles' => array(
                    'less_991' => array(
                        'background' => 'flying-sidebar-border-color'
                    )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-content-default .ueldo-sidebar-wrapper[data-sidebar-responsive-style=\"flying\"] section.ueldo-sidebar .ueldo-widget-call-to-action:hover:before',
                    '.ueldo-content-default.ueldo-content-default-vc-page .ueldo-sidebar-flying section.ueldo-sidebar .ueldo-widget-call-to-action:hover:before'
                ),
                'styles' => array(
                    'less_991' => array(
                        'background' => 'general-colors-main-color',
                        'border-color' => 'general-colors-main-color'
                    )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-content-default[data-ueldo-content-default-sidebar-side=\"right\"] .ueldo-sidebar-wrapper[data-sidebar-responsive-style=\"flying\"] section.ueldo-sidebar .ueldo-widget-call-to-action:before',
                    '.ueldo-content-default[data-ueldo-content-default-sidebar-side=\"left\"] .ueldo-sidebar-wrapper[data-sidebar-responsive-style=\"flying\"] section.ueldo-sidebar .ueldo-widget-call-to-action:before',
                    '.ueldo-content-default.ueldo-content-default-vc-page .ueldo-sidebar-flying[data-flying-sidebar-side=\"right\"] section.ueldo-sidebar .ueldo-widget-call-to-action:before',
                    '.ueldo-content-default.ueldo-content-default-vc-page .ueldo-sidebar-flying[data-flying-sidebar-side=\"left\"] section.ueldo-sidebar .ueldo-widget-call-to-action:before'
                ),
                'styles' => array(
                    'less_991' => array(
                        'border-color' => 'flying-sidebar-border-color'
                    )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-content-default .ueldo-sidebar-wrapper[data-sidebar-responsive-style=\"static\"]',
                    '.vc_row.ueldo-row-with-sidebar-on-left .vc_column_container.ueldo-row-with-sidebar-sidebar-column .wpb_content_element',
                    '.vc_row.ueldo-row-with-sidebar-on-right .vc_column_container.ueldo-row-with-sidebar-sidebar-column .wpb_content_element'
                ),
                'styles' => array(
                    'less_991' => array(
                        'border-color' => 'general-colors-elements-border-color'
                    )
                )
            ),

            array(
                'elements' => array(
                    'header.ueldo-header-bar.ueldo-default-header-bar'
                ),
                'styles' => array(
                    'background' => 'header-bar-and-menu-background-color',
                    '-webkit-box-shadow' => 'header-bar-and-menu-box-shadow',
                    '-moz-box-shadow' => 'header-bar-and-menu-box-shadow',
                    'box-shadow' => 'header-bar-and-menu-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu > ul > li > a'
                ),
                'styles' => array(
                    'color' => 'header-bar-and-menu-link-color',
                    'background' => 'header-bar-and-menu-background-color'
                )
            ),

            array(
                'elements' => array(
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu > ul > li.current-menu-item:not(.ueldo-menu-link-no-highlight) > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu > ul > li.current-menu-parent:not(.ueldo-menu-link-no-highlight) > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu > ul > li.current_page_parent:not(.ueldo-menu-link-no-highlight) > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu > ul > li.current-menu-ancestor:not(.ueldo-menu-link-no-highlight) > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu > ul > li:hover > a'
                ),
                'styles' => array(
                    'color' => 'header-bar-and-menu-active-or-hover-link-color'
                )
            ),

            array(
                'elements' => array(
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.sub-menu',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.children',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu > ul > li > ul.sub-menu:before',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu > ul > li > ul.children:before'
                ),
                'styles' => array(
                    'background' => 'header-bar-and-menu-submenu-background-color'
                )
            ),

            array(
                'elements' => array(
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.sub-menu',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.children'
                ),
                'styles' => array(
                    '-webkit-box-shadow' => 'header-bar-and-menu-submenu-box-shadow',
                    '-moz-box-shadow' => 'header-bar-and-menu-submenu-box-shadow',
                    'box-shadow' => 'header-bar-and-menu-submenu-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.sub-menu > li',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.children > li'
                ),
                'styles' => array(
                    'border-bottom-color' => 'header-bar-and-menu-submenu-element-border-bottom-color'
                )
            ),

            array(
                'elements' => array(
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.sub-menu > li > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.children > li > a'
                ),
                'styles' => array(
                    'color' => 'header-bar-and-menu-submenu-element-link-color'
                )
            ),

            array(
                'elements' => array(
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.sub-menu > li > a:hover',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.sub-menu > li.current-menu-item:not(.ueldo-menu-link-no-highlight) > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.sub-menu > li.current-menu-parent:not(.ueldo-menu-link-no-highlight) > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.sub-menu > li.current_page_parent:not(.ueldo-menu-link-no-highlight) > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.sub-menu > li.current-menu-ancestor:not(.ueldo-menu-link-no-highlight) > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.sub-menu > li:hover > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.children > li > a:hover',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.children > li.current-menu-item:not(.ueldo-menu-link-no-highlight) > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.children > li.current-menu-parent:not(.ueldo-menu-link-no-highlight) > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.children > li.current_page_parent:not(.ueldo-menu-link-no-highlight) > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.children > li.current-menu-ancestor:not(.ueldo-menu-link-no-highlight) > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.children > li:hover > a',
                ),
                'styles' => array(
                    'color' => 'header-bar-and-menu-submenu-element-active-or-hover-link-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav > ul > li > a'
                ),
                'styles' => array(
                    'color' => 'header-bar-and-menu-link-color',
                    'background' => 'header-bar-and-menu-background-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav > ul > li.current-menu-item:not(.ueldo-menu-link-no-highlight) > a',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav > ul > li.current-menu-parent:not(.ueldo-menu-link-no-highlight) > a',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav > ul > li.current_page_parent:not(.ueldo-menu-link-no-highlight) > a',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav > ul > li.current-menu-ancestor:not(.ueldo-menu-link-no-highlight) > a',
                    '.ueldo-shortcode-header-menu:not(.ueldo-shortcode-header-menu-style-02):not(.ueldo-shortcode-header-menu-style-04) nav.ueldo-shortcode-header-menu-nav > ul > li:hover > a',
                    '.ueldo-shortcode-header-menu.ueldo-shortcode-header-menu-style-04 nav.ueldo-shortcode-header-menu-nav > ul > li:not(.menu-item-has-children):hover > a'
                ),
                'styles' => array(
                    'color' => 'header-bar-and-menu-active-or-hover-link-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav > ul > li'
                ),
                'styles' => array(
                    'border-color' => 'general-colors-elements-border-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-header-menu.ueldo-shortcode-header-menu-style-02 nav.ueldo-shortcode-header-menu-nav > ul > li:hover > a',
                    '.ueldo-shortcode-header-menu.ueldo-shortcode-header-menu-style-04 nav.ueldo-shortcode-header-menu-nav > ul > li.menu-item-has-children:hover > a'
                ),
                'styles' => array(
                    'background' => 'header-bar-and-menu-submenu-background-color',
                    'color' => 'header-bar-and-menu-submenu-element-active-or-hover-link-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav > ul > li.current-menu-item:before',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav > ul > li.current-menu-parent:before',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav > ul > li.current_page_parent:before',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav > ul > li.current-menu-ancestor:before'
                ),
                'styles' => array(
                    'background' => 'header-bar-and-menu-active-or-hover-link-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav ul.sub-menu',
                    '.ueldo-shortcode-header-menu.ueldo-shortcode-header-menu-style-01 nav.ueldo-shortcode-header-menu-nav > ul > li > ul.sub-menu:before'
                ),
                'styles' => array(
                    'background' => 'header-bar-and-menu-submenu-background-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav ul.sub-menu'
                ),
                'styles' => array(
                    '-webkit-box-shadow' => 'header-bar-and-menu-submenu-box-shadow',
                    '-moz-box-shadow' => 'header-bar-and-menu-submenu-box-shadow',
                    'box-shadow' => 'header-bar-and-menu-submenu-box-shadow',
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav ul.sub-menu > li'
                ),
                'styles' => array(
                    'border-bottom-color' => 'header-bar-and-menu-submenu-element-border-bottom-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav ul.sub-menu > li > a'
                ),
                'styles' => array(
                    'color' => 'header-bar-and-menu-submenu-element-link-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav ul.sub-menu > li > a:hover',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav ul.sub-menu > li.current-menu-item:not(.ueldo-menu-link-no-highlight) > a',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav ul.sub-menu > li.current-menu-parent:not(.ueldo-menu-link-no-highlight) > a',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav ul.sub-menu > li.current_page_parent:not(.ueldo-menu-link-no-highlight) > a',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav ul.sub-menu > li.current-menu-ancestor:not(.ueldo-menu-link-no-highlight) > a',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav ul.sub-menu > li:hover > a'
                ),
                'styles' => array(
                    'color' => 'header-bar-and-menu-submenu-element-active-or-hover-link-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-languages-switcher .ueldo-shortcode-languages-switcher-current-language'
                ),
                'styles' => array(
                    'color' => 'header-bar-and-menu-link-color',
                    'border-color' => 'general-colors-elements-border-color',
                    'background' => 'header-bar-and-menu-background-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-languages-switcher:hover .ueldo-shortcode-languages-switcher-current-language'
                ),
                'styles' => array(
                    'border-color' => 'header-bar-and-menu-submenu-background-color',
                    'color' => 'header-bar-and-menu-submenu-element-active-or-hover-link-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-languages-switcher .ueldo-shortcode-languages-switcher-list li'
                ),
                'styles' => array(
                    'border-color' => 'header-bar-and-menu-submenu-element-border-bottom-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-languages-switcher .ueldo-shortcode-languages-switcher-list',
                    '.ueldo-shortcode-languages-switcher:hover .ueldo-shortcode-languages-switcher-current-language'
                ),
                'styles' => array(
                    'background' => 'header-bar-and-menu-submenu-background-color',
                    '-webkit-box-shadow' => 'header-bar-and-menu-submenu-box-shadow',
                    '-moz-box-shadow' => 'header-bar-and-menu-submenu-box-shadow',
                    'box-shadow' => 'header-bar-and-menu-submenu-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-languages-switcher .ueldo-shortcode-languages-switcher-list li a'
                ),
                'styles' => array(
                    'color' => 'header-bar-and-menu-submenu-element-link-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-languages-switcher .ueldo-shortcode-languages-switcher-list li a:hover'
                ),
                'styles' => array(
                    'color' => 'header-bar-and-menu-submenu-element-active-or-hover-link-color'
                )
            ),

            array(
                'elements' => array(
                    '#ueldo-side-menu'
                ),
                'styles' => array(
                    '-webkit-box-shadow' => 'side-menu-box-shadow',
                    '-moz-box-shadow' => 'side-menu-box-shadow',
                    'box-shadow' => 'side-menu-box-shadow',
                )
            ),

            array(
                'elements' => array(
                    '#ueldo-side-menu',
                    '#ueldo-side-menu nav.ueldo-side-menu-submenu-links-visible-on-click-as-new-layer ul.sub-menu',
                    '#ueldo-side-menu nav.ueldo-side-menu-submenu-links-visible-on-click-as-new-layer ul.children'
                ),
                'styles' => array(
                    'background' => 'side-menu-background-color'
                )
            ),

            array(
                'elements' => array(
                    '#ueldo-side-menu nav ul li a'
                ),
                'styles' => array(
                    'color' => 'side-menu-link-color',
                    'border-color' => 'side-menu-link-border-bottom-color',
                    'background' => 'side-menu-link-background-color'
                )
            ),

            array(
                'elements' => array(
                    '#ueldo-side-menu nav ul li a:hover'
                ),
                'styles' => array(
                    'color' => 'side-menu-link-color-hover',
                    'border-color' => 'side-menu-link-border-bottom-color-hover',
                    'background' => 'side-menu-link-background-color-hover'
                )
            ),

            array(
                'elements' => array(
                    '#ueldo-side-menu nav ul li.current-menu-item:not(.ueldo-menu-link-no-highlight) > a',
                    '#ueldo-side-menu nav ul li.current-menu-parent:not(.ueldo-menu-link-no-highlight) > a',
                    '#ueldo-side-menu nav ul li.current_page_parent:not(.ueldo-menu-link-no-highlight) > a',
                    '#ueldo-side-menu nav ul li.current-menu-ancestor:not(.ueldo-menu-link-no-highlight) > a'
                ),
                'styles' => array(
                    'color' => 'side-menu-active-link-color',
                    'border-color' => 'side-menu-active-link-border-bottom-color',
                    'background' => 'side-menu-active-link-background-color'
                )
            ),

            array(
                'elements' => array(
                    '#ueldo-side-menu nav a span.ueldo-side-menu-link:before',
                    '#ueldo-side-menu nav a span.ueldo-side-menu-link:after'
                ),
                'styles' => array(
                    'color' => 'side-menu-link-icon-color'
                )
            ),

            array(
                'elements' => array(
                    '#ueldo-side-menu nav a:hover span.ueldo-side-menu-link:before',
                    '#ueldo-side-menu nav a:hover span.ueldo-side-menu-link:after'
                ),
                'styles' => array(
                    'color' => 'side-menu-link-icon-color-hover'
                )
            ),

            array(
                'elements' => array(
                    '#ueldo-side-menu nav ul li.current-menu-item > a > span.ueldo-side-menu-link:before',
                    '#ueldo-side-menu nav ul li.current-menu-item > a > span.ueldo-side-menu-link:after',
                    '#ueldo-side-menu nav ul li.current-menu-parent > a > span.ueldo-side-menu-link:before',
                    '#ueldo-side-menu nav ul li.current-menu-parent > a > span.ueldo-side-menu-link:after',
                    '#ueldo-side-menu nav ul li.current_page_parent > a > span.ueldo-side-menu-link:before',
                    '#ueldo-side-menu nav ul li.current_page_parent > a > span.ueldo-side-menu-link:after',
                    '#ueldo-side-menu nav ul li.current-menu-ancestor > a > span.ueldo-side-menu-link:before',
                    '#ueldo-side-menu nav ul li.current-menu-ancestor > a > span.ueldo-side-menu-link:after'
                ),
                'styles' => array(
                    'color' => 'side-menu-active-link-icon-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-website-wrapper.ueldo-website-wrapper-boxed'
                ),
                'styles' => array(
                    '-webkit-box-shadow' => 'boxed-website-box-shadow',
                    '-moz-box-shadow' => 'boxed-website-box-shadow',
                    'box-shadow' => 'boxed-website-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-two-images-difference .ueldo-shortcode-two-images-difference-left-arrow'
                ),
                'styles' => array(
                    'border-right-color' => 'two-images-difference-shortcode-handle-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-two-images-difference .ueldo-shortcode-two-images-difference-right-arrow'
                ),
                'styles' => array(
                    'border-left-color' => 'two-images-difference-shortcode-handle-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-two-images-difference .ueldo-shortcode-two-images-difference-up-arrow'
                ),
                'styles' => array(
                    'border-bottom-color' => 'two-images-difference-shortcode-handle-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-two-images-difference .ueldo-shortcode-two-images-difference-down-arrow'
                ),
                'styles' => array(
                    'border-top-color' => 'two-images-difference-shortcode-handle-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-two-images-difference-handle'
                ),
                'styles' => array(
                    'border-color' => 'two-images-difference-shortcode-handle-color',
                    '-webkit-box-shadow' => 'two-images-difference-shortcode-handle-box-shadow',
                    '-moz-box-shadow' => 'two-images-difference-shortcode-handle-box-shadow',
                    'box-shadow' => 'two-images-difference-shortcode-handle-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-two-images-difference-overlay:hover'
                ),
                'styles' => array(
                    'background' => 'two-images-difference-shortcode-overlay-background-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-two-images-difference-before-label:before',
                    '.ueldo-shortcode-two-images-difference-after-label:before'
                ),
                'styles' => array(
                    'background' => 'two-images-difference-shortcode-before-and-after-label-background-color',
                    'color' => 'two-images-difference-shortcode-before-and-after-label-text-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-two-images-difference-horizontal .ueldo-shortcode-two-images-difference-handle:before',
                    '.ueldo-shortcode-two-images-difference-horizontal .ueldo-shortcode-two-images-difference-handle:after',
                    '.ueldo-shortcode-two-images-difference-vertical .ueldo-shortcode-two-images-difference-handle:before',
                    '.ueldo-shortcode-two-images-difference-vertical .ueldo-shortcode-two-images-difference-handle:after'
                ),
                'styles' => array(
                    'background' => 'two-images-difference-shortcode-handle-color',
                    '-webkit-box-shadow' => 'two-images-difference-shortcode-handle-box-shadow',
                    '-moz-box-shadow' => 'two-images-difference-shortcode-handle-box-shadow',
                    'box-shadow' => 'two-images-difference-shortcode-handle-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-image-parent-loading',
                    '.ueldo-image-parent-loading .ueldo-image-parent-loading-circle:before'
                ),
                'styles' => array(
                    'background' => 'image-loader-background-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-image-parent-loading .ueldo-image-parent-loading-circle'
                ),
                'styles' => array(
                    'border-color' => 'image-loader-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-content-default .ueldo-sidebar-wrapper .widget .ueldo-widget-call-to-action .ueldo-image-parent-loading',
                    '.ueldo-content-default .ueldo-sidebar-wrapper .widget .ueldo-widget-call-to-action .ueldo-image-parent-loading .ueldo-image-parent-loading-circle:before'
                ),
                'styles' => array(
                    'background' => 'general-colors-website-background'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-content-default .ueldo-sidebar-wrapper .widget .ueldo-widget-call-to-action .ueldo-image-parent-loading .ueldo-image-parent-loading-circle'
                ),
                'styles' => array(
                    'border-color' => 'image-loader-color-for-call-to-action-widget'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-alert-box.ueldo-alert-box-info',
                    '.ueldo-shortcode-announcement.ueldo-shortcode-announcement-type-info',
                    '.nf-form-wrap .nf-response-msg',
                    '.nf-form-wrap .nf-form-fields-required',
                    'p.woocommerce-noreviews'
                ),
                'styles' => array(
                    'background' => 'announcement-info-background-color',
                    'border-color' => 'announcement-info-border-color',
                    '-webkit-box-shadow' => 'announcement-info-box-shadow',
                    '-moz-box-shadow' => 'announcement-info-box-shadow',
                    'box-shadow' => 'announcement-info-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-alert-box.ueldo-alert-box-info *',
                    '.ueldo-shortcode-announcement.ueldo-shortcode-announcement-type-info *',
                    '.nf-form-wrap .nf-response-msg',
                    '.nf-form-wrap .nf-form-fields-required',
                    'p.woocommerce-noreviews'
                ),
                'styles' => array(
                    'color' => 'announcement-info-content-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-alert-box.ueldo-alert-box-success',
                    '.ueldo-shortcode-announcement.ueldo-shortcode-announcement-type-success',
                    '.mc4wp-alert.mc4wp-success',
                    '.gform_confirmation_wrapper .gform_confirmation_message',
                    'form div.wpcf7-mail-sent-ok'
                ),
                'styles' => array(
                    'background' => 'announcement-success-background-color',
                    'border-color' => 'announcement-success-border-color',
                    '-webkit-box-shadow' => 'announcement-success-box-shadow',
                    '-moz-box-shadow' => 'announcement-success-box-shadow',
                    'box-shadow' => 'announcement-success-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-alert-box.ueldo-alert-box-success *',
                    '.ueldo-shortcode-announcement.ueldo-shortcode-announcement-type-success *',
                    '.mc4wp-alert.mc4wp-success *',
                    '.gform_confirmation_wrapper .gform_confirmation_message',
                    'form div.wpcf7-mail-sent-ok'
                ),
                'styles' => array(
                    'color' => 'announcement-success-content-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-alert-box.ueldo-alert-box-error',
                    '.ueldo-shortcode-announcement.ueldo-shortcode-announcement-type-error',
                    '.mc4wp-alert.mc4wp-error',
                    '.nf-form-errors .nf-error-msg',
                    '.gform_wrapper form div.validation_error',
                    'form div.wpcf7-validation-errors'
                ),
                'styles' => array(
                    'background' => 'announcement-error-background-color',
                    'border-color' => 'announcement-error-border-color',
                    '-webkit-box-shadow' => 'announcement-error-box-shadow',
                    '-moz-box-shadow' => 'announcement-error-box-shadow',
                    'box-shadow' => 'announcement-error-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-alert-box.ueldo-alert-box-error *',
                    '.ueldo-shortcode-announcement.ueldo-shortcode-announcement-type-error *',
                    '.mc4wp-alert.mc4wp-error *',
                    '.nf-form-errors .nf-error-msg',
                    '.gform_wrapper form div.validation_error',
                    'form div.wpcf7-validation-errors'
                ),
                'styles' => array(
                    'color' => 'announcement-error-content-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-alert-box.ueldo-alert-box-warning',
                    '.ueldo-shortcode-announcement.ueldo-shortcode-announcement-type-warning',
                    '.mc4wp-alert.mc4wp-notice',
                    'form div.wpcf7-spam-blocked',
                    'form div.wpcf7-mail-sent-ng',
                    'p.logged-in-as'
                ),
                'styles' => array(
                    'background' => 'announcement-warning-background-color',
                    'border-color' => 'announcement-warning-border-color',
                    '-webkit-box-shadow' => 'announcement-warning-box-shadow',
                    '-moz-box-shadow' => 'announcement-warning-box-shadow',
                    'box-shadow' => 'announcement-warning-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-alert-box.ueldo-alert-box-warning *',
                    '.ueldo-shortcode-announcement.ueldo-shortcode-announcement-type-warning *',
                    '.mc4wp-alert.mc4wp-notice *',
                    'form div.wpcf7-spam-blocked',
                    'form div.wpcf7-mail-sent-ng',
                    'p.logged-in-as',
                    'p.logged-in-as *'
                ),
                'styles' => array(
                    'color' => 'announcement-warning-content-color'
                )
            ),

            array(
                'elements' => array(
                    'form input[type=\"text\"]',
                    'form input[type=\"email\"]',
                    'form input[type=\"password\"]',
                    'form input[type=\"url\"]',
                    'form input[type=\"tel\"]',
                    'form input[type=\"number\"]',
                    'form input[type=\"date\"]',
                    'form textarea',
                    '.woocommerce form .form-row textarea',
                    '.ueldo-select-field',
                    'form .ueldo-checkbox-box',
                    'form .ueldo-radio-box .ueldo-radio',
                    '.nf-form-wrap input[type=\"text\"]',
                    '.nf-form-wrap input[type=\"email\"]',
                    '.nf-form-wrap input[type=\"password\"]',
                    '.nf-form-wrap input[type=\"url\"]',
                    '.nf-form-wrap input[type=\"tel\"]',
                    '.nf-form-wrap input[type=\"number\"]',
                    '.nf-form-wrap input[type=\"date\"]',
                    '.nf-form-wrap textarea',
                    '.nf-form-wrap .ueldo-checkbox-box',
                    '.nf-form-wrap .ueldo-radio-box .ueldo-radio',
                    '.select2-container .select2-selection--single'
                ),
                'styles' => array(
                    'border-color' => 'forms-field-border-color',
                    'color' => 'forms-field-text-color',
                    'background' => 'forms-field-background-color',
                    'box-shadow' => ueldo_get_color_pattern_options( 'form-field-box-shadow' )
                )
            ),

            array(
                'elements' => array(
                    '.select2-dropdown'
                ),
                'styles' => array(
                    'border-color' => 'forms-field-border-color',
                    'background' => 'general-colors-website-background'
                )
            ),

            array(
                'elements' => array(
                    '.select2-container--default .select2-search--dropdown .select2-search__field'
                ),
                'styles' => array(
                    'border-bottom-color' => 'general-colors-elements-border-color',
                    'background' => 'general-colors-website-background'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-select-field select',
                    '.ueldo-select-field:hover:after',
                    '.select2-container--default .select2-selection--single .select2-selection__rendered'
                ),
                'styles' => array(
                    'color' => 'forms-field-text-color',
                )
            ),

            array(
                'elements' => array(
                    '.nf-form-wrap hr.ninja-forms-field'
                ),
                'styles' => array(
                    'background' => 'general-colors-elements-border-color'
                )
            ),

            array(
                'elements' => array(
                    '.gform_wrapper .gform_body .gsection',
                    '.woocommerce div.product .woocommerce-tabs.wc-tabs-wrapper > ul.tabs.wc-tabs li:not(.active)'
                ),
                'styles' => array(
                    'border-bottom-color' => 'general-colors-elements-border-color'
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-checkbox-box i.fa-check',
                    '.nf-form-wrap .ueldo-checkbox-box i.fa-check'
                ),
                'styles' => array(
                    'color' => 'forms-checkbox-radio-main-color'
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-radio-box .ueldo-radio .ueldo-radio-checked',
                    '.nf-form-wrap .ueldo-radio-box .ueldo-radio .ueldo-radio-checked'
                ),
                'styles' => array(
                    'background' => 'forms-checkbox-radio-main-color'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-select-field:after',
                    'form .ueldo-date-field .ueldo-date-field-icon',
                    '.nf-form-wrap .ueldo-date-field .ueldo-date-field-icon',
                    '.select2-container--default .select2-selection--single .select2-selection__arrow'
                ),
                'styles' => array(
                    'color' => 'forms-select-and-date-field-icon-color',
                    'border-color' => 'forms-select-and-date-field-icon-border-color',
                    'background' => 'forms-select-and-date-field-icon-background-color'
                )
            ),

            array(
                'elements' => array(
                    '.select2-container--default .select2-selection--single .select2-selection__arrow b'
                ),
                'styles' => array(
                    'border-color' => ueldo_get_color_pattern_options( 'form-field-select2-arrow-color' )
                )
            ),

            array(
                'elements' => array(
                    '.select2-container--default.select2-container--open .select2-selection--single .select2-selection__arrow b'
                ),
                'styles' => array(
                    'border-color' => ueldo_get_color_pattern_options( 'form-field-select2-arrow-opened-color' )
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-date-field .ueldo-date-field-icon i',
                    '.nf-form-wrap .ueldo-date-field .ueldo-date-field-icon i'
                ),
                'styles' => array(
                    'color' => 'forms-select-and-date-field-icon-color'
                )
            ),

            array(
                'elements' => array(
                    'form label',
                    '.nf-form-wrap label',
                    '.nf-form-wrap .nf-field-label'
                ),
                'styles' => array(
                    'color' => 'general-colors-headings-color'
                )
            ),

            array(
                'elements' => array(
                    '.nf-form-wrap .nf-static.nf-element'
                ),
                'styles' => array(
                    'color' => 'general-colors-content-color'
                )
            ),

            array(
                'elements' => array(
                    'form input[type=\"text\"]:hover',
                    'form input[type=\"text\"].ueldo-search-field-hover',
                    'form input[type=\"email\"]:hover',
                    'form input[type=\"password\"]:hover',
                    'form input[type=\"url\"]:hover',
                    'form input[type=\"tel\"]:hover',
                    'form input[type=\"number\"]:hover',
                    'form input[type=\"date\"]:hover',
                    'form textarea:hover',
                    '.ueldo-select-field:hover',
                    'form .ueldo-checkbox-box:hover',
                    'form .ueldo-radio-box:hover .ueldo-radio',
                    '.nf-form-wrap input[type=\"text\"]:hover',
                    '.nf-form-wrap input[type=\"email\"]:hover',
                    '.nf-form-wrap input[type=\"password\"]:hover',
                    '.nf-form-wrap input[type=\"url\"]:hover',
                    '.nf-form-wrap input[type=\"tel\"]:hover',
                    '.nf-form-wrap input[type=\"number\"]:hover',
                    '.nf-form-wrap input[type=\"date\"]:hover',
                    '.nf-form-wrap textarea:hover',
                    '.nf-form-wrap .ueldo-checkbox-box:hover',
                    '.nf-form-wrap .ueldo-radio-box:hover .ueldo-radio'
                ),
                'styles' => array(
                    'border-color' => 'forms-field-border-color-on-hover'
                )
            ),

            array(
                'elements' => array(
                    'form input[type=\"text\"]:focus',
                    'form input[type=\"email\"]:focus',
                    'form input[type=\"password\"]:focus',
                    'form input[type=\"url\"]:focus',
                    'form input[type=\"tel\"]:focus',
                    'form input[type=\"number\"]:focus',
                    'form input[type=\"date\"]:focus',
                    'form textarea:focus',
                    '.nf-form-wrap input[type=\"text\"]:focus',
                    '.nf-form-wrap input[type=\"email\"]:focus',
                    '.nf-form-wrap input[type=\"password\"]:focus',
                    '.nf-form-wrap input[type=\"url\"]:focus',
                    '.nf-form-wrap input[type=\"tel\"]:focus',
                    '.nf-form-wrap input[type=\"number\"]:focus',
                    '.nf-form-wrap input[type=\"date\"]:focus',
                    '.nf-form-wrap textarea:focus'
                ),
                'styles' => array(
                    'border-color' => 'forms-field-border-color-on-focus'
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-search-field button[type=\"submit\"]',
                    '.nf-form-wrap .ueldo-search-field button[type=\"submit\"]'
                ),
                'styles' => array(
                    'background' => 'forms-field-background-color'
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-search-field button[type=\"submit\"] i',
                    'form .ueldo-search-field button[type=\"submit\"] i:before',
                    '.nf-form-wrap .ueldo-search-field button[type=\"submit\"] i',
                    '.nf-form-wrap .ueldo-search-field button[type=\"submit\"] i:before',
                    '.ueldo-shortcode-search-field.ueldo-shortcode-search-field-type-animated .ueldo-animated-search-field button[type=\"submit\"] i',
                    '.ueldo-shortcode-search-field.ueldo-shortcode-search-field-type-animated .ueldo-animated-search-field button[type=\"submit\"] i:before'
                ),
                'styles' => array(
                    'color' => 'forms-field-border-color'
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-search-field button[type=\"submit\"]:hover i',
                    'form .ueldo-search-field button[type=\"submit\"]:hover i:before',
                    '.nf-form-wrap .ueldo-search-field button[type=\"submit\"]:hover i',
                    '.nf-form-wrap .ueldo-search-field button[type=\"submit\"]:hover i:before',
                    '.ueldo-shortcode-search-field.ueldo-shortcode-search-field-type-animated .ueldo-animated-search-field button[type=\"submit\"]:hover i',
                    '.ueldo-shortcode-search-field.ueldo-shortcode-search-field-type-animated .ueldo-animated-search-field button[type=\"submit\"]:hover i:before'
                ),
                'styles' => array(
                    'color' => 'forms-field-border-color-on-focus'
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-range-field input[type=range]::-webkit-slider-runnable-track'
                ),
                'styles' => array(
                    'border-color' => 'forms-field-border-color',
                    'background' => 'forms-field-background-color',
                    'box-shadow' => ueldo_get_color_pattern_options( 'form-field-box-shadow' )
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-range-field input[type=range]:focus::-webkit-slider-runnable-track'
                ),
                'styles' => array(
                    'background' => 'forms-field-background-color'
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-range-field input[type=range]::-webkit-slider-thumb'
                ),
                'styles' => array(
                    'border-color' => 'forms-field-border-color',
                    'background' => 'forms-field-background-color'
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-range-field input[type=range]::-moz-range-track'
                ),
                'styles' => array(
                    'border-color' => 'forms-field-border-color',
                    'background' => 'forms-field-background-color',
                    'box-shadow' => ueldo_get_color_pattern_options( 'form-field-box-shadow' )
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-range-field input[type=range]::-moz-range-thumb'
                ),
                'styles' => array(
                    'border-color' => 'forms-field-border-color',
                    'background' => 'forms-field-background-color'
                )
            ),

            array(
                'elements' => array(
                    'form input[type=\"text\"].wpcf7-not-valid',
                    'form input[type=\"email\"].wpcf7-not-valid',
                    'form input[type=\"password\"].wpcf7-not-valid',
                    'form input[type=\"url\"].wpcf7-not-valid',
                    'form input[type=\"tel\"].wpcf7-not-valid',
                    'form input[type=\"number\"].wpcf7-not-valid',
                    'form input[type=\"date\"].wpcf7-not-valid',
                    'form textarea.wpcf7-not-valid',
                    'form .ueldo-select-field.wpcf7-not-valid',
                    'form .wpcf7-not-valid .ueldo-checkbox-box',
                    'form .wpcf7-not-valid .ueldo-radio-box .ueldo-radio',
                    '.nf-form-wrap .nf-error input[type=\"text\"]',
                    '.nf-form-wrap .nf-error input[type=\"email\"]',
                    '.nf-form-wrap .nf-error input[type=\"password\"]',
                    '.nf-form-wrap .nf-error input[type=\"url\"]',
                    '.nf-form-wrap .nf-error input[type=\"tel\"]',
                    '.nf-form-wrap .nf-error input[type=\"number\"]',
                    '.nf-form-wrap .nf-error input[type=\"date\"]',
                    '.nf-form-wrap .nf-error textarea',
                    '.nf-form-wrap .nf-error .ueldo-select-field',
                    '.nf-form-wrap .nf-error .ueldo-checkbox-box',
                    '.nf-form-wrap .nf-error .ueldo-radio-box .ueldo-radio',
                    '.gform_wrapper form li.gfield_error input[type=\"text\"]',
                    '.gform_wrapper form li.gfield_error input[type=\"email\"]',
                    '.gform_wrapper form li.gfield_error input[type=\"password\"]',
                    '.gform_wrapper form li.gfield_error input[type=\"url\"]',
                    '.gform_wrapper form li.gfield_error input[type=\"tel\"]',
                    '.gform_wrapper form li.gfield_error input[type=\"number\"]',
                    '.gform_wrapper form li.gfield_error input[type=\"date\"]',
                    '.gform_wrapper form li.gfield_error textarea',
                    '.gform_wrapper form li.gfield_error .ueldo-select-field',
                    '.gform_wrapper form li.gfield_error .ueldo-checkbox-box',
                    '.gform_wrapper form li.gfield_error .ueldo-radio-box .ueldo-radio'
                ),
                'styles' => array(
                    'border-color' => ueldo_get_color_pattern_options( 'form-field-invalid-border-color-important' )
                )
            ),

            array(
                'elements' => array(
                    'span.wpcf7-not-valid-tip',
                    '.nf-after-field .nf-error-msg',
                    '.gform_wrapper form .gfield_error .gfield_label',
                    '.gform_wrapper form .validation_message',
                    '.gform_wrapper form li.gfield_error div.ginput_complex.ginput_container label',
                    '.gform_wrapper form li.gfield_error ul.gfield_checkbox',
                    '.gform_wrapper form li.gfield_error ul.gfield_radio',
                    '.gform_wrapper form li.gfield.gfield_error table.gfield_list thead th'
                ),
                'styles' => array(
                    'color' => 'forms-invalid-field-tip-text-color'
                )
            ),

            array(
                'elements' => array(
                    '.gform_wrapper form li.gsection.gf_scroll_text'
                ),
                'styles' => array(
                    'border-color' => 'forms-field-border-color',
                    'border-bottom-color' => ueldo_get_color_pattern_options( 'form-field-border-color-important' )
                )
            ),

            array(
                'elements' => array(
                    '::-webkit-input-placeholder'
                ),
                'styles' => array(
                    'color' => 'forms-placeholder-text-color'
                )
            ),

            array(
                'elements' => array(
                    '::-moz-placeholder'
                ),
                'styles' => array(
                    'color' => 'forms-placeholder-text-color'
                )
            ),

            array(
                'elements' => array(
                    ':-ms-input-placeholder'
                ),
                'styles' => array(
                    'color' => 'forms-placeholder-text-color'
                )
            ),

            array(
                'elements' => array(
                    ':-moz-placeholder'
                ),
                'styles' => array(
                    'color' => 'forms-placeholder-text-color'
                )
            ),

           /**
            *
            * default sub-menu sub-menu margin top value
            *
            */

            array(
                'elements' => array(
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.sub-menu ul.sub-menu',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.children ul.children',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav ul.sub-menu ul.sub-menu'
                ),
                'styles' => array(
                    'margin-top' => ueldo_get_color_pattern_options( 'header-bar-menu-sub-menu-sub-menu-margin-top' )
                )
            ),

           /**
            *
            * read more button: [default]
            * form submit button: [default]
            * call to action widget button: [default]
            *
            * code: [n-n-n]
            *
            */

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button',
                    'form input[type=\"submit\"]',
                    'form input[type=\"button\"]',
                    'form button[type=\"submit\"]',
                    'form button[type=\"submit\"].ueldo-button',
                    '.nf-form-wrap input[type=\"submit\"]',
                    '.nf-form-wrap input[type=\"button\"]',
                    '.nf-form-wrap button[type=\"submit\"]',
                    '.gform_wrapper form .gform_footer input.button',
                    '.gform_wrapper form .gform_footer input[type=\"submit\"]',
                    '.gform_wrapper form .gform_page_footer input.button',
                    '.gform_wrapper form .gform_page_footer input[type=\"submit\"]'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color',
                    'border-color' => 'buttons-global-button-border-color',
                    'color' => 'buttons-global-button-text-color',
                    'box-shadow' => 'buttons-global-button-box-shadow',
                    'font-size' => 'buttons-global-button-font-size',
                    'letter-spacing' => 'buttons-global-button-letter-spacing',
                    'padding' => ueldo_get_color_pattern_options( 'buttons-global-button-padding' ),
                    '-webkit-border-radius' => 'buttons-global-button-border-radius',
                    '-moz-border-radius' => 'buttons-global-button-border-radius',
                    'border-radius' => 'buttons-global-button-border-radius',
                    'border-width' => 'buttons-global-button-border-width'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container span.ueldo-button-link-text'
                ),
                'styles' => array(
                    'font-size' => 'buttons-global-button-font-size'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button',
                    'form input[type=\"submit\"]',
                    'form input[type=\"button\"]',
                    'form button[type=\"submit\"]',
                    'form button[type=\"submit\"].ueldo-button',
                    '.nf-form-wrap input[type=\"submit\"]',
                    '.nf-form-wrap input[type=\"button\"]',
                    '.nf-form-wrap button[type=\"submit\"]',
                    '.gform_wrapper form .gform_footer input.button',
                    '.gform_wrapper form .gform_footer input[type=\"submit\"]',
                    '.gform_wrapper form .gform_page_footer input.button',
                    '.gform_wrapper form .gform_page_footer input[type=\"submit\"]'
                ),
                'styles' => array(
                    'height' => 'buttons-global-button-static-height',
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-global-button-use-static-height' => 'yes'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:hover',
                    'form input[type=\"submit\"]:hover',
                    'form input[type=\"button\"]:hover',
                    'form button[type=\"submit\"]:hover',
                    'form button[type=\"submit\"].ueldo-button:hover',
                    '.nf-form-wrap input[type=\"submit\"]:hover',
                    '.nf-form-wrap input[type=\"button\"]:hover',
                    '.nf-form-wrap button[type=\"submit\"]:hover',
                    '.gform_wrapper form .gform_footer input.button:hover',
                    '.gform_wrapper form .gform_footer input[type=\"submit\"]:hover',
                    '.gform_wrapper form .gform_page_footer input.button:hover',
                    '.gform_wrapper form .gform_page_footer input[type=\"submit\"]:hover'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color-hover',
                    'border-color' => 'buttons-global-button-border-color-hover',
                    'color' => 'buttons-global-button-text-color-hover',
                    'box-shadow' => 'buttons-global-button-box-shadow-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button i',
                    '*:not( input ):not( button ).ueldo-button i:before',
                    'form input[type=\"submit\"] i',
                    'form input[type=\"submit\"] i:before',
                    'form input[type=\"button\"] i',
                    'form input[type=\"button\"] i:before',
                    'form button[type=\"submit\"] i',
                    'form button[type=\"submit\"] i:before',
                    'form button[type=\"submit\"].ueldo-button i',
                    'form button[type=\"submit\"].ueldo-button i:before',
                    '.nf-form-wrap input[type=\"submit\"] i',
                    '.nf-form-wrap input[type=\"submit\"] i:before',
                    '.nf-form-wrap input[type=\"button\"] i',
                    '.nf-form-wrap input[type=\"button\"] i:before',
                    '.nf-form-wrap button[type=\"submit\"] i',
                    '.nf-form-wrap button[type=\"submit\"] i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color',
                    'font-size' => 'buttons-global-button-icon-size'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:hover i',
                    '*:not( input ):not( button ).ueldo-button:hover i:before',
                    'form input[type=\"submit\"]:hover i',
                    'form input[type=\"submit\"]:hover i:before',
                    'form input[type=\"button\"]:hover i',
                    'form input[type=\"button\"]:hover i:before',
                    'form button[type=\"submit\"]:hover i',
                    'form button[type=\"submit\"]:hover i:before',
                    'form button[type=\"submit\"].ueldo-button:hover i',
                    'form button[type=\"submit\"].ueldo-button:hover i:before',
                    '.nf-form-wrap input[type=\"submit\"]:hover i',
                    '.nf-form-wrap input[type=\"submit\"]:hover i:before',
                    '.nf-form-wrap input[type=\"button\"]:hover i',
                    '.nf-form-wrap input[type=\"button\"]:hover i:before',
                    '.nf-form-wrap button[type=\"submit\"]:hover i',
                    '.nf-form-wrap button[type=\"submit\"]:hover i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container i',
                    '.ueldo-shortcode-button-container i:before'
                ),
                'styles' => array(
                    'font-size' => 'buttons-global-button-icon-size'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-before-text',
                    'form input[type=\"submit\"] i.ueldo-button-icon-before-text',
                    'form input[type=\"button\"] i.ueldo-button-icon-before-text',
                    'form button[type=\"submit\"] i.ueldo-button-icon-before-text',
                    'form button[type=\"submit\"].ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-before-text',
                    '.nf-form-wrap input[type=\"submit\"] i.ueldo-button-icon-before-text',
                    '.nf-form-wrap input[type=\"button\"] i.ueldo-button-icon-before-text',
                    '.nf-form-wrap button[type=\"submit\"] i.ueldo-button-icon-before-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-after-text',
                    'form input[type=\"submit\"] i.ueldo-button-icon-after-text',
                    'form input[type=\"button\"] i.ueldo-button-icon-after-text',
                    'form button[type=\"submit\"] i.ueldo-button-icon-after-text',
                    'form button[type=\"submit\"].ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-after-text',
                    '.nf-form-wrap input[type=\"submit\"] i.ueldo-button-icon-after-text',
                    '.nf-form-wrap input[type=\"button\"] i.ueldo-button-icon-after-text',
                    '.nf-form-wrap button[type=\"submit\"] i.ueldo-button-icon-after-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button i.ueldo-button-icon-above-left',
                    '.ueldo-button i.ueldo-button-icon-above-centered',
                    '.ueldo-button i.ueldo-button-icon-above-right'
                ),
                'styles' => array(
                    'margin-bottom' => 'buttons-global-button-margin-between-text-and-icon'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button i.ueldo-button-icon-under-left',
                    '.ueldo-button i.ueldo-button-icon-under-centered',
                    '.ueldo-button i.ueldo-button-icon-under-right'
                ),
                'styles' => array(
                    'margin-top' => 'buttons-global-button-margin-between-text-and-icon'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button .ueldo-button-link-text.ueldo-button-link-text-with-icon-before'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) => ueldo_get_color_pattern_options( 'buttons-icon-visibility-on-hover-only-margin-plus' ),
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => ueldo_get_color_pattern_options( 'buttons-icon-visibility-on-hover-only-margin-minus' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button .ueldo-button-link-text.ueldo-button-link-text-with-icon-after'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) => ueldo_get_color_pattern_options( 'buttons-icon-visibility-on-hover-only-margin-minus' ),
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => ueldo_get_color_pattern_options( 'buttons-icon-visibility-on-hover-only-margin-plus' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button .ueldo-button-link-text.ueldo-button-link-text-with-icon-under-left',
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button .ueldo-button-link-text.ueldo-button-link-text-with-icon-under-centered',
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button .ueldo-button-link-text.ueldo-button-link-text-with-icon-under-right'
                ),
                'styles' => array(
                    'margin-top' => ueldo_get_color_pattern_options( 'buttons-icon-visibility-on-hover-only-margin-plus' ),
                    'margin-bottom' => ueldo_get_color_pattern_options( 'buttons-icon-visibility-on-hover-only-margin-minus' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button .ueldo-button-link-text.ueldo-button-link-text-with-icon-above-left',
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button .ueldo-button-link-text.ueldo-button-link-text-with-icon-above-centered',
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button .ueldo-button-link-text.ueldo-button-link-text-with-icon-above-right'
                ),
                'styles' => array(
                    'margin-top' => ueldo_get_color_pattern_options( 'buttons-icon-visibility-on-hover-only-margin-minus' ),
                    'margin-bottom' => ueldo_get_color_pattern_options( 'buttons-icon-visibility-on-hover-only-margin-plus' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button i.ueldo-button-icon-before-text',
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button i.ueldo-button-icon-after-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => ueldo_get_color_pattern_options( 'buttons-icon-visibility-on-hover-only-margin-for-text' ),
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) => ueldo_get_color_pattern_options( 'buttons-icon-visibility-on-hover-only-margin-for-text' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button:hover i.ueldo-button-icon-before-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) => 'buttons-global-button-margin-between-text-and-icon'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button:hover i.ueldo-button-icon-after-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => 'buttons-global-button-margin-between-text-and-icon'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button i.ueldo-button-icon-under-left',
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button i.ueldo-button-icon-under-centered',
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button i.ueldo-button-icon-under-right',
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button i.ueldo-button-icon-above-left',
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button i.ueldo-button-icon-above-centered',
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button i.ueldo-button-icon-above-right'
                ),
                'styles' => array(
                    'margin-top' => ueldo_get_color_pattern_options( 'buttons-icon-visibility-on-hover-only-margin-for-text' ),
                    'margin-bottom' => ueldo_get_color_pattern_options( 'buttons-icon-visibility-on-hover-only-margin-for-text' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button:hover i.ueldo-button-icon-under-left',
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button:hover i.ueldo-button-icon-under-centered',
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button:hover i.ueldo-button-icon-under-right'
                ),
                'styles' => array(
                    'margin-top' => 'buttons-global-button-margin-between-text-and-icon'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button:hover i.ueldo-button-icon-above-left',
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button:hover i.ueldo-button-icon-above-centered',
                    '.ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only .ueldo-button:hover i.ueldo-button-icon-above-right'
                ),
                'styles' => array(
                    'margin-bottom' => 'buttons-global-button-margin-between-text-and-icon'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container .ueldo-button i.vc-mono'
                ),
                'styles' => array(
                    'width' => 'buttons-global-button-icon-size',
                    'height' => 'buttons-global-button-icon-size'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container .ueldo-button i.vc-mono:before'
                ),
                'styles' => array(
                    '-webkit-transform' => ueldo_get_color_pattern_options( 'buttons-icon-vc-mono-translation'. esc_attr( ueldo_is_rtl() ? '-rtl' : '-ltr' ) ),
                    '-moz-transform' => ueldo_get_color_pattern_options( 'buttons-icon-vc-mono-translation'. esc_attr( ueldo_is_rtl() ? '-rtl' : '-ltr' ) ),
                    'transform' => ueldo_get_color_pattern_options( 'buttons-icon-vc-mono-translation'. esc_attr( ueldo_is_rtl() ? '-rtl' : '-ltr' ) )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container .ueldo-button i.vc-mono.ueldo-button-icon-above-centered',
                    '.ueldo-shortcode-button-container .ueldo-button i.vc-mono.ueldo-button-icon-under-centered'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => ueldo_get_color_pattern_options( 'buttons-icon-vc-mono-margin-centered' )
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-button-container .ueldo-button i.vc-mono.ueldo-button-icon-above-right',
                    '.ueldo-shortcode-button-container .ueldo-button i.vc-mono.ueldo-button-icon-under-right'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => ueldo_get_color_pattern_options( 'buttons-icon-vc-mono-margin-aligned-right' )
                )
            ),

           /**
            *
            * read more button: [custom]
            * form submit button: [default]
            * call to action widget button: [default]
            *
            * code: [y-n-n]
            *
            */

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button)',
                    'form input[type=\"submit\"]',
                    'form input[type=\"button\"]',
                    'form button[type=\"submit\"]',
                    'form button[type=\"submit\"].ueldo-button',
                    '.nf-form-wrap input[type=\"submit\"]',
                    '.nf-form-wrap input[type=\"button\"]',
                    '.nf-form-wrap button[type=\"submit\"]',
                    '.gform_wrapper form .gform_footer input.button',
                    '.gform_wrapper form .gform_footer input[type=\"submit\"]',
                    '.gform_wrapper form .gform_page_footer input.button',
                    '.gform_wrapper form .gform_page_footer input[type=\"submit\"]'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color',
                    'border-color' => 'buttons-global-button-border-color',
                    'color' => 'buttons-global-button-text-color',
                    'box-shadow' => 'buttons-global-button-box-shadow',
                    'font-size' => 'buttons-global-button-font-size',
                    'letter-spacing' => 'buttons-global-button-letter-spacing',
                    'padding' => ueldo_get_color_pattern_options( 'buttons-global-button-padding' ),
                    '-webkit-border-radius' => 'buttons-global-button-border-radius',
                    '-moz-border-radius' => 'buttons-global-button-border-radius',
                    'border-radius' => 'buttons-global-button-border-radius',
                    'border-width' => 'buttons-global-button-border-width'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button)',
                    'form input[type=\"submit\"]',
                    'form input[type=\"button\"]',
                    'form button[type=\"submit\"]',
                    'form button[type=\"submit\"].ueldo-button',
                    '.nf-form-wrap input[type=\"submit\"]',
                    '.nf-form-wrap input[type=\"button\"]',
                    '.nf-form-wrap button[type=\"submit\"]',
                    '.gform_wrapper form .gform_footer input.button',
                    '.gform_wrapper form .gform_footer input[type=\"submit\"]',
                    '.gform_wrapper form .gform_page_footer input.button',
                    '.gform_wrapper form .gform_page_footer input[type=\"submit\"]'
                ),
                'styles' => array(
                    'height' => 'buttons-global-button-static-height',
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-global-button-use-static-height' => 'yes'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):hover',
                    'form input[type=\"submit\"]:hover',
                    'form input[type=\"button\"]:hover',
                    'form button[type=\"submit\"]:hover',
                    'form button[type=\"submit\"].ueldo-button:hover',
                    '.nf-form-wrap input[type=\"submit\"]:hover',
                    '.nf-form-wrap input[type=\"button\"]:hover',
                    '.nf-form-wrap button[type=\"submit\"]:hover',
                    '.gform_wrapper form .gform_footer input.button:hover',
                    '.gform_wrapper form .gform_footer input[type=\"submit\"]:hover',
                    '.gform_wrapper form .gform_page_footer input.button:hover',
                    '.gform_wrapper form .gform_page_footer input[type=\"submit\"]:hover'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color-hover',
                    'border-color' => 'buttons-global-button-border-color-hover',
                    'color' => 'buttons-global-button-text-color-hover',
                    'box-shadow' => 'buttons-global-button-box-shadow-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button.ueldo-read-more-button',
                ),
                'styles' => array(
                    'background' => 'buttons-read-more-button-background-color',
                    'border-color' => 'buttons-read-more-button-border-color',
                    'color' => 'buttons-read-more-button-text-color',
                    'box-shadow' => 'buttons-read-more-button-box-shadow',
                    'font-size' => 'buttons-read-more-button-font-size',
                    'letter-spacing' => 'buttons-read-more-button-letter-spacing',
                    'padding' => ueldo_get_color_pattern_options( 'buttons-read-more-button-padding' ),
                    '-webkit-border-radius' => 'buttons-read-more-button-border-radius',
                    '-moz-border-radius' => 'buttons-read-more-button-border-radius',
                    'border-radius' => 'buttons-read-more-button-border-radius',
                    'border-width' => 'buttons-read-more-button-border-width'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button.ueldo-read-more-button',
                ),
                'styles' => array(
                    'height' => 'buttons-read-more-button-static-height',
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-read-more-button-use-static-height' => 'yes'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button.ueldo-read-more-button:hover',
                ),
                'styles' => array(
                    'background' => 'buttons-read-more-button-background-color-hover',
                    'border-color' => 'buttons-read-more-button-border-color-hover',
                    'color' => 'buttons-read-more-button-text-color-hover',
                    'box-shadow' => 'buttons-read-more-button-box-shadow-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button) i',
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button) i:before',
                    'form input[type=\"submit\"] i',
                    'form input[type=\"submit\"] i:before',
                    'form input[type=\"button\"] i',
                    'form input[type=\"button\"] i:before',
                    'form button[type=\"submit\"] i',
                    'form button[type=\"submit\"] i:before',
                    'form button[type=\"submit\"].ueldo-button i',
                    'form button[type=\"submit\"].ueldo-button i:before',
                    '.nf-form-wrap input[type=\"submit\"] i',
                    '.nf-form-wrap input[type=\"submit\"] i:before',
                    '.nf-form-wrap input[type=\"button\"] i',
                    '.nf-form-wrap input[type=\"button\"] i:before',
                    '.nf-form-wrap button[type=\"submit\"] i',
                    '.nf-form-wrap button[type=\"submit\"] i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color',
                    'font-size' => 'buttons-global-button-icon-size'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):hover i',
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):hover i:before',
                    'form input[type=\"submit\"]:hover i',
                    'form input[type=\"submit\"]:hover i:before',
                    'form input[type=\"button\"]:hover i',
                    'form input[type=\"button\"]:hover i:before',
                    'form button[type=\"submit\"]:hover i',
                    'form button[type=\"submit\"]:hover i:before',
                    'form button[type=\"submit\"].ueldo-button:hover i',
                    'form button[type=\"submit\"].ueldo-button:hover i:before',
                    '.nf-form-wrap input[type=\"submit\"]:hover i',
                    '.nf-form-wrap input[type=\"submit\"]:hover i:before',
                    '.nf-form-wrap input[type=\"button\"]:hover i',
                    '.nf-form-wrap input[type=\"button\"]:hover i:before',
                    '.nf-form-wrap button[type=\"submit\"]:hover i',
                    '.nf-form-wrap button[type=\"submit\"]:hover i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button.ueldo-read-more-button i',
                    '.ueldo-button.ueldo-read-more-button i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-read-more-button-icon-color',
                    'font-size' => 'buttons-read-more-button-icon-size'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button.ueldo-read-more-button:hover i',
                    '.ueldo-button.ueldo-read-more-button:hover i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-read-more-button-icon-color-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-button-without-text) i.ueldo-button-icon-before-text',
                    'form input[type=\"submit\"] i.ueldo-button-icon-before-text',
                    'form input[type=\"button\"] i.ueldo-button-icon-before-text',
                    'form button[type=\"submit\"] i.ueldo-button-icon-before-text',
                    'form button[type=\"submit\"].ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-before-text',
                    '.nf-form-wrap input[type=\"submit\"] i.ueldo-button-icon-before-text',
                    '.nf-form-wrap input[type=\"button\"] i.ueldo-button-icon-before-text',
                    '.nf-form-wrap button[type=\"submit\"] i.ueldo-button-icon-before-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-button-without-text) i.ueldo-button-icon-after-text',
                    'form input[type=\"submit\"] i.ueldo-button-icon-after-text',
                    'form input[type=\"button\"] i.ueldo-button-icon-after-text',
                    'form button[type=\"submit\"] i.ueldo-button-icon-after-text',
                    'form button[type=\"submit\"].ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-after-text',
                    '.nf-form-wrap input[type=\"submit\"] i.ueldo-button-icon-after-text',
                    '.nf-form-wrap input[type=\"button\"] i.ueldo-button-icon-after-text',
                    '.nf-form-wrap button[type=\"submit\"] i.ueldo-button-icon-after-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button.ueldo-read-more-button:not(.ueldo-button-without-text) i.ueldo-button-icon-before-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) => 'buttons-read-more-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button.ueldo-read-more-button:not(.ueldo-button-without-text) i.ueldo-button-icon-after-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => 'buttons-read-more-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

           /**
            *
            * read more button: [default]
            * form submit button: [default]
            * call to action widget button: [custom]
            *
            * code: [n-n-y]
            *
            */

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button)',
                    'form input[type=\"submit\"]',
                    'form input[type=\"button\"]',
                    'form button[type=\"submit\"]',
                    'form button[type=\"submit\"].ueldo-button',
                    '.nf-form-wrap input[type=\"submit\"]',
                    '.nf-form-wrap input[type=\"button\"]',
                    '.nf-form-wrap button[type=\"submit\"]',
                    '.gform_wrapper form .gform_footer input.button',
                    '.gform_wrapper form .gform_footer input[type=\"submit\"]',
                    '.gform_wrapper form .gform_page_footer input.button',
                    '.gform_wrapper form .gform_page_footer input[type=\"submit\"]'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color',
                    'border-color' => 'buttons-global-button-border-color',
                    'color' => 'buttons-global-button-text-color',
                    'box-shadow' => 'buttons-global-button-box-shadow',
                    'font-size' => 'buttons-global-button-font-size',
                    'letter-spacing' => 'buttons-global-button-letter-spacing',
                    'padding' => ueldo_get_color_pattern_options( 'buttons-global-button-padding' ),
                    '-webkit-border-radius' => 'buttons-global-button-border-radius',
                    '-moz-border-radius' => 'buttons-global-button-border-radius',
                    'border-radius' => 'buttons-global-button-border-radius',
                    'border-width' => 'buttons-global-button-border-width'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button)',
                    'form input[type=\"submit\"]',
                    'form input[type=\"button\"]',
                    'form button[type=\"submit\"]',
                    'form button[type=\"submit\"].ueldo-button',
                    '.nf-form-wrap input[type=\"submit\"]',
                    '.nf-form-wrap input[type=\"button\"]',
                    '.nf-form-wrap button[type=\"submit\"]',
                    '.gform_wrapper form .gform_footer input.button',
                    '.gform_wrapper form .gform_footer input[type=\"submit\"]',
                    '.gform_wrapper form .gform_page_footer input.button',
                    '.gform_wrapper form .gform_page_footer input[type=\"submit\"]'
                ),
                'styles' => array(
                    'height' => 'buttons-global-button-static-height',
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-global-button-use-static-height' => 'yes'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button):hover',
                    'form input[type=\"submit\"]:hover',
                    'form input[type=\"button\"]:hover',
                    'form button[type=\"submit\"]:hover',
                    'form button[type=\"submit\"].ueldo-button:hover',
                    '.nf-form-wrap input[type=\"submit\"]:hover',
                    '.nf-form-wrap input[type=\"button\"]:hover',
                    '.nf-form-wrap button[type=\"submit\"]:hover',
                    '.gform_wrapper form .gform_footer input.button:hover',
                    '.gform_wrapper form .gform_footer input[type=\"submit\"]:hover',
                    '.gform_wrapper form .gform_page_footer input.button:hover',
                    '.gform_wrapper form .gform_page_footer input[type=\"submit\"]:hover'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color-hover',
                    'border-color' => 'buttons-global-button-border-color-hover',
                    'color' => 'buttons-global-button-text-color-hover',
                    'box-shadow' => 'buttons-global-button-box-shadow-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button.ueldo-call-to-action-widget-button',
                ),
                'styles' => array(
                    'background' => 'buttons-call-to-action-widget-button-background-color',
                    'border-color' => 'buttons-call-to-action-widget-button-border-color',
                    'color' => 'buttons-call-to-action-widget-button-text-color',
                    'box-shadow' => 'buttons-call-to-action-widget-button-box-shadow',
                    'font-size' => 'buttons-call-to-action-widget-button-font-size',
                    'letter-spacing' => 'buttons-call-to-action-widget-button-letter-spacing',
                    'padding' => ueldo_get_color_pattern_options( 'buttons-call-to-action-widget-button-padding' ),
                    '-webkit-border-radius' => 'buttons-call-to-action-widget-button-border-radius',
                    '-moz-border-radius' => 'buttons-call-to-action-widget-button-border-radius',
                    'border-radius' => 'buttons-call-to-action-widget-button-border-radius',
                    'border-width' => 'buttons-call-to-action-widget-button-border-width'
                ),
                'dependency' => array(
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button.ueldo-call-to-action-widget-button',
                ),
                'styles' => array(
                    'height' => 'buttons-call-to-action-widget-button-static-height',
                ),
                'dependency' => array(
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-use-static-height' => 'yes'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button.ueldo-call-to-action-widget-button:hover',
                ),
                'styles' => array(
                    'background' => 'buttons-call-to-action-widget-button-background-color-hover',
                    'border-color' => 'buttons-call-to-action-widget-button-border-color-hover',
                    'color' => 'buttons-call-to-action-widget-button-text-color-hover',
                    'box-shadow' => 'buttons-call-to-action-widget-button-box-shadow-hover'
                ),
                'dependency' => array(
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button) i',
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button) i:before',
                    'form input[type=\"submit\"] i',
                    'form input[type=\"submit\"] i:before',
                    'form input[type=\"button\"] i',
                    'form input[type=\"button\"] i:before',
                    'form button[type=\"submit\"] i',
                    'form button[type=\"submit\"] i:before',
                    'form button[type=\"submit\"].ueldo-button i',
                    'form button[type=\"submit\"].ueldo-button i:before',
                    '.nf-form-wrap input[type=\"submit\"] i',
                    '.nf-form-wrap input[type=\"submit\"] i:before',
                    '.nf-form-wrap input[type=\"button\"] i',
                    '.nf-form-wrap input[type=\"button\"] i:before',
                    '.nf-form-wrap button[type=\"submit\"] i',
                    '.nf-form-wrap button[type=\"submit\"] i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color',
                    'font-size' => 'buttons-global-button-icon-size'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button):hover i',
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button):hover i:before',
                    'form input[type=\"submit\"]:hover i',
                    'form input[type=\"submit\"]:hover i:before',
                    'form input[type=\"button\"]:hover i',
                    'form input[type=\"button\"]:hover i:before',
                    'form button[type=\"submit\"]:hover i',
                    'form button[type=\"submit\"]:hover i:before',
                    'form button[type=\"submit\"].ueldo-button:hover i',
                    'form button[type=\"submit\"].ueldo-button:hover i:before',
                    '.nf-form-wrap input[type=\"submit\"]:hover i',
                    '.nf-form-wrap input[type=\"submit\"]:hover i:before',
                    '.nf-form-wrap input[type=\"button\"]:hover i',
                    '.nf-form-wrap input[type=\"button\"]:hover i:before',
                    '.nf-form-wrap button[type=\"submit\"]:hover i',
                    '.nf-form-wrap button[type=\"submit\"]:hover i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button.ueldo-call-to-action-widget-button i',
                    '.ueldo-button.ueldo-call-to-action-widget-button i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-call-to-action-widget-button-icon-color',
                    'font-size' => 'buttons-call-to-action-widget-button-icon-size'
                ),
                'dependency' => array(
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button.ueldo-call-to-action-widget-button:hover i',
                    '.ueldo-button.ueldo-call-to-action-widget-button:hover i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-call-to-action-widget-button-icon-color-hover'
                ),
                'dependency' => array(
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button):not(.ueldo-button-without-text) i.ueldo-button-icon-before-text',
                    'form input[type=\"submit\"] i.ueldo-button-icon-before-text',
                    'form input[type=\"button\"] i.ueldo-button-icon-before-text',
                    'form button[type=\"submit\"] i.ueldo-button-icon-before-text',
                    'form button[type=\"submit\"].ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-before-text',
                    '.nf-form-wrap input[type=\"submit\"] i.ueldo-button-icon-before-text',
                    '.nf-form-wrap input[type=\"button\"] i.ueldo-button-icon-before-text',
                    '.nf-form-wrap button[type=\"submit\"] i.ueldo-button-icon-before-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button):not(.ueldo-button-without-text) i.ueldo-button-icon-after-text',
                    'form input[type=\"submit\"] i.ueldo-button-icon-after-text',
                    'form input[type=\"button\"] i.ueldo-button-icon-after-text',
                    'form button[type=\"submit\"] i.ueldo-button-icon-after-text',
                    'form button[type=\"submit\"].ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-after-text',
                    '.nf-form-wrap input[type=\"submit\"] i.ueldo-button-icon-after-text',
                    '.nf-form-wrap input[type=\"button\"] i.ueldo-button-icon-after-text',
                    '.nf-form-wrap button[type=\"submit\"] i.ueldo-button-icon-after-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button.ueldo-call-to-action-widget-button:not(.ueldo-button-without-text) i.ueldo-button-icon-before-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) => 'buttons-call-to-action-widget-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-button.ueldo-call-to-action-widget-button:not(.ueldo-button-without-text) i.ueldo-button-icon-after-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => 'buttons-call-to-action-widget-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

           /**
            *
            * read more button: [default]
            * form submit button: [custom]
            * call to action widget button: [default]
            *
            * code: [n-y-n]
            *
            */

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color',
                    'border-color' => 'buttons-global-button-border-color',
                    'color' => 'buttons-global-button-text-color',
                    'box-shadow' => 'buttons-global-button-box-shadow',
                    'font-size' => 'buttons-global-button-font-size',
                    'letter-spacing' => 'buttons-global-button-letter-spacing',
                    'padding' => ueldo_get_color_pattern_options( 'buttons-global-button-padding' ),
                    '-webkit-border-radius' => 'buttons-global-button-border-radius',
                    '-moz-border-radius' => 'buttons-global-button-border-radius',
                    'border-radius' => 'buttons-global-button-border-radius',
                    'border-width' => 'buttons-global-button-border-width'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button'
                ),
                'styles' => array(
                    'height' => 'buttons-global-button-static-height',
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-global-button-use-static-height' => 'yes'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:hover'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color-hover',
                    'border-color' => 'buttons-global-button-border-color-hover',
                    'color' => 'buttons-global-button-text-color-hover',
                    'box-shadow' => 'buttons-global-button-box-shadow-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-button',
                    'form input[type=\"submit\"]',
                    'form input[type=\"button\"]',
                    'form button[type=\"submit\"]',
                    'form button[type=\"submit\"].ueldo-button',
                    '.nf-form-wrap input[type=\"submit\"]',
                    '.nf-form-wrap input[type=\"button\"]',
                    '.nf-form-wrap button[type=\"submit\"]',
                    '.gform_wrapper form .gform_footer input.button',
                    '.gform_wrapper form .gform_footer input[type=\"submit\"]',
                    '.gform_wrapper form .gform_page_footer input.button',
                    '.gform_wrapper form .gform_page_footer input[type=\"submit\"]'
                ),
                'styles' => array(
                    'background' => 'buttons-form-submit-button-background-color',
                    'border-color' => 'buttons-form-submit-button-border-color',
                    'color' => 'buttons-form-submit-button-text-color',
                    'box-shadow' => 'buttons-form-submit-button-box-shadow',
                    'font-size' => 'buttons-form-submit-button-font-size',
                    'letter-spacing' => 'buttons-form-submit-button-letter-spacing',
                    'padding' => ueldo_get_color_pattern_options( 'buttons-form-submit-button-padding' ),
                    '-webkit-border-radius' => 'buttons-form-submit-button-border-radius',
                    '-moz-border-radius' => 'buttons-form-submit-button-border-radius',
                    'border-radius' => 'buttons-form-submit-button-border-radius',
                    'border-width' => 'buttons-form-submit-button-border-width'
                ),
                'dependency' => array(
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-button',
                    'form input[type=\"submit\"]',
                    'form input[type=\"button\"]',
                    'form button[type=\"submit\"]',
                    'form button[type=\"submit\"].ueldo-button',
                    '.nf-form-wrap input[type=\"submit\"]',
                    '.nf-form-wrap input[type=\"button\"]',
                    '.nf-form-wrap button[type=\"submit\"]',
                    '.gform_wrapper form .gform_footer input.button',
                    '.gform_wrapper form .gform_footer input[type=\"submit\"]',
                    '.gform_wrapper form .gform_page_footer input.button',
                    '.gform_wrapper form .gform_page_footer input[type=\"submit\"]'
                ),
                'styles' => array(
                    'height' => 'buttons-form-submit-button-static-height',
                ),
                'dependency' => array(
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-use-static-height' => 'yes'
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-button:hover',
                    'form input[type=\"submit\"]:hover',
                    'form input[type=\"button\"]:hover',
                    'form button[type=\"submit\"]:hover',
                    'form button[type=\"submit\"].ueldo-button:hover',
                    '.nf-form-wrap input[type=\"submit\"]:hover',
                    '.nf-form-wrap input[type=\"button\"]:hover',
                    '.nf-form-wrap button[type=\"submit\"]:hover',
                    '.gform_wrapper form .gform_footer input.button:hover',
                    '.gform_wrapper form .gform_footer input[type=\"submit\"]:hover',
                    '.gform_wrapper form .gform_page_footer input.button:hover',
                    '.gform_wrapper form .gform_page_footer input[type=\"submit\"]:hover'
                ),
                'styles' => array(
                    'background' => 'buttons-form-submit-button-background-color-hover',
                    'border-color' => 'buttons-form-submit-button-border-color-hover',
                    'color' => 'buttons-form-submit-button-text-color-hover',
                    'box-shadow' => 'buttons-form-submit-button-box-shadow-hover'
                ),
                'dependency' => array(
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button i',
                    '*:not( input ):not( button ).ueldo-button i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color',
                    'font-size' => 'buttons-global-button-icon-size'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:hover i',
                    '*:not( input ):not( button ).ueldo-button:hover i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-button i',
                    'form .ueldo-button i:before',
                    'form input[type=\"submit\"] i',
                    'form input[type=\"submit\"] i:before',
                    'form input[type=\"button\"] i',
                    'form input[type=\"button\"] i:before',
                    'form button[type=\"submit\"] i',
                    'form button[type=\"submit\"] i:before',
                    'form button[type=\"submit\"].ueldo-button i',
                    'form button[type=\"submit\"].ueldo-button i:before',
                    '.nf-form-wrap input[type=\"submit\"] i',
                    '.nf-form-wrap input[type=\"submit\"] i:before',
                    '.nf-form-wrap input[type=\"button\"] i',
                    '.nf-form-wrap input[type=\"button\"] i:before',
                    '.nf-form-wrap button[type=\"submit\"] i',
                    '.nf-form-wrap button[type=\"submit\"] i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-form-submit-button-icon-color',
                    'font-size' => 'buttons-form-submit-button-icon-size'
                ),
                'dependency' => array(
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-button:hover i',
                    'form .ueldo-button:hover i:before',
                    'form input[type=\"submit\"]:hover i',
                    'form input[type=\"submit\"]:hover i:before',
                    'form input[type=\"button\"]:hover i',
                    'form input[type=\"button\"]:hover i:before',
                    'form button[type=\"submit\"]:hover i',
                    'form button[type=\"submit\"]:hover i:before',
                    'form button[type=\"submit\"].ueldo-button:hover i',
                    'form button[type=\"submit\"].ueldo-button:hover i:before',
                    '.nf-form-wrap input[type=\"submit\"]:hover i',
                    '.nf-form-wrap input[type=\"submit\"]:hover i:before',
                    '.nf-form-wrap input[type=\"button\"]:hover i',
                    '.nf-form-wrap input[type=\"button\"]:hover i:before',
                    '.nf-form-wrap button[type=\"submit\"]:hover i',
                    '.nf-form-wrap button[type=\"submit\"]:hover i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-form-submit-button-icon-color-hover'
                ),
                'dependency' => array(
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-before-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-after-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-before-text',
                    'form input[type=\"submit\"] i.ueldo-button-icon-before-text',
                    'form input[type=\"button\"] i.ueldo-button-icon-before-text',
                    'form button[type=\"submit\"] i.ueldo-button-icon-before-text',
                    'form button[type=\"submit\"].ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-before-text',
                    '.nf-form-wrap input[type=\"submit\"] i.ueldo-button-icon-before-text',
                    '.nf-form-wrap input[type=\"button\"] i.ueldo-button-icon-before-text',
                    '.nf-form-wrap button[type=\"submit\"] i.ueldo-button-icon-before-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) => 'buttons-form-submit-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    'form .ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-after-text',
                    'form input[type=\"submit\"] i.ueldo-button-icon-after-text',
                    'form input[type=\"button\"] i.ueldo-button-icon-after-text',
                    'form button[type=\"submit\"] i.ueldo-button-icon-after-text',
                    'form button[type=\"submit\"].ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-after-text',
                    '.nf-form-wrap input[type=\"submit\"] i.ueldo-button-icon-after-text',
                    '.nf-form-wrap input[type=\"button\"] i.ueldo-button-icon-after-text',
                    '.nf-form-wrap button[type=\"submit\"] i.ueldo-button-icon-after-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => 'buttons-form-submit-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

           /**
            *
            * read more button: [custom]
            * form submit button: [default]
            * call to action widget button: [custom]
            *
            * code: [y-n-y]
            *
            */

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button)',
                    'form input[type=\"submit\"]',
                    'form input[type=\"button\"]',
                    'form button[type=\"submit\"]',
                    'form button[type=\"submit\"].ueldo-button',
                    '.nf-form-wrap input[type=\"submit\"]',
                    '.nf-form-wrap input[type=\"button\"]',
                    '.nf-form-wrap button[type=\"submit\"]',
                    '.gform_wrapper form .gform_footer input.button',
                    '.gform_wrapper form .gform_footer input[type=\"submit\"]',
                    '.gform_wrapper form .gform_page_footer input.button',
                    '.gform_wrapper form .gform_page_footer input[type=\"submit\"]'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color',
                    'border-color' => 'buttons-global-button-border-color',
                    'color' => 'buttons-global-button-text-color',
                    'box-shadow' => 'buttons-global-button-box-shadow',
                    'font-size' => 'buttons-global-button-font-size',
                    'letter-spacing' => 'buttons-global-button-letter-spacing',
                    'padding' => ueldo_get_color_pattern_options( 'buttons-global-button-padding' ),
                    '-webkit-border-radius' => 'buttons-global-button-border-radius',
                    '-moz-border-radius' => 'buttons-global-button-border-radius',
                    'border-radius' => 'buttons-global-button-border-radius',
                    'border-width' => 'buttons-global-button-border-width'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button)',
                    'form input[type=\"submit\"]',
                    'form input[type=\"button\"]',
                    'form button[type=\"submit\"]',
                    'form button[type=\"submit\"].ueldo-button',
                    '.nf-form-wrap input[type=\"submit\"]',
                    '.nf-form-wrap input[type=\"button\"]',
                    '.nf-form-wrap button[type=\"submit\"]',
                    '.gform_wrapper form .gform_footer input.button',
                    '.gform_wrapper form .gform_footer input[type=\"submit\"]',
                    '.gform_wrapper form .gform_page_footer input.button',
                    '.gform_wrapper form .gform_page_footer input[type=\"submit\"]'
                ),
                'styles' => array(
                    'height' => 'buttons-global-button-static-height',
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-global-button-use-static-height' => 'yes'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button):hover',
                    'form input[type=\"submit\"]:hover',
                    'form input[type=\"button\"]:hover',
                    'form button[type=\"submit\"]:hover',
                    'form button[type=\"submit\"].ueldo-button:hover',
                    '.nf-form-wrap input[type=\"submit\"]:hover',
                    '.nf-form-wrap input[type=\"button\"]:hover',
                    '.nf-form-wrap button[type=\"submit\"]:hover',
                    '.gform_wrapper form .gform_footer input.button:hover',
                    '.gform_wrapper form .gform_footer input[type=\"submit\"]:hover',
                    '.gform_wrapper form .gform_page_footer input.button:hover',
                    '.gform_wrapper form .gform_page_footer input[type=\"submit\"]:hover'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color-hover',
                    'border-color' => 'buttons-global-button-border-color-hover',
                    'color' => 'buttons-global-button-text-color-hover',
                    'box-shadow' => 'buttons-global-button-box-shadow-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button) i',
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button) i:before',
                    'form input[type=\"submit\"] i',
                    'form input[type=\"submit\"] i:before',
                    'form input[type=\"button\"] i',
                    'form input[type=\"button\"] i:before',
                    'form button[type=\"submit\"] i',
                    'form button[type=\"submit\"] i:before',
                    'form button[type=\"submit\"].ueldo-button i',
                    'form button[type=\"submit\"].ueldo-button i:before',
                    '.nf-form-wrap input[type=\"submit\"] i',
                    '.nf-form-wrap input[type=\"submit\"] i:before',
                    '.nf-form-wrap input[type=\"button\"] i',
                    '.nf-form-wrap input[type=\"button\"] i:before',
                    '.nf-form-wrap button[type=\"submit\"] i',
                    '.nf-form-wrap button[type=\"submit\"] i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color',
                    'font-size' => 'buttons-global-button-icon-size'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button):hover i',
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button):hover i:before',
                    'form input[type=\"submit\"]:hover i',
                    'form input[type=\"submit\"]:hover i:before',
                    'form input[type=\"button\"]:hover i',
                    'form input[type=\"button\"]:hover i:before',
                    'form button[type=\"submit\"]:hover i',
                    'form button[type=\"submit\"]:hover i:before',
                    'form button[type=\"submit\"].ueldo-button:hover i',
                    'form button[type=\"submit\"].ueldo-button:hover i:before',
                    '.nf-form-wrap input[type=\"submit\"]:hover i',
                    '.nf-form-wrap input[type=\"submit\"]:hover i:before',
                    '.nf-form-wrap input[type=\"button\"]:hover i',
                    '.nf-form-wrap input[type=\"button\"]:hover i:before',
                    '.nf-form-wrap button[type=\"submit\"]:hover i',
                    '.nf-form-wrap button[type=\"submit\"]:hover i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button):not(.ueldo-button-without-text) i.ueldo-button-icon-before-text',
                    'form input[type=\"submit\"] i.ueldo-button-icon-before-text',
                    'form input[type=\"button\"] i.ueldo-button-icon-before-text',
                    'form button[type=\"submit\"] i.ueldo-button-icon-before-text',
                    'form button[type=\"submit\"].ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-before-text',
                    '.nf-form-wrap input[type=\"submit\"] i.ueldo-button-icon-before-text',
                    '.nf-form-wrap input[type=\"button\"] i.ueldo-button-icon-before-text',
                    '.nf-form-wrap button[type=\"submit\"] i.ueldo-button-icon-before-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( .ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only ) > *:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button):not(.ueldo-button-without-text) i.ueldo-button-icon-after-text',
                    'form input[type=\"submit\"] i.ueldo-button-icon-after-text',
                    'form input[type=\"button\"] i.ueldo-button-icon-after-text',
                    'form button[type=\"submit\"] i.ueldo-button-icon-after-text',
                    'form button[type=\"submit\"].ueldo-button:not(.ueldo-button-without-text) i.ueldo-button-icon-after-text',
                    '.nf-form-wrap input[type=\"submit\"] i.ueldo-button-icon-after-text',
                    '.nf-form-wrap input[type=\"button\"] i.ueldo-button-icon-after-text',
                    '.nf-form-wrap button[type=\"submit\"] i.ueldo-button-icon-after-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

           /**
            *
            * read more button: [custom]
            * form submit button: [custom]
            * call to action widget button: [default]
            *
            * code: [y-y-n]
            *
            */

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button)'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color',
                    'border-color' => 'buttons-global-button-border-color',
                    'color' => 'buttons-global-button-text-color',
                    'box-shadow' => 'buttons-global-button-box-shadow',
                    'font-size' => 'buttons-global-button-font-size',
                    'letter-spacing' => 'buttons-global-button-letter-spacing',
                    'padding' => ueldo_get_color_pattern_options( 'buttons-global-button-padding' ),
                    '-webkit-border-radius' => 'buttons-global-button-border-radius',
                    '-moz-border-radius' => 'buttons-global-button-border-radius',
                    'border-radius' => 'buttons-global-button-border-radius',
                    'border-width' => 'buttons-global-button-border-width'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button)'
                ),
                'styles' => array(
                    'height' => 'buttons-global-button-static-height',
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-global-button-use-static-height' => 'yes'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):hover'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color-hover',
                    'border-color' => 'buttons-global-button-border-color-hover',
                    'color' => 'buttons-global-button-text-color-hover',
                    'box-shadow' => 'buttons-global-button-box-shadow-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button) i',
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button) i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color',
                    'font-size' => 'buttons-global-button-icon-size'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):hover i',
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):hover i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-button-without-text) i.ueldo-button-icon-before-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-button-without-text) i.ueldo-button-icon-after-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-global-styles'
                )
            ),

           /**
            *
            * read more button: [default]
            * form submit button: [custom]
            * call to action widget button: [custom]
            *
            * code: [n-y-y]
            *
            */

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button)'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color',
                    'border-color' => 'buttons-global-button-border-color',
                    'color' => 'buttons-global-button-text-color',
                    'box-shadow' => 'buttons-global-button-box-shadow',
                    'font-size' => 'buttons-global-button-font-size',
                    'letter-spacing' => 'buttons-global-button-letter-spacing',
                    'padding' => ueldo_get_color_pattern_options( 'buttons-global-button-padding' ),
                    '-webkit-border-radius' => 'buttons-global-button-border-radius',
                    '-moz-border-radius' => 'buttons-global-button-border-radius',
                    'border-radius' => 'buttons-global-button-border-radius',
                    'border-width' => 'buttons-global-button-border-width'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button)'
                ),
                'styles' => array(
                    'height' => 'buttons-global-button-static-height',
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-global-button-use-static-height' => 'yes'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button):hover'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color-hover',
                    'border-color' => 'buttons-global-button-border-color-hover',
                    'color' => 'buttons-global-button-text-color-hover',
                    'box-shadow' => 'buttons-global-button-box-shadow-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button) i',
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button) i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color',
                    'font-size' => 'buttons-global-button-icon-size'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button):hover i',
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button):hover i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button):not(.ueldo-button-without-text) i.ueldo-button-icon-before-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-call-to-action-widget-button):not(.ueldo-button-without-text) i.ueldo-button-icon-after-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-global-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

           /**
            *
            * read more button: [custom]
            * form submit button: [custom]
            * call to action widget button: [custom]
            *
            * code: [y-y-y]
            *
            */

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button)'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color',
                    'border-color' => 'buttons-global-button-border-color',
                    'color' => 'buttons-global-button-text-color',
                    'box-shadow' => 'buttons-global-button-box-shadow',
                    'font-size' => 'buttons-global-button-font-size',
                    'letter-spacing' => 'buttons-global-button-letter-spacing',
                    'padding' => ueldo_get_color_pattern_options( 'buttons-global-button-padding' ),
                    '-webkit-border-radius' => 'buttons-global-button-border-radius',
                    '-moz-border-radius' => 'buttons-global-button-border-radius',
                    'border-radius' => 'buttons-global-button-border-radius',
                    'border-width' => 'buttons-global-button-border-width'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button)'
                ),
                'styles' => array(
                    'height' => 'buttons-global-button-static-height',
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-global-button-use-static-height' => 'yes'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button):hover'
                ),
                'styles' => array(
                    'background' => 'buttons-global-button-background-color-hover',
                    'border-color' => 'buttons-global-button-border-color-hover',
                    'color' => 'buttons-global-button-text-color-hover',
                    'box-shadow' => 'buttons-global-button-box-shadow-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button) i',
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button) i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color',
                    'font-size' => 'buttons-global-button-icon-size'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button):hover i',
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button):hover i:before'
                ),
                'styles' => array(
                    'color' => 'buttons-global-button-icon-color-hover'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button):not(.ueldo-button-without-text) i.ueldo-button-icon-before-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'left' : 'right' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

            array(
                'elements' => array(
                    '*:not( .ueldo-shortcode-button-container.ueldo-shortcode-button-container-icon-visibility-on-hover-only ) > *:not( input ):not( button ).ueldo-button:not(.ueldo-read-more-button):not(.ueldo-call-to-action-widget-button):not(.ueldo-button-without-text) i.ueldo-button-icon-after-text'
                ),
                'styles' => array(
                    'margin-'. esc_attr( ueldo_is_rtl() ? 'right' : 'left' ) => 'buttons-global-button-margin-between-text-and-icon'
                ),
                'dependency' => array(
                    'buttons-read-more-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-form-submit-button-custom-styles-enabled' => 'use-custom-styles',
                    'buttons-call-to-action-widget-button-custom-styles-enabled' => 'use-custom-styles'
                )
            ),

           /**
            *
            * font sizes and line heights
            *
            */

            array(
                'elements' => array(
                    'html',
                    'h1 span.ueldo-heading-subtitle',
                    'h2 span.ueldo-heading-subtitle',
                    'h3 span.ueldo-heading-subtitle',
                    'h4 span.ueldo-heading-subtitle',
                    'h5 span.ueldo-heading-subtitle',
                    'h6 span.ueldo-heading-subtitle',
                    'p',
                    'ul',
                    'ol',
                    'ul li',
                    'ol li',
                    'blockquote cite',
                    'section.ueldo-comments ul.ueldo-comments-list li.comment .comment-respond a#cancel-comment-reply-link',
                    'section.ueldo-sidebar .widget label',
                    '.wpb_content_element .widget label',
                    '.nf-form-wrap .nf-field-label',
                    '.nf-form-wrap .nf-static.nf-element',
                    'span.wpcf7-list-item-label',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector li .ueldo-shortcode-tabs-selector-single-tab-title',
                    '.ueldo-shortcode-pulsating-circles .ueldo-shortcode-pulsating-circles-circle-central .ueldo-shortcode-pulsating-circles-tip',
                    '.ueldo-shortcode-pricing-table h6.ueldo-shortcode-pricing-table-content-title',
                    '.ueldo-shortcode-price-single .ueldo-shortcode-price-single-column .ueldo-shortcode-price-single-content .ueldo-shortcode-price-single-title',
                    '.ueldo-shortcode-price-single .ueldo-shortcode-price-single-column .ueldo-shortcode-price-single-content .ueldo-shortcode-price-single-price',
                    '.ueldo-shortcode-icon-list .ueldo-shortcode-icon-list-single-element .ueldo-shortcode-icon-list-single-element-number span.ueldo-shortcode-icon-list-single-element-number-value',
                    '.ueldo-shortcode-filtered-masonry ul.ueldo-shortcode-filtered-masonry-filter-list li',
                    '.ueldo-shortcode-tabs-box .ueldo-shortcode-tabs-box-tabs-contents .ueldo-shortcode-tabs-box-single-tab .ueldo-shortcode-tabs-box-single-tab-title',
                    '.woocommerce div.product .woocommerce-tabs.wc-tabs-wrapper > ul.tabs.wc-tabs li',
                    '.woocommerce div.product .woocommerce-tabs.wc-tabs-wrapper > ul.tabs.wc-tabs li a',
                    '.ueldo-shortcode-opening-hours-box .ueldo-shortcode-opening-hours-box-heading .ueldo-shortcode-opening-hours-box-heading-title',
                    '.ueldo-shortcode-opening-hours-box .ueldo-shortcode-opening-hours-box-elements .ueldo-shortcode-opening-hours-box-element .ueldo-shortcode-opening-hours-box-element-title',
                    '.ueldo-shortcode-opening-hours-box .ueldo-shortcode-opening-hours-box-elements .ueldo-shortcode-opening-hours-box-element .ueldo-shortcode-opening-hours-box-element-value',
                    '.ueldo-content-default .ueldo-content-wrapper address',
                    '.ueldo-content-default .ueldo-content-wrapper dl:not(.gallery-item) dd',
                    '.ueldo-content-default .ueldo-content-wrapper table:not(.highlight) td',
                    '.ueldo-content-default .ueldo-content-wrapper table:not(.highlight) th',
                    '.ueldo-content-default .ueldo-switch-page span.ueldo-switch-page-content-title',
                    '.ueldo-content-default .ueldo-switch-page span.ueldo-switch-page-content-highlight',
                    'section.ueldo-sidebar .widget ul:not(.ueldo-posts-list) li',
                    '.wpb_content_element .widget ul:not(.ueldo-posts-list) li',
                    'section.ueldo-sidebar .widget ul.ueldo-posts-list .ueldo-posts-list-single-post-title',
                    '.wpb_content_element .widget ul.ueldo-posts-list .ueldo-posts-list-single-post-title',
                    '.gform_wrapper .gform_body .description',
                    '.gform_wrapper .gform_body .gfield_description',
                    '.gform_wrapper .gform_body .gsection_description',
                    '.gform_wrapper .gform_body .instruction',
                    '.ueldo-shortcode-attributes-box .ueldo-shortcode-attributes-box-elements ul li .ueldo-shortcode-attributes-box-element-title',
                    '.ueldo-shortcode-pricing-list ul.ueldo-shortcode-pricing-list-groups-content-group-attributes-list li span.ueldo-shortcode-pricing-list-attribute-title',
                    '.ueldo-shortcode-pricing-list ul.ueldo-shortcode-pricing-list-groups-content-group-attributes-list li span.ueldo-shortcode-pricing-list-attribute-price',
                    '.ueldo-shortcode-presentation .ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-prev-images span.ueldo-shortcode-presentation-elements-switcher-prev-images-content',
                    '.ueldo-shortcode-presentation .ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-next-images span.ueldo-shortcode-presentation-elements-switcher-next-images-content',
                    'form label'
                ),
                'styles' => array(
                    'font-size' => 'font-size-content'
                )
            ),

            array(
                'elements' => array(
                    'p',
                    'ul li',
                    'ol li',
                    '.ueldo-content-default .ueldo-content-wrapper address',
                    '.ueldo-content-default .ueldo-content-wrapper dl:not(.gallery-item) dd',
                    '.ueldo-content-default .ueldo-content-wrapper dl:not(.gallery-item) dt',
                    '.ueldo-content-default .ueldo-content-wrapper table:not(.highlight) td',
                    '.ueldo-content-default .ueldo-content-wrapper table:not(.highlight) th',
                    '.ueldo-content-default .ueldo-switch-page span.ueldo-switch-page-content-title',
                    '.ueldo-content-default .ueldo-switch-page span.ueldo-switch-page-content-highlight',
                    'section.ueldo-sidebar .widget ul:not(.ueldo-posts-list) li',
                    '.wpb_content_element .widget ul:not(.ueldo-posts-list) li',
                    'section.ueldo-sidebar .widget ul.ueldo-posts-list .ueldo-posts-list-single-post-title',
                    '.wpb_content_element .widget ul.ueldo-posts-list .ueldo-posts-list-single-post-title',
                    '.gform_wrapper .gform_body .description',
                    '.gform_wrapper .gform_body .gfield_description',
                    '.gform_wrapper .gform_body .gsection_description',
                    '.gform_wrapper .gform_body .instruction',
                    '.ueldo-shortcode-attributes-box .ueldo-shortcode-attributes-box-elements ul li .ueldo-shortcode-attributes-box-element-title',
                    '.ueldo-shortcode-pricing-list ul.ueldo-shortcode-pricing-list-groups-content-group-attributes-list li span.ueldo-shortcode-pricing-list-attribute-title',
                    '.ueldo-shortcode-pricing-list ul.ueldo-shortcode-pricing-list-groups-content-group-attributes-list li span.ueldo-shortcode-pricing-list-attribute-price',
                    '.ueldo-shortcode-presentation .ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-prev-images span.ueldo-shortcode-presentation-elements-switcher-prev-images-content',
                    '.ueldo-shortcode-presentation .ueldo-shortcode-presentation-elements-switcher .ueldo-shortcode-presentation-elements-switcher-next-images span.ueldo-shortcode-presentation-elements-switcher-next-images-content',
                    'form textarea',
                    '.nf-form-wrap textarea',
                    '.gform_wrapper form .gform_body .description',
                    '.gform_wrapper form .gform_body .gfield_description',
                    '.gform_wrapper form .gform_body .gsection_description',
                    '.gform_wrapper form .gform_body .instruction',
                    'form p.ueldo-fields-inline span.wpcf7-not-valid-tip',
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-box .ueldo-shortcode-quote-box-inner p',
                    '.woocommerce div.product div.product_meta span.posted_in',
                    '.woocommerce div.product div.product_meta span.tagged_as',
                    'form label'
                ),
                'styles' => array(
                    'line-height' => 'line-height-general'
                )
            ),

            array(
                'elements' => array(
                    'h1',
                    'h2',
                    'h3',
                    'h4',
                    'h5',
                    'h6',
                    '.ueldo-shortcode-heading h1 .ueldo-shortcode-heading-text',
                    '.ueldo-shortcode-heading h2 .ueldo-shortcode-heading-text',
                    '.ueldo-shortcode-heading h3 .ueldo-shortcode-heading-text',
                    '.ueldo-shortcode-heading h4 .ueldo-shortcode-heading-text',
                    '.ueldo-shortcode-heading h5 .ueldo-shortcode-heading-text',
                    '.ueldo-shortcode-heading h6 .ueldo-shortcode-heading-text',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h1',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h1 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h2',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h2 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h3',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h3 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h4',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h4 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h5',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h5 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h6',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 h6 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-02 h1',
                    '.ueldo-short-post-box.ueldo-short-post-box-02 h1 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-02 h2',
                    '.ueldo-short-post-box.ueldo-short-post-box-02 h2 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-02 h3',
                    '.ueldo-short-post-box.ueldo-short-post-box-02 h3 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-02 h4',
                    '.ueldo-short-post-box.ueldo-short-post-box-02 h4 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-02 h5',
                    '.ueldo-short-post-box.ueldo-short-post-box-02 h5 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-02 h6',
                    '.ueldo-short-post-box.ueldo-short-post-box-02 h6 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-03 h1',
                    '.ueldo-short-post-box.ueldo-short-post-box-03 h1 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-03 h2',
                    '.ueldo-short-post-box.ueldo-short-post-box-03 h2 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-03 h3',
                    '.ueldo-short-post-box.ueldo-short-post-box-03 h3 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-03 h4',
                    '.ueldo-short-post-box.ueldo-short-post-box-03 h4 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-03 h5',
                    '.ueldo-short-post-box.ueldo-short-post-box-03 h5 a',
                    '.ueldo-short-post-box.ueldo-short-post-box-03 h6',
                    '.ueldo-short-post-box.ueldo-short-post-box-03 h6 a',
                    '.ueldo-shortcode-tabs ul.ueldo-shortcode-tabs-selector li .ueldo-shortcode-tabs-selector-single-tab-title',
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-element .ueldo-shortcode-info-box-element-text',
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-element .ueldo-shortcode-info-box-element-counter',
                    '.ueldo-content-woocommerce nav.woocommerce-pagination ul.page-numbers .page-numbers',
                    'section.ueldo-comments .ueldo-comments-pagination .page-numbers',
                    '.ueldo-content-default article.ueldo-blog-post .ueldo-single-news-page-switcher .ueldo-single-news-page',
                    '.ueldo-content-default article.ueldo-blog-post .ueldo-single-news-page-switcher a',
                    '.ueldo-content-default article.ueldo-page .ueldo-single-news-page-switcher .ueldo-single-news-page',
                    '.ueldo-content-default article.ueldo-page .ueldo-single-news-page-switcher a'
                ),
                'styles' => array(
                    'line-height' => 'line-height-headings'
                )
            ),

            array(
                'elements' => array(
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu > ul > li > a',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav > ul > li > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.sub-menu > li > a',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.children > li > a',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav ul.sub-menu > li > a',
                    '#ueldo-side-menu nav ul li a'
                ),
                'styles' => array(
                    'font-size' => 'font-size-menu-links'
                )
            ),

            array(
                'elements' => array(
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu > ul > li > a > i.fa.fa-caret-down',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav > ul > li > a > i.fa.fa-caret-down',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.sub-menu > li > a > i.fa.fa-caret-left',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.children > li > a > i.fa.fa-caret-left',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav ul.sub-menu > li > a > i.fa.fa-caret-left',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.sub-menu > li > a > i.fa.fa-caret-right',
                    'header.ueldo-header-bar nav.ueldo-header-bar-main-menu ul.children > li > a > i.fa.fa-caret-right',
                    '.ueldo-shortcode-header-menu nav.ueldo-shortcode-header-menu-nav ul.sub-menu > li > a > i.fa.fa-caret-right',
                    '#ueldo-side-menu nav.ueldo-side-menu-submenu-links-visible-on-click-under-parent li.menu-item-has-children > a > span.ueldo-side-menu-link:after',
                    '#ueldo-side-menu nav.ueldo-side-menu-submenu-links-visible-on-click-as-new-layer li.menu-item-has-children > a > span.ueldo-side-menu-link:after',
                    '#ueldo-side-menu nav.ueldo-side-menu-submenu-links-visible-on-click-as-new-layer ul.sub-menu > li > a.ueldo-side-menu-submenu-back-link > span:not(.ueldo-side-menu-link):before',
                    '#ueldo-side-menu nav.ueldo-side-menu-submenu-links-visible-on-click-as-new-layer ul.children > li > a.ueldo-side-menu-submenu-back-link > span:not(.ueldo-side-menu-link):before',
                    '.ueldo-shortcode-languages-switcher .ueldo-shortcode-languages-switcher-current-language i'
                ),
                'styles' => array(
                    'font-size' => 'font-size-menu-links-icons'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-alert-box p',
                    '.ueldo-shortcode-announcement p',
                    '.mc4wp-alert p',
                    'form div.wpcf7-response-output',
                    '.nf-form-errors .nf-error-msg',
                    '.nf-form-wrap .nf-response-msg',
                    '.nf-form-wrap .nf-form-fields-required',
                    '.gform_wrapper form div.validation_error',
                    '.gform_confirmation_wrapper .gform_confirmation_message',
                    'p.logged-in-as',
                    '.ueldo-content-default article.ueldo-blog-post .ueldo-blog-post-data ul li:after',
                    '.ueldo-content-default .ueldo-content-wrapper code',
                    '.ueldo-content-default .ueldo-content-wrapper kbd',
                    '.ueldo-content-default .ueldo-content-wrapper ins',
                    '.ueldo-content-default .ueldo-content-wrapper pre',
                    '.ueldo-website-wrapper pre',
                    '.ueldo-content-default .ueldo-content-wrapper .gallery-caption',
                    '.ueldo-content-default article.ueldo-blog-post .ueldo-single-news-page-switcher .ueldo-single-news-page',
                    '.ueldo-content-default article.ueldo-page .ueldo-single-news-page-switcher .ueldo-single-news-page',
                    'section.ueldo-comments .ueldo-comments-pagination .page-numbers',
                    '.ueldo-content-woocommerce nav.woocommerce-pagination .page-numbers',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 .ueldo-short-post-box-author p.ueldo-short-post-box-author-name',
                    '.ueldo-short-post-box.ueldo-short-post-box-02 .ueldo-short-post-box-author p.ueldo-short-post-box-author-name',
                    'footer.ueldo-footer p',
                    '.gform_wrapper form .gform_body .description',
                    '.gform_wrapper form .gform_body .gfield_description',
                    '.gform_wrapper form .gform_body .gsection_description',
                    '.gform_wrapper form .gform_body .instruction',
                    '.ueldo-shortcode-full-width-testimonials .ueldo-shortcode-full-width-testimonials-single-testimonial-author p.ueldo-shortcode-full-width-testimonials-single-testimonial-author-name',
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-author .ueldo-shortcode-quote-author-content p.ueldo-shortcode-quote-author-content-author-name',
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-card .ueldo-shortcode-timeline-element .ueldo-shortcode-timeline-element-date',
                    '.ueldo-shortcode-timeline.ueldo-shortcode-timeline-display-as-full-width .ueldo-shortcode-timeline-element .ueldo-shortcode-timeline-element-date',
                    '.ueldo-shortcode-languages-switcher .ueldo-shortcode-languages-switcher-current-language',
                    '.ueldo-shortcode-languages-switcher .ueldo-shortcode-languages-switcher-list li a'
                ),
                'styles' => array(
                    'font-size' => 'font-size-small-content'
                )
            ),

            array(
                'elements' => array(
                    'section.ueldo-sidebar .widget .tagcloud a',
                    '.wpb_content_element .widget .tagcloud a',
                    '.ueldo-content-default .ueldo-tags-and-categories p a.element'
                ),
                'styles' => array(
                    'font-size-string' => ueldo_get_color_pattern_options( 'font-size-small-content-important' )
                )
            ),

            array(
                'elements' => array(
                    'section.ueldo-comments ul.ueldo-comments-list li.comment .comment-meta a',
                    'section.ueldo-comments ul.ueldo-comments-list li.comment .ueldo-comments-reply-link i',
                    'section.ueldo-comments ul.ueldo-comments-list li.comment.bypostauthor .ueldo-comment-by-post-author',
                    'section.ueldo-sidebar .widget #calendar_wrap',
                    '.wpb_content_element .widget #calendar_wrap',
                    '.ueldo-short-post-box.ueldo-short-post-box-01 .ueldo-short-post-box-author p',
                    '.ueldo-short-post-box.ueldo-short-post-box-02 .ueldo-short-post-box-author p',
                    '.ueldo-short-post-box.ueldo-short-post-box-03 p.ueldo-short-post-box-post-data',
                    'form span.wpcf7-not-valid-tip',
                    '.nf-after-field .nf-error-msg',
                    '.ueldo-shortcode-two-line-button .ueldo-shortcode-two-line-button-content span.ueldo-shortcode-two-line-button-content-subtitle',
                    '.ueldo-play-video-button .ueldo-play-video-button-title',
                    '.ueldo-shortcode-two-images-difference-before-label:before',
                    '.ueldo-shortcode-two-images-difference-after-label:before'
                ),
                'styles' => array(
                    'font-size' => 'font-size-smallest-content'
                )
            ),

            array(
                'elements' => array(
                    'section.ueldo-sidebar .ueldo-widget-call-to-action .ueldo-widget-call-to-action-offer',
                    '.wpb_content_element .ueldo-widget-call-to-action .ueldo-widget-call-to-action-offer',
                    'section.ueldo-sidebar .ueldo-widget-call-to-action .ueldo-widget-call-to-action-offer i:before',
                    '.wpb_content_element .ueldo-widget-call-to-action .ueldo-widget-call-to-action-offer i:before'
                ),
                'styles' => array(
                    'font-size' => 'font-size-call-to-action-widget-offer'
                )
            ),

            array(
                'elements' => array(
                    'form input[type=\"text\"]',
                    'form input[type=\"email\"]',
                    'form input[type=\"password\"]',
                    'form input[type=\"url\"]',
                    'form input[type=\"tel\"]',
                    'form input[type=\"number\"]',
                    'form input[type=\"date\"]',
                    'form textarea',
                    '.nf-form-wrap input[type=\"text\"]',
                    '.nf-form-wrap input[type=\"email\"]',
                    '.nf-form-wrap input[type=\"password\"]',
                    '.nf-form-wrap input[type=\"url\"]',
                    '.nf-form-wrap input[type=\"tel\"]',
                    '.nf-form-wrap input[type=\"number\"]',
                    '.nf-form-wrap input[type=\"date\"]',
                    '.nf-form-wrap textarea',
                    '.ueldo-select-field select',
                    '.gform_wrapper .gform_body .ueldo-select-field:not(.ueldo-is-multiple-select) select',
                    '.gform_wrapper .gform_body textarea',
                    '.gform_wrapper .gform_body input:not([type=radio]):not([type=checkbox]):not([type=submit]):not([type=button]):not([type=image]):not([type=file])',
                    '.select2-container--default .select2-selection--single .select2-selection__rendered',
                    '.select2-results__option',
                    '.select2-container--default .select2-search--dropdown .select2-search__field'
                ),
                'styles' => array(
                    'font-size' => 'font-size-form-fields'
                )
            ),

            array(
                'elements' => array(
                    'h1',
                    '.ueldo-shortcode-heading h1 .ueldo-shortcode-heading-text',
                    '.gform_wrapper .gform_body h1',
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-element .ueldo-shortcode-info-box-element-text',
                    '.ueldo-shortcode-info-box .ueldo-shortcode-info-box-element .ueldo-shortcode-info-box-element-counter'
                ),
                'styles' => array(
                    'font-size' => 'font-size-h1'
                )
            ),

            array(
                'elements' => array(
                    'h2',
                    '.ueldo-shortcode-heading h2 .ueldo-shortcode-heading-text',
                    '.gform_wrapper .gform_body h2',
                    '.gform_wrapper .gform_body h2.gsection_title'
                ),
                'styles' => array(
                    'font-size' => 'font-size-h2'
                )
            ),

            array(
                'elements' => array(
                    'h3',
                    '.ueldo-shortcode-heading h3 .ueldo-shortcode-heading-text',
                    '.gform_wrapper .gform_body h3',
                    '.gform_wrapper .gform_body h3.gform_title'
                ),
                'styles' => array(
                    'font-size' => 'font-size-h3'
                )
            ),

            array(
                'elements' => array(
                    'h4',
                    '.ueldo-shortcode-heading h4 .ueldo-shortcode-heading-text',
                    '.gform_wrapper .gform_body h4',
                    '.ueldo-shortcode-two-line-button .ueldo-shortcode-two-line-button-content span.ueldo-shortcode-two-line-button-content-title'
                ),
                'styles' => array(
                    'font-size' => 'font-size-h4'
                )
            ),

            array(
                'elements' => array(
                    'h5',
                    '.ueldo-shortcode-heading h5 .ueldo-shortcode-heading-text',
                    '.gform_wrapper .gform_body h5'
                ),
                'styles' => array(
                    'font-size' => 'font-size-h5'
                )
            ),

            array(
                'elements' => array(
                    'h6',
                    '.ueldo-shortcode-heading h6 .ueldo-shortcode-heading-text',
                    '.gform_wrapper .gform_body h6',
                    '.ueldo-content-default .ueldo-content-wrapper dl:not(.gallery-item) dt',
                    '.ueldo-shortcode-quote .ueldo-shortcode-quote-box .ueldo-shortcode-quote-box-inner p'
                ),
                'styles' => array(
                    'font-size' => 'font-size-h6'
                )
            ),

            array(
                'elements' => array(
                    'blockquote p'
                ),
                'styles' => array(
                    'font-size' => 'font-size-blockquote'
                )
            ),

           /**
            *
            * icon-list visual composer shortcode, depended on font size value
            *
            */

            array(
                'elements' => array(
                    '.ueldo-shortcode-icon-list .ueldo-shortcode-icon-list-single-element .ueldo-shortcode-icon-list-single-element-icon',
                    '.ueldo-shortcode-icon-list .ueldo-shortcode-icon-list-single-element .ueldo-shortcode-icon-list-single-element-number'
                ),
                'styles' => array(
                    'width' => 'font-size-content',
                    'height' => 'font-size-content'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-icon-list .ueldo-shortcode-icon-list-single-element .ueldo-shortcode-icon-list-single-element-icon i',
                    '.ueldo-shortcode-icon-list .ueldo-shortcode-icon-list-single-element .ueldo-shortcode-icon-list-single-element-icon i:before'
                ),
                'styles' => array(
                    'font-size' => 'font-size-content'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-icon-list .ueldo-shortcode-icon-list-single-element .ueldo-shortcode-icon-list-single-element-icon span.ueldo-shortcode-icon-list-single-element-icon-middle-helper',
                    '.ueldo-shortcode-icon-list .ueldo-shortcode-icon-list-single-element .ueldo-shortcode-icon-list-single-element-number span.ueldo-shortcode-icon-list-single-element-number-middle-helper'
                ),
                'styles' => array(
                    'height' => 'font-size-content'
                )
            ),

            array(
                'elements' => array(
                    '.ueldo-shortcode-icon-list .ueldo-shortcode-icon-list-single-element .ueldo-shortcode-icon-list-single-element-content'
                ),
                'styles' => array(
                    'width-webkit-calc' => ueldo_get_color_pattern_options( 'icon-list-shortcode-single-element-content-width-webkit-calc' ),
                    'width-moz-calc' => ueldo_get_color_pattern_options( 'icon-list-shortcode-single-element-content-width-moz-calc' ),
                    'width-calc' => ueldo_get_color_pattern_options( 'icon-list-shortcode-single-element-content-width-calc' )
                )
            ),

           /**
            *
            * date & time picker styles
            *
            */

            array(
                'elements' => array(
                    '.ui-datepicker.ueldo-custom-datepicker-theme'
                ),
                'styles' => array(
                    'background' => 'datepicker-container-background-color',
                    '-webkit-box-shadow' => 'datepicker-container-box-shadow',
                    '-moz-box-shadow' => 'datepicker-container-box-shadow',
                    'box-shadow' => 'datepicker-container-box-shadow'
                )
            ),

            array(
                'elements' => array(
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui-datepicker-title',
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui_tpicker_time_label',
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui_tpicker_hour_label',
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui_tpicker_minute_label',
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui_tpicker_second_label',
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui_tpicker_millisec_label',
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui_tpicker_microsec_label',
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui_tpicker_timezone_label',
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui-timepicker-div dl dd.ui_tpicker_time',
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui-datepicker-buttonpane button:hover'
                ),
                'styles' => array(
                    'color' => 'datepicker-headings-color'
                )
            ),

            array(
                'elements' => array(
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui-datepicker-next span:before',
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui-datepicker-prev span:before'
                ),
                'styles' => array(
                    'color' => 'datepicker-next-prev-arrows-color'
                )
            ),

            array(
                'elements' => array(
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui-datepicker-next:hover span:before',
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui-datepicker-prev:hover span:before'
                ),
                'styles' => array(
                    'color' => 'datepicker-next-prev-arrows-color-hover'
                )
            ),

            array(
                'elements' => array(
                    '.ui-datepicker.ueldo-custom-datepicker-theme th',
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui-datepicker-buttonpane button'
                ),
                'styles' => array(
                    'color' => 'datepicker-weekdays-and-buttons-color'
                )
            ),

            array(
                'elements' => array(
                    '.ui-datepicker.ueldo-custom-datepicker-theme td'
                ),
                'styles' => array(
                    'background' => 'datepicker-single-day-background-color'
                )
            ),

            array(
                'elements' => array(
                    '.ui-datepicker.ueldo-custom-datepicker-theme td .ui-state-default'
                ),
                'styles' => array(
                    'color' => 'datepicker-single-day-text-color'
                )
            ),

            array(
                'elements' => array(
                    '.ui-datepicker.ueldo-custom-datepicker-theme td:not(.ui-state-disabled) .ui-state-default:hover',
                    '.ui-datepicker.ueldo-custom-datepicker-theme td:not(.ui-state-disabled) .ui-state-default.ui-state-highlight',
                    '.ui-datepicker.ueldo-custom-datepicker-theme td:not(.ui-state-disabled) .ui-state-default.ui-state-active',
                    '.ui-datepicker.ueldo-custom-datepicker-theme td:not(.ui-state-disabled) .ui-state-default.ui-state-hover'
                ),
                'styles' => array(
                    'color' => 'datepicker-single-day-text-color-hover',
                    'background' => 'datepicker-single-day-background-color-hover'
                )
            ),

            array(
                'elements' => array(
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui-state-disabled .ui-state-default'
                ),
                'styles' => array(
                    'color' => 'datepicker-single-day-disabled-text-color'
                )
            ),

            array(
                'elements' => array(
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui-datepicker-buttonpane',
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui-timepicker-div dl',
                    '.ui-datepicker.ueldo-custom-datepicker-theme th'
                ),
                'styles' => array(
                    'border-top-color' => 'datepicker-dividers-border-color'
                )
            ),

            array(
                'elements' => array(
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui-timepicker-div dl dd .ui-slider'
                ),
                'styles' => array(
                    'background' => 'datepicker-time-slider-background-color'
                )
            ),

            array(
                'elements' => array(
                    '.ui-datepicker.ueldo-custom-datepicker-theme .ui-timepicker-div dl dd .ui-slider .ui-slider-handle'
                ),
                'styles' => array(
                    'background' => 'datepicker-time-slider-handle-background-color'
                )
            )

           /**
            *
            * end of style rules
            *
            */

        ));
    }

   /**
    *
    * get color pattern options
    *
    */

    function ueldo_get_color_pattern_options( $key ) {

        # switch by pattern key
        switch( $key ) {

            # box shadow for pulsating circles tip and info box additional element
            case 'pulsating-circles-tip-and-info-box-additional-element-box-shadow':

                # return pattern
                return( array(
                    'pattern' => '0 0 15px {$1}',
                    'values' => array(
                        '$1' => array(
                            'color' => 'general-colors-main-color',
                            'is_rgba' => 'yes',
                            'opacity' => '0.25'
                        )
                    )
                ));

            break;

            # background color for pulsating circles first circle
            case 'pulsating-circles-first-circle-background-color':

                # return pattern
                return( array(
                    'pattern' => '{$1}',
                    'values' => array(
                        '$1' => array(
                            'color' => 'general-colors-main-color',
                            'is_rgba' => 'yes',
                            'opacity' => '0.55'
                        )
                    )
                ));

            break;

            # background color for pulsating circles second circle
            case 'pulsating-circles-second-circle-background-color':

                # return pattern
                return( array(
                    'pattern' => '{$1}',
                    'values' => array(
                        '$1' => array(
                            'color' => 'general-colors-main-color',
                            'is_rgba' => 'yes',
                            'opacity' => '0.40'
                        )
                    )
                ));

            break;

            # background color for pulsating circles third circle
            case 'pulsating-circles-third-circle-background-color':

                # return pattern
                return( array(
                    'pattern' => '{$1}',
                    'values' => array(
                        '$1' => array(
                            'color' => 'general-colors-main-color',
                            'is_rgba' => 'yes',
                            'opacity' => '0.20'
                        )
                    )
                ));

            break;

            # background color for pulsating circles fourth circle
            case 'pulsating-circles-fourth-circle-background-color':

                # return pattern
                return( array(
                    'pattern' => '{$1}',
                    'values' => array(
                        '$1' => array(
                            'color' => 'general-colors-main-color',
                            'is_rgba' => 'yes',
                            'opacity' => '0.1'
                        )
                    )
                ));

            break;

            # almost transparent website background color
            case 'website-background-transparent':

                # return pattern
                return( array(
                    'pattern' => '{$1}',
                    'values' => array(
                        '$1' => array(
                            'color' => 'general-colors-website-background',
                            'is_rgba' => 'yes',
                            'opacity' => '0.00'
                        )
                    )
                ));

            break;

            # backgrond color for third-style pricing table image overlay
            case 'pricing-table-03-image-overlay-background-color':

                # return pattern
                return( array(
                    'pattern' => '{$1}',
                    'values' => array(
                        '$1' => array(
                            'color' => 'general-colors-website-background',
                            'is_rgba' => 'yes',
                            'opacity' => '0.9'
                        )
                    )
                ));

            break;

            # gradient for full-width timeline, code for opera browsers
            case 'full-width-timeline-element-gradient-o':

                # return pattern
                return( array(
                    'pattern' => '-o-linear-gradient( bottom, rgba( 255, 255, 255, 0 ) 0%, {$1} 100% )',
                    'values' => array(
                        '$1' => array(
                            'color' => 'general-colors-elements-border-color'
                        )
                    )
                ));

            break;

            # gradient for full-width timeline, code for mozilla browsers
            case 'full-width-timeline-element-gradient-moz':

                # return pattern
                return( array(
                    'pattern' => '-moz-linear-gradient( bottom, rgba( 255, 255, 255, 0 ) 0%, {$1} 100% )',
                    'values' => array(
                        '$1' => array(
                            'color' => 'general-colors-elements-border-color'
                        )
                    )
                ));

            break;

            # gradient for full-width timeline, code for webkit browsers
            case 'full-width-timeline-element-gradient-webkit':

                # return pattern
                return( array(
                    'pattern' => '-webkit-linear-gradient( bottom, rgba( 255, 255, 255, 0 ) 0%, {$1} 100% )',
                    'values' => array(
                        '$1' => array(
                            'color' => 'general-colors-elements-border-color'
                        )
                    )
                ));

            break;

            # gradient for full-width timeline, code for ms browsers
            case 'full-width-timeline-element-gradient-ms':

                # return pattern
                return( array(
                    'pattern' => '-ms-linear-gradient( bottom, rgba( 255, 255, 255, 0 ) 0%, {$1} 100% )',
                    'values' => array(
                        '$1' => array(
                            'color' => 'general-colors-elements-border-color'
                        )
                    )
                ));

            break;

            # gradient for full-width timeline, standard code
            case 'full-width-timeline-element-gradient':

                # return pattern
                return( array(
                    'pattern' => 'linear-gradient( to bottom, {$1} 0%, rgba( 255, 255, 255, 0 ) 100% )',
                    'values' => array(
                        '$1' => array(
                            'color' => 'general-colors-elements-border-color'
                        )
                    )
                ));

            break;

            # overlay for presentation elements switcher
            case 'presentation-elements-switcher-inactive-elements-overlay':

                # return pattern
                return( array(
                    'pattern' => '{$1}',
                    'values' => array(
                        '$1' => array(
                            'color' => 'general-colors-website-background',
                            'is_rgba' => 'yes',
                            'opacity' => '0.65'
                        )
                    )
                ));

            break;

            # point of interest pulse, on presentation shortcode
            case 'presentation-point-of-interest-pulse-box-shadow':

                # return pattern
                return( array(
                    'pattern' => 'inset 0 0 1px 1px {$1}',
                    'values' => array(
                        '$1' => array(
                            'color' => 'point-of-interest-pulse-color'
                        )
                    )
                ));

            break;

            # form field box shadow
            case 'form-field-box-shadow':

                # return pattern
                return( array(
                    'pattern' => '{$1}, inset {$2}',
                    'values' => array(
                        '$1' => array(
                            'color' => 'forms-field-box-shadow'
                        ),
                        '$2' => array(
                            'color' => 'forms-field-inset-box-shadow'
                        )
                    )
                ));

            break;

            # form field invalid border color
            case 'form-field-invalid-border-color-important':

                # return pattern
                return( array(
                    'pattern' => '{$1} !important',
                    'values' => array(
                        '$1' => array(
                            'color' => 'forms-field-border-color-for-invalid-values'
                        )
                    )
                ));

            break;

            # important border color to form field
            case 'form-field-border-color-important':

                # return pattern
                return( array(
                    'pattern' => '{$1} !important',
                    'values' => array(
                        '$1' => array(
                            'color' => 'forms-field-border-color'
                        )
                    )
                ));

            break;

            # padding for global buttons
            case 'buttons-global-button-padding':

                # return pattern
                return( array(
                    'pattern' => '{$1}px {$2}px {$3}px {$4}px',
                    'values' => array(
                        '$1' => array(
                            'color' => 'buttons-global-button-padding-top'
                        ),
                        '$2' => array(
                            'color' => 'buttons-global-button-padding-right'
                        ),
                        '$3' => array(
                            'color' => 'buttons-global-button-padding-bottom'
                        ),
                        '$4' => array(
                            'color' => 'buttons-global-button-padding-left'
                        )
                    )
                ));

            break;

            # padding for "read more" buttons
            case 'buttons-read-more-button-padding':

                # return pattern
                return( array(
                    'pattern' => '{$1}px {$2}px {$3}px {$4}px',
                    'values' => array(
                        '$1' => array(
                            'color' => 'buttons-read-more-button-padding-top'
                        ),
                        '$2' => array(
                            'color' => 'buttons-read-more-button-padding-right'
                        ),
                        '$3' => array(
                            'color' => 'buttons-read-more-button-padding-bottom'
                        ),
                        '$4' => array(
                            'color' => 'buttons-read-more-button-padding-left'
                        )
                    )
                ));

            break;

            # padding for "call to action widget" buttons
            case 'buttons-call-to-action-widget-button-padding':

                # return pattern
                return( array(
                    'pattern' => '{$1}px {$2}px {$3}px {$4}px',
                    'values' => array(
                        '$1' => array(
                            'color' => 'buttons-call-to-action-widget-button-padding-top'
                        ),
                        '$2' => array(
                            'color' => 'buttons-call-to-action-widget-button-padding-right'
                        ),
                        '$3' => array(
                            'color' => 'buttons-call-to-action-widget-button-padding-bottom'
                        ),
                        '$4' => array(
                            'color' => 'buttons-call-to-action-widget-button-padding-left'
                        )
                    )
                ));

            break;

            # padding for "form submit" buttons
            case 'buttons-form-submit-button-padding':

                # return pattern
                return( array(
                    'pattern' => '{$1}px {$2}px {$3}px {$4}px',
                    'values' => array(
                        '$1' => array(
                            'color' => 'buttons-form-submit-button-padding-top'
                        ),
                        '$2' => array(
                            'color' => 'buttons-form-submit-button-padding-right'
                        ),
                        '$3' => array(
                            'color' => 'buttons-form-submit-button-padding-bottom'
                        ),
                        '$4' => array(
                            'color' => 'buttons-form-submit-button-padding-left'
                        )
                    )
                ));

            break;

            # margin (plus) for icon visible on hover only
            case 'buttons-icon-visibility-on-hover-only-margin-plus':

                # return pattern
                return( array(
                    'pattern' => 'math[ ( {$1} + {$2} ) / 2 ]',
                    'values' => array(
                        '$1' => array(
                            'color' => 'buttons-global-button-icon-size'
                        ),
                        '$2' => array(
                            'color' => 'buttons-global-button-margin-between-text-and-icon'
                        )
                    )
                ));

            break;

            # margin (minus) for icon visible on hover only
            case 'buttons-icon-visibility-on-hover-only-margin-minus':

                # return pattern
                return( array(
                    'pattern' => '-math[ ( {$1} + {$2} ) / 2 ]',
                    'values' => array(
                        '$1' => array(
                            'color' => 'buttons-global-button-icon-size'
                        ),
                        '$2' => array(
                            'color' => 'buttons-global-button-margin-between-text-and-icon'
                        )
                    )
                ));

            break;

            # margin for text, when icon is visible on hover only
            case 'buttons-icon-visibility-on-hover-only-margin-for-text':

                # return pattern
                return( array(
                    'pattern' => 'math[ {$1} / 2 ]',
                    'values' => array(
                        '$1' => array(
                            'color' => 'buttons-global-button-margin-between-text-and-icon'
                        )
                    )
                ));

            break;

            # vc-mono icon translation for buttons for left-to-right languages
            case 'buttons-icon-vc-mono-translation-ltr':

                # return pattern
                return( array(
                    'pattern' => 'translate( calc( -50% + math[ {$1} / 2 ]px ), calc( -50% + math[ {$1} / 2 ]px ) )',
                    'values' => array(
                        '$1' => array(
                            'color' => 'buttons-global-button-icon-size'
                        )
                    )
                ));

            break;

            # vc-mono icon translation for buttons for right-to-left languages
            case 'buttons-icon-vc-mono-translation-rtl':

                # return pattern
                return( array(
                    'pattern' => 'translate( calc( 50% - math[ {$1} / 2 ]px ), calc( -50% + math[ {$1} / 2 ]px ) )',
                    'values' => array(
                        '$1' => array(
                            'color' => 'buttons-global-button-icon-size'
                        )
                    )
                ));

            break;

            # vc-mono icon margin when centered
            case 'buttons-icon-vc-mono-margin-centered':

                # return pattern
                return( array(
                    'pattern' => '-math[ {$1} / 2 ]',
                    'values' => array(
                        '$1' => array(
                            'color' => 'buttons-global-button-icon-size'
                        )
                    )
                ));

            break;

            # vc-mono icon margin when aligned to right
            case 'buttons-icon-vc-mono-margin-aligned-right':

                # return pattern
                return( array(
                    'pattern' => '-{$1}',
                    'values' => array(
                        '$1' => array(
                            'color' => 'buttons-global-button-icon-size'
                        )
                    )
                ));

            break;

            # important small content font size
            case 'font-size-small-content-important':

                # return pattern
                return( array(
                    'pattern' => '{$1}px !important',
                    'values' => array(
                        '$1' => array(
                            'color' => 'font-size-small-content'
                        )
                    )
                ));

            break;

            # icon list shortcode, single element content width, webkit calc
            case 'icon-list-shortcode-single-element-content-width-webkit-calc':

                # return pattern
                return( array(
                    'pattern' => '-webkit-calc( 100% - math[ {$1} + 15 ]px )',
                    'values' => array(
                        '$1' => array(
                            'color' => 'font-size-content'
                        )
                    )
                ));

            break;

            # icon list shortcode, single element content width, moz calc
            case 'icon-list-shortcode-single-element-content-width-moz-calc':

                # return pattern
                return( array(
                    'pattern' => '-moz-calc( 100% - math[ {$1} + 15 ]px )',
                    'values' => array(
                        '$1' => array(
                            'color' => 'font-size-content'
                        )
                    )
                ));

            break;

            # icon list shortcode, single element content width, calc
            case 'icon-list-shortcode-single-element-content-width-calc':

                # return pattern
                return( array(
                    'pattern' => 'calc( 100% - math[ {$1} + 15 ]px )',
                    'values' => array(
                        '$1' => array(
                            'color' => 'font-size-content'
                        )
                    )
                ));

            break;

            # header bar menu sub-menu sub-menu margin top calculation
            case 'header-bar-menu-sub-menu-sub-menu-margin-top':

                # return pattern
                return( array(
                    'pattern' => '-math[ {$1} + 32 ]',
                    'values' => array(
                        '$1' => array(
                            'color' => 'font-size-menu-links'
                        )
                    )
                ));

            break;

            # arrow color for select2 field
            case 'form-field-select2-arrow-color':

                # return pattern
                return( array(
                    'pattern' => '{$1} transparent transparent transparent',
                    'values' => array(
                        '$1' => array(
                            'color' => 'forms-select-and-date-field-icon-color'
                        )
                    )
                ));

            break;

            # arrow color for opened select2 field
            case 'form-field-select2-arrow-opened-color':

                # return pattern
                return( array(
                    'pattern' => 'transparent transparent {$1} transparent',
                    'values' => array(
                        '$1' => array(
                            'color' => 'general-colors-main-color'
                        )
                    )
                ));

            break;
        }
    }

   /**
    *
    * custom theme options for live wordpress customizer
    *
    */

    class ueldo_customizer {

       /**
        *
        * array of possible theme customizer options
        *
        */

        public static function get_customizer_options() {

            # return result
            return( array(
                'theme-colors' => array(
                    'title' => esc_html( __( 'Theme colors', 'ueldo' ) ),
                    'description' => esc_html( __( 'You can manage theme colors here.', 'ueldo' ) ),
                    'sections' => array(
                        array(
                            'title' => esc_html( __( 'General colors', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage general website colors here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Website background:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-website-background]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-website-background' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Main color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-main-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-main-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Main color contrast text color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-main-color-contrast-text-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-main-color-contrast-text-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Headings color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-headings-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-headings-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Headings subtitle color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-headings-subtitle-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-headings-subtitle-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Content color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-content-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-content-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Blockquote color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-blockquote-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-blockquote-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Blog post data color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-blog-post-data-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-blog-post-data-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Preformatted text color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-preformatted-text-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-preformatted-text-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Elements border color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-elements-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-elements-border-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Elements border color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-elements-hover-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-elements-hover-border-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Elements box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-elements-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-elements-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Elements box shadow (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-elements-hover-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-elements-hover-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Elements inset border color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-elements-inset-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-elements-inset-border-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Elements background icon color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-elements-background-icon-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-elements-background-icon-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Elements heading or active tab background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-elements-heading-or-active-tab-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-elements-heading-or-active-tab-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Icon color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-icon-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-icon-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Image box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-image-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-image-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Circle navigation background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-circle-navigation-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-circle-navigation-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Comment author avatar box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-comment-author-avatar-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-comment-author-avatar-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Pulsating circles central circle box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-pulsating-circles-central-circle-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-pulsating-circles-central-circle-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Pricing list inset box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-pricing-list-inset-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-pricing-list-inset-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Full-width elements inset box shadow (on top):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-full-width-elements-inset-box-shadow-top]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-full-width-elements-inset-box-shadow-top' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Full-width elements inset box shadow (on bottom):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-full-width-elements-inset-box-shadow-bottom]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-full-width-elements-inset-box-shadow-bottom' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Google map marker icon color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-google-map-marker-icon-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-google-map-marker-icon-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Google map marker icon container background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-google-map-marker-icon-container-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-google-map-marker-icon-container-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Google map marker icon container box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][general-colors-google-map-marker-icon-container-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'general-colors-google-map-marker-icon-container-box-shadow' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( 'Default header bar and menu colors', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage default header bar and menu colors here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][header-bar-and-menu-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'header-bar-and-menu-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][header-bar-and-menu-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'header-bar-and-menu-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Link color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][header-bar-and-menu-link-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'header-bar-and-menu-link-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Active or hover color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][header-bar-and-menu-active-or-hover-link-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'header-bar-and-menu-active-or-hover-link-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Submenu background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][header-bar-and-menu-submenu-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'header-bar-and-menu-submenu-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Submenu box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][header-bar-and-menu-submenu-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'header-bar-and-menu-submenu-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Submenu element border bottom color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][header-bar-and-menu-submenu-element-border-bottom-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'header-bar-and-menu-submenu-element-border-bottom-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Submenu element link color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][header-bar-and-menu-submenu-element-link-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'header-bar-and-menu-submenu-element-link-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Submenu element active or hover link color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][header-bar-and-menu-submenu-element-active-or-hover-link-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'header-bar-and-menu-submenu-element-active-or-hover-link-color' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( 'Image loader', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage the image loader colors here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][image-loader-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'image-loader-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][image-loader-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'image-loader-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Color for call to action widget:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][image-loader-color-for-call-to-action-widget]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'image-loader-color-for-call-to-action-widget' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( 'Point of interest', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage the point of interest elements default colors here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Pulse color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][point-of-interest-pulse-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'point-of-interest-pulse-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][point-of-interest-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'point-of-interest-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Close color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][point-of-interest-close-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'point-of-interest-close-color' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( 'Info-box element', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage the info-box element shortcode default colors here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][info-box-element-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'info-box-element-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Border color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][info-box-element-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'info-box-element-border-color' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( 'Opening hours status', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage the opening hours status default colors here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Color when open:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][opening-hours-status-color-when-open]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'opening-hours-status-color-when-open' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Color when closed:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][opening-hours-status-color-when-closed]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'opening-hours-status-color-when-closed' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( 'Sidebar', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage the sidebar and flying sidebar default colors here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Sidebar background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][sidebar-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'sidebar-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Use custom color for sidebar border line:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][sidebar-border-line-custom-color-enabled]',
                                    'type' => 'select',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'sidebar-border-line-custom-color-enabled' ),
                                    'choices' => array(
                                        'yes' => esc_html( __( 'Yes', 'ueldo' ) ),
                                        'no' => esc_html( __( 'No', 'ueldo' ) )
                                    )
                                ),
                                array(
                                    'label' => esc_html( __( 'Sidebar border color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][sidebar-border-line-custom-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'sidebar-border-line-custom-color' ),
                                    'active_callback' => array( 'ueldo_customizer', 'is_sidebar_border_line_custom_color_enabled' ),
                                ),
                                array(
                                    'label' => esc_html( __( 'Flying sidebar border color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][flying-sidebar-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'flying-sidebar-border-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Flying sidebar box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][flying-sidebar-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'flying-sidebar-box-shadow' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( 'Play video button', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage the play video button default colors here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][play-video-button-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'play-video-button-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][play-video-button-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'play-video-button-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Title background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][play-video-button-title-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'play-video-button-title-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Title text color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][play-video-button-title-text-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'play-video-button-title-text-color' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( 'Side menu', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage the side menu default colors here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][side-menu-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'side-menu-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][side-menu-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'side-menu-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Link color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][side-menu-link-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'side-menu-link-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Link border bottom color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][side-menu-link-border-bottom-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'side-menu-link-border-bottom-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Link background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][side-menu-link-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'side-menu-link-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Link color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][side-menu-link-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'side-menu-link-color-hover' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Link border bottom color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][side-menu-link-border-bottom-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'side-menu-link-border-bottom-color-hover' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Link background color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][side-menu-link-background-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'side-menu-link-background-color-hover' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Active link color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][side-menu-active-link-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'side-menu-active-link-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Active link border bottom color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][side-menu-active-link-border-bottom-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'side-menu-active-link-border-bottom-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Active link background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][side-menu-active-link-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'side-menu-active-link-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Link icon color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][side-menu-link-icon-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'side-menu-link-icon-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Link icon color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][side-menu-link-icon-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'side-menu-link-icon-color-hover' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Active link icon color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][side-menu-active-link-icon-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'side-menu-active-link-icon-color' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( 'Boxed website', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage the boxed website box shadow here - it will be applied only for boxed-style website.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][boxed-website-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'boxed-website-box-shadow' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( 'Forms', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage forms default colors here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Field border color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][forms-field-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'forms-field-border-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Field border color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][forms-field-border-color-on-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'forms-field-border-color-on-hover' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Field border color (on focus):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][forms-field-border-color-on-focus]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'forms-field-border-color-on-focus' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Field border color for invalid values:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][forms-field-border-color-for-invalid-values]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'forms-field-border-color-for-invalid-values' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Field text color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][forms-field-text-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'forms-field-text-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Field background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][forms-field-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'forms-field-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Field box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][forms-field-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'forms-field-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Field inset box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][forms-field-inset-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'forms-field-inset-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Checkbox & radio main color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][forms-checkbox-radio-main-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'forms-checkbox-radio-main-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Placeholder text color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][forms-placeholder-text-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'forms-placeholder-text-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Invalid field tip text color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][forms-invalid-field-tip-text-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'forms-invalid-field-tip-text-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Select and date field icon color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][forms-select-and-date-field-icon-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'forms-select-and-date-field-icon-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Select and date field icon border color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][forms-select-and-date-field-icon-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'forms-select-and-date-field-icon-border-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Select and date field icon background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][forms-select-and-date-field-icon-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'forms-select-and-date-field-icon-background-color' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( 'Date & time picker', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage Contact Form 7 Datepicker default colors for theme skin here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Container background color', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][datepicker-container-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'datepicker-container-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Container box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][datepicker-container-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'datepicker-container-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Headings color', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][datepicker-headings-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'datepicker-headings-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Next / prev arrows color', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][datepicker-next-prev-arrows-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'datepicker-next-prev-arrows-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Next / prev arrows color (on hover)', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][datepicker-next-prev-arrows-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'datepicker-next-prev-arrows-color-hover' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Weekdays & buttons color', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][datepicker-weekdays-and-buttons-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'datepicker-weekdays-and-buttons-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Single day background color', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][datepicker-single-day-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'datepicker-single-day-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Single day text color', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][datepicker-single-day-text-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'datepicker-single-day-text-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Single day background color (on hover)', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][datepicker-single-day-background-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'datepicker-single-day-background-color-hover' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Single day text color (on hover)', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][datepicker-single-day-text-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'datepicker-single-day-text-color-hover' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Single day disabled text color', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][datepicker-single-day-disabled-text-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'datepicker-single-day-disabled-text-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Dividers border color', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][datepicker-dividers-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'datepicker-dividers-border-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Time slider background color', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][datepicker-time-slider-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'datepicker-time-slider-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Time slider handle background color', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][datepicker-time-slider-handle-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'datepicker-time-slider-handle-background-color' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( 'Two images difference shortcode', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage "Two images difference" shortcode default colors here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Handle color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][two-images-difference-shortcode-handle-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'two-images-difference-shortcode-handle-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Handle box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][two-images-difference-shortcode-handle-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'two-images-difference-shortcode-handle-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Overlay background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][two-images-difference-shortcode-overlay-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'two-images-difference-shortcode-overlay-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Before and after label background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][two-images-difference-shortcode-before-and-after-label-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'two-images-difference-shortcode-before-and-after-label-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Before and after label text color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][two-images-difference-shortcode-before-and-after-label-text-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'two-images-difference-shortcode-before-and-after-label-text-color' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( 'Image overlay & buttons', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage the gallery on image shortcode default styles colors here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Overlay background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][gallery-image-overlay-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'gallery-image-overlay-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Buttons color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][gallery-image-buttons-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'gallery-image-buttons-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Buttons box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][gallery-image-buttons-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'gallery-image-buttons-box-shadow' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( 'Announcements', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage the announcements default styles colors here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Info: content color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-info-content-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-info-content-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Info: border color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-info-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-info-border-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Info: background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-info-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-info-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Info: box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-info-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-info-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Success: content color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-success-content-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-success-content-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Success: border color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-success-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-success-border-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Success: background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-success-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-success-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Success: box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-success-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-success-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Error: content color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-error-content-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-error-content-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Error: border color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-error-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-error-border-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Error: background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-error-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-error-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Error: box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-error-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-error-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Warning: content color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-warning-content-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-warning-content-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Warning: border color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-warning-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-warning-border-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Warning: background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-warning-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-warning-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Warning: box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][announcement-warning-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'announcement-warning-box-shadow' )
                                )
                            )
                        )
                    )
                ),
                'buttons' => array(
                    'title' => esc_html( __( 'Buttons', 'ueldo' ) ),
                    'description' => esc_html( __( 'You can manage buttons styles here.', 'ueldo' ) ),
                    'sections' => array(
                        array(
                            'title' => esc_html( __( 'Global buttons', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage global buttons styles here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-background-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Border color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-border-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Text color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-text-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-text-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Icon color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-icon-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-icon-color' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-box-shadow' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Background color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-background-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-background-color-hover' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Border color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-border-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-border-color-hover' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Text color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-text-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-text-color-hover' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Icon color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-icon-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-icon-color-hover' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Box shadow (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-box-shadow-hover]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-box-shadow-hover' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Font size:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-font-size]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-font-size' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Letter spacing:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-letter-spacing]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-letter-spacing' ),
                                    'minus_allowed' => true,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Border radius:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-border-radius]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-border-radius' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Border width:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-border-width]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-border-width' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Icon size:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-icon-size]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-icon-size' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Margin between text and icon:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-margin-between-text-and-icon]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-margin-between-text-and-icon' ),
                                    'minus_allowed' => true,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding top:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-padding-top]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-padding-top' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding right:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-padding-right]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-padding-right' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding bottom:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-padding-bottom]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-padding-bottom' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding left:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-padding-left]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-padding-left' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Use static height?', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-use-static-height]',
                                    'type' => 'select',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-use-static-height' ),
                                    'choices' => array(
                                        'yes' => esc_html( __( 'Yes', 'ueldo' ) ),
                                        'no' => esc_html( __( 'No', 'ueldo' ) )
                                    )
                                ),
                                array(
                                    'label' => esc_html( __( 'Static height:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-global-button-static-height]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-global-button-static-height' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false,
                                    'active_callback' => array( 'ueldo_customizer', 'is_global_button_static_height_enabled' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( '"Read more" buttons', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage the "read more" blog buttons styles here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Button styles:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-custom-styles-enabled]',
                                    'type' => 'select',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-custom-styles-enabled' ),
                                    'choices' => array(
                                        'use-global-styles' => esc_html( __( 'Use global button styles', 'ueldo' ) ),
                                        'use-custom-styles' => esc_html( __( 'Use custom styles', 'ueldo' ) )
                                    )
                                ),
                                array(
                                    'label' => esc_html( __( 'Background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-background-color' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                ),
                                array(
                                    'label' => esc_html( __( 'Border color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-border-color' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                ),
                                array(
                                    'label' => esc_html( __( 'Text color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-text-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-text-color' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                ),
                                array(
                                    'label' => esc_html( __( 'Icon color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-icon-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-icon-color' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                ),
                                array(
                                    'label' => esc_html( __( 'Box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-box-shadow' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                ),
                                array(
                                    'label' => esc_html( __( 'Background color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-background-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-background-color-hover' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                ),
                                array(
                                    'label' => esc_html( __( 'Border color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-border-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-border-color-hover' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                ),
                                array(
                                    'label' => esc_html( __( 'Text color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-text-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-text-color-hover' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                ),
                                array(
                                    'label' => esc_html( __( 'Icon color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-icon-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-icon-color-hover' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                ),
                                array(
                                    'label' => esc_html( __( 'Box shadow (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-box-shadow-hover]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-box-shadow-hover' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                ),
                                array(
                                    'label' => esc_html( __( 'Font size:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-font-size]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-font-size' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Letter spacing:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-letter-spacing]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-letter-spacing' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                    'minus_allowed' => true,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Border radius:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-border-radius]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-border-radius' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Border width:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-border-width]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-border-width' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Icon size:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-icon-size]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-icon-size' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Margin between text and icon:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-margin-between-text-and-icon]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-margin-between-text-and-icon' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                    'minus_allowed' => true,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding top:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-padding-top]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-padding-top' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding right:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-padding-right]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-padding-right' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding bottom:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-padding-bottom]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-padding-bottom' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding left:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-padding-left]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-padding-left' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Use static height?', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-use-static-height]',
                                    'type' => 'select',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-use-static-height' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_read_more_custom_styles_enabled' ),
                                    'choices' => array(
                                        'yes' => esc_html( __( 'Yes', 'ueldo' ) ),
                                        'no' => esc_html( __( 'No', 'ueldo' ) )
                                    )
                                ),
                                array(
                                    'label' => esc_html( __( 'Static height:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-read-more-button-static-height]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-read-more-button-static-height' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false,
                                    'active_callback' => array( 'ueldo_customizer', 'is_read_more_button_static_height_enabled' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( '"Form submit" buttons', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage the "form submit" buttons styles here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Button styles:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-custom-styles-enabled]',
                                    'type' => 'select',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-custom-styles-enabled' ),
                                    'choices' => array(
                                        'use-global-styles' => esc_html( __( 'Use global button styles', 'ueldo' ) ),
                                        'use-custom-styles' => esc_html( __( 'Use custom styles', 'ueldo' ) )
                                    )
                                ),
                                array(
                                    'label' => esc_html( __( 'Background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-background-color' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Border color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-border-color' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Text color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-text-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-text-color' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Icon color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-icon-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-icon-color' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-box-shadow' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Background color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-background-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-background-color-hover' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Border color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-border-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-border-color-hover' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Text color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-text-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-text-color-hover' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Icon color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-icon-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-icon-color-hover' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Box shadow (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-box-shadow-hover]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-box-shadow-hover' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Font size:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-font-size]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-font-size' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Letter spacing:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-letter-spacing]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-letter-spacing' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' ),
                                    'minus_allowed' => true,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Border radius:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-border-radius]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-border-radius' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Border width:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-border-width]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-border-width' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Icon size:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-icon-size]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-icon-size' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Margin between text and icon:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-margin-between-text-and-icon]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-margin-between-text-and-icon' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' ),
                                    'minus_allowed' => true,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding top:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-padding-top]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-padding-top' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding right:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-padding-right]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-padding-right' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding bottom:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-padding-bottom]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-padding-bottom' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding left:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-padding-left]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-padding-left' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Use static height?', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-use-static-height]',
                                    'type' => 'select',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-use-static-height' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_form_submit_custom_styles_enabled' ),
                                    'choices' => array(
                                        'yes' => esc_html( __( 'Yes', 'ueldo' ) ),
                                        'no' => esc_html( __( 'No', 'ueldo' ) )
                                    )
                                ),
                                array(
                                    'label' => esc_html( __( 'Static height:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-form-submit-button-static-height]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-form-submit-button-static-height' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false,
                                    'active_callback' => array( 'ueldo_customizer', 'is_form_submit_button_static_height_enabled' )
                                )
                            )
                        ),
                        array(
                            'title' => esc_html( __( '"Call to action widget" button', 'ueldo' ) ),
                            'description' => esc_html( __( 'You can manage the "call to action" widget button styles here.', 'ueldo' ) ),
                            'settings' => array(
                                array(
                                    'label' => esc_html( __( 'Button styles:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-custom-styles-enabled]',
                                    'type' => 'select',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-custom-styles-enabled' ),
                                    'choices' => array(
                                        'use-global-styles' => esc_html( __( 'Use global button styles', 'ueldo' ) ),
                                        'use-custom-styles' => esc_html( __( 'Use custom styles', 'ueldo' ) )
                                    )
                                ),
                                array(
                                    'label' => esc_html( __( 'Background color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-background-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-background-color' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Border color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-border-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-border-color' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Text color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-text-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-text-color' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Icon color:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-icon-color]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-icon-color' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Box shadow:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-box-shadow]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-box-shadow' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Background color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-background-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-background-color-hover' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Border color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-border-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-border-color-hover' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Text color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-text-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-text-color-hover' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Icon color (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-icon-color-hover]',
                                    'type' => 'color',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-icon-color-hover' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Box shadow (on hover):', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-box-shadow-hover]',
                                    'type' => 'box_shadow',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-box-shadow-hover' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' )
                                ),
                                array(
                                    'label' => esc_html( __( 'Font size:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-font-size]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-font-size' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Letter spacing:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-letter-spacing]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-letter-spacing' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' ),
                                    'minus_allowed' => true,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Border radius:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-border-radius]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-border-radius' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Border width:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-border-width]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-border-width' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Icon size:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-icon-size]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-icon-size' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Margin between text and icon:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-margin-between-text-and-icon]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-margin-between-text-and-icon' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' ),
                                    'minus_allowed' => true,
                                    'decimals_allowed' => false
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding top:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-padding-top]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-padding-top' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding right:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-padding-right]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-padding-right' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding bottom:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-padding-bottom]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-padding-bottom' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Padding left:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-padding-left]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-padding-left' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => true
                                ),
                                array(
                                    'label' => esc_html( __( 'Use static height?', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-use-static-height]',
                                    'type' => 'select',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-use-static-height' ),
                                    'active_callback' => array( 'ueldo_customizer', 'are_button_call_to_action_widget_custom_styles_enabled' ),
                                    'choices' => array(
                                        'yes' => esc_html( __( 'Yes', 'ueldo' ) ),
                                        'no' => esc_html( __( 'No', 'ueldo' ) )
                                    )
                                ),
                                array(
                                    'label' => esc_html( __( 'Static height:', 'ueldo' ) ),
                                    'option_key' => 'ueldo_theme_options[styles][buttons-call-to-action-widget-button-static-height]',
                                    'type' => 'px',
                                    'default' => ueldo_get_theme_options_value( 'styles-default', false, 'buttons-call-to-action-widget-button-static-height' ),
                                    'minus_allowed' => false,
                                    'decimals_allowed' => false,
                                    'active_callback' => array( 'ueldo_customizer', 'is_call_to_action_widget_button_static_height_enabled' )
                                )
                            )
                        )
                    )
                ),
                'font_sizes' => array(
                    'title' => esc_html( __( 'Font sizes', 'ueldo' ) ),
                    'description' => esc_html( __( 'You can manage general theme font sizes here.', 'ueldo' ) ),
                    'as_section' => true,
                    'settings' => array(
                        array(
                            'label' => esc_html( __( 'Headings line height:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][line-height-headings]',
                            'type' => 'line_height',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'line-height-headings' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( 'H1 headings font size:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][font-size-h1]',
                            'type' => 'px',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'font-size-h1' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( 'H2 headings font size:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][font-size-h2]',
                            'type' => 'px',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'font-size-h2' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( 'H3 headings font size:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][font-size-h3]',
                            'type' => 'px',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'font-size-h3' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( 'H4 headings font size:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][font-size-h4]',
                            'type' => 'px',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'font-size-h4' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( 'H5 headings font size:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][font-size-h5]',
                            'type' => 'px',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'font-size-h5' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( 'H6 headings font size:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][font-size-h6]',
                            'type' => 'px',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'font-size-h6' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( 'Blockquote font size:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][font-size-blockquote]',
                            'type' => 'px',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'font-size-blockquote' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( 'General contents line height:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][line-height-general]',
                            'type' => 'line_height',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'line-height-general' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( 'Content font size:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][font-size-content]',
                            'type' => 'px',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'font-size-content' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( 'Small content font size:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][font-size-small-content]',
                            'type' => 'px',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'font-size-small-content' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( 'Small content font size:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][font-size-small-content]',
                            'type' => 'px',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'font-size-small-content' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( 'Smallest content font size:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][font-size-smallest-content]',
                            'type' => 'px',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'font-size-smallest-content' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( 'Menu links font size:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][font-size-menu-links]',
                            'type' => 'px',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'font-size-menu-links' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( 'Menu links icons font size:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][font-size-menu-links-icons]',
                            'type' => 'px',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'font-size-menu-links-icons' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( 'Form fields font size:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][font-size-form-fields]',
                            'type' => 'px',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'font-size-form-fields' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        ),
                        array(
                            'label' => esc_html( __( '"Call to action widget" offer font size:', 'ueldo' ) ),
                            'option_key' => 'ueldo_theme_options[styles][font-size-call-to-action-widget-offer]',
                            'type' => 'px',
                            'default' => ueldo_get_theme_options_value( 'styles-default', false, 'font-size-call-to-action-widget-offer' ),
                            'minus_allowed' => false,
                            'decimals_allowed' => false
                        )
                    )
                )
            ));
        }

       /**
        *
        * register custom options for wp customizer
        *
        */

        public static function register( $wp_customize ) {

            # get the alpha-color-picker claas
            require_once( get_template_directory() .'/_assets/_libs/alpha-color-picker/alpha-color-picker.php' );

            # get the "ueldo_wp_customizer_field_box_shadow" claas
            require_once( get_template_directory() .'/_assets/_php/_customizer/box-shadow-field.php' );

            # get the "ueldo_wp_customizer_field_line_height" claas
            require_once( get_template_directory() .'/_assets/_php/_customizer/line-height-field.php' );

            # get the "ueldo_wp_customizer_field_px" claas
            require_once( get_template_directory() .'/_assets/_php/_customizer/px-field.php' );

            # walk for each customizer options
            foreach( self::get_customizer_options() as $panel ) {

                # can we add the panel?
                if( isset( $panel['as_section'] ) && $panel['as_section'] == true ) {

                    # register customizer section
                    $wp_customize -> add_section(
                        'ueldo_customizer_section_'. sanitize_title( $panel['title'] ),
                        array(
                            'title' => esc_html( $panel['title'] ),
                            'description' => esc_html( $panel['description'] ),
                            'capability' => 'edit_theme_options'
                        )
                    );
                }

                # add section instead of panel
                else {

                    # register customizer panel
                    $wp_customize -> add_panel(
                        'ueldo_customizer_panel_'. sanitize_title( $panel['title'] ),
                        array(
                            'title' => esc_html( $panel['title'] ),
                            'description' => esc_html( $panel['description'] ),
                            'priority' => 10,
                            'capability' => 'edit_theme_options'
                        )
                    );
                }

                # do we have panel sections added?
                if( ( isset( $panel['sections'] ) && is_array( $panel['sections'] ) && count( $panel['sections'] ) > 0 ) && !isset( $panel['as_section'] ) ) {

                    # walk for each panel section
                    foreach( $panel['sections'] as $section ) {

                        # register customizer section
                        $wp_customize -> add_section(
                            'ueldo_customizer_panel_'. sanitize_title( $panel['title'] ) .'_section_'. sanitize_title( $section['title'] ),
                            array(
                                'title' => esc_html( $section['title'] ),
                                'description' => esc_html( $section['description'] ),
                                'panel' => 'ueldo_customizer_panel_'. sanitize_title( $panel['title'] )
                            )
                        );

                        # do we have settings inside this section?
                        if( isset( $section['settings'] ) && is_array( $section['settings'] ) && count( $section['settings'] ) > 0 ) {

                            # walk for each section setting
                            foreach( $section['settings'] as $setting ) {

                                # switch by the setting type
                                switch( $setting['type'] ) {

                                    # type: color
                                    case 'color':

                                        # register customizer setting
                                        $wp_customize -> add_setting(
                                            esc_attr( $setting['option_key'] ),
                                            array(
                                                'default' => esc_attr( $setting['default'] ),
                                                'type' => 'option',
                                                'transport' => 'postMessage'
                                            )
                                        );


                                        # register setting controller
                                        $wp_customize -> add_control(
                                            new Customize_Alpha_Color_Control(
                                                $wp_customize,
                                                esc_attr( $setting['option_key'] ),
                                                array(
                                                    'label' => esc_html( $setting['label'] ),
                                                    'section' => 'ueldo_customizer_panel_'. sanitize_title( $panel['title'] ) .'_section_'. sanitize_title( $section['title'] ),
                                                    'settings' => esc_attr( $setting['option_key'] ),
                                                    'active_callback' => isset( $setting['active_callback'] ) ? $setting['active_callback'] : array( 'ueldo_customizer', 'active_callback' )
                                                )
                                            )
                                        );

                                    break;

                                    # type: box shadow
                                    case 'box_shadow':

                                        # register customizer setting
                                        $wp_customize -> add_setting(
                                            esc_attr( $setting['option_key'] ),
                                            array(
                                                'default' => esc_attr( $setting['default'] ),
                                                'type' => 'option',
                                                'transport' => 'postMessage'
                                            )
                                        );

                                        # register setting controller
                                        $wp_customize -> add_control(
                                            new ueldo_wp_customizer_field_box_shadow(
                                                $wp_customize,
                                                esc_attr( $setting['option_key'] ),
                                                array(
                                                    'label' => esc_html( $setting['label'] ),
                                                    'section' => 'ueldo_customizer_panel_'. sanitize_title( $panel['title'] ) .'_section_'. sanitize_title( $section['title'] ),
                                                    'settings' => esc_attr( $setting['option_key'] ),
                                                    'active_callback' => isset( $setting['active_callback'] ) ? $setting['active_callback'] : array( 'ueldo_customizer', 'active_callback' )
                                                )
                                            )
                                        );

                                    break;

                                    # type: select
                                    case 'select':

                                        # register customizer setting
                                        $wp_customize -> add_setting(
                                            esc_attr( $setting['option_key'] ),
                                            array(
                                                'default' => esc_attr( $setting['default'] ),
                                                'sanitize_callback' => array( 'ueldo_customizer', 'sanitize_select' ),
                                                'type' => 'option',
                                                'transport' => 'postMessage'
                                            )
                                        );

                                        # register setting controller
                                        $wp_customize -> add_control(
                                            new WP_Customize_Control(
                                                $wp_customize,
                                                esc_attr( $setting['option_key'] ),
                                                array(
                                                    'label' => esc_html( $setting['label'] ),
                                                    'section' => 'ueldo_customizer_panel_'. sanitize_title( $panel['title'] ) .'_section_'. sanitize_title( $section['title'] ),
                                                    'settings' => esc_attr( $setting['option_key'] ),
                                                    'type' => 'select',
                                                    'choices' => $setting['choices'],
                                                    'active_callback' => isset( $setting['active_callback'] ) ? $setting['active_callback'] : array( 'ueldo_customizer', 'active_callback' )
                                                )
                                            )
                                        );

                                    break;

                                    # type: px
                                    case 'px':

                                        # register customizer setting
                                        $wp_customize -> add_setting(
                                            esc_attr( $setting['option_key'] ),
                                            array(
                                                'default' => esc_attr( $setting['default'] ),
                                                'type' => 'option',
                                                'transport' => 'postMessage'
                                            )
                                        );

                                        # register setting controller
                                        $wp_customize -> add_control(
                                            new ueldo_wp_customizer_field_px(
                                                $wp_customize,
                                                esc_attr( $setting['option_key'] ),
                                                array(
                                                    'label' => esc_html( $setting['label'] ),
                                                    'section' => 'ueldo_customizer_panel_'. sanitize_title( $panel['title'] ) .'_section_'. sanitize_title( $section['title'] ),
                                                    'settings' => esc_attr( $setting['option_key'] ),
                                                    'active_callback' => isset( $setting['active_callback'] ) ? $setting['active_callback'] : array( 'ueldo_customizer', 'active_callback' ),
                                                    'minus_allowed' => esc_attr( $setting['minus_allowed'] ),
                                                    'decimals_allowed' => esc_attr( $setting['decimals_allowed'] )
                                                )
                                            )
                                        );

                                    break;
                                }
                            }
                        }
                    }
                }

                # do we have settings inside panel added?
                if( ( isset( $panel['settings'] ) && is_array( $panel['settings'] ) && count( $panel['settings'] ) > 0 ) && ( isset( $panel['as_section'] ) && $panel['as_section'] == true ) ) {

                    # walk for each section setting
                    foreach( $panel['settings'] as $setting ) {

                        # switch by the setting type
                        switch( $setting['type'] ) {

                            # type: color
                            case 'color':

                                # register customizer setting
                                $wp_customize -> add_setting(
                                    esc_attr( $setting['option_key'] ),
                                    array(
                                        'default' => esc_attr( $setting['default'] ),
                                        'type' => 'option',
                                        'transport' => 'postMessage'
                                    )
                                );

                                # register setting controller
                                $wp_customize -> add_control(
                                    new Customize_Alpha_Color_Control(
                                        $wp_customize,
                                        esc_attr( $setting['option_key'] ),
                                        array(
                                            'label' => esc_html( $setting['label'] ),
                                            'section' => 'ueldo_customizer_section_'. sanitize_title( $panel['title'] ),
                                            'settings' => esc_attr( $setting['option_key'] ),
                                            'active_callback' => isset( $setting['active_callback'] ) ? $setting['active_callback'] : array( 'ueldo_customizer', 'active_callback' )
                                        )
                                    )
                                );

                            break;

                            # type: box shadow
                            case 'box_shadow':

                                # register customizer setting
                                $wp_customize -> add_setting(
                                    esc_attr( $setting['option_key'] ),
                                    array(
                                        'default' => esc_attr( $setting['default'] ),
                                        'type' => 'option',
                                        'transport' => 'postMessage'
                                    )
                                );

                                # register setting controller
                                $wp_customize -> add_control(
                                    new ueldo_wp_customizer_field_box_shadow(
                                        $wp_customize,
                                        esc_attr( $setting['option_key'] ),
                                        array(
                                            'label' => esc_html( $setting['label'] ),
                                            'section' => 'ueldo_customizer_section_'. sanitize_title( $panel['title'] ),
                                            'settings' => esc_attr( $setting['option_key'] ),
                                            'active_callback' => isset( $setting['active_callback'] ) ? $setting['active_callback'] : array( 'ueldo_customizer', 'active_callback' )
                                        )
                                    )
                                );

                            break;

                            # type: select
                            case 'select':

                                # register customizer setting
                                $wp_customize -> add_setting(
                                    esc_attr( $setting['option_key'] ),
                                    array(
                                        'default' => esc_attr( $setting['default'] ),
                                        'sanitize_callback' => array( 'ueldo_customizer', 'sanitize_select' ),
                                        'type' => 'option',
                                        'transport' => 'postMessage'
                                    )
                                );

                                # register setting controller
                                $wp_customize -> add_control(
                                    new WP_Customize_Control(
                                        $wp_customize,
                                        esc_attr( $setting['option_key'] ),
                                        array(
                                            'label' => esc_html( $setting['label'] ),
                                            'section' => 'ueldo_customizer_section_'. sanitize_title( $panel['title'] ),
                                            'settings' => esc_attr( $setting['option_key'] ),
                                            'type' => 'select',
                                            'choices' => $setting['choices'],
                                            'active_callback' => isset( $setting['active_callback'] ) ? $setting['active_callback'] : array( 'ueldo_customizer', 'active_callback' )
                                        )
                                    )
                                );

                            break;

                            # type: px
                            case 'px':

                                # register customizer setting
                                $wp_customize -> add_setting(
                                    esc_attr( $setting['option_key'] ),
                                    array(
                                        'default' => esc_attr( $setting['default'] ),
                                        'type' => 'option',
                                        'transport' => 'postMessage'
                                    )
                                );

                                # register setting controller
                                $wp_customize -> add_control(
                                    new ueldo_wp_customizer_field_px(
                                        $wp_customize,
                                        esc_attr( $setting['option_key'] ),
                                        array(
                                            'label' => esc_html( $setting['label'] ),
                                            'section' => 'ueldo_customizer_section_'. sanitize_title( $panel['title'] ),
                                            'settings' => esc_attr( $setting['option_key'] ),
                                            'active_callback' => isset( $setting['active_callback'] ) ? $setting['active_callback'] : array( 'ueldo_customizer', 'active_callback' ),
                                            'minus_allowed' => esc_attr( $setting['minus_allowed'] ),
                                            'decimals_allowed' => esc_attr( $setting['decimals_allowed'] )
                                        )
                                    )
                                );

                            break;

                            # type: line height
                            case 'line_height':

                                # register customizer setting
                                $wp_customize -> add_setting(
                                    esc_attr( $setting['option_key'] ),
                                    array(
                                        'default' => esc_attr( $setting['default'] ),
                                        'type' => 'option',
                                        'transport' => 'postMessage'
                                    )
                                );

                                # register setting controller
                                $wp_customize -> add_control(
                                    new ueldo_wp_customizer_field_line_height(
                                        $wp_customize,
                                        esc_attr( $setting['option_key'] ),
                                        array(
                                            'label' => esc_html( $setting['label'] ),
                                            'section' => 'ueldo_customizer_section_'. sanitize_title( $panel['title'] ),
                                            'settings' => esc_attr( $setting['option_key'] )
                                        )
                                    )
                                );

                            break;
                        }
                    }
                }
            }
        }

       /**
        *
        * live preview javascript functions
        *
        */

        public static function enqueue_preview_scripts() {

            # enqueue customizer theme functions script
            wp_enqueue_script( 'ueldo-customizer-preview-javascript-functions', get_template_directory_uri() .'/_assets/_js/customizer-preview.js', array( 'jquery', 'customize-preview' ), null, true );

            # add inline script to customizer functions
            wp_add_inline_script( 'ueldo-customizer-preview-javascript-functions', self::prepare_styles_rule_object() );
        }

       /**
        *
        * customizer panel javascript functions
        *
        */

        public static function enqueue_controls_scripts() {

            # enqueue customizer theme functions script
            wp_enqueue_script( 'ueldo-customizer-panel-javascript-functions', get_template_directory_uri() .'/_assets/_js/customizer-panel.js', array( 'jquery' ), null, true );

            # localize script strings
            wp_localize_script( 'ueldo-customizer-panel-javascript-functions', 'ueldo_customizer_panel_javascript_functions_l10n', array(
                'refresh_preview' => esc_html( __( 'Refresh preview', 'ueldo' ) )
            ));
        }

       /**
        *
        * prepare the script for customizer functions
        *
        */

        public static function prepare_styles_rule_object() {

            # prepare the javascript content value
            $js = '';

            # update the javascript content value with styles rule json
            $js .= "var ueldo_customizer_styles_rule_json = '". json_encode( ueldo_customizer_get_styles_rules() ) ."'; ";

            # update the javascript content with theme styles keys json
            $js .= "var ueldo_customizer_theme_styles_json = '". json_encode( ueldo_get_default_theme_styles() ) ."';";

            # return result
            return( $js );
        }

       /**
        *
        * sanitize select field
        *
        */

        public static function sanitize_select( $input, $setting ) {

            # ensure input is a slug
            $input = sanitize_key( $input );

            # get list of choices from the control associated with the setting
            $choices = $setting -> manager -> get_control( $setting -> id ) -> choices;

            # if the input is a valid key, return it; otherwise, return the default
            return( array_key_exists( $input, $choices ) ? $input : $setting -> default );
        }

       /**
        *
        * default active callback - always true
        *
        */

        public static function active_callback() {

            # return result
            return( true );
        }

       /**
        *
        * check if "read more" button custom styles are enabled
        *
        */

        public static function are_button_read_more_custom_styles_enabled() {

            # return result
            return( ueldo_get_theme_options_value( 'styles', false, 'buttons-read-more-button-custom-styles-enabled' ) == 'use-custom-styles' );
        }

       /**
        *
        * check if "form submit" button custom styles are enabled
        *
        */

        public static function are_button_form_submit_custom_styles_enabled() {

            # return result
            return( ueldo_get_theme_options_value( 'styles', false, 'buttons-form-submit-button-custom-styles-enabled' ) == 'use-custom-styles' );
        }

       /**
        *
        * check if "call to action widget" button custom styles are enabled
        *
        */

        public static function are_button_call_to_action_widget_custom_styles_enabled() {

            # return result
            return( ueldo_get_theme_options_value( 'styles', false, 'buttons-call-to-action-widget-button-custom-styles-enabled' ) == 'use-custom-styles' );
        }

       /**
        *
        * is static height enabled for global button?
        *
        */

        public static function is_global_button_static_height_enabled() {

            # return result
            return( ueldo_get_theme_options_value( 'styles', false, 'buttons-global-button-use-static-height' ) == 'yes' );
        }

       /**
        *
        * is static height enabled for read more button?
        *
        */

        public static function is_read_more_button_static_height_enabled() {

            # return result
            return( self::are_button_read_more_custom_styles_enabled() && ueldo_get_theme_options_value( 'styles', false, 'buttons-read-more-button-use-static-height' ) == 'yes' );
        }

       /**
        *
        * is static height enabled for form submit button?
        *
        */

        public static function is_form_submit_button_static_height_enabled() {

            # return result
            return( self::are_button_form_submit_custom_styles_enabled() && ueldo_get_theme_options_value( 'styles', false, 'buttons-form-submit-button-use-static-height' ) == 'yes' );
        }

       /**
        *
        * is static height enabled for call to action button?
        *
        */

        public static function is_call_to_action_widget_button_static_height_enabled() {

            # return result
            return( self::are_button_call_to_action_widget_custom_styles_enabled() && ueldo_get_theme_options_value( 'styles', false, 'buttons-call-to-action-widget-button-use-static-height' ) == 'yes' );
        }

       /**
        *
        * is custom color for sidebar border line enabled?
        *
        */

        public static function is_sidebar_border_line_custom_color_enabled() {

            #  return result
            return( ueldo_get_theme_options_value( 'styles', false, 'sidebar-border-line-custom-color-enabled' ) == 'yes' );
        }

       /**
        *
        * end of class.
        *
        */
    }

   /**
    *
    * add hooks for ueldo_customizer class
    *
    */

    # register class when customizer is registered
    add_action( 'customize_register', array( 'ueldo_customizer', 'register' ) );

    # enqueue live preview javascript in theme customizer admin screen
    add_action( 'customize_preview_init', array( 'ueldo_customizer', 'enqueue_preview_scripts' ) );

    # enqueue panel javascript functions
    add_action( 'customize_controls_enqueue_scripts', array( 'ueldo_customizer', 'enqueue_controls_scripts' ) );

   /**
    *
    * end of file.
    *
    */

?>